export enum FetchStatus {
    Laster = "Laster",
    IkkeHentet = "IkkeHentet",
    Suksess = "Suksess",
    Feil = "Feil",
}

export type Suksess<T> = {
    suksess: true;
    data: T;
    status: FetchStatus.Suksess;
};

export enum FeilType {
    FINNER_IKKE_BRUKER_MED_EPOST = "Finner ikke bruker med epost",
    KUNNE_IKKE_HENTE_BRUKERE = "Kunne ikke hente brukere",
    KUNNE_IKKE_HENTE_KONTRAKTER = "Kunne ikke hente kontrakter",
    UKJENT_KONTRAKTNUMMER_FORMAT = "Ukjent format på kontraktnummer",
    UKJENT_FEIL = "Ukjent feil",
    ELRAPP_ROUTES_EXCEPTION = "ELRAPP_ROUTES_EXCEPTION",
    KUNNE_IKKE_HENTE_RODER = "Kunne ikke hente roder",
    KUNNE_IKKE_HENTE_KAMERA = "Kunne ikke hente kamera",
    KUNNE_IKKE_HENTE_PRODUKSJONSLENKER = "Kunne ikke hente produksjonslenker",
    KUNNE_IKKE_HENTE_KJØRETØY = "Kunne ikke hente kjøretøy",
    KUNNE_IKKE_HENTE_TRAFIKKMELDINGER = "Kunne ikke hente trafikkmeldinger",
    KUNNE_IKKE_HENTE_VÆRDATA = "Kunne ikke hente værdata",
    KUNNE_IKKE_HENTE_ØKTDETALJER = "Kunne ikke hente øktdetaljer",
    KUNNE_IKKE_HENTE_VÆRSTASJONER = "Kunne ikke hente værstasjoner",
    KUNNE_IKKE_HENTE_SISTE_IMPORT = "Kunne ikke hente siste import",
    KUNNE_IKKE_HENTE_ØKTPRODUKSJONSLENKER = "Kunne ikke hente produksjonslenker for økten",
    KUNNE_IKKE_HENTE_PRODUKSJONSDETALJER = "Kunne ikke hente produksjonsdetaljer",
    KUNNE_IKKE_HENTE_KJØRETØYPRODUKSJONSDETALJER = "Kunne ikke hente detaljer for kjøretøy",
    KUNNE_IKKE_HENTE_FRIKSJONSMETADATA = "Kunne ikke hente friksjonsmetadata",
    KUNNE_IKKE_HENTE_FRIKSJONSDATA = "Kunne ikke hente friksjonsdata",
    KUNNE_IKKE_LASTE_OPP_FRIKSJONSDATA = "Kunne ikke laste opp friksjonsdata",
    KUNNE_IKKE_HENTE_FORSINKELSESDATA = "Kunne ikke hente forsinkelsesdata",
    KUNNE_IKKE_HENTE_GEOMETRI_FOR_TRANSPORTKORRIDORER = "Kunne ikke hente geometri for transportkorridorer",
}

export type Laster = {
    status: FetchStatus.Laster;
};

export type IkkeHentet = {
    status: FetchStatus.IkkeHentet;
};

export type DataStatus<T> = ApiRespons<T> | Laster | IkkeHentet;

export type Feil = {
    suksess: false;
    feilmelding: string;
    type: FeilType;
    data?: any;
    status: FetchStatus.Feil;
};

export type ApiRespons<T> = Suksess<T> | Feil;

const suksess = <T>(data: T): Suksess<T> => {
    return { suksess: true, data, status: FetchStatus.Suksess };
};
const feil = (feilmelding: FeilType): Feil => {
    return {
        suksess: false,
        feilmelding: feilmelding,
        type: feilmelding,
        status: FetchStatus.Feil,
    };
};

const apiResponse = <T>(data: ApiRespons<T>): ApiRespons<T> => {
    if (!data.suksess) {
        return { ...data, status: FetchStatus.Feil };
    }
    return { ...data, status: FetchStatus.Suksess };
};

export const ikkeRevalidate = {
    revalidateIfStale: false,
    revalidateOnFocus: false,
    revalidateOnReconnect: false,
};

export async function fetcher<T>(
    url: string,
    feiltype: FeilType,
    medCredentials: boolean = true,
): Promise<ApiRespons<T>> {
    try {
        const res = await fetch(url, {
            method: "get",
            headers: {
                Accept: "application/json",
                "Content-Type": "application/json",
            },
            credentials: medCredentials ? "include" : "omit",
        });
        if (res.ok) {
            return await res
                .json()
                .then((json) => (erEnApiResponse(json) ? apiResponse(json) : suksess(json)));
        } else {
            console.error(res);
            return feil(feiltype);
        }
    } catch (error) {
        console.error(error);
        return feil(feiltype);
    }
}

export async function fetcherPost<T>(
    url: string,
    feiltype: FeilType,
    body: string | FormData,
    medCredentials: boolean = true,
): Promise<ApiRespons<T>> {
    try {
        const res = await fetch(url, {
            method: "post",
            headers: {
                Accept: "application/json",
                "Content-Type": "application/json",
            },
            credentials: medCredentials ? "include" : "omit",
            body: body,
        });

        if (res.ok) {
            return res
                .json()
                .then((json) => (erEnApiResponse(json) ? apiResponse(json) : suksess(json)));
        } else {
            console.error(res);
            return feil(feiltype);
        }
    } catch (error) {
        console.error(error);
        return feil(feiltype);
    }
}

function erEnApiResponse(json: any): json is ApiRespons<any> {
    return (json as ApiRespons<any>).suksess !== undefined;
}
