"use client";
import { useEffect } from "react";
import { OIDC_LOGIN_URL } from "../../utils/baseUrl";
import { finnMiljø, Miljø } from "../../utils/miljø";
import { atom, createStore } from "jotai/index";
import { useAtom } from "jotai";

export enum AuthenticationStatus {
    Initialisert,
    Henter,
    Autentisert,
    LoggerUt,
    Feilet,
}

export const authenticationStore = createStore();

export const authenticationStatusAtom = atom<AuthenticationStatus>(
    AuthenticationStatus.Initialisert,
);

export const InitAuthentication = () => {
    const [status, setStatus] = useAtom(authenticationStatusAtom, { store: authenticationStore });

    useEffect(() => {
        if (finnMiljø() === Miljø.lokal || finnMiljø() === Miljø.mobil) {
            setStatus(AuthenticationStatus.Autentisert);
        } else if (status === AuthenticationStatus.Initialisert) {
            setStatus(AuthenticationStatus.Henter);
            fetch(`${OIDC_LOGIN_URL}/employeeSSO/status`, {
                credentials: "include",
            })
                .then((res) => res.json())
                .then((json) => {
                    if (json.loggedIn) {
                        setStatus(AuthenticationStatus.Autentisert);
                        createCookieRefreshInterval();
                    } else {
                        setStatus(AuthenticationStatus.Henter);
                        redirectToLogin();
                    }
                });
        } else if (status === AuthenticationStatus.LoggerUt) {
            logoutAndRedirect();
        }
    }, [status, setStatus]);
    return null;
};

const createCookieRefreshInterval = () => {
    const MINUTTER_15 = 1000 * 60 * 15;

    const refreshCookie = () => {
        fetch(`${OIDC_LOGIN_URL}/employeeSSO/extend`, {
            credentials: "include",
        }).then((res) => {
            if (res.status === 401) {
                redirectToLogin();
            }
        });
    };

    refreshCookie();
    setInterval(refreshCookie, MINUTTER_15);
};

const redirectToLogin = () => {
    if (typeof window !== "undefined") {
        window.location.replace(
            `${OIDC_LOGIN_URL}/employeeSSO/login?returnUrl=${document.location.href}`,
        );
    }
};

const logoutAndRedirect = () => {
    if (typeof window !== "undefined") {
        window.location.replace(
            `${OIDC_LOGIN_URL}/employeeSSO/logout?returnUrl=https://www.vegvesen.no/`,
        );
    }
};
