import { atom, Getter } from "jotai";
import { øktProduksjonslenkerAtom } from "./ØktLenkerAtoms";
import { produksjonslenkerTilFiltertyper } from "./kartdataHelpers";
import { produksjonslenkerAtom } from "./apiAtoms";
import { atomWithReset, RESET } from "jotai/utils";

export enum Filterkategori {
    Brøyting = "Brøyting",
    Høvling = "Høvling",
    Sand = "Sand",
    Salt = "Salt",
    UkjentMateriale = "UkjentMateriale",
    IngenProduksjon = "IngenProduksjon",
}

export enum Filtertype {
    Tørrsand = "Tørrsand",
    Fastsand = "Fastsand",
    SandMedSaltInnblanding = "SandMedSaltInnblanding",
    Tørrsalt = "Tørrsalt",
    BefuktetSalt = "BefuktetSalt",
    BefuktetFinkornetSalt = "BefuktetFinkornetSalt",
    Saltløsning = "Saltløsning",
    Magnesiumklorid = "Magnesiumklorid",
    PlogNede = "PlogNede",
    Sideplog = "Sideplog",
    UnderliggendeSkjær = "UnderliggendeSkjær",
    TungHøvel = "TungHøvel",
    IngenProduksjon = "IngenProduksjon",
    UkjentMateriale = "UkjentMateriale",
}

export enum MaterialOgAktivitetsNavn {
    Tørrsand = "Tørrsand",
    Fastsand = "Fastsand",
    SandMedSaltInnblanding = "Sand med saltinnblanding",
    Tørrsalt = "Tørrsalt",
    BefuktetSalt = "Befuktet salt",
    BefuktetFinkornetSalt = "Saltslurry",
    Saltløsning = "Saltløsning",
    Magnesiumklorid = "Magnesiumklorid",
    PlogNede = "Plog nede",
    Sideplog = "Sideplog",
    UnderliggendeSkjær = "Underliggende skjær",
    TungHøvel = "Tung høvel",
    UkjentMateriale = "Ukjent materiale",
    IngenProduksjon = "Ingen produksjon",
}

export interface Filter {
    navn: string;
    kategori: Filterkategori;
    type: Filtertype;
    valgt: boolean;
}

export const defaultProduksjonsfilter: Filter[] = [
    {
        navn: MaterialOgAktivitetsNavn.PlogNede,
        type: Filtertype.PlogNede,
        kategori: Filterkategori.Brøyting,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.Sideplog,
        type: Filtertype.Sideplog,
        kategori: Filterkategori.Brøyting,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.UnderliggendeSkjær,
        type: Filtertype.UnderliggendeSkjær,
        kategori: Filterkategori.Høvling,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.TungHøvel,
        type: Filtertype.TungHøvel,
        kategori: Filterkategori.Høvling,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.Tørrsand,
        type: Filtertype.Tørrsand,
        kategori: Filterkategori.Sand,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.Fastsand,
        type: Filtertype.Fastsand,
        kategori: Filterkategori.Sand,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.SandMedSaltInnblanding,
        type: Filtertype.SandMedSaltInnblanding,
        kategori: Filterkategori.Sand,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.Tørrsalt,
        type: Filtertype.Tørrsalt,
        kategori: Filterkategori.Salt,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.BefuktetSalt,
        type: Filtertype.BefuktetSalt,
        kategori: Filterkategori.Salt,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
        type: Filtertype.BefuktetFinkornetSalt,
        kategori: Filterkategori.Salt,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.Saltløsning,
        type: Filtertype.Saltløsning,
        kategori: Filterkategori.Salt,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
        type: Filtertype.Magnesiumklorid,
        kategori: Filterkategori.Salt,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.UkjentMateriale,
        type: Filtertype.UkjentMateriale,
        kategori: Filterkategori.UkjentMateriale,
        valgt: true,
    },
    {
        navn: MaterialOgAktivitetsNavn.IngenProduksjon,
        type: Filtertype.IngenProduksjon,
        kategori: Filterkategori.IngenProduksjon,
        valgt: false,
    },
];

const valgteProduksjonsfiltereAtom = atomWithReset<Filter[]>(defaultProduksjonsfilter);
export const produksjonsfilterAtom = atom(
    (get: Getter) => {
        const valgteProduksjonsfiltere = get(valgteProduksjonsfiltereAtom);
        const filtertyperIProduksjonslenker = get(filtertyperIProduksjonslenkerAtom);
        return finnDefaultValgteProduksjonsfilter(
            valgteProduksjonsfiltere,
            filtertyperIProduksjonslenker,
        );
    },
    (get, set, nyVerdi: Filter[] | typeof RESET) => {
        set(valgteProduksjonsfiltereAtom, nyVerdi);
    },
);

export const filtertyperIProduksjonslenkerAtom = atom((get: Getter) => {
    const produksjonslenker = get(produksjonslenkerAtom);
    const øktProduksjonslenker = get(øktProduksjonslenkerAtom);
    if (øktProduksjonslenker.length > 0) {
        return produksjonslenkerTilFiltertyper(øktProduksjonslenker);
    }
    if (produksjonslenker?.suksess) {
        return produksjonslenkerTilFiltertyper(produksjonslenker.data);
    }
    return [];
});
export const erDefaultFiltreValgtAtom = atom((get) => {
    const produksjonsfilter = get(produksjonsfilterAtom);
    const filtertyperIProduksjonslenker = get(filtertyperIProduksjonslenkerAtom);
    const defaultFiltertyper = filtertyperIProduksjonslenker
        .filter((filter) => filter !== Filtertype.IngenProduksjon)
        .sort();
    const valgteFiltere = produksjonsfilter
        .filter((filter) => filter.valgt)
        .map((filter) => filter.type)
        .sort();

    const defaultOgValgteFiltereErLike =
        JSON.stringify(valgteFiltere) === JSON.stringify(defaultFiltertyper);

    return defaultOgValgteFiltereErLike;
});

export const finnDefaultValgteProduksjonsfilter = (
    produksjonsfilter: Filter[],
    filtertyperIProduksjonslenker: Filtertype[],
): Filter[] => {
    return produksjonsfilter.map((filter) => ({
        ...filter,
        valgt: filtertyperIProduksjonslenker!.includes(filter.type) && filter.valgt,
    }));
};
