import { KontraktDto } from "../useHentKontraktinfo";
import dayjs, { Dayjs } from "dayjs";
import { Kontrakt } from "./kontraktAtoms";
import { Produksjonslenke } from "../../kartSide/types/produksjonslenke";
import { Filtertype } from "./ProduksjonsfilterAtoms";
import { aktivitetTilFiltertype } from "../../kartSide/types/aktivitet";
import { materialeTilFiltertype } from "../../kartSide/types/materiale";

export const tilKontrakter = (kontrakter: KontraktDto[]): Kontrakt[] =>
    kontrakter.map((kontrakt) => tilKontrakt(kontrakt));

const tilKontrakt = (dto: KontraktDto) => ({
    navn: dto.kontraktNavn,
    navnNvdb: dto.kontraktNavnNvdb,
    elrappId: dto.elrappKontraktId,
    startDato: dto.startDato ? dayjs(dto.startDato) : undefined,
    sluttDato: dto.sluttDato ? dayjs(dto.sluttDato) : undefined,
});

export const erKontraktGyldig = (kontrakt: Kontrakt | undefined, dato: Dayjs) =>
    kontrakt !== undefined
        ? (kontrakt.startDato === undefined ||
              kontrakt.startDato.isBefore(dato) ||
              kontrakt.sluttDato?.isSame(dato)) &&
          (kontrakt.sluttDato === undefined ||
              kontrakt.sluttDato.isAfter(dato) ||
              kontrakt.startDato?.isSame(dato))
        : false;

export const produksjonslenkerTilFiltertyper = (
    produksjonsdata: Produksjonslenke[],
): Filtertype[] => {
    return produksjonsdata.reduce((result: Filtertype[], lenke) => {
        const produksjonsaktiviteter =
            lenke.produksjonstyper.length > 0
                ? lenke.produksjonstyper.reduce((res: Filtertype[], produksjonstype) => {
                      produksjonstype.ibruk &&
                          res.push(aktivitetTilFiltertype(produksjonstype.aktivitet));
                      return res;
                  }, [])
                : [];
        const produksjonsmatriale = lenke.produksjonsmateriale
            ? [materialeTilFiltertype(lenke.produksjonsmateriale)]
            : [];
        const ingenProduksjon =
            lenke.produksjonsmateriale === undefined &&
            (lenke.produksjonstyper.length === 0 ||
                !lenke.produksjonstyper.map((p) => p.ibruk).some((p) => p))
                ? [Filtertype.IngenProduksjon]
                : [];
        [...produksjonsaktiviteter, ...produksjonsmatriale, ...ingenProduksjon].forEach(
            (element) => {
                if (!result.includes(element)) {
                    result.push(element);
                }
            },
        );
        return result;
    }, []);
};
