import { atom, WritableAtom } from "jotai/index";
import { LocalStorageKey } from "../../utils/storage/nøkler";
import {
    LocalStorageKontrakt,
    localStorageKontraktTilKontrakt,
} from "../../kartSide/utils/kartUrlUtils";
import { atomWithStorage } from "jotai/utils";
import dayjs, { Dayjs } from "dayjs";

export interface Kontrakt {
    navn: string;
    navnNvdb: string;
    elrappId: number;
    startDato?: Dayjs;
    sluttDato?: Dayjs;
}

export const kontrakterAtom = atom<Kontrakt[]>([]);
export const aktivKontraktAtom = aktivKontrakt();

export const kontraktFinnesAtom = atom((get) => {
    const kontrakter = get(kontrakterAtom);
    const aktivKontrakt = get(aktivKontraktAtom);
    return !(kontrakter.length === 0 && aktivKontrakt === undefined);
});

export const tidspunktAtom = atom<Dayjs>(dayjs());

function aktivKontrakt(): WritableAtom<Kontrakt | undefined, Kontrakt[], void> {
    const aktivKontrakt = atomWithStorage<Kontrakt | undefined>(
        LocalStorageKey.LOCALSTORAGE_AKTIV_KONTRAKT,
        undefined,
    );

    return atom(
        (get) => {
            const fraStorage = get(aktivKontrakt);
            return fraStorage
                ? localStorageKontraktTilKontrakt(fraStorage as unknown as LocalStorageKontrakt)
                : undefined;
        },
        (get, set, nextValue: Kontrakt) => {
            set(aktivKontrakt, nextValue);
        },
    );
}
