"use client";

import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "./api";
import {
    Friksjonsdata,
    Friksjonsmåling,
    FriksjonsmålingMetadata,
} from "../friksjonsdashboardSide/friksjonsmålingTyper";
import { DRIFTSPORTAL_API_URL } from "../utils/baseUrl";
import useSWR from "swr";
import dayjs from "dayjs";
import { fraFriksjonsTimestampStr } from "../utils/tid";

export function useHentFriksjondata(id: string): ApiRespons<FriksjonsdataDto> | undefined {
    const customFetcher = async (): Promise<ApiRespons<FriksjonsdataDto>> =>
        await fetcher<FriksjonsdataDto>(
            `${DRIFTSPORTAL_API_URL}/friksjonsdata/${id}`,
            FeilType.KUNNE_IKKE_HENTE_FRIKSJONSDATA,
        );
    const { data } = useSWR<ApiRespons<FriksjonsdataDto>>(id, customFetcher, ikkeRevalidate);

    return data;
}

const friksjonsmålingDtoTilFriksjonsmåling = (
    friksjonsmålingDto: FriksjonsmålingDto,
): Friksjonsmåling => {
    return {
        dato: dayjs(friksjonsmålingDto.dato),
        tid: friksjonsmålingDto.tid,
        uM: friksjonsmålingDto.um,
        uI: friksjonsmålingDto.ui,
        uY: friksjonsmålingDto.uy,
        lat: friksjonsmålingDto.lat,
        lng: friksjonsmålingDto.lng,
        vegsystemreferanse: friksjonsmålingDto.vegsystemreferanse,
        usikker: friksjonsmålingDto.usikker,
        omT: friksjonsmålingDto.omT,
        ovT: friksjonsmålingDto.ovT,
    };
};

export const friksjonsmålingMetadataDtoTilFriksjonsmålingMetadata = (
    friksjonsmålingMetadataDto: FriksjonsmålingMetadataDto,
): FriksjonsmålingMetadata => {
    return {
        id: friksjonsmålingMetadataDto.id,
        datoLastetOpp: fraFriksjonsTimestampStr(friksjonsmålingMetadataDto.datoLastetOpp),
        lastetOppAv: friksjonsmålingMetadataDto.lastetOppAv,
        dato: fraFriksjonsTimestampStr(friksjonsmålingMetadataDto.dato),
        viaFriction: friksjonsmålingMetadataDto.viaFriction,
        filnavn: friksjonsmålingMetadataDto.filnavn,
        programvareversjon: friksjonsmålingMetadataDto.programvareversjon,
        sted: friksjonsmålingMetadataDto.sted,
        operatør: friksjonsmålingMetadataDto.operatør ? friksjonsmålingMetadataDto.operatør : "",
        vær: friksjonsmålingMetadataDto.vær,
        målingskommentarer: friksjonsmålingMetadataDto.målingskommentarer,
        spor: friksjonsmålingMetadataDto.spor,
        utstyr: friksjonsmålingMetadataDto.utstyr,
        vegnettsversjon: friksjonsmålingMetadataDto.vegnettsversjon,
        fylke: friksjonsmålingMetadataDto.fylke,
        veg: friksjonsmålingMetadataDto.veg,
        retning: friksjonsmålingMetadataDto.retning,
        type: friksjonsmålingMetadataDto.type,
        start: friksjonsmålingMetadataDto.start,
        stopp: friksjonsmålingMetadataDto.stopp,
        utkjørtDistanse: friksjonsmålingMetadataDto.utkjørtDistanse,
    };
};

export const friksjonsdataDtoTilFriksjonsdata = (
    friksjonsdataDto: FriksjonsdataDto,
): Friksjonsdata => {
    return {
        metadata: friksjonsmålingMetadataDtoTilFriksjonsmålingMetadata(friksjonsdataDto.metadata),
        friksjonsmålinger: friksjonsdataDto.friksjonsmålinger.map(
            friksjonsmålingDtoTilFriksjonsmåling,
        ),
    };
};

type FriksjonsdataDto = {
    metadata: FriksjonsmålingMetadataDto;
    friksjonsmålinger: FriksjonsmålingDto[];
};

type FriksjonsmålingDto = {
    dato: string;
    tid: number;
    um: number;
    ui: number;
    uy: number;
    lat: number;
    lng: number;
    vegsystemreferanse: string;
    usikker: string;
    omT: number;
    ovT: number;
};

export type FriksjonsmålingMetadataDto = {
    id: number;
    datoLastetOpp: string;
    lastetOppAv: string;
    dato: string;
    viaFriction: string;
    filnavn: string;
    programvareversjon: string;
    sted: string;
    operatør: string;
    vær: string;
    målingskommentarer: string;
    spor: string;
    utstyr: string;
    vegnettsversjon: string;
    fylke: string;
    veg: string;
    retning: string;
    fil?: number;
    start: string;
    type: string;
    overvåkingsgrense?: number;
    stopp: string;
    utkjørtDistanse: number;
};
