import useSWR from "swr";
import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "./api";
import { DRIFTSPORTAL_API_URL, GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { Dayjs } from "dayjs";
import { fraOracleTimestampTilNorskString, tilEnkelTimestampStr } from "../utils/tid";

export function useHentHistoriskVærdata(
    tidspunkt: Dayjs,
    målestasjonId: string | undefined,
    skalHenteData: boolean = true,
): ApiRespons<Værdata | undefined> | undefined {
    const customFetcher = async (): Promise<ApiRespons<Værdata | undefined>> => {
        return await fetcher<Værdata | undefined>(
            `${DRIFTSPORTAL_API_URL}/værdata?tidspunkt=${tilEnkelTimestampStr(
                tidspunkt,
            )}&maalestasjonId=${målestasjonId}`,
            FeilType.KUNNE_IKKE_HENTE_VÆRDATA,
        ).then((response) =>
            response.suksess
                ? {
                      ...response,
                      data: response.data
                          ? {
                                ...response.data,
                                måletidspunkt: response.data.måletidspunkt
                                    ? fraOracleTimestampTilNorskString(response.data.måletidspunkt)
                                    : undefined,
                            }
                          : undefined,
                  }
                : response,
        );
    };

    const { data } = useSWR<ApiRespons<Værdata | undefined>>(
        skalHenteData ? `værdata${tilEnkelTimestampStr(tidspunkt)}${målestasjonId}` : null,
        customFetcher,
        ikkeRevalidate,
    );

    return data;
}

export interface Værdata {
    målestasjonid?: string;
    måletidspunkt?: string;
    relativFuktighet?: number;
    vegbaneTemperatur?: number;
    vindhastighet?: number;
    vindhastighetMaks?: number;
    vindretning?: number;
    luftTemperatur?: number;
    duggpunktTemperatur?: number;
    nedbør?: number;
    friksjon?: number;
    sikt?: number;
}
