import { useEffect } from "react";
import { ApiRespons, FeilType, fetcherPost, ikkeRevalidate } from "./api";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { atom, useSetAtom } from "jotai/index";
import useSWR from "swr";

export interface KjoretoyProduksjonsdetaljerDto {
    produksjonsdataRestRec: number;
    kjoeretoyid?: string;
    vegnr?: string;
    rodeid?: string;
    datoLogget: string;
    hastighetkmh: number;
    sprederbreddetoerrstoffcm: number;
    sprederbreddevaatstoffcm: number;
    doseringtoerrstoffgm2: number;
    doseringvaatstoffmlm2: number;
    ertoerrstoffsprederpaa?: boolean;
    ervaatstoffsprederpaa?: boolean;
    erplognede?: boolean;
    erhoevelskjaernede?: boolean;
    erunderliggendeskjaernede?: boolean;
    ersideplogibruk?: boolean;
    materiale?: string;
    eksternReferanse?: string;
}

export const kjøretøyProduksjonsdetaljerAtom = atom<
    ApiRespons<KjoretoyProduksjonsdetaljerDto[]> | undefined
>(undefined);

export const useHentKjoretoyProduksjonDetaljer = (målepunkter: number[]) => {
    const setProuksjonsdetaljer = useSetAtom(kjøretøyProduksjonsdetaljerAtom);
    const key = `${GCP_MEDIATOR_URL}/produksjonsdetaljer&målepunkter=${JSON.stringify(
        målepunkter,
    )}`;

    const customFetcher = () => {
        return hentKjøretøyProduksjonsdetaljer(målepunkter);
    };
    const { data } = useSWR(key, customFetcher, ikkeRevalidate);

    useEffect(() => {
        setProuksjonsdetaljer(data);
    }, [data]);
};

const hentKjøretøyProduksjonsdetaljer = async (
    målepunkter: number[],
): Promise<ApiRespons<KjoretoyProduksjonsdetaljerDto[]>> => {
    const url = `${GCP_MEDIATOR_URL}/produksjonsdetaljer`;
    const body = { målepunkter: målepunkter };
    return fetcherPost<KjoretoyProduksjonsdetaljerDto[]>(
        url,
        FeilType.KUNNE_IKKE_HENTE_KJØRETØYPRODUKSJONSDETALJER,
        JSON.stringify(body),
    );
};
