import useSWR from "swr";
import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "./api";
import { DRIFTSPORTAL_API_URL } from "../utils/baseUrl";
import { Geometry } from "geojson";

export interface RodeDto {
    rodeId: string;
    rodeNavn: string;
    vinterdriftsKlasser?: string[];
    detaljer: RodeVegnett;
}

export interface RodeVegnett {
    veglenke: string[];
    geometri: Geometry;
    vegsystemreferanse: string[];
    gatenavn: string[];
}

export function useHentRoder(
    elrappKontraktId: number | undefined,
): ApiRespons<RodeDto[]> | undefined {
    const customFetcher = async (): Promise<ApiRespons<RodeDto[]>> =>
        await fetcher<RodeDto[]>(
            `${DRIFTSPORTAL_API_URL}/roder_v2?elrappkontraktid=${elrappKontraktId}`,
            FeilType.KUNNE_IKKE_HENTE_RODER,
        );
    const { data } = useSWR<ApiRespons<RodeDto[]>>(
        elrappKontraktId ? `roder${elrappKontraktId}` : null,
        customFetcher,
        ikkeRevalidate,
    );
    return data;
}
