import useSWR from "swr";
import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "./api";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { Dayjs } from "dayjs";
import { Geometry, Point } from "geojson";
import { tilEnkelTimestampStr } from "../utils/tid";

export interface TrafikkmeldingerDto {
    recordType?: string;
    recordSubtypes: string[];
    overallStartTime?: string;
    overallEndTime?: string;
    recurringTimePeriods: RecurringTimePeriods[];
    dataProcessingNote?: string;
    description?: string;
    locations: Locations[];
    roadClosed: boolean;
}

export interface RecurringTimePeriods {
    startTime?: string;
    endTime?: string;
    daysOfWeek: string[];
}

interface Locations {
    coordinatesForDisplay?: Point;
    locationDescriptor?: string;
    roadNumber?: string;
}

export function useHentTrafikkmeldinger(
    tidspunkt: Dayjs,
): ApiRespons<TrafikkmeldingerDto[]> | undefined {
    const customFetcher = async (): Promise<ApiRespons<TrafikkmeldingerDto[]>> =>
        await fetcher<TrafikkmeldingerDto[]>(
            `${GCP_MEDIATOR_URL}/trafikkmeldinger?tidspunkt=${tilEnkelTimestampStr(tidspunkt)}`,
            FeilType.KUNNE_IKKE_HENTE_TRAFIKKMELDINGER,
        );
    const { data } = useSWR<ApiRespons<TrafikkmeldingerDto[]>>(
        `trafikkmeldinger${tilEnkelTimestampStr(tidspunkt)}`,
        customFetcher,
        ikkeRevalidate,
    );
    return data;
}

export const reccuringTimePeriodToString = (period: RecurringTimePeriods) =>
    `${period.startTime} - ${period.endTime}: ${reccuringTimePeriodDaysOfWeekToString(
        period.daysOfWeek,
    )}`;

const reccuringTimePeriodDaysOfWeekToString = (days: string[]) => {
    let outString = "";
    if (days.includes("MONDAY")) {
        outString += "Mandag, ";
    }
    if (days.includes("TUESDAY")) {
        outString += "Tirsdag, ";
    }
    if (days.includes("WEDNESDAY")) {
        outString += "Onsdag, ";
    }
    if (days.includes("THURSDAY")) {
        outString += "Torsdag, ";
    }
    if (days.includes("FRIDAY")) {
        outString += "Fredag, ";
    }
    if (days.includes("SATURDAY")) {
        outString += "Lørdag, ";
    }
    if (days.includes("SUNDAY")) {
        outString += "Søndag, ";
    }
    return outString.slice(0, -2);
};
