import useSWR from "swr";
import { ApiRespons, FeilType, fetcher, ikkeRevalidate } from "./api";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { Værdata } from "./useHentHistoriskVærdata";
import { fraEnkelTimestampStr, tilNorskTimestamp } from "../utils/tid";

export interface Kamera extends Værdata {
    geometri: { type: string; coordinates: number[] };
    id: String;
    beskrivelse?: string;
    retning?: string;
    vegNummer?: string;
    bildeUrl?: string;
    bildeBeskrivelse?: string;
    videoUrl?: string;
    værvaselYr?: string;
    navn?: string;
}

export function useHentVærstasjon(): ApiRespons<Kamera[]> | undefined {
    const customFetcher = async (): Promise<ApiRespons<Kamera[]>> => {
        return await fetcher<KameraDto[]>(
            `${GCP_MEDIATOR_URL}/kameramedvær`,
            FeilType.KUNNE_IKKE_HENTE_VÆRSTASJONER,
        ).then((response) =>
            response.suksess
                ? {
                      ...response,
                      data: response.data.map((dto) => dtoTilKamera(dto)),
                  }
                : response,
        );
    };

    const { data } = useSWR<ApiRespons<Kamera[]>>("kameramedvær", customFetcher, ikkeRevalidate);
    return data;
}

const dtoTilKamera = (dto: KameraDto): Kamera => ({
    geometri: dto.geometri,
    id: dto.id,
    beskrivelse: dto.beskrivelse,
    retning: dto.retning,
    vegNummer: dto.vegNummer,
    bildeUrl: dto.bildeUrl,
    bildeBeskrivelse: dto.bildeBeskrivelse,
    videoUrl: dto.videoUrl,
    værvaselYr: dto.værvaselYr,
    navn: dto.navn,
    målestasjonid: dto.målestasjonId,
    måletidspunkt: dto.værtidspunkt
        ? tilNorskTimestamp(fraEnkelTimestampStr(dto.værtidspunkt))
        : undefined,
    relativFuktighet: dto.luftfuktighet,
    vegbaneTemperatur: dto.vegbanetemperatur,
    vindhastighet: dto.vindHastighet,
    vindhastighetMaks: dto.vindHastighetMax,
    vindretning: dto.vindRetning,
    luftTemperatur: dto.temperatur,
    duggpunktTemperatur: dto.duggpunktTemperatur,
    nedbør: dto.nedbør,
    friksjon: dto.friksjon,
    sikt: dto.sikt,
});

interface KameraDto extends KameraVærdataDto {
    geometri: { type: string; coordinates: number[] };
    id: String;
    beskrivelse?: string;
    retning?: string;
    vegNummer?: string;
    bildeUrl?: string;
    bildeBeskrivelse?: string;
    videoUrl?: string;
    værvaselYr?: string;
    navn?: string;
}
interface KameraVærdataDto {
    målestasjonId?: string;
    værtidspunkt?: string;
    luftfuktighet?: number;
    vegbanetemperatur?: number;
    vindHastighet?: number;
    vindHastighetMax?: number;
    vindRetning?: number;
    temperatur?: number;
    duggpunktTemperatur?: number;
    nedbør?: number;
    friksjon?: number;
    sikt?: number;
}
