import { Dayjs } from "dayjs";
import { ApiRespons, FeilType, fetcher, FetchStatus, ikkeRevalidate } from "./api";
import { Produksjonslenke } from "../kartSide/types/produksjonslenke";
import { useSetAtom } from "jotai";
import { useEffect } from "react";
import {
    øktProduksjonslenkerAtom,
    øktProduksjonslenkerResponsAtom,
} from "./context/ØktLenkerAtoms";
import { dtoTilProduksjonslenke, ProduksjonslenkeDto } from "./useHentProduksjonslenker";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { tilEnkelTimestampStr } from "../utils/tid";
import useSWR from "swr";

export const useHentØktProduksjonslenker = (
    øktid: string | undefined,
    tidspunkt: Dayjs,
): ApiRespons<Produksjonslenke[]> | undefined => {
    const setØktProduksjonslenkerRespons = useSetAtom(øktProduksjonslenkerResponsAtom);
    const setØktProduksjonslenker = useSetAtom(øktProduksjonslenkerAtom);
    const key = øktid
        ? `${GCP_MEDIATOR_URL}/økt?økt=${øktid}&tidspunkt=${tilEnkelTimestampStr(tidspunkt)}`
        : null;
    const { data, isLoading } = useSWR<ApiRespons<Produksjonslenke[]>>(
        key,
        customFetcher,
        ikkeRevalidate,
    );

    useEffect(() => {
        if (!øktid) {
            setØktProduksjonslenkerRespons({ status: FetchStatus.IkkeHentet });
            setØktProduksjonslenker([]);
            return;
        }

        if (isLoading) {
            setØktProduksjonslenkerRespons({ status: FetchStatus.Laster });
            setØktProduksjonslenker([]);
            return;
        }

        data && setØktProduksjonslenkerRespons(data);

        if (data?.suksess) {
            setØktProduksjonslenker(data.data);
        }
    }, [data, øktid, tidspunkt]);

    return data;
};

async function customFetcher(url: string): Promise<ApiRespons<Produksjonslenke[]>> {
    const response = await fetcher<ProduksjonslenkeDto[]>(
        url,
        FeilType.KUNNE_IKKE_HENTE_ØKTPRODUKSJONSLENKER,
    );
    if (response?.suksess) {
        return {
            ...response,
            data: response.data.map(dtoTilProduksjonslenke),
        };
    }
    return response;
}
