import { useEffect } from "react";
import { øktProduksjonsdetaljerAtom } from "./context/InitØktdetaljer";
import { ApiRespons, FeilType, fetcher, FetchStatus, ikkeRevalidate } from "./api";
import { Produksjonsdetaljer } from "../kartSide/types/produksjonsdetaljer";
import { dtoTilProduksjonsdetaljer, ProduksjonsdetaljerDto } from "./useHentProduksjonsdetaljer";
import { GCP_MEDIATOR_URL } from "../utils/baseUrl";
import { useSetAtom } from "jotai";
import useSWR from "swr";

export const useHentØktdetaljer = (øktid: string | undefined) => {
    const setProduksjonsdetaljer = useSetAtom(øktProduksjonsdetaljerAtom);
    const key = øktid ? `${GCP_MEDIATOR_URL}/økt-detaljer?økt=${øktid}` : null;
    const { data, isLoading } = useSWR<ApiRespons<Produksjonsdetaljer[]>>(
        key,
        customFetcher,
        ikkeRevalidate,
    );

    useEffect(() => {
        if (!øktid) {
            setProduksjonsdetaljer({ status: FetchStatus.IkkeHentet });
            return;
        }

        if (isLoading) {
            setProduksjonsdetaljer({ status: FetchStatus.Laster });
            return;
        }

        data && setProduksjonsdetaljer(data);
    }, [data, isLoading, øktid]);
};

async function customFetcher(url: string): Promise<ApiRespons<Produksjonsdetaljer[]>> {
    const response = await fetcher<ProduksjonsdetaljerDto[]>(
        url,
        FeilType.KUNNE_IKKE_HENTE_ØKTDETALJER,
    );
    if (response?.suksess) {
        return {
            ...response,
            data: response.data.map(dtoTilProduksjonsdetaljer),
        };
    }
    return response;
}
