import React from "react";
import { motion } from "framer-motion";
import styled from "styled-components";
import { KnappUtenStyling } from "../fellesKomponenter/knapper/KnappUtenStyling";

interface BurgerknappProps {
    åpen: boolean;
    onClick: () => void;
}

export const Burgerknapp = ({ åpen, onClick }: BurgerknappProps) => {
    const top = {
        opened: {
            rotate: 45,
            translateY: 2,
        },
        closed: {
            rotate: 0,
            translateY: 0,
        },
    };
    const midt = {
        opened: {
            opacity: 0,
        },
        closed: {
            opacity: 1,
        },
    };
    const bunn = {
        opened: {
            rotate: -45,
            translateY: -2,
        },
        closed: {
            rotate: 0,
            translateY: 0,
        },
    };
    const lineProps = {
        stroke: "var(--gray-dark)",
        strokeWidth: 2,
        vectorEffect: "non-scaling-stroke",
        initial: "closed",
        animate: åpen ? "opened" : "closed",
    };
    return (
        <StyledKnapp onClick={onClick}>
            <motion.svg
                viewBox={`0 0 4 4`}
                whileHover={{
                    scale: 1.1,
                    transition: { duration: 0.1 },
                    cursor: "pointer",
                }}
                overflow="visible"
                width={24}
                height={24}
            >
                <motion.line x1="0" x2={4} y1="0" y2="0" variants={top} {...lineProps} />
                <motion.line x1="0" x2={4} y1="2" y2="2" variants={midt} {...lineProps} />
                <motion.line x1="0" x2={4} y1="4" y2="4" variants={bunn} {...lineProps} />
            </motion.svg>
        </StyledKnapp>
    );
};

const StyledKnapp = styled(KnappUtenStyling)`
    &:focus-visible {
        outline: none;
    }
`;
