import React, { ReactNode, useCallback, useState } from "react";
import styled from "styled-components";
import { useCloseOnOutsideClick } from "../../hooks/useCloseOnOutsideClick";
import { AnimatePresence, motion } from "framer-motion";
import { Burgerknapp } from "./Burgerknapp";
import { useWindowSize } from "../../hooks/useWindowSize";
import { loggEventMedTabellnavn, TabellNavn } from "../../utils/loggFrontend";

interface BurgermenyProps {
    children: ReactNode[];
}

export const Burgermeny = ({ children }: BurgermenyProps) => {
    const [åpen, setÅpen] = useState(false);

    const lukkMeny = useCallback(() => {
        setÅpen(false);
    }, [setÅpen]);
    const id = "hamburgermeny";
    useCloseOnOutsideClick(id, lukkMeny);
    const childrenSkalVises = children.flat().filter((child) => child !== false);

    const { windowWidth } = useWindowSize();

    const håndterBurgerknappKlikket = () => {
        !åpen && loggEventMedTabellnavn(TabellNavn.burgermenyTrykk, "Åpne");
        setÅpen(!åpen);
    };
    return (
        <div id={id}>
            <Burgerknapp åpen={åpen} onClick={håndterBurgerknappKlikket} />
            <AnimatePresence>
                {åpen && (
                    <MenyListe
                        åpen={åpen.toString()}
                        maksbredde={windowWidth - 40 + "px"}
                        initial="collapsed"
                        animate={åpen ? "open" : "closed"}
                        exit="collapsed"
                        variants={{
                            open: { opacity: 1, height: "auto" },
                            collapsed: { opacity: 0, height: 0 },
                        }}
                        transition={{
                            duration: 0.3,
                        }}
                    >
                        {childrenSkalVises.map((child, index) => (
                            <Menyelement key={index}>{child}</Menyelement>
                        ))}
                    </MenyListe>
                )}
            </AnimatePresence>
        </div>
    );
};

const MenyListe = styled(motion.ul)<{ åpen: string; maksbredde: string }>`
    position: absolute;
    right: 0;
    background: var(--white);
    list-style: none;
    padding: 16px 24px;
    width: fit-content;
    max-width: ${({ maksbredde }) => maksbredde};
    z-index: 1080;
    pointer-events: ${({ åpen }) => (åpen === "true" ? "auto" : "none")};
    overflow: hidden;
`;

const Menyelement = styled.li`
    align-items: center;
    border-bottom: 2px solid var(--gray-regular-dark);
    display: flex;
    gap: 8px;
    margin-bottom: 16px;
    padding-bottom: 16px;
    width: 293px;
`;
