"use client";
import { finnMiljø, Miljø } from "../../utils/miljø";
import React, { ReactNode } from "react";
import { Feilside } from "./Feilside";
import { loggFrontend, LoggNivå } from "../../utils/loggFrontend";

interface ErrorBoundaryProps {
    children: ReactNode;
    info?: string;
}

interface State {
    error?: Error;
}

class ErrorBoundary extends React.Component<ErrorBoundaryProps, State> {
    public constructor(props: ErrorBoundaryProps) {
        super(props);
        this.state = { error: undefined };
    }

    static getDerivedStateFromError(error: Error) {
        // Update state so the next render will show the fallback UI.
        return { error };
    }

    public componentDidCatch(error: Error) {
        switch (finnMiljø()) {
            case Miljø.lokal || Miljø.mobil:
                console.error(`${error.name}\n${error.message}`);
                loggFrontend({ loggNivå: LoggNivå.Error, error });
                break;
            case Miljø.utv:
            case Miljø.test:
            case Miljø.prod:
                loggFrontend({
                    loggNivå: LoggNivå.Error,
                    error,
                    loggMelding: this.props.info,
                });
                break;
            default:
                loggFrontend({
                    loggNivå: LoggNivå.Error,
                    error: error,
                    loggMelding: `Ukjent miljø ved logging: ${window.location.href}`,
                });
                break;
        }
    }

    render(): React.ReactNode {
        if (this.state.error) {
            return (
                <Feilside tittel={"Rusk i maskineriet"}>
                    Her har det visst skjedd noe galt. Vi i KOS-teamet har fått beskjed og vil
                    utbedre feilen så fort som mulig. Kontakt{" "}
                    <a href="mailto:kos@vegvesen.no">kos@vegvesen.no</a> dersom feilen vedvarer.
                </Feilside>
            );
        }
        return this.props.children;
    }
}

export default ErrorBoundary;
