import { createContext, ReactNode, useState } from "react";
import styled from "styled-components";

export interface CheckboxGruppeState {
    value?: string[];
    toggleValue: (value: string) => void;
}

export const CheckboxGruppeContext = createContext<CheckboxGruppeState | null>(null);

interface CheckboxGruppeProps {
    children: ReactNode;
    value: string[];
    onChange: (values: string[]) => void;
}

export const CheckboxGruppe = ({ children, value, onChange }: CheckboxGruppeProps) => {
    const [state, setState] = useState<string[]>([]);
    const toggleValue = (v: string) => {
        const newValue = value ?? state;
        const newState = newValue.includes(v) ? newValue.filter((x) => x !== v) : [...newValue, v];

        value === undefined && setState(newState);
        onChange(newState);
    };

    return (
        <Gruppe>
            <CheckboxGruppeContext.Provider value={{ value, toggleValue }}>
                {children}
            </CheckboxGruppeContext.Provider>
        </Gruppe>
    );
};

const Gruppe = styled.div`
    display: flex;
    flex-direction: column;
    gap: 16px;
    margin-bottom: 24px;
`;
