import React, { useState } from "react";
import styled from "styled-components";
import { FormLabel } from "./FormLabel";
import { Inputfelt } from "./Inputfelt";
import dayjs, { Dayjs } from "dayjs";
import { fraIsoDatoString, tilIsoDatoString } from "../../../utils/tid";
import { ColumnWrapper, RowWrapper } from "../wrappers/wrappers";
import { HjelpetekstPopup } from "../HjelpetekstPopup";
import { InfoknappLoggEvent } from "../../../utils/loggFrontend";

interface DatofeltProps {
    dato: Dayjs;
    setDato: (nyDato: Dayjs) => void;
    tittel: string;
    hjelpetekst?: string;
}

export const Datofelt = ({ dato, setDato, tittel, hjelpetekst }: DatofeltProps) => {
    const [lokalDato, setLokalDato] = useState(tilIsoDatoString(dato));
    const handleNyDate = (e: React.ChangeEvent<HTMLInputElement>) => {
        setLokalDato(e.target.value);
        setDato(fraIsoDatoString(e.target.value));
    };
    return (
        <ColumnWrapper>
            <StyledRowWrapper>
                <FormLabel htmlFor="dato">{tittel}</FormLabel>
                {hjelpetekst && (
                    <IkonWrapper>
                        <HjelpetekstPopup
                            plassering={"right center"}
                            størrelse={"S"}
                            infoknappLoggEvent={InfoknappLoggEvent.datoInfoknapp}
                        >
                            {hjelpetekst}
                        </HjelpetekstPopup>
                    </IkonWrapper>
                )}
            </StyledRowWrapper>

            <Inputfelt
                type="date"
                id="dato"
                $størrelse="L"
                min={"2020-01-01"}
                max={tilIsoDatoString(dayjs())}
                onChange={handleNyDate}
                value={lokalDato}
            />
        </ColumnWrapper>
    );
};

const StyledRowWrapper = styled(RowWrapper)`
    gap: 0.5rem;
    align-items: flex-start;
`;

export const IkonWrapper = styled.div`
    align-self: flex-start;
    margin: 0 0 5px 0;
`;
