import React, { FC, HTMLAttributes } from "react";
import styled from "styled-components";
import { Lenke } from "./Lenke";
import { Størrelse } from "../typografi/TekstStyles";

interface EksternLenkeProps extends HTMLAttributes<HTMLAnchorElement> {
    children: React.ReactNode;
    href: string;
    lenkeikon?: "vis" | "skjul";
    størrelse?: Størrelse;
    fontWeight?: number;
    onClick?: () => void;
}

export const EksternLenke: FC<EksternLenkeProps> = ({
    children,
    href,
    lenkeikon = "vis",
    størrelse,
    fontWeight,
    onClick,
}) => (
    <span>
        <Lenke
            $fontWeight={fontWeight}
            href={href}
            target={"_blank"}
            rel="noreferrer"
            $størrelse={størrelse}
            onClick={onClick}
        >
            {children}
            {lenkeikon == "vis" && <EksternLenkeIkon $ersvart={true} />}
        </Lenke>
        f
    </span>
);

interface EksternLenkeIkonProps {
    $ersvart: boolean;
}
export const EksternLenkeIkon = styled.i<EksternLenkeIkonProps>`
    display: inline-block;
    width: 16px;
    height: 16px;
    background-image: url(${(props) =>
        props.$ersvart ? "/ikon/ekstern-lenke.svg" : "/ikon/ekstern-lenke-hvit.svg"});
    background-repeat: no-repeat;
    background-position: 100%;
    margin-left: 8px;
`;
