import styled from "styled-components";
import React, { useEffect } from "react";
import FocusTrap from "focus-trap-react";
import { Lukknapp } from "../knapper/Lukknapp";
import { useWindowSize } from "../../../hooks/useWindowSize";

export interface ModalProps {
    onClose: () => void;
    id: string;
    children: React.ReactNode;
    maksBredde?: number;
    maksHøyde?: number;
}

export const Modal = ({ onClose, id, children, maksBredde, maksHøyde }: ModalProps) => {
    const { windowWidth, windowHeight } = useWindowSize();
    const modalWidth = maksBredde ? Math.min(windowWidth - 30, maksBredde) : windowWidth - 30;
    const modalHeight = maksHøyde ? Math.min(windowHeight - 30, maksHøyde) : windowHeight - 30;

    const callback = (event: MouseEvent | TouchEvent) => {
        if (event.target instanceof Element && !event.target.closest("#" + id)) {
            onClose();
        }
    };

    const escFunction = (event: KeyboardEvent) => {
        if (event.key === "Escape") {
            onClose();
        }
    };

    useEffect(() => {
        window.addEventListener("click", callback, true);
        document.addEventListener("keydown", escFunction, false);
        return () => {
            window.removeEventListener("click", callback, true);
            document.removeEventListener("keydown", escFunction, false);
        };
    }, []);

    return (
        <div>
            <FocusTrap focusTrapOptions={{ initialFocus: false }}>
                <ModalWrapper id={id} maksBredde={modalWidth} maksHøyde={modalHeight}>
                    <KnappWrapper>
                        <Lukknapp onClick={onClose} />
                    </KnappWrapper>
                    {children}
                </ModalWrapper>
            </FocusTrap>
            <ModalBackground />
        </div>
    );
};

const ModalWrapper = styled.div<{ maksBredde?: number; maksHøyde?: number }>`
    min-width: 200px;
    width: fit-content;
    max-width: ${(props) => props.maksBredde}px;
    max-height: ${(props) => props.maksHøyde}px;
    height: fit-content;
    z-index: 3200;
    position: fixed;
    background-color: var(--white);
    box-shadow: rgba(0, 0, 0, 0.25) 0 2px 4px 0;
    cursor: auto;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    padding: 40px;
    border-radius: 5px;
    overflow: auto;
`;

const ModalBackground = styled.div`
    background-color: #000000;
    opacity: 50%;
    position: fixed;
    left: 0;
    top: 0;
    width: 100vw;
    height: 100vh;
    z-index: 3100;
`;

const KnappWrapper = styled.div`
    position: absolute;
    top: 10px;
    right: 10px;
`;
