import React, { ChangeEvent, InputHTMLAttributes } from "react";
import styled from "styled-components";
import { Tekst } from "../typografi/Tekst";

export interface RadioknappProps
    extends Omit<InputHTMLAttributes<HTMLInputElement>, "size" | "value"> {
    value: string;
    name: string;
    children: React.ReactNode;
    disabled?: boolean;
    checked: boolean;
    onChange: (e: ChangeEvent<HTMLInputElement>) => void;
    størrelse?: "S" | "L";
    tekstStørrelse?: "S" | "M" | "L";
}

export const Radioknapp = ({
    value,
    name,
    children,
    disabled,
    checked,
    onChange,
    størrelse = "L",
    tekstStørrelse = "L",
}: RadioknappProps) => {
    return (
        <Wrapper>
            <Input
                id={value}
                type="radio"
                value={value}
                name={name}
                checked={checked}
                onChange={onChange}
                disabled={disabled}
                $størrelse={størrelse}
            />
            <RadioLabel htmlFor={value} $størrelse={størrelse}>
                <Tekst as="span" $størrelse={tekstStørrelse}>
                    {children}
                </Tekst>
            </RadioLabel>
        </Wrapper>
    );
};

const Wrapper = styled.div`
    position: relative;
    width: fit-content;
    display: flex;
    gap: 10px;
`;

const Input = styled.input<{ $størrelse: string }>`
    cursor: pointer;
    height: 32px;
    width: 32px;
    opacity: 0;
    position: absolute;
    top: -4px;
    left: -6px;
    z-index: 1;

    ${(props) =>
        props.$størrelse === "S" &&
        `
        height: 26px;
        width: 26px;
        `}
`;

const RadioLabel = styled.label<{ $størrelse: string }>`
    align-items: center;
    cursor: pointer;
    display: flex;
    gap: 8px;

    ${Input}:disabled + & > ${Tekst} {
        color: var(--gray-regular-dark);
    }

    &:before {
        background-color: var(--white);
        border-radius: 50%;
        box-shadow: inset 0 0 0 2px var(--gray-dark);
        content: "";
        flex-shrink: 0;
        height: 32px;
        width: 32px;

        ${(props) =>
            props.$størrelse === "S" &&
            `
        height: 24px;
        width: 24px;
        `}

        ${Input}:checked + & {
            background: radial-gradient(circle at center, black 50%, transparent 50%);
            background-repeat: no-repeat;
            background-position: center;
            background-size: 25px 25px;

            ${(props) =>
                props.$størrelse === "S" &&
                `
                background-size: 18px 18px;
            `}
        }

        ${Input}:hover + & {
            box-shadow: inset 0 0 0 3px var(--gray-dark);
        }

        ${Input}:focus + & {
            box-shadow: inset 0 0 0 3px var(--gray-dark);
            outline: 3px solid var(--orange);
            outline-offset: 2px;
        }

        ${Input}:disabled + & {
            box-shadow: inset 0 0 0 2px var(--gray-regular-dark);
        }
    }
`;
