import React from "react";
import classNames from "classnames";

type Storrelse = "xxliten" | "xliten" | "liten" | "medium" | "stor";

type SpinnerProps = React.PropsWithChildren<{
    sentrert?: boolean;
    storrelse?: Storrelse;
    inline?: boolean;
}>;

type WrapperBlockProps = React.PropsWithChildren<{}>;

export function WrapperBlock({ children, ...rest }: WrapperBlockProps) {
    return <div {...rest}>{children}</div>;
}

export function Spinner({
    sentrert = true,
    storrelse = "medium",
    inline = false,
    children,
}: SpinnerProps) {
    const SpinnerWrapper: any = inline ? React.Fragment : WrapperBlock;
    let wrapperProps = {};

    if (!inline) {
        wrapperProps = {
            className: classNames({
                "svv-spinner--sentrert": sentrert,
            }),
        };
    }
    return (
        <SpinnerWrapper {...wrapperProps}>
            <div
                className={classNames("svv-spinner__wrapper svv-spinner--active", {
                    "svv-spinner--liten": storrelse === "liten",
                    "svv-spinner--stor": storrelse === "stor",
                    "svv-spinner--xliten": storrelse === "xliten",
                    "svv-spinner--xxliten": storrelse === "xxliten",
                })}
            >
                <div className="svv-spinner__layer">
                    <div className="svv-spinner__circle-clipper svv-spinner__circle-clipper--left">
                        <div className="svv-spinner__circle" />
                    </div>
                    <div className="svv-spinner__spacing-fix">
                        <div className="svv-spinner__circle" />
                    </div>
                    <div className="svv-spinner__circle-clipper svv-spinner__circle-clipper--right">
                        <div className="svv-spinner__circle" />
                    </div>
                </div>
            </div>
            {children && <div className="svv-spinner__text">{children}</div>}
        </SpinnerWrapper>
    );
}
