import { TrekkspillKnapp } from "./TrekkspillKnapp";
import React from "react";
import styled from "styled-components";
import { AnimatePresence, motion } from "framer-motion";

export type TrekkspillStil = "Ramme" | "UtenRamme";
export type TrekkspillStørrelse = "M" | "L";

interface TrekkspillProps {
    åpen: boolean;
    tittel: string;
    type: TrekkspillStil;
    størrelse?: TrekkspillStørrelse;
    onClick: () => void;
    width?: string;
    children: React.ReactNode;
    makshøyde?: string;
    position?: "imbedded" | "overlay";
}
export const Trekkspill = ({
    children,
    åpen,
    onClick,
    type,
    størrelse = "L",
    tittel,
    width,
    makshøyde,
    position = "overlay",
}: TrekkspillProps) => {
    return (
        <TrekkspillContainer $width={width}>
            <TrekkspillKnapp
                onClick={onClick}
                tittel={tittel}
                åpen={åpen}
                type={type}
                størrelse={størrelse}
            />
            <TrekkspillInnholdWrapper
                type={type}
                makshøyde={makshøyde}
                position={position}
                initial="collapsed"
                animate={åpen ? "open" : "closed"}
                exit="collapsed"
                variants={{
                    open: { opacity: 1, height: "auto" },
                    collapsed: { opacity: 0, height: 0 },
                }}
                transition={{
                    duration: 0.3,
                }}
            >
                <AnimatePresence>{åpen && children}</AnimatePresence>
            </TrekkspillInnholdWrapper>
        </TrekkspillContainer>
    );
};

interface TrekkspillContainerProps {
    $width?: string;
}
export const TrekkspillContainer = styled.div.attrs<TrekkspillContainerProps>((props) => ({
    $width: props.$width || "300px",
}))`
    justify-self: right;
    position: relative;
    width: ${(props) => props.$width};

    @media (max-width: 380px) {
        max-width: 250px;
    }
`;
interface TrekkspillInnholdWrapperProps {
    type: TrekkspillStil;
    makshøyde?: string;
    position: "imbedded" | "overlay";
}

export const TrekkspillInnholdWrapper = styled(motion.section)<TrekkspillInnholdWrapperProps>`
    background: var(--white);
    position: ${({ position }) => (position === "overlay" ? "absolute" : "inherit")};
    width: 100%;
    box-sizing: border-box;
    border: 2px solid var(--gray-dark);
    overflow-y: auto;
    border-top: ${({ type }) => (type === "Ramme" ? "none" : "1px solid var(--gray-dark)")};
    border-bottom: ${({ type }) => type === "Ramme" && "3px solid var(--orange);"};
    max-height: ${({ makshøyde }) => makshøyde || "none"};
    z-index: 1060;
`;
