import styled, { css } from "styled-components";
import { Tekst } from "../typografi/Tekst";
import { Tekstpil } from "../../Ikon/Tekstpil";
import React from "react";
import { TrekkspillStil, TrekkspillStørrelse } from "./Trekkspill";

interface TrekkspillKnappProps {
    åpen: boolean;
    tittel: string;
    type: TrekkspillStil;
    størrelse: TrekkspillStørrelse;
    onClick: () => void;
}
export const TrekkspillKnapp = ({
    åpen,
    tittel,
    type,
    størrelse,
    onClick,
}: TrekkspillKnappProps) => {
    const TittelComponent = getTittelType(type);
    return (
        <TrekkspillKnappStyled onClick={onClick} $knapptype={type}>
            <TittelComponent as="span" $størrelse={størrelse}>
                {tittel}
            </TittelComponent>
            <Tekstpil $rotert={åpen} størrelse={getPilStørrelse(størrelse)} />
        </TrekkspillKnappStyled>
    );
};

const getTittelType = (knapptype: TrekkspillStil) => {
    switch (knapptype) {
        case "UtenRamme":
            return TrekkspillTittelUtenRamme;
        case "Ramme":
            return TrekkspillTittelMedRamme;
    }
};

const getPilStørrelse = (størrelse: TrekkspillStørrelse) => {
    switch (størrelse) {
        case "M":
            return 14;
        case "L":
            return 16;
    }
};

interface KnappProps {
    $knapptype: TrekkspillStil;
}
export const TrekkspillKnappStyled = styled.button<KnappProps>`
    display: flex;
    align-items: center;
    appearance: none;
    border: 0;
    width: 100%;
    gap: 10px;

    &:hover {
        cursor: pointer;
    }

    ${(props) =>
        props.$knapptype === "Ramme" &&
        css`
            background-color: var(--white);
            box-shadow: inset 0 0 0 2px var(--gray-dark);
            padding: 9px 20px;
        `};

    ${(props) =>
        props.$knapptype === "UtenRamme" &&
        css`
            justify-content: space-between;
            background-color: transparent;
            border-bottom: 1px solid var(--gray-dark);
            padding: 0 10px;
        `};
`;

interface TittelProps {
    $størrelse?: TrekkspillStørrelse;
}
export const TrekkspillTittelUtenRamme = styled(Tekst).attrs<TittelProps>((props) => ({
    $størrelse: props.$størrelse || "M",
}))`
    max-width: 100%;
    overflow: hidden;
    white-space: nowrap;
`;

const TrekkspillTittelMedRamme = styled(Tekst).attrs<TittelProps>((props) => ({
    $størrelse: props.$størrelse || "L",
}))`
    width: 100%;
`;
