import React, { useEffect, useState } from "react";
import styled from "styled-components";
import { useKnappTrykk } from "../../../hooks/useKnappTrykk";
import { TrekkspillKnapp } from "./TrekkspillKnapp";
import { TrekkspillContainer } from "./Trekkspill";
import { motion } from "framer-motion";
import { fontsizeLargeScreen, fontsizeSmallScreen } from "../typografi/TekstStyles";
import { breakpointNettbrett } from "../../../utils/constants";

interface DropdownProps {
    utvalg: string[];
    håndterValg: (valg: string) => void;
    tittel: string;
    fitContent?: boolean;
}

export function TrekkspillSøkbar({
    utvalg,
    håndterValg,
    tittel,
    fitContent = false,
}: DropdownProps) {
    const [åpen, settÅpen] = useState<boolean>(false);
    const [sokeord, settSokeord] = useState<string>("");
    const [hoverIndeks, settHoverIndeks] = useState<number>(-1);

    const [knappNedIntervall, settKnappNedIntervall] = useState<any>(null);
    const [knappOppIntervall, settKnappOppIntervall] = useState<any>(null);
    const håndterTrekkspillKnappKlikk = () => {
        settÅpen(!åpen);
        settSokeord("");
        settHoverIndeks(-1);
    };

    const pilNed = useKnappTrykk("ArrowDown");
    const pilOpp = useKnappTrykk("ArrowUp");
    const enter = useKnappTrykk("Enter");

    useEffect(() => {
        if (pilNed) {
            settHoverIndeks((prevState) =>
                prevState < filtrerUtvalg().length - 1 ? prevState + 1 : prevState,
            );
            const _interval = setInterval(() => {
                settHoverIndeks((prevState) =>
                    prevState < filtrerUtvalg().length - 1 ? prevState + 1 : prevState,
                );
            }, 300);
            settKnappNedIntervall(_interval);
        } else if (knappNedIntervall !== null) {
            clearInterval(knappNedIntervall);
            settKnappNedIntervall(null);
        }
    }, [pilNed]);

    useEffect(() => {
        if (pilOpp) {
            if (hoverIndeks === -1) {
                settHoverIndeks(filtrerUtvalg().length - 1);
            } else {
                settHoverIndeks((prevState) => (prevState > 0 ? prevState - 1 : prevState));
                const _interval = setInterval(() => {
                    settHoverIndeks((prevState) => (prevState > 0 ? prevState - 1 : prevState));
                }, 300);
                settKnappOppIntervall(_interval);
            }
        } else if (knappOppIntervall !== null) {
            clearInterval(knappOppIntervall);
            settKnappOppIntervall(null);
        }
    }, [pilOpp]);

    useEffect(() => {
        if (enter && hoverIndeks > -1) {
            håndterValg(filtrerUtvalg()[hoverIndeks]);
            settÅpen(false);
        }
    }, [enter]);

    const håndterSokeordEndring = (e: React.ChangeEvent<HTMLInputElement>) => {
        settSokeord(e.target.value);
        settHoverIndeks(-1);
    };
    const filtrerUtvalg = () =>
        utvalg.filter((utvalg) => utvalg.toLowerCase().includes(sokeord.toLowerCase())) ?? [];

    return (
        <TrekkspillContainer>
            <TrekkspillKnapp
                onClick={håndterTrekkspillKnappKlikk}
                åpen={åpen}
                type={"UtenRamme"}
                størrelse={"M"}
                tittel={tittel}
            />
            <Trekkspill
                onMouseEnter={() => settHoverIndeks(-1)}
                initial="collapsed"
                animate={åpen ? "open" : "closed"}
                exit="collapsed"
                variants={{
                    open: { opacity: 1, height: "auto" },
                    collapsed: { opacity: 0, height: 0 },
                }}
                transition={{
                    duration: 0.3,
                }}
            >
                {åpen && (
                    <InnholdContainer>
                        <Sokefelt
                            onChange={håndterSokeordEndring}
                            placeholder={"Søk"}
                            type={"text"}
                            ref={(input) => input?.focus()}
                            value={sokeord}
                        />

                        {filtrerUtvalg().map((element, i) => (
                            <VelgElementKnapp
                                key={i}
                                onClick={() => {
                                    håndterValg(element);
                                    settÅpen(false);
                                }}
                                $hoverIndeks={hoverIndeks}
                                $nøkkel={i}
                            >
                                <>{element}</>
                            </VelgElementKnapp>
                        ))}
                    </InnholdContainer>
                )}
            </Trekkspill>
        </TrekkspillContainer>
    );
}

interface VelgElementKnappProps {
    $hoverIndeks: number;
    key: number;
    $nøkkel: number;
}

const VelgElementKnapp = styled.button<VelgElementKnappProps>`
    background-color: ${(props) => (props.$nøkkel === props.$hoverIndeks ? "#f2f2f2" : "#fff")};
    border: none;
    cursor: pointer;
    ${fontsizeLargeScreen};
    padding: 4px 8px 4px 8px;
    text-align: left;
    width: 100%;

    &:hover {
        background-color: ${(props) => props.$hoverIndeks === -1 && "#f2f2f2"};
        font-weight: 600;
    }

    @media (max-width: ${breakpointNettbrett}) {
        ${fontsizeSmallScreen};
    }
`;

const Trekkspill = styled(motion.div)`
    background: var(--white);
    border: 2px solid var(--gray-dark);
    border-top: 1px solid var(--gray-dark);
    max-height: 80vh;
    overflow: auto;
    position: absolute;
    width: calc(100% - 4px);
    z-index: 100;
`;

const Sokefelt = styled.input`
    border: none;
    border-bottom: 1px solid var(--gray-dark);
    ${fontsizeLargeScreen};
    height: 28px;
    margin: 4px;
    width: calc(100% - 12px);

    &:focus {
        outline: none;
    }

    @media (max-width: ${breakpointNettbrett}) {
        ${fontsizeSmallScreen};
    }
`;

const InnholdContainer = styled.div`
    display: flex;
    flex-direction: column;

    @media (pointer: coarse) {
        gap: 12px;
    }
`;
