import { Tekst } from "../fellesKomponenter/typografi/Tekst";
import { Radioknapp } from "../fellesKomponenter/radioknapper/Radioknapp";
import React from "react";
import { aktivGrafKategoriAtom, GrafKategori, GrafType } from "../../øktdetaljerSide/jotai/atoms";
import { useAtom } from "jotai";
import {
    GrafvalgLoggEvent,
    loggEventMedTabellnavnOgVerdi,
    TabellNavn,
} from "../../utils/loggFrontend";
import { ColumnWrapperValg } from "./styles";
import { capitalizeFirst } from "../../utils/tekst";

export const AktivGrafValg = ({ grafside }: { grafside: "øktdetaljer" | "friksjon" }) => {
    const [aktivGrafKategori, setAktivGrafKategori] = useAtom(aktivGrafKategoriAtom);

    const grafkategorier =
        grafside === "øktdetaljer"
            ? [GrafKategori.hastighet, GrafKategori.dosering]
            : [GrafKategori.friksjon, GrafKategori.temperatur];
    const håndterAktivGraf = (type: GrafKategori) => {
        setAktivGrafKategori(type);
        if (grafside === "øktdetaljer") {
            loggEventMedTabellnavnOgVerdi(
                TabellNavn.grafvalgØkt,
                GrafvalgLoggEvent.graftype,
                type.toString(),
            );
        } else {
            loggEventMedTabellnavnOgVerdi(
                TabellNavn.grafvalgFriksjon,
                GrafvalgLoggEvent.graftype,
                type.toString(),
            );
        }
    };

    return (
        <ColumnWrapperValg>
            <Tekst $bold={true} $nomargin={true} $størrelse={"M"}>
                Velg graftype
            </Tekst>
            {grafkategorier.map((grafkategori) => (
                <Radioknapp
                    key={"aktivgraf" + grafkategori}
                    value={grafkategori}
                    checked={aktivGrafKategori === grafkategori}
                    name={"aktivgraf"}
                    onChange={() => håndterAktivGraf(grafkategori)}
                    størrelse={"S"}
                    tekstStørrelse={"M"}
                >
                    {capitalizeFirst(grafkategori)}
                </Radioknapp>
            ))}
        </ColumnWrapperValg>
    );
};
