import React, { ReactNode } from "react";
import styled from "styled-components";
import { Tekst } from "../fellesKomponenter/typografi/Tekst";
import { useAtomValue } from "jotai";
import { aktivGrafKategoriAtom, GrafKategori } from "../../øktdetaljerSide/jotai/atoms";

interface GeneriskGrafvalgProps {
    children: ReactNode;
}
export const GeneriskGrafvalg = ({ children }: GeneriskGrafvalgProps) => {
    const grafKategori = useAtomValue(aktivGrafKategoriAtom);
    return (
        <GrafvalgContainer>
            <Innhold>
                <InnstillingerWrapper>
                    <InnstillingerTekst>Innstillinger for graf</InnstillingerTekst>
                    <Tekst $nomargin={true} $størrelse={"M"}>
                        {grafKategori === GrafKategori.hastighet ||
                            (grafKategori === GrafKategori.dosering &&
                                "Verdiene viser gjennomsnitt per minutt.")}
                    </Tekst>
                    <Tekst $nomargin={true} $størrelse={"M"}>
                        Du kan legge inn referanseverdier i grafen for å lett kunne se om verdiene
                        er over eller under standarene.
                    </Tekst>
                </InnstillingerWrapper>
                {children}
            </Innhold>
        </GrafvalgContainer>
    );
};

const GrafvalgContainer = styled.div`
    display: flex;
    flex-direction: column;
    width: 100%;
    background-color: var(--gray-light);
    height: fit-content;
    padding-bottom: 10px;
`;

const Innhold = styled.div`
    display: flex;
    flex-direction: column;
    padding: 30px;
    gap: 20px;
`;

const InnstillingerTekst = styled(Tekst).attrs(() => ({
    størrelse: "M",
    $nomargin: true,
    $bold: true,
}))`
    border-bottom: 2px solid var(--orange);
    width: fit-content;
    margin-top: 10px;
`;

export const ValgContainer = styled.div`
    display: flex;
    flex-direction: row;
    justify-content: flex-start;
    gap: 40px;
    flex-wrap: wrap;
`;

const InnstillingerWrapper = styled.div`
    display: flex;
    flex-direction: column;
    gap: 5px;
`;
