import { FormLabel } from "../fellesKomponenter/inputfelt/FormLabel";
import { Inputfelt } from "../fellesKomponenter/inputfelt/Inputfelt";
import { KnappPrimær } from "../fellesKomponenter/knapper/KnappPrimær";
import { KnappSekundær } from "../fellesKomponenter/knapper/KnappSekundær";
import { Trekkspill } from "../fellesKomponenter/trekkspill/Trekkspill";
import React, { useState } from "react";
import styled from "styled-components";
import { erGyldigNumeriskInput } from "../../utils/inputValidering";
import { useCloseOnOutsideClick } from "../../hooks/useCloseOnOutsideClick";
import {
    fontsizeLargeScreen,
    fontsizeSmallScreen,
} from "../fellesKomponenter/typografi/TekstStyles";
import { breakpointNettbrett } from "../../utils/constants";
import { useAtomValue, useSetAtom } from "jotai";
import {
    aktivGrafTypeAtom,
    GrafKategori,
    reflinjeIKartAtom,
} from "../../øktdetaljerSide/jotai/atoms";
import {
    GrafvalgLoggEvent,
    loggEventMedTabellnavnOgVerdi,
    TabellNavn,
} from "../../utils/loggFrontend";
import { TrekkspillInnhold } from "../../øktdetaljerSide/grafer/referanselinjeUtils";
import { ColumnWrapperValg } from "./styles";

interface ReferanselinjeValgProps {
    trekkspillInnhold: TrekkspillInnhold[];
}
export const ReferanselinjeValg = ({ trekkspillInnhold }: ReferanselinjeValgProps) => {
    const setReflinjeIKart = useSetAtom(reflinjeIKartAtom);
    const [trekkspillOpen, setTrekkspillOpen] = useState<boolean>(false);
    const [reflinjeInput, setReflinjeInput] = useState<string>("");
    const [error, setError] = useState<boolean>(false);
    const [aktivtTrekkspillElement, setAktivtTrekkspillElement] = useState<
        TrekkspillInnhold | undefined
    >(undefined);
    const aktivGraf = useAtomValue(aktivGrafTypeAtom);

    const handleSubmit = () => {
        const gyldigInput = erGyldigNumeriskInput(reflinjeInput);
        setError(!gyldigInput);
        if (gyldigInput) {
            setReflinjeIKart(parseFloat(reflinjeInput.replaceAll(",", ".")));
            if (
                trekkspillInnhold[0].grafKategori === GrafKategori.hastighet ||
                trekkspillInnhold[0].grafKategori === GrafKategori.dosering
            ) {
                loggEventMedTabellnavnOgVerdi(
                    TabellNavn.grafvalgØkt,
                    GrafvalgLoggEvent.grenseverdi + " " + aktivGraf,
                    reflinjeInput,
                );
            } else {
                loggEventMedTabellnavnOgVerdi(
                    TabellNavn.grafvalgFriksjon,
                    GrafvalgLoggEvent.grenseverdi,
                    reflinjeInput,
                );
            }
        }
    };
    const nullstillReflinje = () => {
        setReflinjeInput("");
        setError(false);
        setAktivtTrekkspillElement(undefined);
        setReflinjeIKart(undefined);
    };

    const handleTrekspillKlikk = (element: TrekkspillInnhold) => {
        setReflinjeIKart(element.verdi);
        setAktivtTrekkspillElement(element);
        setReflinjeInput("");
        setError(false);
        setTrekkspillOpen(false);
        if (
            element.grafKategori === GrafKategori.dosering ||
            element.grafKategori === GrafKategori.hastighet
        ) {
            loggEventMedTabellnavnOgVerdi(
                TabellNavn.grafvalgØkt,
                GrafvalgLoggEvent.standardgrenseverdi,
                element.tittel,
            );
        } else {
            loggEventMedTabellnavnOgVerdi(
                TabellNavn.grafvalgFriksjon,
                GrafvalgLoggEvent.standardgrenseverdi,
                element.tittel,
            );
        }
    };
    useCloseOnOutsideClick("reflinjeTrekkspill", () => setTrekkspillOpen(false));

    return (
        <>
            <ColumnWrapperValg>
                <FormLabel htmlFor="referanselinjeInput">Skriv inn grenseverdi</FormLabel>
                <RowWrapper>
                    <ColumnWrapperValg>
                        <Inputfelt
                            $error={error}
                            type="text"
                            id="referanselinjeInput"
                            $størrelse="S"
                            onChange={(e) => setReflinjeInput(e.target.value)}
                            value={reflinjeInput}
                            pattern={"([0-9]*[.]*[,])?[0-9]+"}
                        />
                        {error && <ErrorMelding>Skriv inn et tall</ErrorMelding>}
                    </ColumnWrapperValg>

                    <KnappPrimær size={"Small"} onClick={handleSubmit}>
                        Ok
                    </KnappPrimær>
                    <KnappSekundær size={"Small"} onClick={() => nullstillReflinje()}>
                        Nullstill
                    </KnappSekundær>
                </RowWrapper>
            </ColumnWrapperValg>
            <ColumnWrapperValg id={"reflinjeTrekkspill"}>
                <FormLabel htmlFor="referanselinje">Velg standarisert grenseverdi</FormLabel>
                <Trekkspill
                    åpen={trekkspillOpen}
                    tittel={
                        aktivtTrekkspillElement
                            ? aktivtTrekkspillElement.tittel
                            : "Velg standarisert grenseverdi"
                    }
                    type={"Ramme"}
                    onClick={() => setTrekkspillOpen(!trekkspillOpen)}
                    width="300px"
                    størrelse={"M"}
                >
                    <Innhold>
                        {trekkspillInnhold.map((element, index) => (
                            <TrekkspillElementKnapp
                                key={index}
                                onClick={() => {
                                    handleTrekspillKlikk(element);
                                }}
                            >
                                {element.tittel}
                            </TrekkspillElementKnapp>
                        ))}
                    </Innhold>
                </Trekkspill>
            </ColumnWrapperValg>
        </>
    );
};

const Innhold = styled.div`
    background-color: var(--white);
    padding: 0 1rem;
    margin-bottom: 0.5rem;
    margin-top: 0.5rem;
    display: flex;
    flex-direction: column;

    @media (pointer: coarse) {
        gap: 12px;
    }
`;

const TrekkspillElementKnapp = styled.button`
    background: var(--white);
    border: none;
    cursor: pointer;
    ${fontsizeLargeScreen};
    padding: 4px 8px 4px 8px;
    text-align: left;
    width: 100%;
    color: var(--gray-dark);

    &:hover {
        background-color: #f2f2f2;
    }

    @media (max-width: ${breakpointNettbrett}) {
        ${fontsizeSmallScreen};
    }
`;

const RowWrapper = styled.div`
    display: flex;
    flex-direction: row;
    gap: 0.5rem;
    align-items: flex-start;
`;

export const ErrorMelding = styled.p`
    color: var(--gray-dark);
    margin: 0 0 0 0;
    max-width: 120px;
    position: relative;
    background-color: var(--red-bg);
    padding: 2px;
`;
