import dayjs from "dayjs";
import { GrafType } from "../../øktdetaljerSide/jotai/atoms";

export const hentTicksXaxis = (startTid: dayjs.Dayjs, sluttTid: dayjs.Dayjs) => {
    const varighetMinutter = sluttTid.diff(startTid, "minute");
    const maksAntallIntervaller = 20;
    const minsteIntervall = varighetMinutter < 20 ? 1 : 5;
    const intervallStørrelseMinutter =
        Math.ceil(varighetMinutter / maksAntallIntervaller / minsteIntervall) * minsteIntervall;
    const startidRundetOppTilIntervall =
        Math.ceil(startTid.minute() / minsteIntervall) * minsteIntervall;
    const diffStarttid = startidRundetOppTilIntervall - startTid.minute();

    const intervaller = [];
    for (let i = 0; i < maksAntallIntervaller; i++) {
        const nyttIntervall = startTid.add(diffStarttid + intervallStørrelseMinutter * i, "minute");
        const erFørSluttTid = nyttIntervall.isBefore(sluttTid);
        erFørSluttTid && intervaller.push(nyttIntervall.valueOf());
    }
    return intervaller;
};

export const hentYAxisLabel = (dataKey: GrafType, doseringsBenevning?: string) => {
    switch (dataKey) {
        case GrafType.hastighet:
            return "Hastighet (km/t)";
        case GrafType.dosering:
            return `Dosering (${doseringsBenevning})`;
        case GrafType.sprederbredde:
            return "Sprederbredde (cm)";
        case GrafType.friksjon:
            return "Friksjon (µ)";
        case GrafType.temperatur:
            return "Temperatur (°C)";
    }
};
export const hentGraftittel = (dataKey: GrafType) => {
    switch (dataKey) {
        case GrafType.hastighet:
            return "Gjennomsnittshastighet";
        case GrafType.dosering:
            return "Dosering";
        case GrafType.sprederbredde:
            return "Sprederbredde";
        case GrafType.friksjon:
            return "Friksjon";
        case GrafType.temperatur:
            return "Temperatur";
    }
};
export const lagArrayMedInkrementer = (lengde: number, inkrement: number, start?: number) => {
    return Array.from({ length: lengde }, (_, i) => (start ?? 0) + i * inkrement);
};

export const hentReflinjeBenevning = (dataKey: GrafType, doseringsBenevning?: string) => {
    switch (dataKey) {
        case GrafType.hastighet:
            return " km/t";
        case GrafType.dosering:
            return ` ${doseringsBenevning}`;
        case GrafType.sprederbredde:
            return " cm";
        case GrafType.friksjon:
            return " µ";
        case GrafType.temperatur:
            return " °C";
    }
};
