import { Side, sideInfo } from "../../sider";
import { Burgermeny } from "../burgermeny/Burgermeny";
import { BurgermenyEksternLenke, Burgermenylenke } from "../burgermeny/BurgermenyLenker";
import { Burgermenyknapp } from "../burgermeny/Burgermenyknapp";
import {
    AuthenticationStatus,
    authenticationStatusAtom,
    authenticationStore,
} from "../../api/context/InitAuthentication";
import { useSetAtom } from "jotai";
import { visKartintroAtom } from "../../kartSide/jotai/karvalgAtoms";
import { loggEventMedTabellnavn, TabellNavn } from "../../utils/loggFrontend";

interface BurgermenyVisningProps {
    side: Side;
}

export const BurgermenyVisning = ({ side }: BurgermenyVisningProps) => {
    const setStatus = useSetAtom(authenticationStatusAtom, { store: authenticationStore });
    const setVisKartintro = useSetAtom(visKartintroAtom);

    return (
        <Burgermeny>
            {Object.entries(sideInfo).map(
                (entry) =>
                    entry[0] !== side && (
                        <Burgermenylenke
                            key={entry[0]}
                            href={entry[1].href}
                            ikonUrl={entry[1].ikonUrl}
                            tekst={entry[1].navn}
                        />
                    ),
            )}

            {side === "produksjonskart" && (
                <Burgermenyknapp
                    onClick={() => {
                        setVisKartintro((prev) => !prev);
                        loggEventMedTabellnavn(TabellNavn.burgermenyTrykk, "Om kartet");
                    }}
                    ikonUrl="/ikon/hjelpetekst.svg"
                    tekst="Om kartet"
                />
            )}

            <BurgermenyEksternLenke
                href={
                    "https://teams.microsoft.com/l/channel/19%3a92e5e5f079524cf3a08309ade5a454f3%40thread.tacv2/Oppdateringer?groupId=ba4d81c4-9300-4114-977e-a32631c19af1&tenantId=38856954-ed55-49f7-8bdd-738ffbbfd390"
                }
                ikonUrl="/ikon/bjelle.svg"
                tekst={"Siste nytt"}
            />

            <Burgermenyknapp
                onClick={() => {
                    setStatus(AuthenticationStatus.LoggerUt);
                    loggEventMedTabellnavn(TabellNavn.burgermenyTrykk, "Logg ut");
                }}
                ikonUrl="/ikon/loggut.svg"
                tekst="Logg ut"
            />
        </Burgermeny>
    );
};
