import { TilbakeLenke } from "../fellesKomponenter/lenker/TilbakeLenke";
import { Heading } from "../fellesKomponenter/typografi/Heading";
import { Side, sideInfo } from "../../sider";
import { Kontraktvelger } from "../../kartSide/kontraktvelger/Kontraktvelger";
import { BurgermenyVisning } from "./BurgermenyVisning";
import styled from "styled-components";
import { useAtomValue } from "jotai";
import { kontraktFinnesAtom } from "../../api/context/kontraktAtoms";

export interface SideHeaderProps {
    side: Side;
    tilbakeHref?: string;
}
export const SideHeader = ({ side, tilbakeHref }: SideHeaderProps) => {
    const kontraktFinnes = useAtomValue(kontraktFinnesAtom);
    const tittel = sideInfo[side].beskrivelse;

    return (
        <Container>
            <InnholdContainer>
                <TilbakeLenke href={tilbakeHref} />
                <TittelWrapper>
                    <Heading as={"h1"} $stylelevel={"3"}>
                        {tittel}
                    </Heading>
                </TittelWrapper>
                {side === "produksjonskart" && kontraktFinnes && <Kontraktvelger />}
            </InnholdContainer>
            <BurgerContainer>
                <BurgermenyVisning side={side} />
            </BurgerContainer>
        </Container>
    );
};

const Container = styled.div`
    min-height: fit-content;
    display: flex;
    justify-content: space-between;
    align-items: flex-start;
`;

const InnholdContainer = styled.div`
    align-items: center;
    display: flex;
    flex-grow: 1;
    gap: 1rem;
    margin: 16px 24px;
    justify-content: space-between;
    flex-wrap: wrap;
`;

const BurgerContainer = styled.div`
    align-items: center;
    display: flex;
    margin: 16px 24px 16px 0;
`;

const TittelWrapper = styled.div`
    display: flex;
    gap: 2rem;
    margin-top: 4px;
    justify-content: center;
    flex-grow: 1;
    flex-wrap: nowrap;
`;
