"use client";
import { EksterntLenkeKort } from "./navigasjon/EksterntLenkeKort";
import styled from "styled-components";
import portalLenker from "./tekst/portal-lenker.json";
import { OmKos } from "./OmKos";
import { InterntLenkeKort } from "./navigasjon/InterntLenkeKort";
import React, { useEffect, useState } from "react";
import { DriftsportalHeader } from "./DriftsportalHeader";
import { sideInfo } from "../sider";
import { AuthenticationWrapper } from "../components/AuthenticationWrapper";
import { Heading } from "../components/fellesKomponenter/typografi/Heading";
import ErrorBoundary from "../components/feil/ErrorBoundary";
import { breakpointNettbrett } from "../utils/constants";
import { favorittLenkerAtom } from "./jotai/atoms";
import { useAtom } from "jotai";
import {
    FrontendLoggEvent,
    loggEventMedTabellnavn,
    loggEventMedTabellnavnOgVerdi,
    loggFrontendEvent,
    loggNettbrett,
    loggSkjermstørrelse,
    Sider,
    TabellNavn,
} from "../utils/loggFrontend";

export const DriftsportalSide = () => {
    const [favorittLenker, settFavorittLenker] = useAtom(favorittLenkerAtom);
    const [valgtFilter, setValgtFilter] = useState<"Alle" | "Drift" | "Elektro" | "Vedlikehold">(
        "Alle",
    );

    useEffect(() => {
        loggFrontendEvent(FrontendLoggEvent.driftsportalInnlasting);
        loggSkjermstørrelse(window, Sider.driftsportal);
        loggNettbrett(Sider.driftsportal);
    }, []);

    const håndterFavorittLenkeKlikk = (lenkeTittel: string, erLenkeFavoritt: boolean) => {
        const nyFavorittliste = erLenkeFavoritt
            ? favorittLenker.filter((favoritt) => favoritt !== lenkeTittel)
            : [...favorittLenker, lenkeTittel];
        settFavorittLenker(nyFavorittliste);
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.driftsportalfavoritt,
            lenkeTittel,
            !erLenkeFavoritt ? "På" : "Av",
        );
    };

    return (
        <ErrorBoundary info={`side: Driftsportalen`}>
            <AuthenticationWrapper>
                <DriftsportalHeader />
                <Innhold>
                    <Snarveier>
                        <InterntLenkeKort
                            lenke={sideInfo.produksjonskart.href}
                            tekst={sideInfo.produksjonskart.beskrivelse}
                            ikonPath={sideInfo.produksjonskart.ikonUrl}
                            loggKlikk={() =>
                                loggEventMedTabellnavn(
                                    TabellNavn.driftsportalkortlenkeKlikk,
                                    sideInfo.produksjonskart.beskrivelse,
                                )
                            }
                        />
                        <InterntLenkeKort
                            lenke={sideInfo.øktdetaljer.href}
                            tekst={sideInfo.øktdetaljer.beskrivelse}
                            ikonPath={sideInfo.øktdetaljer.ikonUrl}
                            loggKlikk={() =>
                                loggEventMedTabellnavn(
                                    TabellNavn.driftsportalkortlenkeKlikk,
                                    sideInfo.øktdetaljer.beskrivelse,
                                )
                            }
                        />
                        <InterntLenkeKort
                            lenke={sideInfo.webkamera.href}
                            tekst={sideInfo.webkamera.beskrivelse}
                            ikonPath={sideInfo.webkamera.ikonUrl}
                            loggKlikk={() =>
                                loggEventMedTabellnavn(
                                    TabellNavn.driftsportalkortlenkeKlikk,
                                    sideInfo.webkamera.beskrivelse,
                                )
                            }
                        />
                        <InterntLenkeKort
                            lenke={sideInfo.friksjonsdashboard.href}
                            tekst={sideInfo.friksjonsdashboard.beskrivelse}
                            ikonPath={sideInfo.friksjonsdashboard.ikonUrl}
                            loggKlikk={() =>
                                loggEventMedTabellnavn(
                                    TabellNavn.driftsportalkortlenkeKlikk,
                                    sideInfo.friksjonsdashboard.beskrivelse,
                                )
                            }
                        />
                    </Snarveier>{" "}
                    {favorittLenker.length > 0 && (
                        <>
                            <Heading as="h2" $stylelevel={"2"}>
                                Favoritter
                            </Heading>
                            <Lenkeliste aria-label="Nyttige lenker">
                                {portalLenker
                                    .sort((lenke1, lenke2) =>
                                        lenke1.tittel < lenke2.tittel ? -1 : 1,
                                    )
                                    .filter((lenke) => favorittLenker.includes(lenke.tittel))
                                    .map((lenke, index) => (
                                        <EksterntLenkeKort
                                            tittel={lenke.tittel}
                                            lenke={lenke.lenke}
                                            key={index}
                                            ingress={lenke.tekst}
                                            erFavoritt={favorittLenker.includes(lenke.tittel)}
                                            håndterFavorittKlikket={håndterFavorittLenkeKlikk}
                                            dato={lenke.dato}
                                        />
                                    ))}
                            </Lenkeliste>
                            <Heading as="h2" $stylelevel={"2"}>
                                Alle lenker
                            </Heading>
                        </>
                    )}
                    <>
                        <ToggleButtonGroup>
                            <ToggleButton
                                $ervalgt={valgtFilter == "Alle"}
                                onClick={() => setValgtFilter("Alle")}
                            >
                                Alle
                            </ToggleButton>
                            <ToggleButton
                                $ervalgt={valgtFilter == "Drift"}
                                onClick={() => setValgtFilter("Drift")}
                            >
                                Drift
                            </ToggleButton>
                            <ToggleButton
                                $ervalgt={valgtFilter == "Elektro"}
                                onClick={() => setValgtFilter("Elektro")}
                            >
                                Elektro
                            </ToggleButton>
                            <ToggleButton
                                $ervalgt={valgtFilter == "Vedlikehold"}
                                onClick={() => setValgtFilter("Vedlikehold")}
                            >
                                Vedlikehold
                            </ToggleButton>
                        </ToggleButtonGroup>

                        <Lenkeliste aria-label="Nyttige lenker">
                            {portalLenker
                                .sort((lenke1, lenke2) => (lenke1.tittel < lenke2.tittel ? -1 : 1))
                                .filter((lenke) => {
                                    if (valgtFilter === "Elektro") {
                                        return lenke.elektro === "true";
                                    } else if (valgtFilter === "Drift") {
                                        return lenke.drift === "true";
                                    } else if (valgtFilter === "Vedlikehold") {
                                        return lenke.vedlikehold === "true";
                                    } else {
                                        return true;
                                    }
                                })
                                .map((lenke, index) => (
                                    <EksterntLenkeKort
                                        tittel={lenke.tittel}
                                        lenke={lenke.lenke}
                                        key={index}
                                        ingress={lenke.tekst}
                                        erFavoritt={favorittLenker.includes(lenke.tittel)}
                                        håndterFavorittKlikket={håndterFavorittLenkeKlikk}
                                        dato={lenke.dato}
                                    />
                                ))}
                        </Lenkeliste>
                        <OmKos />
                        <Padding />
                    </>
                </Innhold>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Innhold = styled.main`
    margin: auto;
    display: flex;
    flex-direction: column;
    gap: 2rem;
    max-width: 100rem;
    padding: 0 2rem;

    @media (max-width: ${breakpointNettbrett}) {
        padding: 0 1rem;
    }
`;

const Lenkeliste = styled.ul`
    display: flex;
    flex-wrap: wrap;
    list-style: none;
    padding: 0;
    gap: 1.5rem;
    column-gap: 1.5rem;
`;

const Snarveier = styled.ul`
    list-style: none;
    display: flex;
    gap: 1.5rem;
    padding: 0;
    flex-wrap: wrap;
    flex-direction: row;
`;

const ToggleButtonGroup = styled.div`
    border-radius: 0.5rem;
    border: 1px solid #858d90ff;
    background: var(--white);
    padding: 0.5rem;
    grid-auto-columns: 1fr;
    grid-auto-flow: column;
    display: inline-grid;
    gap: 1rem;
    width: 500px;

    @media (min-width: 768px) {
        body {
            font-size: 1.125rem;
            line-height: 1.6875rem;
        }
    }
`;

const ToggleButton = styled.div<{ $ervalgt: boolean }>`
    padding: 0.75rem 1.5rem;
    font-size: 1rem;
    line-height: 1.5rem;
    color: #444f55ff;
    text-align: center;
    cursor: pointer;
    font-weight: 600;
    max-width: 100%;
    border: 1px solid transparent;
    border-radius: 0.5rem;
    background-color: transparent;
    outline: none;
    justify-content: center;
    align-items: center;
    display: flex;
    position: relative;

    &:active {
        background-color: #ecececff;
        border: 1px solid #231f20ff;
        box-shadow: 0 0 0 2px #231f20ff;
    }

    ${(props) =>
        props.$ervalgt
            ? `
        background-color: var(--white);
        border: 1px solid #231f20ff;
        box-shadow: 0 0 0 2px #231f20ff;
        `
            : `    
        &:hover {
            box-shadow: 0 0 0 1px #231f20ff;
        }
        `}
`;

const Padding = styled.div`
    margin-bottom: 2rem;
`;
