import styled from "styled-components";
import { Kortlenke } from "./Kortlenke";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import React from "react";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { breakpointNettbrett } from "../../utils/constants";
import { loggEventMedTabellnavn, TabellNavn } from "../../utils/loggFrontend";
import dayjs from "dayjs";

interface EksterntLenkeKortProps {
    tittel: string;
    lenke: string;
    ingress: string;
    erFavoritt: boolean;
    håndterFavorittKlikket: (linkTittel: string, erFavoritt: boolean) => void;
    dato: string | undefined;
}

export const EksterntLenkeKort = ({
    tittel,
    lenke,
    ingress,
    erFavoritt,
    håndterFavorittKlikket,
    dato,
}: EksterntLenkeKortProps) => {
    const handleLenkeKlikk = () => {
        loggEventMedTabellnavn(TabellNavn.driftsportalkortlenkeKlikk, tittel);
    };
    const erNy = dato ? dayjs(dato).add(15, "day").isAfter(dayjs()) : false;

    return (
        <ListeElement>
            <Kortlenke href={lenke} target={"_blank"} rel={"noreferrer"} onClick={handleLenkeKlikk}>
                <TittelWrapper>
                    <Heading $stylelevel="4" as="h2">
                        {tittel}
                    </Heading>
                    <NyOgStjerneWrapper>
                        {erNy && <NyTag $størrelse={"S"}>Ny</NyTag>}
                        <FavorittIkon
                            $favoritt={erFavoritt}
                            onClick={(event) => {
                                event.preventDefault();
                                håndterFavorittKlikket(tittel, erFavoritt);
                            }}
                        />
                    </NyOgStjerneWrapper>
                </TittelWrapper>
                {ingress && <Tekst>{ingress}</Tekst>}
            </Kortlenke>
        </ListeElement>
    );
};

const ListeElement = styled.li`
    box-sizing: border-box;
    min-width: 17.5rem;
    width: 100%;

    @media (min-width: ${breakpointNettbrett}) {
        min-height: 9rem;
        width: 48%;
    }

    @media (min-width: 1024px) {
        min-height: 10rem;
        width: 31%;
    }
`;

const TittelWrapper = styled.div`
    flex-shrink: 0;
    display: flex;
    justify-content: space-between;
`;

const NyOgStjerneWrapper = styled.div`
    display: flex;
    align-items: center;
`;

const FavorittIkon = styled.i<{ $favoritt?: boolean }>`
    width: 22px;
    height: 22px;
    background: url(${(props) =>
            props.$favoritt ? "/ikon/favoritt_valgt.svg" : "/ikon/favoritt.svg"})
        no-repeat;
    background-size: contain;
    flex-shrink: 0;

    &:hover {
        background-image: url("/ikon/favoritt_hover.svg");
        cursor: pointer;
        scale: 1.2;
    }
`;

const NyTag = styled(Tekst)`
    margin: 0 0.5rem;
    background-color: var(--orange);
    color: var(--white);
    padding: 0.25rem 0.5rem;
    border-radius: 0.25rem;
    height: 20px;
`;
