"use client";

import React from "react";
import styled from "styled-components";
import { SideHeader } from "../components/sideheader/SideHeader";
import { friksjonsdataDtoTilFriksjonsdata, useHentFriksjondata } from "../api/useHentFriksjonsdata";
import ErrorBoundary from "../components/feil/ErrorBoundary";
import { AuthenticationWrapper } from "../components/AuthenticationWrapper";
import { Feil, FetchStatus } from "../api/api";
import BrøytebilSpinner from "../kartSide/brøytebilSpinner/BrøytebilSpinner";
import { KartvisningFeil } from "../kartSide/feil/KartvisningFeil";
import { hentFeil } from "../kartSide/utils/kartSideUtils";
import { FriksjonsdashboardVisning } from "./FriksjonsdashboardVisning";
import { sideInfo } from "../sider";

interface FriksjonsdashboardSideProps {
    id: string;
}

export const FriksjonsdashboardSide = ({ id }: FriksjonsdashboardSideProps) => {
    const friksjonsdataDto = useHentFriksjondata(id);

    return (
        <ErrorBoundary info="Feil i friksjonsdashboardsiden, side: Friksjonsdashboard">
            <AuthenticationWrapper>
                <Container>
                    <SideHeader
                        side={"friksjonsdashboard"}
                        tilbakeHref={sideInfo.friksjonsdashboard.href}
                    />
                    {!friksjonsdataDto ? (
                        <BrøytebilSpinner />
                    ) : friksjonsdataDto.status === FetchStatus.Feil ? (
                        <KartvisningFeil
                            feilmeldinger={hentFeil(
                                [friksjonsdataDto].filter(
                                    (respons) => respons?.status === "Feil",
                                ) as Feil[],
                            )}
                        />
                    ) : (
                        <FriksjonsdashboardVisning
                            friksjonsdata={friksjonsdataDtoTilFriksjonsdata(friksjonsdataDto.data)}
                        />
                    )}
                </Container>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Container = styled.div`
    margin: 20px 20px 100px 20px;
    background-color: var(--white);
`;
