"use client";

import React, { useEffect, useRef } from "react";
import { Friksjonsdata } from "./friksjonsmålingTyper";
import dynamic from "next/dynamic";
import { Spinner } from "../components/fellesKomponenter/spinner/Spinner";
import styled from "styled-components";
import { breakpointNettbrett } from "../utils/constants";
import { FriksjonskartProps } from "./Friksjonskart";
import { useAtom } from "jotai";
import { FriksjonsmålingTabell } from "./FriksjonsmålingTabell";
import { RowWrapper } from "../components/fellesKomponenter/wrappers/wrappers";
import { FriksjonsmålingMetadataPanel } from "./FriksjonsmålingMetadataPanel";
import { Friksjonsgraf } from "./grafer/Friksjonsgraf";
import { UnderArbeidMelding } from "./UnderArbeidMelding";
import { aktivGrafTypeAtom, GrafType } from "../øktdetaljerSide/jotai/atoms";
import { Temperaturgraf } from "./grafer/Temperaturgraf";
import { Tekst } from "../components/fellesKomponenter/typografi/Tekst";
import { KnappSekundær } from "../components/fellesKomponenter/knapper/KnappSekundær";

interface FriksjonsdashboardVisningProps {
    friksjonsdata: Friksjonsdata;
}

export const FriksjonsdashboardVisning = ({ friksjonsdata }: FriksjonsdashboardVisningProps) => {
    const [graftype, setGraftype] = useAtom(aktivGrafTypeAtom);

    useEffect(() => {
        setGraftype(GrafType.friksjon);
    }, []);

    const kartvisningContainerRef = useRef<any>(null);

    return (
        <>
            <UnderArbeidMelding />
            <GrafdataContainer>
                <MetadataContainer>
                    <Tekst $størrelse={"M"} $nomargin={true} $bold={true}>
                        Metadata
                    </Tekst>
                    <FriksjonsmålingMetadataPanel friksjonsdataMetadata={friksjonsdata.metadata} />
                </MetadataContainer>
                <PunktdatakartContainer>
                    <RowWrapper>
                        <KartvisningContainer ref={kartvisningContainerRef}>
                            <DynamicKartvisning
                                friksjonsmålinger={friksjonsdata.friksjonsmålinger.sort(
                                    (a, b) => a.tid - b.tid,
                                )}
                                containerRef={kartvisningContainerRef}
                            />
                        </KartvisningContainer>
                        <Panel>
                            <FriksjonsmålingTabell startDato={friksjonsdata.metadata?.dato} />
                        </Panel>
                    </RowWrapper>
                    <>
                        <GrafContainer>
                            {graftype === GrafType.friksjon && (
                                <Friksjonsgraf
                                    friksjonsmålinger={friksjonsdata.friksjonsmålinger}
                                    startDato={friksjonsdata.metadata?.dato}
                                />
                            )}
                            {graftype === GrafType.temperatur && (
                                <Temperaturgraf
                                    friksjonsmålinger={friksjonsdata.friksjonsmålinger}
                                    startDato={friksjonsdata.metadata?.dato}
                                />
                            )}
                        </GrafContainer>
                    </>
                </PunktdatakartContainer>
            </GrafdataContainer>
        </>
    );
};

const DynamicKartvisning = dynamic<FriksjonskartProps>(
    () => import("./Friksjonskart").then((mod) => mod.Friksjonskart),
    {
        loading: () => <Spinner />,
        ssr: false,
    },
);

const KartvisningContainer = styled.div`
    height: 400px;
    width: 65%;
    @media (max-width: ${breakpointNettbrett}) {
        width: 100%;
    }
`;

const Panel = styled.div`
    width: 35%;
    background-color: var(--gray-light);
    padding: 20px;
    gap: 10px;
    height: 360px;
    overflow: auto;

    @media (max-width: ${breakpointNettbrett}) {
        width: 100%;
    }
`;

const PunktdatakartContainer = styled.div`
    @media (min-width: 1280px) {
        width: 70%;
    }
`;

const GrafdataContainer = styled.div`
    display: flex;
    flex-direction: column;
    gap: 10px;

    @media (min-width: 1280px) {
        flex-direction: row;
    }
`;

const GrafContainer = styled.div`
    display: flex;
    flex-direction: column;
    width: 100%;
    margin: 20px 0;
`;

const MetadataContainer = styled.div`
    padding: 15px;
    background-color: var(--gray-light);
    @media (min-width: 1280px) {
        width: 30%;
    }
`;
