import styled from "styled-components";
import { useAtomValue } from "jotai/index";
import { Dayjs } from "dayjs";
import { tilNorskTimestamp } from "../utils/tid";
import { Tekst } from "../components/fellesKomponenter/typografi/Tekst";
import { aktivFriksjonsmålingAtom } from "./jotai/atoms";

interface FriksjonsmålingTabellProps {
    startDato?: Dayjs;
}
export const FriksjonsmålingTabell = ({ startDato }: FriksjonsmålingTabellProps) => {
    const friksjonsmåling = useAtomValue(aktivFriksjonsmålingAtom);
    return (
        <>
            <Tekst $størrelse={"M"} $nomargin={true} $bold={true}>
                Data fra valgt punkt
            </Tekst>
            {!friksjonsmåling && (
                <Tekst $størrelse={"M"} $nomargin={true}>
                    Trykk i kartet eller grafen for å velge et nytt datapunkt
                </Tekst>
            )}

            {friksjonsmåling && (
                <StyledTable>
                    <thead>
                        <StyledTableRow>
                            <StyledTh>Data</StyledTh>
                            <StyledTh>Verdi</StyledTh>
                        </StyledTableRow>
                    </thead>

                    <tbody>
                        <StyledTableRow>
                            <StyledTd>Dato og klokkeslett</StyledTd>
                            <StyledTd>
                                {friksjonsmåling?.tid &&
                                    startDato &&
                                    tilNorskTimestamp(startDato.add(friksjonsmåling?.tid, "ms"))}
                            </StyledTd>
                        </StyledTableRow>
                        {friksjonsmåling?.uM && (
                            <StyledTableRow>
                                <StyledTd>Friksjon (µ) midt</StyledTd>
                                <StyledTd>{friksjonsmåling.uM}</StyledTd>
                            </StyledTableRow>
                        )}
                        {friksjonsmåling?.uI && (
                            <StyledTableRow>
                                <StyledTd>Friksjon (µ) indre</StyledTd>
                                <StyledTd>{friksjonsmåling.uI}</StyledTd>
                            </StyledTableRow>
                        )}
                        {friksjonsmåling?.uY && (
                            <StyledTableRow>
                                <StyledTd>Friksjon (µ) ytre</StyledTd>
                                <StyledTd>{friksjonsmåling.uY}</StyledTd>
                            </StyledTableRow>
                        )}
                        <StyledTableRow>
                            <StyledTd>Lat og long</StyledTd>
                            <StyledTd>
                                {friksjonsmåling?.lat.toString()}, {friksjonsmåling?.lng.toString()}
                            </StyledTd>
                        </StyledTableRow>
                        <StyledTableRow>
                            <StyledTd>Vegsystemreferanse</StyledTd>
                            <StyledTd>{friksjonsmåling?.vegsystemreferanse}</StyledTd>
                        </StyledTableRow>
                        <StyledTableRow>
                            <StyledTd>Usikker</StyledTd>
                            <StyledTd>
                                {friksjonsmåling?.usikker.toString() === "false" ? "Nei" : "Ja"}
                            </StyledTd>
                        </StyledTableRow>
                        <StyledTableRow>
                            <StyledTd>Områdetemperatur</StyledTd>
                            <StyledTd>
                                {!friksjonsmåling?.omT ? (
                                    <i>Ingen måling</i>
                                ) : (
                                    friksjonsmåling?.omT?.toString()
                                )}
                            </StyledTd>
                        </StyledTableRow>
                        <StyledTableRow>
                            <StyledTd>Overflatetemperatur</StyledTd>
                            <StyledTd>
                                {!friksjonsmåling?.ovT ? (
                                    <i>Ingen måling</i>
                                ) : (
                                    friksjonsmåling?.ovT.toString()
                                )}
                            </StyledTd>
                        </StyledTableRow>
                    </tbody>
                </StyledTable>
            )}
        </>
    );
};

export const StyledTableRow = styled.tr`
    background-color: #ffffff;

    &:hover {
        background-color: #ddd;
    }
`;

export const StyledTd = styled.td`
    padding: 8px;
    border: 1px solid #ddd;
    text-align: left;
    font-size: 14px;
`;

export const StyledTh = styled.th`
    padding: 8px;
    border: 1px solid #ddd;
    border-bottom: 2px solid var(--orange);
    text-align: left;
    width: 50%;
    font-size: 14px;
`;

export const StyledTable = styled.table`
    border-collapse: collapse;
    width: 100%;
    max-width: 600px;
    margin-top: 10px;
`;
