"use client";

import { Friksjonsmåling } from "./friksjonsmålingTyper";
import { Feature, FeatureCollection } from "geojson";
import * as L from "leaflet";
import { LatLngBoundsExpression, Layer, LeafletMouseEvent } from "leaflet";
import { finnKartBoundsForKooridnater } from "../kartSide/Kartvisning/kartBoundsUtils";

const aktivMålepunktRadius = 10;
const målepunktRadius = 2;

export const mapFriksjonsmålingerTilKartdata = (målinger: Friksjonsmåling[]): FeatureCollection => {
    return {
        type: "FeatureCollection",
        features: målinger.reduce((features: Feature[], måling) => {
            if (måling.tid !== 0) {
                const feature = friksjonsmålingTilFeature(måling);
                features.push(feature);
            }
            return features;
        }, []),
    };
};

const friksjonsmålingTilFeature = (måling: Friksjonsmåling): Feature => {
    return {
        type: "Feature",
        properties: {
            måling: måling,
        },
        geometry: {
            type: "Point",
            coordinates: [måling.lng, måling.lat],
        },
        id: måling.tid.toString(),
    };
};

export const punktTilLayer = (
    feature: Feature,
    latlng: L.LatLng,
    aktivMålepunktTid?: number,
    aktivHoverRecord?: number,
) => {
    const måling = feature.properties!.måling as Friksjonsmåling;
    const friksjonMidt = måling.uM ?? 1;
    const friksjonHøyre = måling.uY ?? 1;
    const friksjonVenstre = måling.uI ?? 1;
    const farger = friksjonTilFargekode(friksjonHøyre, friksjonVenstre, friksjonMidt);

    const radius =
        aktivMålepunktTid === måling.tid || aktivHoverRecord === måling.tid
            ? aktivMålepunktRadius
            : målepunktRadius;

    return L.circleMarker(latlng, {
        radius: radius,
        color: farger,
        fillColor: farger,
        fillOpacity: 1,
    });
};

export enum FriksjonsFargekode {
    RØD = "#b7010a",
    ORANSJE = "#E35A29",
    GUL = "#f5e72b",
    GRØNN = "#29E329",
}

const friksjonTilFargekode = (friksjonH: number, friksjonV: number, friksjonM: number) => {
    const friksjon = Math.min(friksjonH, friksjonV, friksjonM);
    if (friksjon < 0.2) {
        return FriksjonsFargekode.RØD;
    } else if (friksjon < 0.25) {
        return FriksjonsFargekode.ORANSJE;
    } else if (friksjon < 0.3) {
        return FriksjonsFargekode.GUL;
    } else {
        return FriksjonsFargekode.GRØNN;
    }
};

export const onEachLenkeFeature = (
    feature: Feature | undefined,
    layer: Layer,
    handleOnClick: (friksjonsmåling: Friksjonsmåling) => void,
    aktivFriksjonsmåling: Friksjonsmåling | undefined,
) => {
    const onClick = (e: LeafletMouseEvent) => {
        handleOnClick(e.target.feature.properties.måling);
        e.target.setStyle({ radius: aktivMålepunktRadius });
    };
    const onHover = (e: LeafletMouseEvent) => {
        e.target.setStyle({ radius: aktivMålepunktRadius });
    };
    const onOut = (e: LeafletMouseEvent) => {
        const friksjonsmåling = e.target.feature.properties.måling as Friksjonsmåling;
        if (friksjonsmåling.tid === aktivFriksjonsmåling?.tid) {
            e.target.setStyle({ radius: aktivMålepunktRadius });
        } else {
            e.target.setStyle({ radius: målepunktRadius });
        }
    };
    layer.on({
        click: onClick,
        mouseover: onHover,
        mouseout: onOut,
    });
};

export const finnKartBounds = (målinger: Friksjonsmåling[]): LatLngBoundsExpression => {
    const defaultBounds: LatLngBoundsExpression = [
        [69, 12],
        [60, 10],
    ];
    const koordinater = målinger.map((måling) => [måling.lng, måling.lat]);
    return finnKartBoundsForKooridnater(koordinater) ?? defaultBounds;
};
