import { Friksjonsmåling } from "../friksjonsmålingTyper";
import { Dayjs } from "dayjs";
import React, { useEffect, useState } from "react";
import { FriksjonsgrafLegend } from "./FriksjonsgrafLegend";
import { FriksjonstyperVisning } from "../types";
import { GeneriskFriksjonsgraf } from "./GeneriskFriksjonsgraf";
import { GeneriskGrafvalg, ValgContainer } from "../../components/grafer/GeneriskGrafvalg";
import { AktivGrafValg } from "../../components/grafer/AktivGrafValg";
import { hentReferanserForFriksjon, hentTicksYaxisFriksjon } from "./friksjonsgrafUtils";
import { ReferanselinjeValg } from "../../components/grafer/ReferanselinjeValg";
import { Skillelinje } from "../../components/grafer/styles";

interface FriksjonsgrafProps {
    friksjonsmålinger: Friksjonsmåling[];
    startDato?: Dayjs;
}

export const Friksjonsgraf = ({ friksjonsmålinger, startDato }: FriksjonsgrafProps) => {
    const [dataKeysFriksjon, setDataKeysFriksjon] = useState<FriksjonstyperVisning[]>([]);
    const visMidtSpor = friksjonsmålinger[0]?.uM !== null;
    const visYtreSpor = friksjonsmålinger[0]?.uY !== null;
    const visIndreSpor = friksjonsmålinger[0]?.uI !== null;
    const visTemperatur = friksjonsmålinger[0]?.omT || friksjonsmålinger[0]?.ovT;
    const trekkspillInnhold = hentReferanserForFriksjon();

    useEffect(() => {
        setDataKeysFriksjon([
            {
                vis: visMidtSpor,
                finnes: visMidtSpor,
                color: "#003f5c",
                datakey: "uM",
                tittel: "Friksjon midt",
            },
            {
                vis: visYtreSpor,
                finnes: visYtreSpor,
                color: "#003f5c",
                datakey: "uY",
                tittel: "Friksjon ytre",
            },
            {
                vis: visIndreSpor,
                finnes: visIndreSpor,
                color: "#ffa600",
                datakey: "uI",
                tittel: "Friksjon indre",
            },
        ]);
    }, [friksjonsmålinger]);

    const customLegend = (
        <FriksjonsgrafLegend dataKeys={dataKeysFriksjon} setDataKeys={setDataKeysFriksjon} />
    );

    const tickArrayYaxis = hentTicksYaxisFriksjon(friksjonsmålinger);
    return (
        <>
            <GeneriskFriksjonsgraf
                grafdata={friksjonsmålinger}
                startDato={startDato}
                tickArrayYaxis={tickArrayYaxis}
                customLegend={customLegend}
                dataKeys={dataKeysFriksjon}
            />
            <GeneriskGrafvalg>
                <ValgContainer>
                    {visTemperatur && (
                        <>
                            <AktivGrafValg grafside={"friksjon"} />
                            <Skillelinje />
                        </>
                    )}
                    <ReferanselinjeValg trekkspillInnhold={trekkspillInnhold} />
                </ValgContainer>
            </GeneriskGrafvalg>
        </>
    );
};
