import { KnappUtenStyling } from "../../components/fellesKomponenter/knapper/KnappUtenStyling";
import React from "react";
import { FriksjonstyperVisning } from "../types";
import { LegendContainer, LegendItem } from "../../components/grafer/styles";
import {
    GrafvalgLoggEvent,
    loggEventMedTabellnavnOgVerdi,
    TabellNavn,
} from "../../utils/loggFrontend";

interface FriksjonsgrafLegendProps {
    dataKeys: FriksjonstyperVisning[];
    setDataKeys: (friksjonvisning: FriksjonstyperVisning[]) => void;
}

export const FriksjonsgrafLegend = ({ dataKeys, setDataKeys }: FriksjonsgrafLegendProps) => {
    const toggleVisning = (tittel: string) => {
        const newDataKeys: FriksjonstyperVisning[] = dataKeys.map((data) => {
            if (data.tittel === tittel) {
                return {
                    ...data,
                    vis: !data.vis,
                };
            } else {
                return { ...data };
            }
        });
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.grafvalgFriksjon,
            GrafvalgLoggEvent.filterForFriksjon,
            tittel,
        );
        setDataKeys(newDataKeys);
    };
    return (
        <LegendContainer>
            {dataKeys
                ?.filter((data) => data.finnes)
                .map((data, index) => (
                    <KnappUtenStyling
                        onClick={() => toggleVisning(data.tittel)}
                        key={`item-${index}`}
                    >
                        <LegendItem $color={data.color} $visible={data.vis}>
                            {data.tittel}
                        </LegendItem>
                    </KnappUtenStyling>
                ))}
        </LegendContainer>
    );
};
