import { Dayjs } from "dayjs";
import { TooltipProps } from "recharts";
import { NameType, ValueType } from "recharts/types/component/DefaultTooltipContent";
import styled from "styled-components";
import { GrafKategori } from "../../øktdetaljerSide/jotai/atoms";

interface CustomTooltip extends TooltipProps<ValueType, NameType> {
    startDato?: Dayjs;
    grafKategori: GrafKategori;
    setAktivHoverRecord: (record: number | undefined) => void;
}

export const FriksjonsgrafToolip = ({
    active,
    payload,
    startDato,
    setAktivHoverRecord,
    grafKategori,
}: CustomTooltip) => {
    const tid = payload && payload[0]?.payload.tid;
    const dato = startDato?.add(tid, "millisecond");
    active && payload && payload.length
        ? setAktivHoverRecord(payload[0].payload.tid)
        : setAktivHoverRecord(undefined);

    if (active && payload && payload.length) {
        return (
            <TooltipContainer>
                <p>{`Dato: ${dato && dato.format("DD.MM HH:mm")}`}</p>
                <p>{`Vegsystemreferanse: ${payload[0].payload.vegsystemreferanse}`}</p>
                {grafKategori === GrafKategori.friksjon ? (
                    <>
                        {payload[0].payload.uM && (
                            <p>{`Friksjon midt: ${payload[0].payload.uM}`}</p>
                        )}
                        {payload[0].payload.uI && (
                            <p>{`Friksjon indre: ${payload[0].payload.uI}`}</p>
                        )}
                        {payload[0].payload.uY && (
                            <p>{`Friksjon ytre: ${payload[0].payload.uY}`}</p>
                        )}
                    </>
                ) : (
                    <>
                        {payload[0].payload.omT && (
                            <p>{`Områdetemperatur: ${payload[0].payload.omT}`}</p>
                        )}
                        {payload[0].payload.ovT && (
                            <p>{`Overflatetemperatur: ${payload[0].payload.ovT}`}</p>
                        )}
                    </>
                )}
            </TooltipContainer>
        );
    }
    return null;
};

const TooltipContainer = styled.div`
    background-color: white;
    border: 1px solid black;
    padding: 10px;

    p {
        color: var(--gray-dark);
        margin: 0;
    }
`;
