import { Friksjonsmåling } from "../friksjonsmålingTyper";
import { Dayjs } from "dayjs";
import { GeneriskGraf } from "../../components/grafer/GeneriskGraf";
import { Line } from "recharts";
import React from "react";
import styled from "styled-components";
import { useAtomValue, useSetAtom } from "jotai/index";
import { FriksjonstyperVisning } from "../types";
import { aktivGrafKategoriAtom } from "../../øktdetaljerSide/jotai/atoms";
import { FriksjonsgrafToolip } from "./FriksjonsgrafTooltip";
import { aktivFriksjonsmålingAtom, aktivHoverRecordFriksjonAtom } from "../jotai/atoms";

interface GeneriskFriksjonsgrafProps {
    grafdata: Friksjonsmåling[];
    startDato?: Dayjs;
    tickArrayYaxis: number[];
    customLegend?: JSX.Element;
    dataKeys: FriksjonstyperVisning[];
}
export const GeneriskFriksjonsgraf = ({
    grafdata,
    startDato,
    tickArrayYaxis,
    customLegend,
    dataKeys,
}: GeneriskFriksjonsgrafProps) => {
    const grafKategori = useAtomValue(aktivGrafKategoriAtom);
    const setAktivFriksjonsmåling = useSetAtom(aktivFriksjonsmålingAtom);
    const setAktivHoverRecord = useSetAtom(aktivHoverRecordFriksjonAtom);

    if (startDato === undefined) {
        return;
    }
    const startTid = startDato.add(grafdata[0].tid, "ms");
    const sluttTid = startTid?.add(grafdata[grafdata.length - 1].tid, "ms");
    const dataKeyXaxis = (grafdata: Friksjonsmåling) => {
        return startDato.add(grafdata.tid, "ms").valueOf();
    };
    const customTooltip = (
        <FriksjonsgrafToolip
            startDato={startDato}
            grafKategori={grafKategori}
            setAktivHoverRecord={setAktivHoverRecord}
        />
    );

    return (
        <GrafContainer>
            {dataKeys.length > 0 && (
                <GeneriskGraf
                    tickArrayYaxis={tickArrayYaxis}
                    customTooltip={customTooltip}
                    customLegend={customLegend}
                    startTid={startTid}
                    sluttTid={sluttTid}
                    dataKeyXaxis={dataKeyXaxis}
                    setAktivFriksjonsmåling={setAktivFriksjonsmåling}
                >
                    <>
                        {grafdata.length > 0 &&
                            dataKeys
                                .filter((data) => data.vis)
                                .map((data, index) => (
                                    <Line
                                        key={"linje" + index}
                                        data={grafdata}
                                        type="monotone"
                                        dataKey={data.datakey}
                                        stroke={data.color}
                                        strokeWidth={2}
                                        dot={false}
                                        isAnimationActive={false}
                                        activeDot={{ r: 6 }}
                                        name={data.tittel}
                                    />
                                ))}
                    </>
                </GeneriskGraf>
            )}
        </GrafContainer>
    );
};

const GrafContainer = styled.div`
    margin-top: 20px;
`;
