import { Friksjonsmåling } from "../friksjonsmålingTyper";
import { Dayjs } from "dayjs";
import React, { useEffect, useState } from "react";
import { FriksjonsgrafLegend } from "./FriksjonsgrafLegend";
import { FriksjonstyperVisning } from "../types";
import { GeneriskFriksjonsgraf } from "./GeneriskFriksjonsgraf";
import { GeneriskGrafvalg, ValgContainer } from "../../components/grafer/GeneriskGrafvalg";
import { AktivGrafValg } from "../../components/grafer/AktivGrafValg";
import { Skillelinje } from "../../components/grafer/styles";
import { hentTicksYaxisTemperatur } from "./friksjonsgrafUtils";

interface FriksjonsgrafProps {
    friksjonsmålinger: Friksjonsmåling[];
    startDato?: Dayjs;
}

export const Temperaturgraf = ({ friksjonsmålinger, startDato }: FriksjonsgrafProps) => {
    const [dataKeysTemperatur, setDataKeysTemperatur] = useState<FriksjonstyperVisning[]>([]);
    const visOmråde = friksjonsmålinger[0]?.omT !== null;
    const visOverflate = friksjonsmålinger[0]?.ovT !== null;

    useEffect(() => {
        setDataKeysTemperatur([
            {
                vis: true,
                finnes: visOmråde,
                color: "#1D7721",
                datakey: "omT",
                tittel: "Områdetemperatur",
            },
            {
                vis: true,
                finnes: visOverflate,
                color: "#0E0099",
                datakey: "ovT",
                tittel: "Overflatetemperatur",
            },
        ]);
    }, [friksjonsmålinger]);

    const customLegend = (
        <FriksjonsgrafLegend dataKeys={dataKeysTemperatur} setDataKeys={setDataKeysTemperatur} />
    );
    const tickArrayYaxis = hentTicksYaxisTemperatur(friksjonsmålinger);

    return (
        <>
            <GeneriskFriksjonsgraf
                grafdata={friksjonsmålinger}
                startDato={startDato}
                tickArrayYaxis={tickArrayYaxis}
                customLegend={customLegend}
                dataKeys={dataKeysTemperatur}
            />
            <GeneriskGrafvalg>
                <ValgContainer>
                    <AktivGrafValg grafside={"friksjon"} />
                    <Skillelinje />
                </ValgContainer>
            </GeneriskGrafvalg>
        </>
    );
};
