import { Datofelt } from "../../components/fellesKomponenter/inputfelt/Datofelt";
import { LiveDataInput } from "./LiveDataInput";
import React from "react";
import { FriksjonsmålingMetadata } from "../friksjonsmålingTyper";
import dayjs, { Dayjs } from "dayjs";
import styled from "styled-components";

interface FriksjonsdashboardFilterProps {
    fraDato: Dayjs;
    setFraDato: (dato: Dayjs) => void;
    tilDato: Dayjs;
    setTilDato: (dato: Dayjs) => void;
    setSøk: (søk: string) => void;
}
export const FriksjonsdashboardFilter = ({
    fraDato,
    setFraDato,
    tilDato,
    setTilDato,
    setSøk,
}: FriksjonsdashboardFilterProps) => (
    <FilterWrapper>
        <Datofelt dato={fraDato} setDato={setFraDato} tittel={"Fra:"} />
        <Datofelt dato={tilDato} setDato={setTilDato} tittel={"Til:"} />
        <LiveDataInput tittel={"Søk:"} onchange={setSøk} størrelse={"XXL"} />
    </FilterWrapper>
);

export const filtrerFriksjonsmetadata = (
    friksjonsmetadata: FriksjonsmålingMetadata[],
    fraDato: Dayjs,
    tilDato: Dayjs,
    søk: string,
) =>
    friksjonsmetadata.filter((måling) => {
        const dato = dayjs(måling.dato);
        return dato.isAfter(fraDato) && dato.isBefore(tilDato) && friksjonsmetadataSøk(måling, søk);
    });

const friksjonsmetadataSøk = (friksjonsmetadata: FriksjonsmålingMetadata, søk: string) => {
    return (
        friksjonsmetadata.veg.toLowerCase().includes(søk.toLowerCase()) ||
        friksjonsmetadata.start.toLowerCase().includes(søk.toLowerCase()) ||
        friksjonsmetadata.operatør.toLowerCase().includes(søk.toLowerCase()) ||
        friksjonsmetadata.fylke.toLowerCase().includes(søk.toLowerCase())
    );
};

const FilterWrapper = styled.div`
    display: flex;
    gap: 1rem;
    margin-bottom: 1rem;
    flex-wrap: wrap;
`;
