"use client";

import styled from "styled-components";
import { SideHeader } from "../../components/sideheader/SideHeader";
import React, { ChangeEvent, useEffect, useState } from "react";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { ColumnWrapper, RowWrapper } from "../../components/fellesKomponenter/wrappers/wrappers";
import { FriksjonLoggEvent, loggEventMedTabellnavn, TabellNavn } from "../../utils/loggFrontend";
import { KnappPrimær } from "../../components/fellesKomponenter/knapper/KnappPrimær";
import { useHentFriksjonsmetadata } from "../../api/useHentFriksjonsmetadata";
import { Friksjonsmetadatatabell } from "./Friksjonsmetadatatabell";
import { lastOppFriksjonsdata } from "../../api/lastOppFriksjonsdata";
import { FetchStatus } from "../../api/api";
import { Spinner } from "../../components/fellesKomponenter/spinner/Spinner";
import { FriksjonsmålingMetadata } from "../friksjonsmålingTyper";
import {
    FriksjonsmålingMetadataDto,
    friksjonsmålingMetadataDtoTilFriksjonsmålingMetadata,
} from "../../api/useHentFriksjonsdata";
import { UnderArbeidMelding } from "../UnderArbeidMelding";
import ErrorBoundary from "../../components/feil/ErrorBoundary";
import { AuthenticationWrapper } from "../../components/AuthenticationWrapper";
import dayjs from "dayjs";
import { filtrerFriksjonsmetadata, FriksjonsdashboardFilter } from "./FriksjonsdashboardFilter";

export const FriksjonsdashboardLandingsside = () => {
    const [filopplastingsfeil, setFilopplastingsfeil] = useState<string | undefined>();
    const [friksjonsmetadata, settFriksjonsmetadata] = useState<FriksjonsmålingMetadata[]>([]);
    const friksjonsmetadataDto = useHentFriksjonsmetadata();
    const [lasterOpp, settLasterOpp] = useState<boolean>(false);
    const [fraDato, setFraDato] = useState<dayjs.Dayjs>(dayjs("01/01/2020"));
    const [tilDato, setTilDato] = useState<dayjs.Dayjs>(dayjs());
    const [søk, setSøk] = useState<string>("");

    useEffect(() => {
        if (friksjonsmetadataDto?.status === FetchStatus.Suksess) {
            const deserialisertFriksjonsmetadata = friksjonsmetadataDto?.data?.map((metadata) =>
                friksjonsmålingMetadataDtoTilFriksjonsmålingMetadata(metadata),
            );
            settFriksjonsmetadata(deserialisertFriksjonsmetadata);
        }
    }, [friksjonsmetadataDto]);

    const håndterFilopplasting = (event: ChangeEvent<HTMLInputElement>) => {
        setFilopplastingsfeil(undefined);

        if (event.target.files === null || event.target.files.length === 0) {
            loggEventMedTabellnavn(
                TabellNavn.friksjonsdashboard,
                FriksjonLoggEvent.lastOppMålingError,
            );
            setFilopplastingsfeil("Klarte ikke finne filen");
            return;
        }
        settLasterOpp(true);

        const fil = event.target.files[0];
        lastOppFriksjonsdata(fil).then((response) => {
            if (!response) {
                settLasterOpp(true);
            } else if (response.status === FetchStatus.Feil) {
                loggEventMedTabellnavn(
                    TabellNavn.friksjonsdashboard,
                    FriksjonLoggEvent.lastOppMålingError,
                );
                settLasterOpp(false);
                setFilopplastingsfeil("Klarte ikke laste opp filen");
            } else {
                loggEventMedTabellnavn(
                    TabellNavn.friksjonsdashboard,
                    FriksjonLoggEvent.lastOppMålingSuksess,
                );
                settLasterOpp(false);
                const metadata = friksjonsmålingMetadataDtoTilFriksjonsmålingMetadata(
                    response.data as FriksjonsmålingMetadataDto,
                );
                settFriksjonsmetadata([...friksjonsmetadata, metadata]);
            }
        });
    };

    return (
        <ErrorBoundary info="Feil i friksjonsdashboardsiden, side: Friksjonsdashboard">
            <AuthenticationWrapper>
                <Container>
                    <SideHeader side={"friksjonsdashboard"} />
                    <UnderArbeidMelding />

                    <InnholdContainer>
                        <StyledRowWrapper>
                            <Heading $stylelevel="1">Friksjonsmålinger</Heading>
                            <ColumnWrapper>
                                <KnappPrimær
                                    onClick={() => document.getElementById("file")?.click()}
                                    size={"Small"}
                                    disabled={lasterOpp}
                                >
                                    Last opp og se friksjonsfil
                                    {lasterOpp ? (
                                        <SpinnerWrapper>
                                            <Spinner storrelse="xxliten" inline={true} />
                                        </SpinnerWrapper>
                                    ) : (
                                        <LastOppIkon />
                                    )}
                                </KnappPrimær>
                                <input
                                    id="file"
                                    type="file"
                                    onChange={håndterFilopplasting}
                                    style={{ display: "none" }}
                                />
                                {filopplastingsfeil && (
                                    <StyledTekst $nomargin={true}>{filopplastingsfeil}</StyledTekst>
                                )}
                            </ColumnWrapper>
                        </StyledRowWrapper>
                        <Tekst>
                            Her ligger alle opplastede friksjonsmålinger. Velg en måling for å se
                            detaljer om målingen eller last opp en ny fil for å se den visualisert.
                        </Tekst>

                        <FriksjonsdashboardFilter
                            fraDato={fraDato}
                            setFraDato={setFraDato}
                            tilDato={tilDato}
                            setTilDato={setTilDato}
                            setSøk={setSøk}
                        />

                        <Friksjonsmetadatatabell
                            friksjonsmetadata={filtrerFriksjonsmetadata(
                                friksjonsmetadata,
                                fraDato,
                                tilDato,
                                søk,
                            )}
                        />
                    </InnholdContainer>
                </Container>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const InnholdContainer = styled.div`
    padding: 40px;
    max-width: 1400px;
    margin: auto;
`;

const Container = styled.div`
    margin: 20px 20px 100px 20px;
    background-color: var(--white);
`;

const StyledTekst = styled(Tekst)`
    color: var(--red-regular);
    padding-left: 6px;
`;

const StyledRowWrapper = styled(RowWrapper)`
    justify-content: space-between;
`;

const LastOppIkon = styled.div`
    background: url("/ikon/last-opp.svg") no-repeat;
    background-size: 16px 16px;
    height: 16px;
    width: 16px;
    margin-left: 8px;
    display: inline-block;
`;

const SpinnerWrapper = styled.div`
    display: inline-block;
    width: 16px;
    height: 16px;
    margin-left: 8px;
`;
