import { FriksjonsmålingMetadata } from "../friksjonsmålingTyper";
import React, { useEffect, useState } from "react";
import styled from "styled-components";
import { FriksjonsmetadatatabellPaginering } from "./FriksjonsmetadatatabellPaginering";
import { useRouter } from "next/navigation";
import { tilNorskTimestamp } from "../../utils/tid";
import BrøytebilSpinner from "../../kartSide/brøytebilSpinner/BrøytebilSpinner";
import { Sortering } from "../../kartSide/popup/veglenke/ProduksjonsdetaljerTabell/ProduksjonsdetaljerTabell";
import { sorterFriksjonsmetadata } from "./FriksjonsmetadatatabellSorteringUtils";
import { FriksjonsmetadatatabellTh } from "./FriksjonsmetadataTabellTh";

interface FriksjonsmetadatatabellProps {
    friksjonsmetadata: FriksjonsmålingMetadata[] | undefined;
}

export enum FriksjonsmetadataSorteringskolonne {
    dato = "dato",
    veg = "veg",
    start = "start",
    operatør = "operatør",
    fylke = "fylke",
    lastetOppAv = "lastetOppAv",
    datoLastetOpp = "datoLastetOpp",
}

export const Friksjonsmetadatatabell = ({ friksjonsmetadata }: FriksjonsmetadatatabellProps) => {
    const paginergingsStørrelse = 20;
    const [friksjonsmetadataForVisning, setFriksjonsmetadataForVisning] = useState<
        FriksjonsmålingMetadata[] | undefined
    >(undefined);
    const [sortering, setSortering] = useState<Sortering<FriksjonsmetadataSorteringskolonne>>({
        sorterEtter: FriksjonsmetadataSorteringskolonne.dato,
        stigende: true,
    });
    const [pagineringsSide, setPagineringsSide] = useState<number>(0);
    const router = useRouter();

    const oppdaterFriksjonsmetadataForVisning = (side: number) => {
        const sortert = sorterFriksjonsmetadata(
            sortering.sorterEtter,
            sortering.stigende,
            friksjonsmetadata,
        );
        setFriksjonsmetadataForVisning(
            sortert.slice(
                side * paginergingsStørrelse,
                side * paginergingsStørrelse + paginergingsStørrelse,
            ),
        );
        setPagineringsSide(side);
    };

    useEffect(() => {
        oppdaterFriksjonsmetadataForVisning(0);
    }, [friksjonsmetadata]);

    const håndterSortering = (sorteringskolonne: FriksjonsmetadataSorteringskolonne) => {
        const sorteringsRetning =
            sortering.sorterEtter === sorteringskolonne ? !sortering.stigende : true;
        setSortering({ sorterEtter: sorteringskolonne, stigende: sorteringsRetning });
        const sortert = sorterFriksjonsmetadata(
            sorteringskolonne,
            sorteringsRetning,
            friksjonsmetadata,
        );
        setFriksjonsmetadataForVisning(sortert.slice(0, paginergingsStørrelse));
        setPagineringsSide(0);
    };

    const finnSorteringsretning = (
        sorteringsnøkkel: FriksjonsmetadataSorteringskolonne,
    ): boolean | undefined =>
        sortering.sorterEtter === sorteringsnøkkel ? sortering.stigende : undefined;

    return !friksjonsmetadataForVisning ? (
        <BrøytebilSpinner />
    ) : (
        <>
            <StyledTable>
                <thead>
                    <tr>
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.dato}
                            tekst={"Dato"}
                        />
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.veg}
                            tekst={"Veg"}
                        />
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.start}
                            tekst={"Start posisjon"}
                        />
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.operatør}
                            tekst={"Operatør"}
                        />
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.fylke}
                            tekst={"Fylke"}
                        />
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.lastetOppAv}
                            tekst={"Lastet opp av"}
                        />
                        <FriksjonsmetadatatabellTh
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                            sorteringskolonne={FriksjonsmetadataSorteringskolonne.datoLastetOpp}
                            tekst={"Lastet opp dato"}
                        />
                    </tr>
                </thead>
                <tbody>
                    {friksjonsmetadataForVisning.map((måling, index) => (
                        <StyledTr
                            key={index}
                            onClick={() => {
                                router.push(`/friksjonsdashboard/${måling.id}`);
                            }}
                        >
                            <StyledTd>{tilNorskTimestamp(måling.dato)}</StyledTd>
                            <StyledTd>{måling.veg}</StyledTd>
                            <StyledTd>{måling.start}</StyledTd>
                            <StyledTd>{måling.operatør}</StyledTd>
                            <StyledTd>{måling.fylke}</StyledTd>
                            <StyledTd>{måling.lastetOppAv}</StyledTd>
                            <StyledTd>{tilNorskTimestamp(måling.datoLastetOpp)}</StyledTd>
                        </StyledTr>
                    ))}
                </tbody>
            </StyledTable>
            {friksjonsmetadata!.length > paginergingsStørrelse && (
                <FriksjonsmetadatatabellPaginering
                    pagineringsSide={pagineringsSide}
                    sistePagineringSide={Math.ceil(
                        friksjonsmetadata!.length / paginergingsStørrelse,
                    )}
                    oppdaterFriksjonsmetadataForVisning={oppdaterFriksjonsmetadataForVisning}
                />
            )}
        </>
    );
};

const StyledTable = styled.table`
    border-collapse: collapse;
    width: 100%;
    table-layout: fixed;
`;

const StyledTd = styled.td`
    border-bottom: 1px solid black;
    padding: 8px;
`;

const StyledTr = styled.tr`
    cursor: pointer;

    &:hover {
        background-color: #f2f2f2;
    }
`;
