import { useEffect } from "react";

export const useCloseOnOutsideClick = (id: string, onClose: () => void) => {
    const callback = (event: MouseEvent) => {
        if (event.target instanceof Element && !event.target.closest("#" + id)) {
            onClose();
        }
    };

    useEffect(() => {
        window.addEventListener("click", callback, true);
        return () => {
            window.removeEventListener("click", callback, true);
        };
    }, []);
};
