import { useEffect, useState } from "react";

export const useElementSize = (elementRef: React.RefObject<HTMLDivElement>) => {
    const [height, setHeight] = useState(0);
    const [width, setWidth] = useState(0);

    useEffect(() => {
        const handleResize = () => {
            setHeight(elementRef.current?.offsetHeight || 0);
            setWidth(elementRef.current?.offsetWidth || 0);
        };
        handleResize();
        window.addEventListener("resize", handleResize);
        window.addEventListener("orientationchange", handleResize);

        return () => {
            window.removeEventListener("resize", handleResize);
            window.removeEventListener("orientationchange", handleResize);
        };
    }, [elementRef.current]);

    return { height: height, width: width };
};
