import styled from "styled-components";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { Lenke } from "../../components/fellesKomponenter/lenker/Lenke";
import { Modal } from "../../components/fellesKomponenter/modal/Modal";
import { Ikon } from "../../components/Ikon/Ikon";
import { ColumnWrapper } from "../../components/fellesKomponenter/wrappers/wrappers";
import { useAtom } from "jotai";
import { visKartintroAtom } from "../jotai/karvalgAtoms";

export const KartInfo = () => {
    const [visKartintro, setVisKartintro] = useAtom(visKartintroAtom);
    return visKartintro ? (
        <Modal
            onClose={() => setVisKartintro(false)}
            id="kartinfo"
            maksBredde={500}
            maksHøyde={window.innerHeight - 150}
        >
            <RowWrapper>
                <Ikon height={60} width={60} $url="/ikon/kart/truck-plow-solid-sirkel.svg" />
                <ColumnWrapper>
                    <Header>
                        <Heading as="h1" $stylelevel="2">
                            Om løsningen
                        </Heading>
                    </Header>
                    <Tekst $størrelse={"S"} $nomargin={true}>
                        Sist oppdatert: 15. desember 2023
                    </Tekst>
                </ColumnWrapper>
            </RowWrapper>

            <Tekst $størrelse={"S"}>
                Vi jobber kontinuerlig for å gjøre løsningen bedre, send oss en mail om du har du
                innspill eller spørsmål (
                <Lenke $størrelse={"S"} href="mailto:kos@vegvesen.no">
                    kos@vegvesen.no
                </Lenke>
                )
            </Tekst>
            <Tekst $størrelse="S">
                Kartet viser vinterdrift som har blitt utført i kontraktsområdet fra det valgte
                tidspunktet og 12 timer tilbake i tid. Brøytebilene viser siste posisjon til biler
                som har vært aktive de siste 90 minuttene. Kartet henter data fra ELRAPP, Vegvær og
                Yr.no
            </Tekst>
            <br />
            <Heading as="h2" $stylelevel="3">
                Mange muligheter i kartet!
            </Heading>
            <br />
            <ForklaringContainer>
                <BlåLinje />
                <ColumnWrapper>
                    <ForklaringTekst>Er kartet &quot;live&quot;?</ForklaringTekst>
                    <InfoTekst>
                        Entreprenørene sender inn data fra bilene til ELRAPP hvert 10. minutt,
                        ELRAPP jobber med dataen de får inn i <i>inntil</i> 5 minutter før
                        produksjonskartet henter data fra ELRAPP igjen hvert 10. minutt. Det vil si
                        at i <i>beste fall</i> tar det 5 minutt fra produksjonen blir gjort til den
                        vises i kartet, i <i>verste fall</i> 25 minutt.
                    </InfoTekst>

                    <ForklaringTekst>Kun automatiske rapporterte økter vises</ForklaringTekst>
                    <InfoTekst>
                        Kartet kan kun vise automatiske rapporterte økter. Dersom det er sendt inn
                        korrigeringer eller manuelle mengder vil ikke dette dukke opp, men du ser
                        dette i ELRAPP.
                    </InfoTekst>

                    <ForklaringTekst>Hvorfor er det opphold i produksjonen?</ForklaringTekst>
                    <InfoTekst>
                        Når entreprenørene sender inn data fra bilene så er produksjonen knyttet til
                        GPS-punkter. ELRAPP knytter disse punktene til veglenker sånn at man skal
                        kunne se hvor de har kjørt på veien (avkjørsler, filer etc). Disse
                        veglenkene viser vi igjen i kartet. Veglenker har ulik lengde, noen er korte
                        og noen er lange (det ser du i kartet når du holder musen over produksjon
                        uten å trykke på det, noen er lange og noen er korte). GPS-punktene fra
                        entreprenørene kommer med jevne mellomrom (hver 100 m), og disse
                        mellomrommene gjør at man kan derfor i noen tilfeller «miste» produksjon på
                        noen veglenker – dette vises som «mellomrom» i kartet. Det betyr ikke
                        (nødvendigvis) at det ikke har vært produksjon; men at man var «uheldig» med
                        å knytte GPS-punkter sammen med veglenker, at man traff èn veglenke, mens
                        neste veglenke ikke fikk noen GPS-punkter, før neste igjen fikk. Vi jobber
                        med å forbedre dette.
                    </InfoTekst>

                    <ForklaringTekst>Fart</ForklaringTekst>
                    <InfoTekst>
                        Farten som sendes inn fra bilene er hastigheten bilen har på det GPS-punktet
                        som dataen er registrert på. Siden GPS-punktene blir gjort om til veglenker
                        (se over) så lager vi en snitthastighet på denne måten: <br /> For ett
                        kjøretøy på én økt som gjør samme aktivitet og/eller legger samme materiale
                        innenfor samme veglenke <i>og</i> innenfor maks ett minutt - slår vi sammen
                        punkthastighetene som har kommet inn og regner ut snittet.
                    </InfoTekst>

                    <ForklaringTekst>Produksjon, roder eller begge deler?</ForklaringTekst>
                    <InfoTekst>
                        Du kan velge om du vil se bare produksjon, bare roder eller begge deler
                        samtidig.
                    </InfoTekst>

                    <ForklaringTekst>Hvordan finne syklustid?</ForklaringTekst>
                    <InfoTekst>
                        I popupen som kommer når du trykker på en veglenke kan du velge å huke av
                        for “Vis kun produksjon innenfor syklustiden”. Denne filtrerer bort
                        passeringer som er eldre enn syklustiden for den aktuelle
                        vinterdriftsklassen på roden. NB! Du må selv vite hva været er/var og når et
                        tiltak burde starte.
                    </InfoTekst>

                    <ForklaringTekst>Informasjon om produksjon</ForklaringTekst>
                    <InfoTekst>
                        Ved å trykke på produksjon vil du få all info vi har på dette punktet. Du
                        kan selv velge hvilken informasjon som skal vises i tabellen.
                    </InfoTekst>
                    <RowWrapper>
                        <img
                            src="/kolonnevalg.png"
                            alt="Kolonnevalg"
                            height="120px"
                            loading={"lazy"}
                        />
                        <div>
                            <InfoTekst>
                                Huk av for de du ønsker å se i tabellen. Du kan også eksportere det
                                du får opp til excel.
                            </InfoTekst>
                        </div>
                    </RowWrapper>

                    <ForklaringTekst>Tilpass kartet til ditt behov</ForklaringTekst>
                    <StyledUl>
                        Du kan velge å skjule og vise informasjon i kartet;
                        <li>Brøytebiler</li>
                        <li>Trafikkmeldinger</li>
                        <li>Værstasjoner/kameraer</li>
                        <li>Forklaring på tidsintervall</li>
                        Det er også mulig å velge darkmode for å få bedre kontrast i kartet. Du kan
                        også huke av og på de ulike tidsintervallene for å kun vise produksjon innen
                        valgte intervaller.
                    </StyledUl>
                    <ForklaringTekst>Dele med noen som ikke har tilgang?</ForklaringTekst>
                    <InfoTekst>
                        Du kan eksportere det du ser i kartet eller på en veglenke til excel. I
                        filen vil du få opp all informasjon og en lenke tilbake til kartet på det
                        tidspunktet du har satt.
                    </InfoTekst>
                </ColumnWrapper>
            </ForklaringContainer>
        </Modal>
    ) : null;
};

const ForklaringContainer = styled.div`
    display: flex;
    flex-direction: row;
`;

const BlåLinje = styled.div`
    position: relative;
    margin-right: 20px;

    &:before {
        position: absolute;
        top: 5px;
        bottom: 0;
        left: 0;
        border-left: 2px solid #183b79;
        width: 2px;
        content: "";
    }
`;

const ForklaringTekst = styled(Tekst).attrs(() => ({
    $størrelse: "M",
    $nomargin: true,
    $bold: true,
}))`
    color: #183b79;
    display: flex;
    position: relative;

    &:before {
        position: absolute;
        left: -26px;
        top: 4px;
        background-color: #183b79;
        border-radius: 50%;
        content: "";
        flex-shrink: 0;
        height: 14px;
        width: 14px;
    }
`;

const InfoTekst = styled(Tekst).attrs(() => ({
    $størrelse: "S",
    $nomargin: true,
}))`
    margin-bottom: 20px;
`;

const StyledUl = styled(Tekst).attrs(() => ({
    as: "ul",
    $størrelse: "S",
    $nomargin: true,
}))`
    padding: 0;
    margin-bottom: 20px;
    & li {
        margin-left: 20px;
    }
`;

export const Header = styled.div`
    display: flex;
    justify-content: space-between;
    align-items: center;
`;

const RowWrapper = styled.div`
    display: flex;
    flex-direction: row;
    gap: 1.5rem;
    margin-bottom: 20px;
`;
