"use client";
import React, { useEffect, useRef } from "react";
import { AuthenticationWrapper } from "../components/AuthenticationWrapper";
import { Spinner } from "../components/fellesKomponenter/spinner/Spinner";
import { KartInfo } from "./KartInfo/KartInfo";
import styled, { createGlobalStyle } from "styled-components";
import ErrorBoundary from "../components/feil/ErrorBoundary";
import { Kontakt } from "./kartParameterVelger/Kontakt";
import { KlarteIkkeHenteKontrakterForBrukerFeilmelding } from "./feil/KlarteIkkeHenteKontrakterForBrukerFeilmelding";
import { ProduksjonskartInnhold } from "./kartInnhold/ProduksjonskartInnhold";
import { SideHeader } from "../components/sideheader/SideHeader";
import { HopptilHovedinnholdLenke } from "../components/fellesKomponenter/lenker/HoppTilHovedinnholdLenke";
import { useElementSize } from "../hooks/useElementSize";
import { useAtomValue } from "jotai";
import { aktivKontraktAtom, kontraktFinnesAtom, tidspunktAtom } from "../api/context/kontraktAtoms";
import { brukerInfoAtom } from "../api/context/apiAtoms";
import { loggNettbrett, loggSkjermstørrelse, Sider } from "../utils/loggFrontend";

export const KartSide = () => {
    const brukerInfo = useAtomValue(brukerInfoAtom);
    const tidspunkt = useAtomValue(tidspunktAtom);
    const aktivKontrakt = useAtomValue(aktivKontraktAtom);
    const kontraktFinnes = useAtomValue(kontraktFinnesAtom);
    const elementRef = useRef<HTMLDivElement>(null);
    const { height } = useElementSize(elementRef);
    useEffect(() => {
        loggSkjermstørrelse(window, Sider.produksjonskart);
        loggNettbrett(Sider.produksjonskart);
    }, []);

    return (
        <ErrorBoundary
            info={`${
                brukerInfo?.suksess ? brukerInfo.data.fulltnavn : "Ukjent bruker"
            }, ${aktivKontrakt?.navn}, ${tidspunkt.toISOString()}, elrappid: ${aktivKontrakt?.elrappId}, side: Produksjonskart`}
        >
            <Container>
                <AuthenticationWrapper>
                    <HopptilHovedinnholdLenke hovedinnholdId={"kartparametervelger"} />
                    <SideHeaderWrapper ref={elementRef}>
                        <SideHeader side={"produksjonskart"} />
                        <Kontakt />
                    </SideHeaderWrapper>
                    <HeaderVariables height={height} />
                    {!brukerInfo ? (
                        <Spinner storrelse="liten" sentrert={true} inline={false}>
                            Henter kontrakter for bruker...
                        </Spinner>
                    ) : brukerInfo.suksess && kontraktFinnes ? (
                        <>
                            <ProduksjonskartInnhold />
                            <KartInfo />
                        </>
                    ) : (
                        <KlarteIkkeHenteKontrakterForBrukerFeilmelding
                            brukerInfo={brukerInfo}
                            kontraktFinnes={kontraktFinnes}
                        />
                    )}
                </AuthenticationWrapper>
            </Container>
        </ErrorBoundary>
    );
};

const Container = styled.div`
    display: flex;
    flex-direction: column;
    height: 100vh;
`;

const SideHeaderWrapper = styled.div`
    background-color: var(--gray-light);
    z-index: 3050;
`;

const HeaderVariables = createGlobalStyle<{ height: number }>`
  &:root {
    --header-height: ${({ height }) => height}px;
  }
`;
