import { Checkbox } from "../../../components/fellesKomponenter/checkboxer/Checkbox";
import styled from "styled-components";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";

interface IntervallProps {
    children: string;
    farge: string;
    valgt: boolean;
    erRedigeringsTilstand: boolean;
    oppdaterTidsfilter: () => void;
    idString: string;
    automatiskFokus?: boolean;
}

export const Intervall = ({
    children,
    farge,
    valgt,
    erRedigeringsTilstand,
    oppdaterTidsfilter,
    idString,
    automatiskFokus,
}: IntervallProps) => (
    <>
        {erRedigeringsTilstand ? (
            <Checkbox
                value={idString}
                størrelse={"XS"}
                checked={valgt}
                onChange={oppdaterTidsfilter}
                automatiskFokus={automatiskFokus}
            >
                <IntervallWrapper id={idString}>
                    <Fargestrek $farge={farge} />
                    <IntervallTekst $størrelse="S" $valgt={valgt}>
                        {children}
                    </IntervallTekst>
                </IntervallWrapper>
            </Checkbox>
        ) : (
            <IntervallWrapper>
                <Fargestrek $farge={farge} />
                <IntervallTekst $størrelse="S" $valgt={valgt}>
                    {children}
                </IntervallTekst>
            </IntervallWrapper>
        )}
    </>
);

const IntervallWrapper = styled.div`
    display: flex;
`;

const Fargestrek = styled.i<{ $farge: string }>`
    background-color: ${({ $farge }) => $farge};
    display: block;
    width: 1rem;
    height: 3px;
    margin-top: auto;
    margin-bottom: auto;
`;

const IntervallTekst = styled(Tekst)<{ $valgt: boolean }>`
    margin: 0 0 0 0.5rem;
    font-weight: 300;
    ${(props) => !props.$valgt && `text-decoration: line-through;`}
`;
