import styled from "styled-components";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { Ikon } from "../../../components/Ikon/Ikon";
import { useRef, useState } from "react";
import { KnappUtenStyling } from "../../../components/fellesKomponenter/knapper/KnappUtenStyling";
import { tidsfilterAtom } from "../../jotai/TidsfilterAtom";
import { Intervall } from "./Intervall";
import { useDisableClickPropagation } from "../../../hooks/useDisableClickPropagation";
import { TidsintervallFarge } from "../../utils/tidsintervallUtils";
import { erMuseKlikk } from "../../utils/kartUtils";
import { useAtom } from "jotai";
import {
    loggEventMedTabellnavnOgVerdi,
    TabellNavn,
    TidSidenSisteAktivitetEvent,
} from "../../../utils/loggFrontend";

export const IntervallLegend = () => {
    const intrervallLegendRef = useRef(null);
    const [tidsfilter, setTidsfilter] = useAtom(tidsfilterAtom);
    const [erRedigeringsTilstand, setErRedigeringsTilstand] = useState(false);
    const [automatiskFokus, setAutomatiskFokus] = useState(false);

    useDisableClickPropagation(intrervallLegendRef);

    const oppdaterTidsfilter = (indeks: number) => {
        const tidsfilterKopi = [...tidsfilter];
        tidsfilterKopi[indeks].valgt = !tidsfilterKopi[indeks].valgt;
        setTidsfilter(tidsfilterKopi);
    };

    const resetTidsfilter = () => {
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.sisteAktivtetTrykk,
            TidSidenSisteAktivitetEvent.tilbakestill,
            "klikk",
        );
        const tidsfilterKopi = [...tidsfilter];
        tidsfilterKopi.forEach((filter) => (filter.valgt = true));
        setTidsfilter(tidsfilterKopi);
    };

    const handleEndreKlikk = (e: React.MouseEvent<HTMLElement>) => {
        setAutomatiskFokus(erMuseKlikk(e));
        if (erRedigeringsTilstand) {
            loggEventMedTabellnavnOgVerdi(
                TabellNavn.sisteAktivtetTrykk,
                TidSidenSisteAktivitetEvent.lagre,
                "klikk",
            );
        } else {
            loggEventMedTabellnavnOgVerdi(
                TabellNavn.sisteAktivtetTrykk,
                TidSidenSisteAktivitetEvent.endre,
                "klikk",
            );
        }
        setErRedigeringsTilstand(!erRedigeringsTilstand);
    };

    const gråFarge = "#C0C0C0";

    const håndterBoksKlikket = (index: number, tidsromValgt: TidSidenSisteAktivitetEvent) => {
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.sisteAktivtetTrykk,
            tidsromValgt,
            !tidsfilter[index].valgt ? "På" : "Av",
        );
        oppdaterTidsfilter(index);
    };

    return (
        <Wrapper ref={intrervallLegendRef}>
            <HeaderStyled $størrelse="S" $bold={true}>
                Tid siden siste aktivitet
            </HeaderStyled>
            <Intervall
                farge={tidsfilter[0].valgt ? TidsintervallFarge.time1h30 : gråFarge}
                erRedigeringsTilstand={erRedigeringsTilstand}
                valgt={tidsfilter[0].valgt}
                oppdaterTidsfilter={() =>
                    håndterBoksKlikket(0, TidSidenSisteAktivitetEvent.mindreEnnHalvannenTime)
                }
                idString={"mindreEnn1,5time"}
                automatiskFokus={automatiskFokus}
            >
                Mindre enn 1,5 time
            </Intervall>
            <Intervall
                farge={tidsfilter[1].valgt ? TidsintervallFarge.time2h : gråFarge}
                erRedigeringsTilstand={erRedigeringsTilstand}
                valgt={tidsfilter[1].valgt}
                oppdaterTidsfilter={() =>
                    håndterBoksKlikket(1, TidSidenSisteAktivitetEvent.halvannenTilToTimer)
                }
                idString={"1,5til2timer"}
            >
                1,5 - 2 timer
            </Intervall>
            <Intervall
                farge={tidsfilter[2].valgt ? TidsintervallFarge.time3h : gråFarge}
                erRedigeringsTilstand={erRedigeringsTilstand}
                valgt={tidsfilter[2].valgt}
                oppdaterTidsfilter={() =>
                    håndterBoksKlikket(2, TidSidenSisteAktivitetEvent.toTilTreTimer)
                }
                idString={"2til3timer"}
            >
                2 - 3 timer
            </Intervall>
            <Intervall
                farge={tidsfilter[3].valgt ? TidsintervallFarge.time4h : gråFarge}
                erRedigeringsTilstand={erRedigeringsTilstand}
                valgt={tidsfilter[3].valgt}
                oppdaterTidsfilter={() =>
                    håndterBoksKlikket(3, TidSidenSisteAktivitetEvent.treTilFireTimer)
                }
                idString={"3til4timer"}
            >
                3 - 4 timer
            </Intervall>
            <Intervall
                farge={tidsfilter[4].valgt ? TidsintervallFarge.time12h : gråFarge}
                erRedigeringsTilstand={erRedigeringsTilstand}
                valgt={tidsfilter[4].valgt}
                oppdaterTidsfilter={() =>
                    håndterBoksKlikket(4, TidSidenSisteAktivitetEvent.fireTilTolvTimer)
                }
                idString={"4til12timer"}
            >
                4 - 12 timer
            </Intervall>
            <RedigerContainer $rediger={erRedigeringsTilstand}>
                {erRedigeringsTilstand && (
                    <KnappUtenStyling onClick={() => resetTidsfilter()}>
                        <KnappTekst>Tilbakestill</KnappTekst>
                    </KnappUtenStyling>
                )}
                <KnappUtenStyling
                    onClick={(e: React.MouseEvent<HTMLElement>) => handleEndreKlikk(e)}
                >
                    <KnappTekst>{erRedigeringsTilstand ? "Lagre" : "Endre"}</KnappTekst>
                    <StyledIkon height={10} width={10} $url="/ikon/endre-blyant.svg" />
                </KnappUtenStyling>
            </RedigerContainer>
        </Wrapper>
    );
};

const KnappTekst = styled.span`
    color: var(--gray-dark-65);
    border-bottom: 1px solid var(--gray-dark-65);
    font-size: 10px;

    &:hover {
        color: var(--gray-dark);
        border-bottom: 1px solid var(--gray-dark);
    }
`;

const StyledIkon = styled(Ikon)`
    margin-left: 5px;
`;

const RedigerContainer = styled.div<{ $rediger: boolean }>`
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-top: 4px;
    ${(props) => !props.$rediger && `justify-content: flex-end;`}
`;

const Wrapper = styled.div`
    background-color: var(--white);
    box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.25);
    padding: 1rem;
    width: max-content;
    position: absolute;
    z-index: 1000;
    right: 3px;
    top: 8px;
    display: flex;
    flex-direction: column;
    cursor: auto;
`;

const HeaderStyled = styled(Tekst)`
    margin-top: 0;
    margin-bottom: 0.5rem;
`;
