import styled from "styled-components";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import React, { useRef } from "react";
import { Checkbox } from "../../components/fellesKomponenter/checkboxer/Checkbox";
import { Spinner } from "../../components/fellesKomponenter/spinner/Spinner";
import { ApiRespons } from "../../api/api";
import { TrafikkmeldingerDto } from "../../api/useHentTrafikkmeldinger";
import { useDisableScrollAndClick } from "../../hooks/useDisableScrollAndClick";
import { useCloseOnOutsideClick } from "../../hooks/useCloseOnOutsideClick";
import { motion } from "framer-motion";
import { useAtom } from "jotai/index";
import {
    visBrøytebilerAtom,
    visDarkModeAtom,
    visKameraerAtom,
    visLegendAtom,
    visTrafikkmeldingerAtom,
} from "../jotai/karvalgAtoms";
import { useAtomValue } from "jotai";
import { loggEventMedTabellnavnOgVerdi, TabellNavn, VisIKartEvent } from "../../utils/loggFrontend";

interface Props {
    handleTrafikkmeldingToggle: (visStengteVeier: boolean) => void;
    trafikkmeldinger: ApiRespons<TrafikkmeldingerDto[]> | undefined;
    onClose: () => void;
    åpen: boolean;
}

export const KartlagValg = ({
    handleTrafikkmeldingToggle,
    trafikkmeldinger,
    onClose,
    åpen,
}: Props) => {
    const ref = useRef(null);
    const id = "karlagvalg";
    useDisableScrollAndClick(ref);
    useCloseOnOutsideClick(id, onClose);
    const [visDarkmode, settVisDarkmode] = useAtom(visDarkModeAtom);
    const [visKameraer, setVisKameraer] = useAtom(visKameraerAtom);
    const [visBrøytebiler, setVisBrøytebiler] = useAtom(visBrøytebilerAtom);
    const [visLegend, settVisLegend] = useAtom(visLegendAtom);
    const visTrafikkmeldinger = useAtomValue(visTrafikkmeldingerAtom);

    return (
        <Container
            initial="collapsed"
            animate={åpen ? "open" : "closed"}
            exit="exit"
            variants={{
                open: { opacity: 1, x: 0 },
                collapsed: { opacity: 0, x: "100%" },
                exit: { opacity: 0, x: "100%" },
            }}
            transition={{
                duration: 0.3,
            }}
            ref={ref}
            id={id}
        >
            <Wrapper>
                <Tekst $størrelse={"M"} $nomargin={true} $bold={true}>
                    Vis i kart
                </Tekst>
                <Checkbox
                    tabIndex={1}
                    key={"kamera"}
                    onChange={() => {
                        loggEventMedTabellnavnOgVerdi(
                            TabellNavn.kartlagTrykk,
                            VisIKartEvent.kameraOgVærstasjoner,
                            !visKameraer ? "På" : "Av",
                        );
                        setVisKameraer(!visKameraer);
                    }}
                    checked={visKameraer}
                    value={"kamera"}
                    størrelse={"L"}
                    tekstStørrelse={"M"}
                >
                    Kamera og værstasjoner
                </Checkbox>
                <Checkbox
                    key={"brøytebiler"}
                    onChange={() => {
                        loggEventMedTabellnavnOgVerdi(
                            TabellNavn.kartlagTrykk,
                            VisIKartEvent.kjøretøy,
                            !visBrøytebiler ? "På" : "Av",
                        );
                        setVisBrøytebiler(!visBrøytebiler);
                    }}
                    checked={visBrøytebiler}
                    value={"brøytebiler"}
                    størrelse={"L"}
                    tekstStørrelse={"M"}
                >
                    Kjøretøy
                </Checkbox>
                <Checkbox
                    key={"stengteveier"}
                    onChange={() => {
                        loggEventMedTabellnavnOgVerdi(
                            TabellNavn.kartlagTrykk,
                            VisIKartEvent.trafikkmeldinger,
                            !visTrafikkmeldinger ? "På" : "Av",
                        );
                        handleTrafikkmeldingToggle(!visTrafikkmeldinger);
                    }}
                    checked={visTrafikkmeldinger}
                    value={"stengteveier"}
                    størrelse={"L"}
                    tekstStørrelse={"M"}
                    disabled={!trafikkmeldinger || !trafikkmeldinger.suksess}
                >
                    Trafikkmeldinger{" "}
                    {trafikkmeldinger === undefined && <Spinner storrelse="xliten" inline={true} />}
                </Checkbox>
                <Checkbox
                    key={"vislegendintervaller"}
                    onChange={() => {
                        loggEventMedTabellnavnOgVerdi(
                            TabellNavn.kartlagTrykk,
                            VisIKartEvent.fargeforklaring,
                            !visLegend ? "På" : "Av",
                        );
                        settVisLegend(!visLegend);
                    }}
                    checked={visLegend}
                    value={"vislegendintervaller"}
                    størrelse={"L"}
                    tekstStørrelse={"M"}
                >
                    Fargeforklaring
                </Checkbox>
                <Checkbox
                    key={"visdarkmode"}
                    onChange={() => {
                        loggEventMedTabellnavnOgVerdi(
                            TabellNavn.kartlagTrykk,
                            VisIKartEvent.darkmode,
                            !visDarkmode ? "På" : "Av",
                        );
                        settVisDarkmode(!visDarkmode);
                    }}
                    checked={visDarkmode}
                    value={"visdarkmode"}
                    størrelse={"L"}
                    tekstStørrelse={"M"}
                >
                    Darkmode
                </Checkbox>
            </Wrapper>
        </Container>
    );
};

const Container = styled(motion.div)`
    position: fixed;
    background-color: var(--white);
    right: 70px;
    bottom: 126px;
    width: fit-content;
    height: fit-content;
    z-index: 1001;
    cursor: auto;
    box-shadow: 0px 0px 6px 2px rgba(53, 62, 67, 0.08);
    border: 2px solid var(--gray-dark);
`;

const Wrapper = styled.div`
    display: flex;
    flex-direction: column;
    padding: 20px;
    gap: 10px;

    @media (pointer: coarse) {
        gap: 12px;
    }
`;
