import { useEffect, useState } from "react";
import {
    informasjonsmeldinger,
    informasjonsmeldingMedTimeoutAtom,
    InformasjonsmeldingType,
} from "../jotai/InformasjonsmeldingAtom";
import { hastighetsfilterAtom } from "../jotai/HastighetsfilterAtom";
import { produksjonsfilterAtom } from "../../api/context/ProduksjonsfilterAtoms";
import { Produksjonslenke } from "../types/produksjonslenke";
import { useAtom, useAtomValue } from "jotai";
import { tidsfilterAtom } from "../jotai/TidsfilterAtom";
import { filtrerProduksjonslenker } from "../filtre/filtrerProduksjon/filtrerProduksjon";

export const useFiltrerteLenker = (produksjonslenker: Produksjonslenke[]): Produksjonslenke[] => {
    const [informasjonsmelding, setInformasjonsmelding] = useAtom(
        informasjonsmeldingMedTimeoutAtom,
    );
    const produksjonsfilter = useAtomValue(produksjonsfilterAtom);
    const hastighetsfilter = useAtomValue(hastighetsfilterAtom);
    const tidsfilter = useAtomValue(tidsfilterAtom);
    const [filtrerteLenker, setFiltrerteLenker] = useState(produksjonslenker);

    useEffect(() => {
        const filtrertelenker = filtrerProduksjonslenker(
            produksjonsfilter,
            hastighetsfilter,
            produksjonslenker,
            tidsfilter,
        );

        setFiltrerteLenker(filtrertelenker);

        if (skalIngenDataForFiltereMeldingVises(filtrertelenker, produksjonslenker)) {
            setInformasjonsmelding(informasjonsmeldinger.ingenDataForFiltere);
        } else {
            if (informasjonsmelding?.type === InformasjonsmeldingType.ingenDataForFiltere) {
                setInformasjonsmelding(undefined);
            }
        }
    }, [produksjonsfilter, hastighetsfilter, tidsfilter]);

    return filtrerteLenker;
};

const skalIngenDataForFiltereMeldingVises = (
    filtrerteProduksjonslenker: Produksjonslenke[] | undefined,
    produksjonslenker: Produksjonslenke[],
) =>
    filtrerteProduksjonslenker &&
    filtrerteProduksjonslenker.length === 0 &&
    !(produksjonslenker.length === 0);
