import { GeoJSON, Pane } from "react-leaflet";
import { mapRoderTilKartdata } from "./geoJSONutilsRoder";
import {
    aktivDarkmodeFarge,
    aktivFarge,
    hentRodeColor,
    onEachRodeFeature,
    rodeStyleBredAktiv,
} from "../kartStyleUtils";
import React, { useMemo } from "react";
import { RodeDto } from "../../../api/useHentRoder";
import { Proj4GeoJSONFeature } from "proj4leaflet";
import { LeafletEvent } from "leaflet";
import { Feature } from "geojson";
import { mapAktivFeatureTilKartdata } from "./geoJSONutilsVeglenker";
import { useAtomValue } from "jotai";
import { visDarkModeAtom } from "../../jotai/karvalgAtoms";

interface GeoJsonRoderProps {
    roder: RodeDto[];
    håndterRodeKlikket: (event: LeafletEvent, feature: Feature) => void;
    aktivRodeFeature: Proj4GeoJSONFeature | undefined;
}
export const GeoJsonRoder = ({
    roder,
    håndterRodeKlikket,
    aktivRodeFeature,
}: GeoJsonRoderProps) => {
    const visDarkmode = useAtomValue(visDarkModeAtom);

    const rodeGeoJson = useMemo(
        () => (
            <GeoJSON
                data={mapRoderTilKartdata(roder)}
                style={hentRodeColor}
                onEachFeature={(event, feature) =>
                    onEachRodeFeature(event, feature, håndterRodeKlikket)
                }
                key={Math.random()}
            />
        ),
        [aktivRodeFeature, roder],
    );

    const rodeGeoJsonAktiv = useMemo(() => {
        if (aktivRodeFeature === undefined) return;
        return (
            <GeoJSON
                data={mapAktivFeatureTilKartdata(aktivRodeFeature)}
                onEachFeature={(_, layer: any) => {
                    layer.setStyle(rodeStyleBredAktiv);
                    layer.setStyle(visDarkmode ? aktivDarkmodeFarge : aktivFarge);
                }}
                key={Math.random()}
            />
        );
    }, [aktivRodeFeature, visDarkmode]);

    return (
        <Pane name="rode-pane" style={{ zIndex: 300 }}>
            {rodeGeoJson}
            {rodeGeoJsonAktiv}
        </Pane>
    );
};
