import React, { useMemo } from "react";
import {
    mapAktivFeatureTilKartdata,
    mapProduksjonslenkerTilKartdata,
    tilSegmentStyle,
} from "./geoJSONutilsVeglenker";
import { Feature } from "geojson";
import { LeafletEvent } from "leaflet";
import { Proj4GeoJSONFeature } from "proj4leaflet";
import { GeoJSON, Pane } from "react-leaflet";
import { Produksjonslenke } from "../../types/produksjonslenke";
import {
    aktivOgHoverStyle,
    onEachLenkeFeature,
    onEachLenkeFeatureNettbrett,
} from "../kartStyleUtils";

const erPåNettbrett = () => {
    return window.matchMedia("(pointer: coarse)").matches;
};
interface GeoJsonVeglenkerProps {
    filtrerteProduksjonslenker: Produksjonslenke[] | undefined;
    håndterVeglenkeKlikket: (event: LeafletEvent, feature: Feature) => void;
    aktivVeglenkeFeature: Proj4GeoJSONFeature | undefined;
}

export const GeoJsonVeglenker = ({
    filtrerteProduksjonslenker,
    håndterVeglenkeKlikket,
    aktivVeglenkeFeature,
}: GeoJsonVeglenkerProps) => {
    const produksjonGeoJson = useMemo(
        () => (
            <div>
                <GeoJSON
                    data={mapProduksjonslenkerTilKartdata(filtrerteProduksjonslenker ?? [], true)}
                    style={tilSegmentStyle}
                    onEachFeature={(event, feature) =>
                        onEachLenkeFeature(event, feature, håndterVeglenkeKlikket)
                    }
                    key={Math.random()}
                />
                {erPåNettbrett() && (
                    <GeoJSON
                        data={mapProduksjonslenkerTilKartdata(
                            filtrerteProduksjonslenker ?? [],
                            true,
                        )}
                        style={tilSegmentStyle}
                        onEachFeature={(event, feature) =>
                            onEachLenkeFeatureNettbrett(event, feature, håndterVeglenkeKlikket)
                        }
                        key={Math.random()}
                    />
                )}
            </div>
        ),
        [filtrerteProduksjonslenker],
    );

    const produksjonGeoJsonAktiv = useMemo(() => {
        if (aktivVeglenkeFeature === undefined) return;

        return (
            <GeoJSON
                data={mapAktivFeatureTilKartdata(aktivVeglenkeFeature)}
                style={tilSegmentStyle}
                onEachFeature={(_, layer: any) => layer.setStyle(aktivOgHoverStyle)}
                key={Math.random()}
            />
        );
    }, [aktivVeglenkeFeature]);

    return (
        <Pane name="produksjon-pane" style={{ zIndex: 400 }}>
            {produksjonGeoJson}
            {produksjonGeoJsonAktiv}
        </Pane>
    );
};
