import React from "react";
import { GeoJSON } from "react-leaflet";
import { tilFargekode } from "../../utils/tidsintervallUtils";
import { onEachLenkeFeature } from "../kartStyleUtils";
import { Feature, FeatureCollection } from "geojson";
import { Produksjonslenke } from "../../types/produksjonslenke";
import { Proj4GeoJSONFeature } from "proj4leaflet";

export const tilProduksjonslenkeGeojsonFeaturesEnkeltLag = (
    prodData: Produksjonslenke[],
): Proj4GeoJSONFeature[] =>
    prodData.reduce((result: Proj4GeoJSONFeature[], lenke: Produksjonslenke) => {
        const featureÅBytteUt = finnFeatureÅBytteUt(lenke, result);
        if (featureÅBytteUt) {
            result = result.filter((element) => element != featureÅBytteUt);
            return result.concat([
                {
                    type: "Feature",
                    properties: lenke,
                    geometry: lenke.geometri,
                    id: "veglenke" + lenke.veglenkesekvensId + lenke.veglenkeNummer,
                },
            ]);
        }
        return !erProduksjonslenkeIGeoJSONFeature(lenke, result)
            ? result.concat([
                  {
                      type: "Feature",
                      properties: lenke,
                      geometry: lenke.geometri,
                      id: "veglenke" + lenke.veglenkesekvensId + lenke.veglenkeNummer,
                  },
              ])
            : result;
    }, []);

export const tilProduksjonslenkeGeojsonFeaturesFlereLag = (
    prodData: Produksjonslenke[],
): Proj4GeoJSONFeature[] =>
    prodData.map((lenke) => ({
        type: "Feature",
        properties: lenke,
        geometry: lenke.geometri,
        id: "veglenke" + lenke.veglenkesekvensId + lenke.veglenkeNummer,
    }));

const erProduksjonslenkeIGeoJSONFeature = (
    produksjonslenke: Produksjonslenke,
    geoJsonFeature: Proj4GeoJSONFeature[],
): Boolean =>
    geoJsonFeature.some(
        (feature) =>
            (feature.properties as Produksjonslenke).veglenkesekvensId ===
                produksjonslenke.veglenkesekvensId &&
            (feature.properties as Produksjonslenke).veglenkeNummer ===
                produksjonslenke.veglenkeNummer,
    );

const finnFeatureÅBytteUt = (
    produksjonslenke: Produksjonslenke,
    geoJsonFeature: Proj4GeoJSONFeature[],
): Proj4GeoJSONFeature | undefined =>
    geoJsonFeature.find(
        (feature) =>
            (feature.properties as Produksjonslenke).veglenkesekvensId ===
                produksjonslenke.veglenkesekvensId &&
            (feature.properties as Produksjonslenke).veglenkeNummer ===
                produksjonslenke.veglenkeNummer &&
            (feature.properties as Produksjonslenke).minutterSiden > produksjonslenke.minutterSiden,
    );

export const mapProduksjonslenkerTilKartdata = (
    produksjonslenke: Produksjonslenke[],
    enkeltLag: boolean,
): FeatureCollection =>
    ({
        type: "FeatureCollection",
        features: enkeltLag
            ? tilProduksjonslenkeGeojsonFeaturesEnkeltLag(produksjonslenke)
            : tilProduksjonslenkeGeojsonFeaturesFlereLag(produksjonslenke),
    }) as FeatureCollection;

export const mapAktivFeatureTilKartdata = (feature: Proj4GeoJSONFeature): FeatureCollection =>
    ({
        type: "FeatureCollection",
        features: [feature],
    }) as FeatureCollection;

export const getGeoJsonØktVeglenke = (
    filtrerteProduksjonslenker: Produksjonslenke[] | undefined,
    aktivHoverRecord?: number[],
) => {
    return (
        <GeoJSON
            data={mapProduksjonslenkerTilKartdata(filtrerteProduksjonslenker ?? [], false)}
            style={(feature) => tilØktSegmentStyle(feature, aktivHoverRecord)}
            onEachFeature={(event, feature) => onEachLenkeFeature(event, feature, () => {})}
            key={Math.random()}
        />
    );
};

const tilØktSegmentStyle = (feature: Feature | undefined, aktivHoverRecord?: number[]) => {
    return skalVæreBold(feature, aktivHoverRecord)
        ? { color: "#E32129", dashArray: "10", weight: 10 }
        : { color: "#E32129" };
};

export const tilSegmentStyle = (feature: Feature | undefined) => {
    const minutterSiden: number = feature?.properties?.minutterSiden;
    return { color: tilFargekode(minutterSiden) };
};

const skalVæreBold = (feature: Feature | undefined, aktivHoverRecord?: number[]) =>
    aktivHoverRecord
        ? feature?.properties?.målepunkter.some((rec: number) => aktivHoverRecord.includes(rec))
        : false;
