import { LatLngBoundsExpression } from "leaflet";
import { Produksjonslenke } from "../types/produksjonslenke";
import { RodeDto } from "../../api/useHentRoder";
import { Geometry, LineString, MultiLineString, Position } from "geojson";
import { defaultBounds } from "../utils/kartUtils";

export const finnKartBoundsForProduksjonskart = (
    roder: RodeDto[],
    produksjonslenker: Produksjonslenke[],
): LatLngBoundsExpression => {
    const kartBoundsForRoder = finnKartBoundsForRoder(roder);
    if (kartBoundsForRoder) {
        return kartBoundsForRoder;
    }
    const kartBoundsForProduksjonslenker = finnKartBoundsForProduksjonslenker(produksjonslenker);
    if (kartBoundsForProduksjonslenker) {
        return kartBoundsForProduksjonslenker;
    }
    return defaultBounds;
};

export const finnKartBoundsForØktdetaljer = (
    produksjonslenker: Produksjonslenke[],
): LatLngBoundsExpression => {
    const kartBoundsForProduksjonslenker = finnKartBoundsForProduksjonslenker(produksjonslenker);
    if (kartBoundsForProduksjonslenker) {
        return kartBoundsForProduksjonslenker;
    }
    return [
        [69, 12],
        [60, 10],
    ];
};
const finnKartBoundsForProduksjonslenker = (
    produksjonslenker: Produksjonslenke[],
): LatLngBoundsExpression | undefined => {
    const koordinater = produksjonslenker
        .map((produksjonslenke) => produksjonslenke.geometri)
        .map((geometri) => geometriTilKoordinatliste(geometri))
        .flat();
    return finnKartBoundsForKooridnater(koordinater);
};
const finnKartBoundsForRoder = (roder: RodeDto[]): LatLngBoundsExpression | undefined => {
    const koordinater = roder
        .map((rode) => rode.detaljer.geometri)
        .map((geometri) => geometriTilKoordinatliste(geometri))
        .flat();
    return finnKartBoundsForKooridnater(koordinater);
};

export const finnKartBoundsForKooridnater = (
    koordinater: Position[],
): LatLngBoundsExpression | undefined => {
    let north = 0,
        south = 180,
        west = 180,
        east = 0;
    koordinater.forEach((koordinat) => {
        if (koordinat[0] > north) {
            north = koordinat[0];
        }
        if (koordinat[0] < south) {
            south = koordinat[0];
        }
        if (koordinat[1] > east) {
            east = koordinat[1];
        }
        if (koordinat[1] < west) {
            west = koordinat[1];
        }
    });

    if (north === 0 && south === 180 && west === 180 && east === 0) {
        return undefined;
    }

    return [
        [west, north],
        [east, south],
    ];
};

const geometriTilKoordinatliste = (geometri: Geometry): Position[] => {
    switch (geometri.type) {
        case "LineString":
            return (geometri as LineString).coordinates;
        case "MultiLineString":
            return (geometri as MultiLineString).coordinates.flat();
        default:
            console.error(`Klarte ikke mappe lenke med type ${geometri.type}`);
            return [];
    }
};
