import { Feature } from "geojson";
import { LeafletEvent, LeafletMouseEvent } from "leaflet";

export const defaultStyle = { dashArray: "0", weight: 3 };
export const aktivOgHoverStyle = { dashArray: "10", weight: 10 };
export const aktivFarge = { color: "#504f4f" };
export const aktivDarkmodeFarge = { color: "#f8f5f5" };
export const rodeStyleBredAktiv = { dashArray: "0", weight: 18 };
export const rodeStyleBredIkkeAktiv = { dashArray: "0", weight: 18, opacity: 0.67 };
export const rodeStyleBredIkkeAktivHover = { dashArray: "0", weight: 22, opacity: 0.75 };
export const usynligTouchLenke = { weight: 22, opacity: 0 };

export const hentOnHoverStyle = (type: string) =>
    type === "rode" ? rodeStyleBredIkkeAktivHover : aktivOgHoverStyle;

export const hentOnOutStyle = (type: string) =>
    type === "rode" ? rodeStyleBredIkkeAktiv : defaultStyle;

export const hentRodeColor = (feature: Feature | undefined) => {
    return { color: feature?.properties?.color };
};

export const onEachLenkeFeature = (
    feature: Feature | undefined,
    layer: any,
    håndterVeglenkeKlikket: (event: LeafletEvent, feature: Feature) => void,
) => {
    const onClick = (e: LeafletMouseEvent) => {
        håndterVeglenkeKlikket(e, e.sourceTarget.feature);
    };
    const onHover = (e: LeafletMouseEvent) => {
        e.target.setStyle(hentOnHoverStyle("veglenke"));
    };
    const onOut = (e: LeafletMouseEvent) => {
        e.target.setStyle(hentOnOutStyle("veglenke"));
    };
    layer.on({
        click: onClick,
        mouseover: onHover,
        mouseout: onOut,
    });
    layer.bringToFront();
};

export const onEachLenkeFeatureNettbrett = (
    feature: Feature | undefined,
    layer: any,
    håndterVeglenkeKlikket: (event: LeafletEvent, feature: Feature) => void,
) => {
    layer.setStyle(usynligTouchLenke);
    const onClick = (e: LeafletMouseEvent) => {
        håndterVeglenkeKlikket(e, e.sourceTarget.feature);
    };
    layer.on({
        click: onClick,
    });
};

export const onEachRodeFeature = (
    feature: Feature | undefined,
    layer: any,
    håndterRodeKlikket: (event: LeafletEvent, feature: Feature) => void,
) => {
    layer.setStyle(rodeStyleBredIkkeAktiv);

    const onClick = (e: LeafletMouseEvent) => {
        håndterRodeKlikket(e, e.sourceTarget.feature);
    };
    const onHover = (e: LeafletMouseEvent) => {
        e.target.setStyle(hentOnHoverStyle("rode"));
    };
    const onOut = (e: LeafletMouseEvent) => {
        e.target.setStyle(hentOnOutStyle("rode"));
    };

    layer.on({
        click: onClick,
        mouseover: onHover,
        mouseout: onOut,
    });
};
