import { ApiRespons, Feil, FeilType } from "../../api/api";
import { KontraktBrukerDto } from "../../api/useHentKontraktinfo";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import styled from "styled-components";
import React from "react";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { Lenke } from "../../components/fellesKomponenter/lenker/Lenke";
import { hentFeil } from "../utils/kartSideUtils";
import { KartvisningFeil } from "./KartvisningFeil";
import { useAtomValue } from "jotai/index";
import { aktivKontraktAtom, tidspunktAtom } from "../../api/context/kontraktAtoms";
import { produksjonslenkerAtom, roderAtom } from "../../api/context/apiAtoms";
import { useHentVærstasjon } from "../../api/useHentVærstasjoner";
import { useHentSisteKjøretøy } from "../../api/useHentSisteKjøretøy";

interface KlarteIkkeHenteKontrakterForBrukerFeilmeldingProps {
    brukerInfo: Feil | ApiRespons<KontraktBrukerDto>;
    kontraktFinnes: boolean;
}

export const KlarteIkkeHenteKontrakterForBrukerFeilmelding = ({
    brukerInfo,
    kontraktFinnes,
}: KlarteIkkeHenteKontrakterForBrukerFeilmeldingProps) => {
    const tidspunkt = useAtomValue(tidspunktAtom);
    const aktivKontrakt = useAtomValue(aktivKontraktAtom);
    const produksjonslenker = useAtomValue(produksjonslenkerAtom);
    const roder = useAtomValue(roderAtom);
    const kameradata = useHentVærstasjon();
    const kjøretøydata = useHentSisteKjøretøy(aktivKontrakt, tidspunkt);
    return (
        <>
            {!brukerInfo.suksess && brukerInfo.type === FeilType.FINNER_IKKE_BRUKER_MED_EPOST ? (
                <FeilmeldingContainer>
                    <Heading as="h3" $stylelevel="3">
                        Fant ikke bruker
                    </Heading>
                    <Tekst $størrelse="M">
                        Vi fant ingen ELRAPP-bruker med e-postadressen {brukerInfo.data.epost}. Det
                        kan være flere grunner til dette:
                    </Tekst>

                    <Heading as="h5" $stylelevel="6" $bold={true}>
                        Dersom du har tilgang til driftskontrakter i ELRAPP til vanlig:{" "}
                    </Heading>
                    <Tekst $størrelse="M">
                        Endre eposten din på din profil i ELRAPP til å inneholde full epostadresse,
                        ikke kortversjonen med initialene. Årsaken er at vi foreløpig ikke har
                        felles innloggingsløsning. Profilen din finner du ved å trykke på
                        person-ikonet øverst i høyre hjørnet og deretter “VIS PROFIL”. Dersom
                        eposten er lik begge steder, ta kontakt på
                        <Lenke $størrelse="M" href={"mailto:kos@vegvesen.no"}>
                            {" "}
                            kos@vegvesen.no
                        </Lenke>
                        .{" "}
                    </Tekst>

                    <Heading as="h5" $stylelevel="6" $bold={true}>
                        Ikke bruker i ELRAPP?
                    </Heading>
                    <Tekst $størrelse="M">
                        Send en mail til{" "}
                        <b>
                            <Lenke $størrelse="M" href={"mailto:elrapp@vegvesen.no"}>
                                {" "}
                                elrapp@vegvesen.no
                            </Lenke>
                        </b>{" "}
                        der du forklarer hvilket område du ønsker å ha tilgang til å se i kartet. Vi
                        svarer fortløpende, men det kan ta et par dager.
                    </Tekst>
                </FeilmeldingContainer>
            ) : brukerInfo.suksess && !kontraktFinnes ? (
                <FeilmeldingContainer>
                    <Heading as="h3" $stylelevel="3">
                        Fant ingen kontrakter på din bruker
                    </Heading>
                    <Tekst $størrelse="M">
                        Vi fant ingen kontrakter på din ELRAPP-bruker med e-postadressen{" "}
                        {brukerInfo.data.epost}.
                    </Tekst>
                    <Tekst $størrelse="M">
                        Dersom du mener dette er feil, send en mail til{" "}
                        <b>
                            <Lenke $størrelse="M" href={"mailto:elrapp@vegvesen.no"}>
                                {" "}
                                elrapp@vegvesen.no
                            </Lenke>
                        </b>{" "}
                        der du forklarer hvilket område du ønsker å ha tilgang til å se i kartet. Vi
                        svarer fortløpende, men det kan ta et par dager.
                    </Tekst>
                </FeilmeldingContainer>
            ) : (
                <KartvisningFeil
                    feilmeldinger={hentFeil([
                        roder,
                        produksjonslenker,
                        kjøretøydata,
                        kameradata,
                        brukerInfo,
                    ])}
                />
            )}
        </>
    );
};

const FeilmeldingContainer = styled.div`
    max-width: 750px;
    padding: 24px;
    margin: 20px auto;

    p {
        margin-top: 0;
    }
`;
