import {
    Filter,
    Filterkategori,
    filtertyperIProduksjonslenkerAtom,
    produksjonsfilterAtom,
} from "../../../api/context/ProduksjonsfilterAtoms";
import { Checkbox } from "../../../components/fellesKomponenter/checkboxer/Checkbox";
import styled from "styled-components";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { useAtom, useAtomValue } from "jotai";
import { loggEventMedTabellnavnOgVerdi, TabellNavn } from "../../../utils/loggFrontend";

interface FiltergruppeProps {
    filternavn: string;
    filterkategori: Filterkategori;
}

export const Filtergruppe = ({ filternavn, filterkategori }: FiltergruppeProps) => {
    const filtertyperIProduksjonslenker = useAtomValue(filtertyperIProduksjonslenkerAtom);
    const [produksjonsfilter, setProduksjonsfilter] = useAtom(produksjonsfilterAtom);
    const filtervalg = produksjonsfilter.filter((valg) => valg.kategori === filterkategori);

    const setFiltervalg = (nyeFiltervalg: Filter[]) =>
        setProduksjonsfilter(
            produksjonsfilter.map((valg) => {
                const nyttValg = nyeFiltervalg.find((v) => v.navn === valg.navn);
                if (nyttValg) {
                    return nyttValg;
                } else {
                    return valg;
                }
            }),
        );

    const toggleValgtAlle = (): void => {
        if (noenValgt()) {
            settAlle(false);
        } else {
            settAlle(true);
        }
    };

    const settAlle = (valgt: boolean): void => {
        loggEventMedTabellnavnOgVerdi(TabellNavn.filterKlikk, filternavn, valgt ? "På" : "Av");
        setFiltervalg(
            filtervalg.map((valg) => {
                if (
                    valg.kategori === filterkategori &&
                    filtertyperIProduksjonslenker.includes(valg.type)
                ) {
                    return {
                        navn: valg.navn,
                        type: valg.type,
                        kategori: valg.kategori,
                        valgt: valgt,
                    };
                } else {
                    return valg;
                }
            }),
        );
    };

    const toggleValgt = (oppdaterValg: Filter): void =>
        setFiltervalg(
            filtervalg.map((valg) => {
                if (valg.navn === oppdaterValg.navn) {
                    loggEventMedTabellnavnOgVerdi(
                        TabellNavn.filterKlikk,
                        valg.navn,
                        !valg.valgt ? "På" : "Av",
                    );
                    return {
                        navn: valg.navn,
                        type: valg.type,
                        kategori: valg.kategori,
                        valgt: !valg.valgt,
                    };
                } else {
                    return valg;
                }
            }),
        );

    const noenValgt = (): boolean => filtervalg.find((valg) => valg.valgt)?.valgt ?? false;

    const alleValgt = (): boolean => filtervalg.every((valg) => valg.valgt);

    const erDisabled = (): boolean =>
        !filtervalg.some((filter) => filtertyperIProduksjonslenker.includes(filter.type));

    return (
        <Fieldset>
            {filtervalg.length > 1 && (
                <ToggleButton disabled={erDisabled()} onClick={toggleValgtAlle}>
                    <ToggleCheckbox
                        $noenvalgt={noenValgt() && !alleValgt()}
                        $allevalgt={alleValgt()}
                        aria-label={noenValgt() ? "Avvelg alle" : "Velg alle"}
                    />
                    <Tekst $bold={true} $nomargin={true} $størrelse={"M"}>
                        {filternavn} - {noenValgt() ? "Fjern alle" : "Velg alle"}
                    </Tekst>
                </ToggleButton>
            )}

            {filtervalg.map((valg, index) => (
                <Checkbox
                    key={`${filternavn}-${index}`}
                    onChange={() => toggleValgt(valg)}
                    checked={valg.valgt}
                    value={valg.navn}
                    disabled={!filtertyperIProduksjonslenker.includes(valg.type)}
                    tekstStørrelse={"M"}
                >
                    {valg.navn}
                </Checkbox>
            ))}
        </Fieldset>
    );
};

const Fieldset = styled.fieldset`
    border: 0;
    border-bottom: 1px solid;
    display: flex;
    flex-direction: column;
    gap: 8px;
    margin-bottom: 8px;
    padding-bottom: 16px;

    &:last-child {
        border-bottom: none;
        margin-bottom: 4px;
        padding-bottom: 8px;
    }
`;

const ToggleCheckbox = styled.div<{ $allevalgt: boolean; $noenvalgt: boolean }>`
    background-color: var(--white);
    border: none;
    border-radius: 0;
    box-shadow: inset 0 0 0 2px var(--gray-dark);
    content: "";
    flex-shrink: 0;
    height: 32px;
    width: 32px;

    ${(props) => props.$noenvalgt && `background: url("/ikon/checkmark-dash.svg") no-repeat 50%;`};
    ${(props) => props.$allevalgt && `background: url("/ikon/checkmark.svg") no-repeat 50%;`};
`;

const ToggleButton = styled.button`
    align-items: center;
    background-color: var(--white);
    border: none;
    cursor: pointer;
    display: flex;
    gap: 8px;
    margin-bottom: 8px;
    padding: 0;

    &:hover + ${ToggleCheckbox} {
        box-shadow: inset 0 0 0 3px var(--gray-dark);
        cursor: pointer;
    }

    &:focus + ${ToggleCheckbox} {
        box-shadow: inset 0 0 0 3px var(--gray-dark);
        outline: 3px solid var(--orange);
        outline-offset: 2px;
    }

    &:disabled {
        ${Tekst} {
            color: var(--gray-regular-dark);
        }

        ${ToggleCheckbox} {
            box-shadow: inset 0 0 0 2px var(--gray-regular-dark);
        }
    }
`;
