import { Filtergruppe } from "./Filtergruppe";
import {
    Filterkategori,
    Filtertype,
    filtertyperIProduksjonslenkerAtom,
    produksjonsfilterAtom,
} from "../../../api/context/ProduksjonsfilterAtoms";
import styled from "styled-components";
import {
    fontsizeLargeScreen,
    fontsizeSmallScreen,
} from "../../../components/fellesKomponenter/typografi/TekstStyles";
import { AnimatePresence } from "framer-motion";
import { breakpointNettbrett } from "../../../utils/constants";
import { useAtom, useAtomValue } from "jotai";

interface ProduksjonsdetaljerFiltrerVelgerProps {
    åpen: boolean;
}

export const ProduksjonsdataFilterVelger = ({ åpen }: ProduksjonsdetaljerFiltrerVelgerProps) => {
    const filtertyperIProduksjonslenker = useAtomValue(filtertyperIProduksjonslenkerAtom);
    const [produksjonsfilter, setProduksjonsfilter] = useAtom(produksjonsfilterAtom);

    const defaultValgteProduksjonsfilter = produksjonsfilter.map((filter) => ({
        ...filter,
        valgt:
            filtertyperIProduksjonslenker!.includes(filter.type) &&
            filter.type !== Filtertype.IngenProduksjon,
    }));

    return (
        <AnimatePresence>
            {åpen && (
                <>
                    <NullstillButton
                        onClick={() => setProduksjonsfilter(defaultValgteProduksjonsfilter)}
                    >
                        Velg all produksjon
                    </NullstillButton>
                    <Filtergruppe filternavn="Brøyting" filterkategori={Filterkategori.Brøyting} />
                    <Filtergruppe filternavn="Høvling" filterkategori={Filterkategori.Høvling} />
                    <Filtergruppe filternavn="Sand" filterkategori={Filterkategori.Sand} />
                    <Filtergruppe filternavn="Salt" filterkategori={Filterkategori.Salt} />
                    <Filtergruppe
                        filternavn="Ingen produksjon"
                        filterkategori={Filterkategori.IngenProduksjon}
                    />
                    <Filtergruppe
                        filternavn="Ukjent produksjon"
                        filterkategori={Filterkategori.UkjentMateriale}
                    />
                </>
            )}
        </AnimatePresence>
    );
};

const NullstillButton = styled.button`
    background-color: var(--white);
    border: none;
    cursor: pointer;
    display: block;
    text-align: left;
    ${fontsizeLargeScreen};
    margin: 8px 2px 8px 2px;
    padding: 0 0 8px 9px;
    text-decoration: underline;
    border-bottom: 1px solid;
    width: calc(100% - 4px);
    color: var(--gray-dark);

    @media (max-width: ${breakpointNettbrett}) {
        ${fontsizeSmallScreen};
    }
`;
