import { Filtertype, MaterialOgAktivitetsNavn } from "../../../api/context/ProduksjonsfilterAtoms";
import { MaterialType, MaterialKategori } from "../../types/materiale";
import { AktivitetType, AktivitetKategori } from "../../types/aktivitet";
import { Produksjonslenke } from "../../types/produksjonslenke";
import { produksjonslenkerTilFiltertyper } from "../../../api/context/kartdataHelpers";

describe("Produksjonsdata filter velger", () => {
    it("skal finne tom liste av filtre hvis produksjonsdata er tom", () => {
        expect(produksjonslenkerTilFiltertyper([])).toBeEmpty();
    });

    it("skal bare ha hver filtertype en gang om det finnes flere i produksjonsdata", () => {
        const lenker: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 39,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.PlogNede,
                            type: AktivitetType.PlogNede,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: undefined,
            },
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 39,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.PlogNede,
                            type: AktivitetType.PlogNede,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: undefined,
            },
        ];

        const filtertyper = produksjonslenkerTilFiltertyper(lenker);

        expect(filtertyper).toEqual([Filtertype.PlogNede]);
    });
    it("skal legge til filter for materialer, plog, høvel og ingen produksjon", () => {
        const lenker: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 39,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.PlogNede,
                            type: AktivitetType.PlogNede,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: undefined,
            },
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 39,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Saltløsning,
                    type: MaterialType.Saltløsning,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 39,
                produksjonstyper: [],
            },
        ];

        const filtertyper = produksjonslenkerTilFiltertyper(lenker);

        expect(filtertyper).toEqual([
            Filtertype.PlogNede,
            Filtertype.TungHøvel,
            Filtertype.Saltløsning,
            Filtertype.IngenProduksjon,
        ]);
    });
});
