import {
    Filterkategori,
    Filtertype,
    MaterialOgAktivitetsNavn,
} from "../../../api/context/ProduksjonsfilterAtoms";
import { filtrerProduksjonslenker } from "./filtrerProduksjon";
import { Produksjonslenke } from "../../types/produksjonslenke";
import { AktivitetKategori, AktivitetType } from "../../types/aktivitet";
import { MaterialKategori, MaterialType } from "../../types/materiale";
import { setTestFiltre } from "./filterTestUtils";
import { defaultTidsfilter } from "../../jotai/TidsfilterAtom";
import { Tidsintervall } from "../../utils/tidsintervallUtils";

describe("Kartvisning", () => {
    const lenker: Produksjonslenke[] = [
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 43,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.PlogNede,
                        type: AktivitetType.PlogNede,
                        kategori: AktivitetKategori.Brøyting,
                    },
                    ibruk: true,
                },
            ],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 2,
            veglenkeNummer: 1,
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 91,
            økt: "1234",
            hastighetKmH: 43,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.Sideplog,
                        type: AktivitetType.Sideplog,
                        kategori: AktivitetKategori.Brøyting,
                    },

                    ibruk: true,
                },
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.TungHøvel,
                        type: AktivitetType.TungHøvel,
                        kategori: AktivitetKategori.Høvling,
                    },

                    ibruk: true,
                },
            ],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.Tørrsand,
                type: MaterialType.Tørrsand,
                kategori: MaterialKategori.Sand,
            },
        },
        {
            veglenkesekvensId: 3,
            veglenkeNummer: 1,
            økt: "1235",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 121,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.Fastsand,
                type: MaterialType.Fastsand,
                kategori: MaterialKategori.Sand,
            },
        },
        {
            veglenkesekvensId: 4,
            veglenkeNummer: 1,
            økt: "1235",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 181,
            hastighetKmH: 43,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.TungHøvel,
                        type: AktivitetType.TungHøvel,
                        kategori: AktivitetKategori.Høvling,
                    },
                    ibruk: true,
                },
            ],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.SandMedSaltInnblanding,
                type: MaterialType.SandMedSaltInnblanding,
                kategori: MaterialKategori.Sand,
            },
        },
        {
            veglenkesekvensId: 5,
            veglenkeNummer: 1,
            økt: "1235",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 241,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.Tørrsalt,
                type: MaterialType.Tørrsalt,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 6,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 711,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.BefuktetSalt,
                type: MaterialType.BefuktetSalt,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 7,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
                type: MaterialType.BefuktetFinkornetSalt,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 8,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.Saltløsning,
                type: MaterialType.Saltløsning,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 9,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
                type: MaterialType.Magnesiumklorid,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 10,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 11,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 48,
            produksjonstyper: [],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 12,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 48,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
                type: MaterialType.Magnesiumklorid,
                kategori: MaterialKategori.Salt,
            },
        },
    ];
    const tomtHastighetsFilter = {
        verdi: "",
        valgt: false,
    };

    it("skal beholde alle produksjonslenker når alle filtere er skudd på", () => {
        const filter = setTestFiltre([Filtertype.IngenProduksjon], []);
        const nyeLenker = filtrerProduksjonslenker(
            filter,
            tomtHastighetsFilter,
            lenker,
            defaultTidsfilter,
        );
        expect(lenker).toEqual(nyeLenker);
    });

    it("Viser tung høvel når tung høvel er valgt", () => {
        const filter = setTestFiltre(
            [Filtertype.TungHøvel],
            [
                Filtertype.PlogNede,
                Filtertype.Sideplog,
                Filtertype.UnderliggendeSkjær,
                Filtertype.Tørrsand,
                Filtertype.Fastsand,
                Filtertype.SandMedSaltInnblanding,
                Filtertype.Tørrsalt,
                Filtertype.BefuktetSalt,
                Filtertype.BefuktetFinkornetSalt,
                Filtertype.Saltløsning,
                Filtertype.Magnesiumklorid,
                Filtertype.IngenProduksjon,
            ],
        );
        const nyeLenker = filtrerProduksjonslenker(
            filter,
            tomtHastighetsFilter,
            lenker,
            defaultTidsfilter,
        );
        const lenkerMedTungHøvel: Produksjonslenke[] = [
            {
                veglenkesekvensId: 2,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 91,
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.Sideplog,
                            type: AktivitetType.Sideplog,
                            kategori: AktivitetKategori.Brøyting,
                        },

                        ibruk: true,
                    },
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },

                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Tørrsand,
                    type: MaterialType.Tørrsand,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 4,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 181,
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.SandMedSaltInnblanding,
                    type: MaterialType.SandMedSaltInnblanding,
                    kategori: MaterialKategori.Sand,
                },
            },
        ];
        expect(nyeLenker).toEqual(lenkerMedTungHøvel);
    });

    it("fjerner ingenproduksjon når filter skudd av", () => {
        const filter = setTestFiltre([], [Filtertype.IngenProduksjon]);
        const nyeLenker = filtrerProduksjonslenker(
            filter,
            tomtHastighetsFilter,
            lenker,
            defaultTidsfilter,
        );
        const lenkerUtenIngenProduksjon: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.PlogNede,
                            type: AktivitetType.PlogNede,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: undefined,
            },
            {
                veglenkesekvensId: 2,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 91,
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.Sideplog,
                            type: AktivitetType.Sideplog,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: true,
                    },
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Tørrsand,
                    type: MaterialType.Tørrsand,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 3,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 121,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Fastsand,
                    type: MaterialType.Fastsand,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 4,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 181,
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.SandMedSaltInnblanding,
                    type: MaterialType.SandMedSaltInnblanding,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 5,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 241,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Tørrsalt,
                    type: MaterialType.Tørrsalt,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 6,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 711,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.BefuktetSalt,
                    type: MaterialType.BefuktetSalt,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 7,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
                    type: MaterialType.BefuktetFinkornetSalt,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 8,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Saltløsning,
                    type: MaterialType.Saltløsning,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 9,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
                    type: MaterialType.Magnesiumklorid,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 12,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 48,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
                    type: MaterialType.Magnesiumklorid,
                    kategori: MaterialKategori.Salt,
                },
            },
        ];
        // expect(nyeLenker).toHaveLength(10);
        expect(nyeLenker).toEqual(lenkerUtenIngenProduksjon);
    });
    it("Viser all kjøring over 45kmt når hastighestfilteret er valgt", () => {
        const filter = setTestFiltre([Filtertype.IngenProduksjon], []);
        const hastighetsfilter = {
            verdi: "45",
            valgt: true,
        };
        const nyeLenker = filtrerProduksjonslenker(
            filter,
            hastighetsfilter,
            lenker,
            defaultTidsfilter,
        );
        const lenkerMedsKjøringerOver45: Produksjonslenke[] = [
            {
                veglenkesekvensId: 11,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 48,
                produksjonstyper: [],
                produksjonsmateriale: undefined,
            },
            {
                veglenkesekvensId: 12,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 48,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
                    type: MaterialType.Magnesiumklorid,
                    kategori: MaterialKategori.Salt,
                },
            },
        ];
        expect(nyeLenker).toEqual(lenkerMedsKjøringerOver45);
    });
    it("Viser kjøring over 45kmt for akutelle filtere når over 45 og noen filtere valgt", () => {
        const filter = setTestFiltre([Filtertype.IngenProduksjon], [Filtertype.Magnesiumklorid]);
        const hastighetsfilter = {
            verdi: "45",
            valgt: true,
        };
        const nyeLenker = filtrerProduksjonslenker(
            filter,
            hastighetsfilter,
            lenker,
            defaultTidsfilter,
        );
        const lenkerMedsKjøringerOver45: Produksjonslenke[] = [
            {
                veglenkesekvensId: 11,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 48,
                produksjonstyper: [],
                produksjonsmateriale: undefined,
            },
        ];
        expect(nyeLenker).toEqual(lenkerMedsKjøringerOver45);
    });

    it("Viser kun for gjeldene tidsfilter når tidsfilter er valgt", () => {
        const filter = setTestFiltre([Filtertype.IngenProduksjon], []);
        const tidsfilter = [
            {
                startTidspunkt: Tidsintervall.time0h,
                sluttTidspunkt: Tidsintervall.time1h30m,
                valgt: false,
            },
            {
                startTidspunkt: Tidsintervall.time1h30m,
                sluttTidspunkt: Tidsintervall.time2h,
                valgt: true,
            },
            {
                startTidspunkt: Tidsintervall.time2h,
                sluttTidspunkt: Tidsintervall.time3h,
                valgt: true,
            },
            {
                startTidspunkt: Tidsintervall.time3h,
                sluttTidspunkt: Tidsintervall.time4h,
                valgt: true,
            },
            {
                startTidspunkt: Tidsintervall.time4h,
                sluttTidspunkt: Tidsintervall.time12h,
                valgt: true,
            },
        ];
        const nyeLenker = filtrerProduksjonslenker(
            filter,
            tomtHastighetsFilter,
            lenker,
            tidsfilter,
        );

        const lenkerMedTidsfilterOver1h30m = [
            {
                veglenkesekvensId: 2,
                veglenkeNummer: 1,
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 91,
                økt: "1234",
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.Sideplog,
                            type: AktivitetType.Sideplog,
                            kategori: AktivitetKategori.Brøyting,
                        },

                        ibruk: true,
                    },
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },

                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Tørrsand,
                    type: MaterialType.Tørrsand,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 3,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 121,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Fastsand,
                    type: MaterialType.Fastsand,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 4,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 181,
                hastighetKmH: 43,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.TungHøvel,
                            type: AktivitetType.TungHøvel,
                            kategori: AktivitetKategori.Høvling,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.SandMedSaltInnblanding,
                    type: MaterialType.SandMedSaltInnblanding,
                    kategori: MaterialKategori.Sand,
                },
            },
            {
                veglenkesekvensId: 5,
                veglenkeNummer: 1,
                økt: "1235",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 241,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.Tørrsalt,
                    type: MaterialType.Tørrsalt,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 6,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 711,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.BefuktetSalt,
                    type: MaterialType.BefuktetSalt,
                    kategori: MaterialKategori.Salt,
                },
            },
        ];

        expect(nyeLenker).toEqual(lenkerMedTidsfilterOver1h30m);
    });
});

describe("Filtere samsvarer med gcp-kontrakt", () => {
    test("at alle kjente AktivitetType og MaterialType kan mappes til Filterkategori", () => {
        Object.values(AktivitetKategori).forEach((type) =>
            expect(type).toEqual(Filterkategori[type]),
        );
        Object.values(MaterialKategori).forEach((type) =>
            expect(type).toEqual(Filterkategori[type]),
        );
    });
    test("at kjente Produksjonsaktivitet og Materiale kan mappes til Filtertype", () => {
        Object.values(AktivitetType).forEach((type) => expect(type).toEqual(Filtertype[type]));
        Object.values(MaterialType).forEach((type) => expect(type).toEqual(Filtertype[type]));
    });
    describe("Det finnes ingen overflødige filtere", () => {
        test("at filter supplerer med kategori og type for ingen produksjon", () => {
            expect(Filterkategori.IngenProduksjon && Filtertype.IngenProduksjon).toBeTruthy();
        });
        test("at antall implementerte filtere samsvarer med forventede dtoer", () => {
            const kategorierPlussIngenProduksjonPlussOver45 =
                Object.entries(AktivitetKategori).length +
                Object.entries(MaterialKategori).length +
                1;
            const typerPlussIngenProduksjonPlussOver45 =
                Object.entries(AktivitetType).length + Object.entries(MaterialType).length + 1;
            expect(kategorierPlussIngenProduksjonPlussOver45).toEqual(
                Object.entries(Filterkategori).length,
            );
            expect(typerPlussIngenProduksjonPlussOver45).toEqual(Object.entries(Filtertype).length);
        });
    });
});
