import { atom } from "jotai";

type InformasjonsmeldingKategori = "advarsel" | "info" | "error";

export enum InformasjonsmeldingType {
    ingenDataForFiltere = "ingenDataForFiltere",
    ingenDataForStengteVeier = "ingenDataForStengteVeier",
    lasterStengteVeier = "lasterStengteVeier",
    ingenProddataForValgteTimer = "ingenProddataForValgteTimer",
    tidspunktFremITid = "tidspunktFremITid",
    viserAltSisteProduksjon = "viserAltSisteProduksjon",
    ingenDataIKartet = "ingenDataIKartet",
    kontraktIkkeGyldig = "kontraktIkkeGyldig",
}

const ingenDataForFiltere: Informasjonsmelding = {
    tekst: "Ingen data for valgte filtere.",
    type: InformasjonsmeldingType.ingenDataForFiltere,
    kategori: "advarsel",
};

const ingenProddataForValgteTimer: Informasjonsmelding = {
    tekst: "Vi fant ikke noe produksjonsdata for de valgte 12 timene.",
    type: InformasjonsmeldingType.ingenProddataForValgteTimer,
    kategori: "advarsel",
};

const ingenDataForStengteVeier: Informasjonsmelding = {
    tekst: "Laster informasjon om stengte veier.",
    type: InformasjonsmeldingType.ingenDataForStengteVeier,
    kategori: "info",
};

const lasterStengteVeier: Informasjonsmelding = {
    tekst: "Laster informasjon om stengte veier.",
    type: InformasjonsmeldingType.lasterStengteVeier,
    kategori: "info",
};

const tidspunktFremITid: Informasjonsmelding = {
    tekst: "Du kan ikke velge et tidspunkt som er frem i tid.",
    type: InformasjonsmeldingType.tidspunktFremITid,
    kategori: "error",
};

const viserAltSisteProduksjon: Informasjonsmelding = {
    tekst: "Sist oppdaterte produksjon vises allerede i kartet. Vi henter data fra Elrapp hvert femte minutt.",
    type: InformasjonsmeldingType.viserAltSisteProduksjon,
    kategori: "info",
};

const ingenDataIKartet: Informasjonsmelding = {
    tekst: "Det er ingen produksjon i kartet.",
    type: InformasjonsmeldingType.ingenDataIKartet,
    kategori: "advarsel",
};

const kontraktIkkeGyldig: Informasjonsmelding = {
    tekst: "Kontrakten er ikke gyldig for valgt tidspunkt.",
    type: InformasjonsmeldingType.kontraktIkkeGyldig,
    kategori: "advarsel",
};

export const informasjonsmeldinger = {
    ingenDataForFiltere: ingenDataForFiltere,
    ingenProddataForValgteTimer: ingenProddataForValgteTimer,
    ingenDataForStengteVeier: ingenDataForStengteVeier,
    lasterStengteVeier: lasterStengteVeier,
    tidspunktFremITid: tidspunktFremITid,
    viserAltSisteProduksjon: viserAltSisteProduksjon,
    ingenDataIKartet: ingenDataIKartet,
    kontraktIkkeGyldig: kontraktIkkeGyldig,
};

export interface Informasjonsmelding {
    tekst: string;
    type: InformasjonsmeldingType;
    kategori: InformasjonsmeldingKategori;
    onClose?: () => void;
}

const informasjonsmeldingAtom = atom<Informasjonsmelding | undefined>(undefined);

export const informasjonsmeldingMedTimeoutAtom = atom<
    Informasjonsmelding | undefined,
    [nextValue: Informasjonsmelding | undefined, tid?: number],
    void
>(
    (get) => get(informasjonsmeldingAtom),
    (get, set, nextValue: Informasjonsmelding | undefined, tid?: number) => {
        set(informasjonsmeldingAtom, nextValue);
        setTimeout(() => {
            set(informasjonsmeldingAtom, undefined);
        }, tid ?? 10000);
    },
);
