import "leaflet/dist/leaflet.css";
import BrøytebilSpinner from "../brøytebilSpinner/BrøytebilSpinner";
import { KartvisningFeil } from "../feil/KartvisningFeil";
import dynamic from "next/dynamic";
import { useHentSisteKjøretøy } from "../../api/useHentSisteKjøretøy";
import { hentFeil } from "../utils/kartSideUtils";
import { ProduksjonskartVisningProps } from "../Kartvisning/ProduksjonskartVisning";
import { useHentVærstasjon } from "../../api/useHentVærstasjoner";
import { useAtomValue } from "jotai";
import { aktivKontraktAtom, tidspunktAtom } from "../../api/context/kontraktAtoms";
import { produksjonslenkerAtom, roderAtom } from "../../api/context/apiAtoms";

export const ProduksjonskartInnhold = () => {
    const tidspunkt = useAtomValue(tidspunktAtom);
    const aktivKontrakt = useAtomValue(aktivKontraktAtom);
    const produksjonslenker = useAtomValue(produksjonslenkerAtom);
    const roder = useAtomValue(roderAtom);
    const kameradata = useHentVærstasjon();
    const kjøretøydata = useHentSisteKjøretøy(aktivKontrakt, tidspunkt);

    return (
        <>
            {!roder || !kameradata || !produksjonslenker || !kjøretøydata ? (
                <BrøytebilSpinner />
            ) : !(
                  //roder.suksess &&
                  (kameradata.suksess && kjøretøydata.suksess && produksjonslenker.suksess)
              ) ? (
                <KartvisningFeil
                    feilmeldinger={hentFeil([produksjonslenker, kjøretøydata, kameradata])}
                />
            ) : (
                <DynamicKartvisning
                    produksjonslenker={produksjonslenker.suksess ? produksjonslenker.data : []}
                    kjøretøydata={kjøretøydata.suksess ? kjøretøydata.data : []}
                    roder={roder?.suksess ? roder.data : []}
                    kameradata={kameradata.suksess ? kameradata.data : []}
                />
            )}
        </>
    );
};

const DynamicKartvisning = dynamic<ProduksjonskartVisningProps>(
    () => import("../Kartvisning/ProduksjonskartVisning").then((mod) => mod.ProduksjonskartVisning),
    {
        loading: () => <BrøytebilSpinner />,
        ssr: false,
    },
);
