import React, { useState } from "react";
import { FormLabel } from "../../components/fellesKomponenter/inputfelt/FormLabel";
import { HjelpetekstPopup } from "../../components/fellesKomponenter/HjelpetekstPopup";
import { KnappPrimær } from "../../components/fellesKomponenter/knapper/KnappPrimær";
import { KnappSekundær } from "../../components/fellesKomponenter/knapper/KnappSekundær";
import { Inputfelt } from "../../components/fellesKomponenter/inputfelt/Inputfelt";
import { Spinner } from "../../components/fellesKomponenter/spinner/Spinner";
import { ColumnWrapper, RowWrapper } from "../../components/fellesKomponenter/wrappers/wrappers";
import styled from "styled-components";
import { InfoknappLoggEvent } from "../../utils/loggFrontend";

interface DataInputProps {
    tittel: string;
    handleSubmit: (data: string) => void;
    errormelding: string[];
    $error: boolean;
    setError: (error: boolean) => void;
    hjelpetekst?: string;
    infoknappLoggEvent?: InfoknappLoggEvent;
    laster?: boolean;
    resetData?: () => void;
    størrelse?: StørrelseType;
    verdi?: string;
}

export type StørrelseType = "XXL" | "XL" | "L" | "M" | "S" | "XS";

export const DataInput = ({
    handleSubmit,
    resetData,
    hjelpetekst,
    infoknappLoggEvent,
    tittel,
    errormelding,
    laster,
    $error,
    setError,
    størrelse,
    verdi,
}: DataInputProps) => {
    const [data, setData] = useState<string>(verdi ?? "");
    const nullstillData = () => {
        setData("");
        setError(false);
        resetData && resetData();
    };

    const handleSubmitForm = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();
        handleSubmit(data);
    };

    return (
        <ColumnWrapper>
            <StyledRowWrapper>
                <FormLabel htmlFor={tittel}>{tittel}</FormLabel>
                {hjelpetekst && infoknappLoggEvent && (
                    <IkonWrapper>
                        <HjelpetekstPopup
                            plassering={"right center"}
                            størrelse={"S"}
                            infoknappLoggEvent={infoknappLoggEvent}
                        >
                            {hjelpetekst}
                        </HjelpetekstPopup>
                    </IkonWrapper>
                )}
            </StyledRowWrapper>

            <StyledRowWrapper>
                <StyledForm onSubmit={handleSubmitForm}>
                    <Inputfelt
                        $error={$error}
                        type="text"
                        id={tittel}
                        $størrelse={størrelse ? størrelse : "S"}
                        onChange={(e) => setData(e.target.value)}
                        value={data}
                    />
                    <KnappPrimær size={"Small"} type="submit" disabled={laster}>
                        {laster ? <Spinner storrelse="xliten" inline={true} /> : "Ok"}
                    </KnappPrimær>
                </StyledForm>
                {resetData && (
                    <KnappSekundær size={"Small"} onClick={nullstillData} disabled={laster}>
                        Nullstill
                    </KnappSekundær>
                )}
            </StyledRowWrapper>
            {$error &&
                errormelding.map((melding, index) => (
                    <ErrorMelding key={index}>{melding}</ErrorMelding>
                ))}
        </ColumnWrapper>
    );
};

const StyledRowWrapper = styled(RowWrapper)`
    gap: 0.5rem;
    align-items: flex-start;
`;

const StyledForm = styled.form`
    gap: 0.5rem;
    align-items: flex-start;
    max-width: max-content;
    display: flex;
    flex-direction: row;
    flex-shrink: 0;
`;

export const IkonWrapper = styled.div`
    align-self: flex-start;
    margin: 0 0 5px 0;
`;

export const ErrorMelding = styled.p`
    color: var(--gray-dark);
    margin: 0 0 0 0;
    position: relative;
    background-color: var(--red-bg);
    padding: 2px;
`;
