import React, { useEffect, useState } from "react";
import styled from "styled-components";
import { Datofelt } from "../../components/fellesKomponenter/inputfelt/Datofelt";
import { KlokkeslettFelt } from "../../components/fellesKomponenter/inputfelt/Klokkelsettfelt";
import { KnappPrimær } from "../../components/fellesKomponenter/knapper/KnappPrimær";
import dayjs, { Dayjs } from "dayjs";
import { settKartUrlParam } from "../utils/kartUrlUtils";
import { KnappSekundær } from "../../components/fellesKomponenter/knapper/KnappSekundær";
import { usePathname } from "next/navigation";
import {
    informasjonsmeldinger,
    informasjonsmeldingMedTimeoutAtom,
} from "../jotai/InformasjonsmeldingAtom";
import { resetKartFeaturesAtom } from "../jotai/karvalgAtoms";
import { useAtom, useAtomValue, useSetAtom } from "jotai";
import { aktivKontraktAtom, tidspunktAtom } from "../../api/context/kontraktAtoms";
import { produksjonsfilterAtom } from "../../api/context/ProduksjonsfilterAtoms";
import { produksjonslenkerAtom } from "../../api/context/apiAtoms";
import { FormLabel } from "../../components/fellesKomponenter/inputfelt/FormLabel";
import { RESET } from "jotai/utils";
import tekster from "../../tekster.json";

export const DatoInput = () => {
    const [tidspunkt, setTidspunkt] = useAtom(tidspunktAtom);
    const aktivKontrakt = useAtomValue(aktivKontraktAtom);
    const produksjonslenker = useAtomValue(produksjonslenkerAtom);
    const setInformasjonsmelding = useSetAtom(informasjonsmeldingMedTimeoutAtom);
    const setProduksjonsfilter = useSetAtom(produksjonsfilterAtom);
    const pathname = usePathname();
    const lasterKartdata = produksjonslenker === undefined;
    const [formDato, setFormDato] = useState(tidspunkt);
    const [formKlokkeslett, setFormKlokkeslett] = useState(tidspunkt);
    const resetKartFeatures = useSetAtom(resetKartFeaturesAtom);

    useEffect(() => {
        aktivKontrakt &&
            settKartUrlParam(pathname ? pathname : "", {
                elrappKontraktId: aktivKontrakt.elrappId,
                timestamp: tidspunkt,
            });
    }, [produksjonslenker]);

    const handleSubmit = (e: React.FormEvent<HTMLFormElement>) => {
        e.preventDefault();
        validerOgSubmit();
    };

    const validerOgSubmit = (nå?: boolean) => {
        const endreTilDato = nå ? dayjs() : formDato;
        const endreTilKlokkeslett = nå ? dayjs() : formKlokkeslett;
        const formOgContextErLike =
            endreTilDato.date() === tidspunkt.date() &&
            endreTilDato.month() === tidspunkt.month() &&
            endreTilDato.year() === tidspunkt.year() &&
            endreTilKlokkeslett.hour() === tidspunkt.hour() &&
            endreTilKlokkeslett.minute() === tidspunkt.minute();
        if (!validerSkjema(endreTilDato, endreTilKlokkeslett)) {
            setInformasjonsmelding(informasjonsmeldinger.tidspunktFremITid);
        } else if (formOgContextErLike) {
            setInformasjonsmelding(informasjonsmeldinger.viserAltSisteProduksjon);
        } else if (!lasterKartdata) {
            setInformasjonsmelding(undefined);
            setTidspunkt(
                endreTilDato
                    .set("hour", endreTilKlokkeslett.hour())
                    .set("minute", endreTilKlokkeslett.minute()),
            );
            setProduksjonsfilter(RESET);
            resetKartFeatures();
        }
    };

    const settNåtid = (e: React.FormEvent<HTMLButtonElement>) => {
        e.preventDefault();
        const nå = dayjs();
        setFormDato(nå);
        setFormKlokkeslett(nå);
        validerOgSubmit(true);
    };

    return (
        <StyledForm onSubmit={handleSubmit}>
            <Datofelt
                dato={formDato}
                setDato={setFormDato}
                tittel={"Velg dato"}
                hjelpetekst={tekster.velgDato}
            />
            <div>
                <StyledDiv>
                    <FormLabel htmlFor="klokkeslett">Velg klokkeslett</FormLabel>
                </StyledDiv>
                <RowWrapper>
                    <KlokkeslettFelt
                        klokkeslett={formKlokkeslett}
                        settKlokkeslett={setFormKlokkeslett}
                        aria-controls="informasjonsmelding"
                    />
                    <KnappSekundær
                        size="Small"
                        type="button"
                        onClick={settNåtid}
                        disabled={lasterKartdata}
                    >
                        Nå
                    </KnappSekundær>
                    <KnappPrimær type="submit" disabled={lasterKartdata} size="Small">
                        Hent data
                    </KnappPrimær>
                </RowWrapper>
            </div>
        </StyledForm>
    );
};

const validerSkjema = (dato: Dayjs, tidspunkt: Dayjs) =>
    dato.isBefore(dayjs(), "day") ||
    (dato.isSame(dayjs(), "day") && (tidspunkt.isBefore(dayjs()) || tidspunkt.isSame(dayjs())));

const StyledForm = styled.form`
    max-width: max-content;
    display: flex;
    flex-direction: column;
    gap: 0.7rem;
    align-items: flex-start;
    flex-shrink: 0;
`;

const RowWrapper = styled.div`
    display: flex;
    flex-direction: row;
    gap: 0.5rem;
    align-items: flex-end;
`;

const StyledDiv = styled.div`
    margin-bottom: 0.3rem;
`;
