import React, { useState } from "react";
import { FormLabel } from "../../components/fellesKomponenter/inputfelt/FormLabel";
import { Inputfelt } from "../../components/fellesKomponenter/inputfelt/Inputfelt";
import { ColumnWrapper, RowWrapper } from "../../components/fellesKomponenter/wrappers/wrappers";
import styled from "styled-components";
import { EksternLenkeIkon } from "../../components/fellesKomponenter/lenker/EksternLenke";
import { LenkeKnapp } from "../../components/fellesKomponenter/lenker/LenkeKnapp";
import {
    KartparametereLoggEvent,
    loggEventMedTabellnavn,
    TabellNavn,
} from "../../utils/loggFrontend";

interface DataInputProps {
    tittel: string;
    primærKnappTekst: string;
}

export const InputLink = ({ tittel, primærKnappTekst }: DataInputProps) => {
    const [øktid, setØktid] = useState<string>("");

    return (
        <ColumnWrapper>
            <StyledRowWrapper>
                <FormLabel htmlFor={tittel}>{tittel}</FormLabel>
            </StyledRowWrapper>

            <StyledRowWrapper>
                <Inputfelt
                    type="text"
                    $størrelse={"S"}
                    onChange={(e) => setØktid(e.target.value)}
                    value={øktid}
                />
                <LenkeKnapp
                    href={
                        øktid === ""
                            ? "/oktdetaljer"
                            : `/oktdetaljer/?oktid=${øktid.replaceAll(" ", "")}`
                    }
                    target={"_blank"}
                    onClick={() =>
                        loggEventMedTabellnavn(
                            TabellNavn.kartparametere,
                            KartparametereLoggEvent.øktdetaljerLenke,
                        )
                    }
                    size={"Small"}
                >
                    {primærKnappTekst}
                    <EksternLenkeIkon $ersvart={false} />
                </LenkeKnapp>
            </StyledRowWrapper>
        </ColumnWrapper>
    );
};

const StyledRowWrapper = styled(RowWrapper)`
    gap: 0.5rem;
    align-items: flex-start;
`;
