import React, { useState } from "react";
import { DatoInput } from "./DatoInput";
import { ProduksjonsdataFilter } from "../filtre/filtervelger/ProduksjonsdataFilter";
import { TidspunktSisteImport } from "./TidspunktSisteImport";
import { MenyContainer } from "../../components/fellesKomponenter/uttrekksmeny/MenyContainer";
import { RodeListe } from "./RodeListe";
import { KartvisningsValg } from "./KartvisningsValg";
import { EksporterAllData } from "./EksporterAllData";
import styled from "styled-components";
import { DataInput } from "./DataInput";
import { erGyldigNumeriskInput } from "../../utils/inputValidering";
import { lasterØktProduksjonslenkerAtom } from "../../api/context/ØktLenkerAtoms";
import { hastighetsfilterAtom } from "../jotai/HastighetsfilterAtom";
import tekster from "../../tekster.json";
import { useAtom, useAtomValue, useSetAtom } from "jotai";
import { produksjonslenkerAtom } from "../../api/context/apiAtoms";
import { menyÅpenAtom } from "../jotai/karvalgAtoms";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { KnappBasis } from "../../components/fellesKomponenter/knapper/KnappBasis";
import { InfoknappLoggEvent, loggEventMedTabellnavn, TabellNavn } from "../../utils/loggFrontend";
import { InputLink } from "./InputLink";

export const KartParameterVelger = () => {
    const [hastighetError, setHastighetError] = useState<boolean>(false);
    const produksjonslenker = useAtomValue(produksjonslenkerAtom);
    const [hastighetsfilter, setHastighetsfilter] = useAtom(hastighetsfilterAtom);
    const laster = useAtomValue(lasterØktProduksjonslenkerAtom);
    const setMenyÅpen = useSetAtom(menyÅpenAtom);

    const handleSubmitHastighet = (hastighet: string) => {
        const gyldigInput = erGyldigNumeriskInput(hastighet);
        setHastighetError(!gyldigInput);
        if (gyldigInput) {
            setHastighetsfilter({ verdi: hastighet.replaceAll(" ", ""), valgt: true });
            loggEventMedTabellnavn(TabellNavn.hastighetsfilterIMeny, hastighet);
        }
    };

    const handleResetHastighet = () => {
        setHastighetError(false);
        setHastighetsfilter({ verdi: "", valgt: false });
    };

    return (
        <section id={"kartparametervelger"}>
            <MenyContainer>
                <div>
                    <MenyInnholdContainer>
                        <Wrapper>
                            <Heading $stylelevel="5" as={"h5"} $bold={true}>
                                Filter
                            </Heading>
                            <SkjulMenyKnapp size={"Small"} onClick={() => setMenyÅpen(false)}>
                                Skjul meny
                            </SkjulMenyKnapp>
                        </Wrapper>
                    </MenyInnholdContainer>

                    <MenyInnholdContainer>
                        <KartvisningsValg />
                    </MenyInnholdContainer>

                    <MenyInnholdContainer>
                        <TidspunktSisteImport />
                        <DatoInput />
                    </MenyInnholdContainer>

                    <MenyInnholdContainer>
                        <ProduksjonsdataFilter />
                        <DataInput
                            tittel={"Minimum snittfart/minutt"}
                            handleSubmit={handleSubmitHastighet}
                            resetData={handleResetHastighet}
                            errormelding={["Skriv inn et tall"]}
                            $error={hastighetError}
                            setError={setHastighetError}
                            hjelpetekst={tekster.minimumSnittfart}
                            infoknappLoggEvent={InfoknappLoggEvent.fartfilterInfoknapp}
                            verdi={hastighetsfilter.verdi}
                        />
                        <InputLink tittel={"Velg økt"} primærKnappTekst={"Se øktdetaljer"} />
                        <EksporterAllData produksjonslenker={produksjonslenker} />
                    </MenyInnholdContainer>

                    <MenyInnholdContainer>
                        <RodeListe />
                    </MenyInnholdContainer>
                </div>
            </MenyContainer>
        </section>
    );
};

export const MenyInnholdContainer = styled.div`
    display: flex;
    flex-direction: column;
    gap: 0.7rem;
    padding-top: 20px;
`;

const Wrapper = styled.div`
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    align-items: center;
`;

const SkjulMenyKnapp = styled(KnappBasis)`
    background-color: var(--gray-light);
    height: 38px;
    border: none;
    font-weight: 400;

    &:hover {
        background-color: var(--gray-regular-dark);
    }
`;
