import { RodeDto } from "../../api/useHentRoder";
import styled from "styled-components";
import React, { useEffect, useState } from "react";
import { getPopupType } from "../popup/popupUtils";
import { InformasjonsPopupType } from "../Kartvisning/KartvisningGenerell";
import { Søkefelt } from "../../components/fellesKomponenter/søkefelt/Søkefelt";
import { Trekkspill } from "../../components/fellesKomponenter/trekkspill/Trekkspill";
import { ColumnWrapper, RowWrapper } from "../../components/fellesKomponenter/wrappers/wrappers";
import { FormLabel } from "../../components/fellesKomponenter/inputfelt/FormLabel";
import { HjelpetekstPopup } from "../../components/fellesKomponenter/HjelpetekstPopup";
import tekster from "../../tekster.json";
import { IkonWrapper } from "../../components/fellesKomponenter/inputfelt/Datofelt";
import { useAtom, useAtomValue, useSetAtom } from "jotai";
import {
    aktivRodeFeatureAtom,
    popupInfoAtom,
    selektertRodeFraListeAtom,
    visRoderAtom,
} from "../jotai/karvalgAtoms";
import { tilAktivRodeGeojsonFeatures } from "../Kartvisning/geoJson/geoJSONutilsRoder";
import { roderAtom } from "../../api/context/apiAtoms";
import {
    InfoknappLoggEvent,
    KartparametereLoggEvent,
    loggEventMedTabellnavn,
    TabellNavn,
} from "../../utils/loggFrontend";

export const RodeListe = () => {
    const [visRoder, settVisRoder] = useAtom(visRoderAtom);
    const rodeResponse = useAtomValue(roderAtom);
    const popupInfo = useAtomValue(popupInfoAtom);
    const settPopupInfo = useSetAtom(popupInfoAtom);
    const settSelektertRodeFraListe = useSetAtom(selektertRodeFraListeAtom);
    const settAktivRodeFeature = useSetAtom(aktivRodeFeatureAtom);

    const aktivRodePopupId =
        getPopupType(popupInfo) === InformasjonsPopupType.RODE
            ? (popupInfo as RodeDto).rodeId
            : undefined;

    const rodeNavnKlikket = (rode: RodeDto) => {
        loggEventMedTabellnavn(TabellNavn.kartparametere, KartparametereLoggEvent.rodeIRodeliste);
        settSelektertRodeFraListe(rode);
        settPopupInfo(rode);
        settAktivRodeFeature(tilAktivRodeGeojsonFeatures(rode));
        if (!visRoder) {
            settVisRoder(true);
        }
    };

    useEffect(() => {
        setÅpen(visRoder);
    }, [visRoder]);

    const [åpen, setÅpen] = useState(visRoder);
    const [søkeord, setSøkeord] = useState("");
    const roder = rodeResponse?.suksess ? rodeResponse.data : [];
    const filtrerteRoder =
        roder
            .filter((r) => r.rodeNavn.toLowerCase().includes(søkeord.toLowerCase()))
            .sort((a, b) => a.rodeId.localeCompare(b.rodeId)) ?? [];

    return (
        <Container>
            <ColumnWrapper>
                <StyledRowWrapper>
                    <FormLabel htmlFor={"roder"}>Velg rode</FormLabel>
                    <IkonWrapper>
                        <HjelpetekstPopup
                            plassering={"right center"}
                            størrelse={"S"}
                            infoknappLoggEvent={InfoknappLoggEvent.rodelisteInfoknapp}
                        >
                            {tekster.velgRode}
                        </HjelpetekstPopup>
                    </IkonWrapper>
                </StyledRowWrapper>
                <Trekkspill
                    åpen={åpen}
                    tittel={"Roder"}
                    type={"Ramme"}
                    størrelse={"M"}
                    onClick={() => setÅpen(!åpen)}
                    width={"260px"}
                    makshøyde={"none"}
                    position={"imbedded"}
                >
                    <Innhold>
                        <Søkefelt søkeord={søkeord} setSøkeord={setSøkeord} />
                        {filtrerteRoder.map((rode, index) => (
                            <Rodenavn
                                key={index}
                                onClick={() => rodeNavnKlikket(rode)}
                                $erAktiv={aktivRodePopupId === rode.rodeId}
                            >
                                {rode.rodeNavn}
                            </Rodenavn>
                        ))}
                    </Innhold>
                </Trekkspill>
            </ColumnWrapper>
        </Container>
    );
};

const Container = styled.div`
    align-items: flex-end;
    display: flex;
    max-width: max-content;
`;

const Innhold = styled.div`
    background-color: var(--white);
    padding: 0 0.5rem;
    margin-bottom: 1rem;
    display: flex;
    flex-direction: column;
    gap: 4px;

    @media (pointer: coarse) {
        gap: 10px;
    }
`;

const Rodenavn = styled.button<{ $erAktiv: boolean }>`
    margin: 0 0 5px 0;
    font-size: 14px;
    border: 0;
    border-bottom: ${({ $erAktiv }) => ($erAktiv ? "2px solid var(--orange)" : "2px solid white")};
    font-weight: ${({ $erAktiv }) => $erAktiv && "800"};
    color: var(--gray-dark);
    display: flex;
    align-items: center;
    appearance: none;
    width: fit-content;
    justify-content: space-between;
    background-color: transparent;
    padding: 0;
    text-align: left;

    &:hover {
        font-weight: 600;
        cursor: pointer;
        border-bottom: ${({ $erAktiv }) =>
            $erAktiv ? "2px solid var(--orange)" : "2px solid var(--gray-dark-65)"};
    }
`;

const StyledRowWrapper = styled(RowWrapper)`
    gap: 0.5rem;
    align-items: flex-start;
`;
