import React, { useEffect } from "react";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { settKartUrlParam } from "../utils/kartUrlUtils";
import { usePathname } from "next/navigation";
import { TrekkspillSøkbar } from "../../components/fellesKomponenter/trekkspill/TrekkspillSøkbar";
import { informasjonsmeldingMedTimeoutAtom } from "../jotai/InformasjonsmeldingAtom";
import { produksjonsfilterAtom } from "../../api/context/ProduksjonsfilterAtoms";
import dayjs, { Dayjs } from "dayjs";
import { erKontraktGyldig } from "../../api/context/kartdataHelpers";
import { useAtom, useAtomValue, useSetAtom } from "jotai";
import {
    aktivKontraktAtom,
    Kontrakt,
    kontrakterAtom,
    tidspunktAtom,
} from "../../api/context/kontraktAtoms";
import { RESET } from "jotai/utils";
import { resetKartFeaturesAtom } from "../jotai/karvalgAtoms";
import { produksjonslenkerAtom } from "../../api/context/apiAtoms";

export const Kontraktvelger = () => {
    const tidspunkt = useAtomValue(tidspunktAtom);
    const produksjonslenker = useAtomValue(produksjonslenkerAtom);
    const setInformasjonsmelding = useSetAtom(informasjonsmeldingMedTimeoutAtom);
    const setProduksjonsfilter = useSetAtom(produksjonsfilterAtom);
    const pathname = usePathname();
    const resetKartvalg = useSetAtom(resetKartFeaturesAtom);
    const [aktivKontrakt, setAktivKontrakt] = useAtom(aktivKontraktAtom);
    const kontrakter = useAtomValue(kontrakterAtom);

    useEffect(() => {
        aktivKontrakt &&
            settKartUrlParam(pathname ?? "", {
                elrappKontraktId: aktivKontrakt.elrappId,
                timestamp: tidspunkt,
            });
    }, [produksjonslenker]);
    const setAktivKontraktFunction = (kontraktString: string) => {
        const klikketKontrakt = kontrakter.find(
            (kontakt) => kontakt.navn === fjernPrefixFraKontraktNavn(kontraktString),
        );

        if (klikketKontrakt) {
            setAktivKontrakt(klikketKontrakt);
            setInformasjonsmelding(undefined);
            setProduksjonsfilter(RESET);
            resetKartvalg();
        }
    };

    return kontrakter.length > 1 ? (
        <TrekkspillSøkbar
            utvalg={kontrakter.map((kontrakt) => genererKontraktNavn(kontrakt)).sort()}
            håndterValg={setAktivKontraktFunction}
            tittel={aktivKontrakt ? genererKontraktNavn(aktivKontrakt) : "Ingen valgt kontrakt"}
        />
    ) : (
        <Tekst>{aktivKontrakt?.navn ?? "Ingen valgt kontrakt"}</Tekst>
    );
};

const genererKontraktNavn = (kontrakt: Kontrakt) =>
    erKontraktGyldig(kontrakt, dayjs())
        ? kontrakt.navn
        : erKontraktUtgått(kontrakt, dayjs())
          ? utgåttPrefix + kontrakt.navn
          : ikkeStartetPrefix + kontrakt.navn;

const erKontraktUtgått = (kontrakt: Kontrakt, dato: Dayjs) =>
    kontrakt.sluttDato !== undefined && kontrakt.sluttDato.isBefore(dato);

const fjernPrefixFraKontraktNavn = (kontraktNavn: string) =>
    kontraktNavn.replace(utgåttPrefix, "").replace(ikkeStartetPrefix, "");

const utgåttPrefix = "UTGÅTT ";
const ikkeStartetPrefix = "IKKE STARTET ";
