import { Marker } from "react-leaflet";
import React from "react";
import { KameraPopup } from "../popup/kamera/KameraPopup";
import { AnimatePresence } from "framer-motion";
import { normalIkon, valgtIkon } from "./markerUtils";
import { LatLngExpression } from "leaflet";
import { Kamera } from "../../api/useHentVærstasjoner";
import { useAtom } from "jotai";
import { popupInfoAtom } from "../jotai/karvalgAtoms";
import { InformasjonsPopupType } from "../Kartvisning/KartvisningGenerell";
import { getPopupType } from "../popup/popupUtils";
import { loggEventMedTabellnavn, PopupLoggEvent, TabellNavn } from "../../utils/loggFrontend";

interface KameraMarkerProps {
    kamera: Kamera;
}

export const KameraMarker = ({ kamera }: KameraMarkerProps) => {
    const [popupInfo, settPopupInfo] = useAtom(popupInfoAtom);
    const kameraPopupInfo =
        getPopupType(popupInfo) === InformasjonsPopupType.KAMERA
            ? (popupInfo as Kamera)
            : undefined;

    const erValgt = kameraPopupInfo && kameraPopupInfo.id === kamera.id;
    const ikon = erValgt
        ? valgtIkon("/ikon/kart/varkamera-pin-valgt.svg")
        : normalIkon("/ikon/kart/varkamera-pin.svg");
    const håndterKameramarkerKlikket = (kamera: Kamera) => {
        settPopupInfo(kamera);
        loggEventMedTabellnavn(TabellNavn.popupTrykk, PopupLoggEvent.kamera);
    };

    return (
        <Marker
            position={kamera.geometri.coordinates as LatLngExpression}
            icon={ikon}
            autoPan={true}
            eventHandlers={{
                click: () => håndterKameramarkerKlikket(kamera),
            }}
            keyboard={false}
        >
            <AnimatePresence>{erValgt && <KameraPopup kamera={kamera} />}</AnimatePresence>
        </Marker>
    );
};
