import { MarkerClusterGroupWrapper } from "./MarkerClusterGroup";
import React from "react";
import styles from "./Cluster.module.css";
import { divIcon, MarkerCluster } from "leaflet";
import { SisteKjøretøyDto } from "../../api/useHentSisteKjøretøy";
import { KjøretøyMarker } from "./KjøretøyMarker";
import { harValgtMarker } from "./markerUtils";
import cn from "classnames";
import { markerWidth } from "../../utils/constants";

interface KjøretøyCluster {
    kjøretøyListe: SisteKjøretøyDto[];
}

export const KjøretøyCluster = ({ kjøretøyListe }: KjøretøyCluster) => {
    return (
        <MarkerClusterGroupWrapper
            maxClusterRadius={80}
            disableClusteringAtZoom={12}
            zoomToBoundsOnClick={true}
            iconCreateFunction={lagClusterIkon}
        >
            {kjøretøyListe.map((kjøretøy, index) => (
                <KjøretøyMarker kjøretøy={kjøretøy} key={index} />
            ))}
        </MarkerClusterGroupWrapper>
    );
};

const lagClusterIkon = (cluster: MarkerCluster) => {
    const ikonUrl = harValgtMarker(cluster)
        ? "/ikon/kart/broytebil-sirkel-valgt.svg"
        : "/ikon/kart/broytebil-sirkel.svg";
    const imageHtml = `<img src=${ikonUrl} alt="Brøytebilgruppe"/>
            <span class="${cn(styles.clustermarkertekst, {
                [styles.clustermarkertekstselected]: harValgtMarker(cluster),
            })}">
                ${cluster.getChildCount()}
            </span>
        </img>`;

    return divIcon({
        html: imageHtml,
        iconSize: [markerWidth, markerWidth],
        className: `cluster-marker ${styles.clustermarker}`,
    });
};
