import { SisteKjøretøyDto } from "../../api/useHentSisteKjøretøy";
import { Marker } from "react-leaflet";
import React from "react";
import { KjøretøyPopup } from "../popup/kjøretøy/KjøretøyPopup";
import { AnimatePresence } from "framer-motion";
import { normalIkon, valgtIkon } from "./markerUtils";
import { getPopupType } from "../popup/popupUtils";
import { InformasjonsPopupType } from "../Kartvisning/KartvisningGenerell";
import { useAtom } from "jotai/index";
import { popupInfoAtom } from "../jotai/karvalgAtoms";
import { loggEventMedTabellnavn, PopupLoggEvent, TabellNavn } from "../../utils/loggFrontend";

interface KjøretøyMarkerProps {
    kjøretøy: SisteKjøretøyDto;
}

export const KjøretøyMarker = ({ kjøretøy }: KjøretøyMarkerProps) => {
    const [popupInfo, settPopupInfo] = useAtom(popupInfoAtom);
    const kjøretøyPopupInfo =
        getPopupType(popupInfo) === InformasjonsPopupType.KJØRETØY
            ? (popupInfo as SisteKjøretøyDto)
            : undefined;

    const erValgt = kjøretøyPopupInfo && kjøretøyPopupInfo === kjøretøy;
    const ikon = erValgt
        ? valgtIkon("/ikon/kart/broytebil-pin-valgt.svg")
        : normalIkon("/ikon/kart/broytebil-pin.svg");

    const håndterKjøretøymarkerKlikket = (kjøretøy: SisteKjøretøyDto) => {
        settPopupInfo(kjøretøy);
        loggEventMedTabellnavn(TabellNavn.popupTrykk, PopupLoggEvent.kjøretøy);
    };

    return (
        <Marker
            position={[kjøretøy.lokasjon[0].coordinates[1], kjøretøy.lokasjon[0].coordinates[0]]}
            icon={ikon}
            autoPan={true}
            eventHandlers={{
                click: () => håndterKjøretøymarkerKlikket(kjøretøy),
            }}
            keyboard={false}
        >
            <AnimatePresence>{erValgt && <KjøretøyPopup kjøretøy={kjøretøy} />}</AnimatePresence>
        </Marker>
    );
};
