import { createPathComponent } from "@react-leaflet/core";
import { markerClusterGroup, MarkerClusterGroup, MarkerClusterGroupOptions } from "leaflet";
import "leaflet.markercluster";
import { ForwardRefExoticComponent, RefAttributes } from "react";
import { PropsWithChildren } from "@react-leaflet/core/lib/component";

export const MarkerClusterGroupWrapper: ForwardRefExoticComponent<
    PropsWithChildren & RefAttributes<MarkerClusterGroup> & MarkerClusterGroupOptions
> = createPathComponent(({ children: _c, ...props }, ctx) => {
    const clusterProps: { [key: string]: any } = {};
    const clusterEvents: { [key: string]: any } = {};

    // Splitting props and events to different objects
    Object.entries(props).forEach(([propName, prop]) =>
        propName.startsWith("on")
            ? (clusterEvents[propName] = prop)
            : (clusterProps[propName] = prop),
    );

    // Creating markerClusterGroup Leaflet element
    const group = markerClusterGroup(clusterProps);

    // Initializing event listeners
    Object.entries(clusterEvents).forEach(([eventAsProp, callback]) => {
        const clusterEvent = `cluster${eventAsProp.substring(2).toLowerCase()}`;
        group.on(clusterEvent, callback);
    });

    return {
        instance: group,
        context: { ...ctx, layerContainer: group },
    };
});

/*
Hentet fra https://github.com/YUzhva/react-leaflet-markercluster
Prosjektet er arkivert, derfor er koden kopiert til prosjektet for å lettere
kunne modifisere og jobbe med koden.

Denne filen har derfor følgende lisens:

MIT License

Copyright (c) 2017 Yevhen Uzhva

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
*/
