import { TrafikkmeldingMarker } from "./TrafikkmeldingMarker";
import { MarkerClusterGroupWrapper } from "./MarkerClusterGroup";
import React from "react";
import styles from "./Cluster.module.css";
import { divIcon, MarkerCluster } from "leaflet";
import { harValgtMarker } from "./markerUtils";
import cn from "classnames";
import { TrafikkmeldingerDto } from "../../api/useHentTrafikkmeldinger";
import { markerWidth } from "../../utils/constants";

interface TrafikkmeldingCluster {
    trafikkmeldingdata: TrafikkmeldingerDto[];
    stengtVeg: boolean;
}

export const TrafikkmeldingCluster = ({ trafikkmeldingdata, stengtVeg }: TrafikkmeldingCluster) => {
    return (
        <MarkerClusterGroupWrapper
            maxClusterRadius={80}
            disableClusteringAtZoom={12}
            zoomToBoundsOnClick={true}
            iconCreateFunction={
                stengtVeg ? lagStengtVegClusterIkon : lagTraffikkemeldingClusterIkon
            }
        >
            {trafikkmeldingdata.map((trafikkmelding, index) => (
                <TrafikkmeldingMarker trafikkmelding={trafikkmelding} key={index} />
            ))}
        </MarkerClusterGroupWrapper>
    );
};

const lagTraffikkemeldingClusterIkon = (cluster: MarkerCluster) => {
    const ikonUrl = harValgtMarker(cluster)
        ? "/ikon/kart/alert-gruppe-valgt.svg"
        : "/ikon/kart/alert-gruppe.svg";
    return lagClusterIkon(cluster, ikonUrl);
};

const lagStengtVegClusterIkon = (cluster: MarkerCluster) => {
    const ikonUrl = harValgtMarker(cluster)
        ? "/ikon/kart/stengt-valgt.svg"
        : "/ikon/kart/stengt.svg";
    return lagClusterIkon(cluster, ikonUrl);
};

const lagClusterIkon = (cluster: MarkerCluster, ikonUrl: String) => {
    const imageHtml = `<img src=${ikonUrl} alt="Trafikkmeldinggruppe"/>
            <span class="${cn(styles.clustermarkertekst, {
                [styles.clustermarkertekstselected]: harValgtMarker(cluster),
            })}">
                ${cluster.getChildCount()}
            </span>
        </img>`;

    return divIcon({
        html: imageHtml,
        iconSize: [markerWidth, markerWidth],
        className: `cluster-marker ${styles.clustermarker}`,
    });
};
