import { Marker } from "react-leaflet";
import React from "react";
import { TrafikkmeldingerDto } from "../../api/useHentTrafikkmeldinger";
import { StengtVegPupup } from "../popup/stengtVeg/StengtVegPopup";
import { AnimatePresence } from "framer-motion";
import { normalIkon, valgtIkon } from "./markerUtils";
import { getPopupType } from "../popup/popupUtils";
import { InformasjonsPopupType } from "../Kartvisning/KartvisningGenerell";
import { useAtom } from "jotai/index";
import { popupInfoAtom } from "../jotai/karvalgAtoms";
import { loggEventMedTabellnavn, PopupLoggEvent, TabellNavn } from "../../utils/loggFrontend";

interface TrafikkmeldingMarker {
    trafikkmelding: TrafikkmeldingerDto;
}

export const TrafikkmeldingMarker = ({ trafikkmelding }: TrafikkmeldingMarker) => {
    const [popupInfo, settPopupInfo] = useAtom(popupInfoAtom);
    const trafikkmeldingPopupInfo =
        getPopupType(popupInfo) === InformasjonsPopupType.TRAFIKKMELDING
            ? (popupInfo as TrafikkmeldingerDto)
            : undefined;

    const erValgt = trafikkmeldingPopupInfo && trafikkmeldingPopupInfo === trafikkmelding;
    const ikon = finnTrafikkmeldingMarker(erValgt ?? false, trafikkmelding.roadClosed);
    const håndterTrafikkmeldingmarkerKlikket = (trafikkmelding: TrafikkmeldingerDto) => {
        settPopupInfo(trafikkmelding);
        loggEventMedTabellnavn(TabellNavn.popupTrykk, PopupLoggEvent.trafikkmelding);
    };

    return (
        <div>
            {trafikkmelding.locations[0].coordinatesForDisplay && (
                <Marker
                    position={[
                        trafikkmelding.locations[0].coordinatesForDisplay.coordinates[1],
                        trafikkmelding.locations[0].coordinatesForDisplay.coordinates[0],
                    ]}
                    icon={ikon}
                    autoPan={true}
                    eventHandlers={{
                        click: () => {
                            håndterTrafikkmeldingmarkerKlikket(trafikkmelding);
                        },
                    }}
                    keyboard={false}
                >
                    <AnimatePresence>
                        {erValgt && <StengtVegPupup trafikkmelding={trafikkmeldingPopupInfo} />}
                    </AnimatePresence>
                </Marker>
            )}
        </div>
    );
};

const finnTrafikkmeldingMarker = (erValgt: boolean, erStengtVei: boolean) =>
    erStengtVei
        ? erValgt
            ? valgtIkon("/ikon/kart/stengt-pin-valgt.svg")
            : normalIkon("/ikon/kart/stengt-pin.svg")
        : erValgt
          ? valgtIkon("/ikon/kart/alert-valgt.svg")
          : normalIkon("/ikon/kart/alert.svg");
