import React, { useRef } from "react";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import styled from "styled-components";
import { Lukknapp } from "../../components/fellesKomponenter/knapper/Lukknapp";
import { IkonBase } from "../../components/Ikon/IkonBase";
import { Heading } from "../../components/fellesKomponenter/typografi/Heading";
import { useDisableClickPropagation } from "../../hooks/useDisableClickPropagation";
import { useDisableScrollPropagtaion } from "../../hooks/useDisableScrollPropagtaion";
import { AnimatePresence, motion } from "framer-motion";
import { useWindowSize } from "../../hooks/useWindowSize";
import { useElementSize } from "../../hooks/useElementSize";
import { useAtomValue, useSetAtom } from "jotai";
import { menyÅpenAtom, resetKartFeaturesAtom } from "../jotai/karvalgAtoms";

interface InformasjonPopupProps {
    tittel: string;
    undertekst?: string;
    undertekstHtml?: React.ReactNode;
    ikonPath: string;
    detaljWidth: number;
    children: React.ReactNode;
    ikonBorder?: number;
    skalHaDetaljMinHeight?: boolean;
}

export const InformasjonPopup = ({
    tittel,
    undertekst,
    undertekstHtml,
    ikonPath,
    detaljWidth,
    children,
    ikonBorder = undefined,
    skalHaDetaljMinHeight = false,
}: InformasjonPopupProps) => {
    const menyÅpen = useAtomValue(menyÅpenAtom);
    const popupRef = useRef(null);
    useDisableClickPropagation(popupRef);
    useDisableScrollPropagtaion(popupRef);
    const { windowHeight } = useWindowSize();
    const elementRef = useRef<HTMLDivElement>(null);
    const popupHeaderHeight = useElementSize(elementRef).height;
    const detaljHeight = windowHeight - popupHeaderHeight - 30;
    const resetKartFeatures = useSetAtom(resetKartFeaturesAtom);

    return (
        <InformasjonPopupWrapper
            initial={{
                opacity: 1,
                scale: 0,
                x: 0,
            }}
            animate={{
                opacity: 1,
                scale: 1,
                transition: {
                    duration: 0.3,
                },
                x: menyÅpen ? `calc(var(--meny-width, 0px) + 42px)` : 170,
                y: 0,
            }}
            exit={{
                opacity: 0,
                scale: 0.75,
                transition: {
                    ease: "easeOut",
                    duration: 0.3,
                },
            }}
            ref={popupRef}
        >
            <StyledArticle>
                <PopupHeader ref={elementRef}>
                    <PopupTittelgruppe>
                        <IkonBase $path={ikonPath} $border={ikonBorder} />
                        <div>
                            <PopupOverskrift as="h1" $stylelevel="4">
                                {tittel}
                            </PopupOverskrift>
                            {undertekst && (
                                <PopupUndertext $størrelse="S">{undertekst}</PopupUndertext>
                            )}
                            {undertekstHtml && undertekstHtml}
                        </div>
                    </PopupTittelgruppe>
                    <Lukknapp onClick={() => resetKartFeatures()}>Lukk</Lukknapp>
                </PopupHeader>
                <DetaljWrapper
                    height={detaljHeight}
                    width={detaljWidth}
                    $skalHaDetaljMinHeight={skalHaDetaljMinHeight}
                    className="leaflet-popup-content"
                >
                    <AnimatePresence>{children}</AnimatePresence>
                </DetaljWrapper>
            </StyledArticle>
        </InformasjonPopupWrapper>
    );
};

const InformasjonPopupWrapper = styled(motion.div)`
    z-index: 1050;
    position: fixed;
    top: calc(var(--header-height, 0px) + 10px);
    background-color: var(--white);
    cursor: auto;
    max-width: calc(100vw - 56px);

    .leaflet-popup-content {
        margin: 0;

        p {
            margin: 0;
        }
    }
`;

const StyledArticle = styled.article`
    max-height: inherit;
`;

interface detaljWrapperProps {
    width: number;
    height: number;
    $skalHaDetaljMinHeight: boolean;
}

const DetaljWrapper = styled.section<detaljWrapperProps>`
    width: ${({ width }) => width}px;
    ${({ $skalHaDetaljMinHeight, height }) =>
        $skalHaDetaljMinHeight && `height: calc( ${height}px - var(--header-height)  );`}
    max-height: calc(${({ height }) => height}px - var(--header-height));
    min-width: 100%;
    max-width: 100%;
    margin: 0;
    overflow: auto;
    resize: both;
`;

const PopupHeader = styled.div`
    display: flex;
    background: var(--blue-bg);
    align-items: flex-start;
    padding: 16px;
    justify-content: space-between;
`;

const PopupTittelgruppe = styled.div`
    display: flex;
    gap: 16px;
    margin-right: 5px;
`;

const PopupUndertext = styled(Tekst)`
    margin: 0;
`;

const PopupOverskrift = styled(Heading)`
    max-width: 550px;
`;
