import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { sideInfo } from "../../../sider";
import { Strek } from "../../../components/fellesKomponenter/Strek";
import styled from "styled-components";
import { KameraLenke } from "./KameraLenke";
import { EksternLenke } from "../../../components/fellesKomponenter/lenker/EksternLenke";
import { Kamera } from "../../../api/useHentVærstasjoner";
import { erIDag, erSammeTime } from "../../../utils/tid";
import { useAtomValue } from "jotai";
import { tidspunktAtom } from "../../../api/context/kontraktAtoms";
import { Værdata } from "../../../api/useHentHistoriskVærdata";
import { VærtabellPanel } from "./VærtabellPanel";

interface KameraPanelProps {
    kamera: Kamera;
    historiskVærdata?: Værdata;
}

export const KameraPanel = ({ kamera, historiskVærdata }: KameraPanelProps) => {
    const tidspunkt = useAtomValue(tidspunktAtom);
    return (
        <KameraWrapper>
            <Container>
                {kamera.bildeUrl ? (
                    <Vegkamera
                        src={kamera.bildeUrl}
                        alt={`Vegkamera ${kamera.vegNummer} ${kamera.beskrivelse}`}
                    />
                ) : (
                    <Tekst>Vi har ikke bilde fra dette kameraet</Tekst>
                )}
                {!erSammeTime(tidspunkt) && (
                    <Tekst $størrelse={"XS"}>
                        Vi har ikke historiske bilder. Kameraet viser nå-bilde. Dersom du trenger
                        historiske bilder så kan dette hentes ut i Vegvær.
                    </Tekst>
                )}
            </Container>
            <Kamerainfo>
                <Kamerainfogruppe>
                    <Tekst $størrelse="S">Alle vegkameraene samlet på en side</Tekst>
                    <KameraLenke href={sideInfo.webkamera.href} />
                </Kamerainfogruppe>
                <Strek />
                <Kamerainfogruppe>
                    <Tekst $størrelse="S">Vegvær har tidligere kamerabilder</Tekst>
                    <EksternLenke
                        størrelse="M"
                        href={
                            kamera.målestasjonid
                                ? `https://vegvar.atlas.vegvesen.no/#/stasjon/${kamera.målestasjonid}/sammendrag`
                                : "https://vegvar.atlas.vegvesen.no/"
                        }
                    >
                        Åpne Vegvær
                    </EksternLenke>
                </Kamerainfogruppe>
                <Strek />
                {kamera.værvaselYr && kamera.værvaselYr.length > 1 && (
                    <Kamerainfogruppe>
                        <Tekst $størrelse="S">
                            {erIDag(tidspunkt)
                                ? "Værmelding er hentet fra yr.no"
                                : "Vi har ikke historisk værdata"}
                        </Tekst>
                        <EksternLenke størrelse="M" href={kamera.værvaselYr}>
                            Åpne værstasjon i Yr
                        </EksternLenke>
                    </Kamerainfogruppe>
                )}
                <Strek />
                <VærtabellPanel værdata={historiskVærdata ? historiskVærdata : kamera} />
            </Kamerainfo>
        </KameraWrapper>
    );
};

const Vegkamera = styled.img`
    width: 100%;
    object-fit: contain;
    flex: 1 0 auto;
`;

const KameraWrapper = styled.section`
    display: flex;
    gap: 16px;
    flex-wrap: wrap;
    overflow: hidden;
`;

const Kamerainfo = styled.section``;

const Kamerainfogruppe = styled.section`
    display: flex;
    flex-direction: column;
    gap: 6px;
    margin-bottom: 16px;
`;

const Container = styled.div`
    width: 60%;
    max-width: 100%;
    align-self: center;
`;
