import { KjøretøyPopup } from "./KjøretøyPopup";
import { render, screen } from "@testing-library/react";
import { ApiRespons, FeilType, FetchStatus } from "../../../api/api";
import { KjoretoyProduksjonsdetaljerDto } from "../../../api/useHentKjøretøyProduksjonsdetaljer";
import { axeTilpasset } from "../../../utils/axeTilpasset";
import React from "react";
import { SisteKjøretøyDto } from "../../../api/useHentSisteKjøretøy";
import fetch from "jest-fetch-mock";

describe("KjøretøyPopup", () => {
    const kjøretøy1: SisteKjøretøyDto = {
        produksjonsdataRestRec: 1,
        lokasjon: [
            { type: "Point", coordinates: [17.739443, 68.476372] },
            { type: "Point", coordinates: [17.739468, 68.476364] },
        ],
    };

    const kjøretøy2: SisteKjøretøyDto = { ...kjøretøy1, produksjonsdataRestRec: 2 };
    const kjøretøy3: SisteKjøretøyDto = { ...kjøretøy1, produksjonsdataRestRec: 3 };
    const kjøretøy4: SisteKjøretøyDto = { ...kjøretøy1, produksjonsdataRestRec: 4 };

    it("skal vise feilmelding om man får tom liste fra produksjonsdetaljer", async () => {
        const tomRespons = JSON.stringify({
            suksess: true,
            data: [],
        });

        fetch.mockResponseOnce(tomRespons);
        render(<KjøretøyPopup kjøretøy={kjøretøy1} />);

        await screen.findByText(
            "Klarte ikke finne produksjonsdetaljer for brøytebilens sist kjente loggpunkt.",
        );
        expect(
            screen.getByText(
                "Klarte ikke finne produksjonsdetaljer for brøytebilens sist kjente loggpunkt.",
            ),
        ).toBeVisible();
    });

    it("skal vise feilmelding om man får feil i apiresponse fra produksjonsdetaljer", async () => {
        const feilmelding = "Tester feil";
        const responsFeil = JSON.stringify({
            suksess: false,
            feilmelding: feilmelding,
            type: FeilType.UKJENT_FEIL,
            status: FetchStatus.Feil,
        });
        fetch.mockResponseOnce(responsFeil);

        render(<KjøretøyPopup kjøretøy={kjøretøy2} />);

        await screen.findByText(feilmelding);
        expect(screen.getByText(feilmelding)).toBeVisible();
    });

    it("skal vise data fra produksjonsdetaljer", async () => {
        const produksjonsdetaljer: KjoretoyProduksjonsdetaljerDto = {
            datoLogget: "",
            doseringtoerrstoffgm2: 10,
            doseringvaatstoffmlm2: 10,
            eksternReferanse: "",
            erhoevelskjaernede: false,
            erplognede: true,
            ersideplogibruk: false,
            ertoerrstoffsprederpaa: true,
            erunderliggendeskjaernede: undefined,
            ervaatstoffsprederpaa: true,
            hastighetkmh: 40,
            kjoeretoyid: "12345",
            materiale: "Befuktet salt (NaCl)",
            produksjonsdataRestRec: 0,
            rodeid: "rode 1",
            sprederbreddetoerrstoffcm: 200,
            sprederbreddevaatstoffcm: 200,
            vegnr: "",
        };
        const respons = JSON.stringify({
            suksess: true,
            data: [produksjonsdetaljer],
            status: FetchStatus.Suksess,
        });
        fetch.mockResponseOnce(respons);

        render(<KjøretøyPopup kjøretøy={kjøretøy3} />);

        await screen.findAllByLabelText("datafelt");

        screen
            .getAllByLabelText("datafelt")
            .map((label) => ({
                label: label.children.item(0)?.textContent,
                verdi: label.children.item(1)?.textContent,
            }))
            .forEach((label) => {
                switch (label.label) {
                    case "Fart":
                        expect(label.verdi).toEqual(`${produksjonsdetaljer.hastighetkmh} km/t`);
                        break;
                    case "Materiale":
                        expect(label.verdi).toEqual(produksjonsdetaljer.materiale);
                        break;
                    case "Plog":
                        expect(label.verdi).toEqual("Nede");
                        break;
                    case "Sideplog":
                        expect(label.verdi).toEqual("Ikke i bruk");
                        break;
                    case "Høvelskjær":
                        expect(label.verdi).toEqual("Oppe");
                        break;
                    case "Underliggende skjær":
                        expect(label.verdi).toEqual("-");
                        break;
                    case "Sprederbredde våtstoff":
                        expect(label.verdi).toEqual(
                            `${produksjonsdetaljer.sprederbreddevaatstoffcm} cm`,
                        );
                        break;
                    case "Dosering våtstoff":
                        expect(label.verdi).toEqual(
                            `${produksjonsdetaljer.doseringvaatstoffmlm2} ml/m²`,
                        );
                        break;
                    case "Sprederbredde tørrstoff":
                        expect(label.verdi).toEqual(
                            `${produksjonsdetaljer.sprederbreddetoerrstoffcm} cm`,
                        );
                        break;
                    case "Dosering tørrstoff":
                        expect(label.verdi).toEqual(
                            `${produksjonsdetaljer.doseringtoerrstoffgm2} g/m²`,
                        );
                        break;
                    case "Kjøretøy ID":
                        expect(label.verdi).toEqual(produksjonsdetaljer.kjoeretoyid);
                        break;
                    case "Økt ID":
                        expect(label.verdi).toEqual(
                            produksjonsdetaljer.produksjonsdataRestRec === 0
                                ? "-"
                                : produksjonsdetaljer.produksjonsdataRestRec,
                        );
                        break;
                    case "Rode":
                        expect(label.verdi).toEqual("-");
                        break;
                }
            });
    });

    it("rendrer uten jest-axe-violations (fanger ikke alle UU-brudd)", async () => {
        const produksjonsdetaljer: KjoretoyProduksjonsdetaljerDto = {
            datoLogget: "",
            doseringtoerrstoffgm2: 0,
            doseringvaatstoffmlm2: 0,
            hastighetkmh: 99,
            produksjonsdataRestRec: 0,
            sprederbreddetoerrstoffcm: 0,
            sprederbreddevaatstoffcm: 0,
        };

        const respons = JSON.stringify({
            suksess: true,
            data: [produksjonsdetaljer],
            status: FetchStatus.Suksess,
        });
        fetch.mockResponseOnce(respons);

        const { container } = render(<KjøretøyPopup kjøretøy={kjøretøy4} />);
        await screen.findByText("99 km/t");
        expect(await axeTilpasset(container)).toHaveNoViolations();
    });
});
