import { timestampStringTilEnkeltKlokkeslett } from "../../../utils/tid";
import { InformasjonPopup } from "../InformasjonPopup";
import { ApiRespons } from "../../../api/api";
import styled from "styled-components";
import {
    KjoretoyProduksjonsdetaljerDto,
    kjøretøyProduksjonsdetaljerAtom,
    useHentKjoretoyProduksjonDetaljer,
} from "../../../api/useHentKjøretøyProduksjonsdetaljer";
import { RodeDto } from "../../../api/useHentRoder";
import { SisteKjøretøyDto } from "../../../api/useHentSisteKjøretøy";
import { KjørtetøyPopupInnhold } from "./KjøretøyPopupInnhold";
import { useAtomValue } from "jotai";
import { roderAtom } from "../../../api/context/apiAtoms";

interface KjøretøyPopupProps {
    kjøretøy: SisteKjøretøyDto;
}

export const KjøretøyPopup = ({ kjøretøy }: KjøretøyPopupProps) => {
    const produksjonsdetaljer = useAtomValue(kjøretøyProduksjonsdetaljerAtom);
    const roder = useAtomValue(roderAtom);
    const rodeNavn = hentRodeNavnFraId(
        produksjonsdetaljer?.suksess ? produksjonsdetaljer.data[0]?.rodeid : undefined,
        roder?.suksess ? roder.data : undefined,
    );
    useHentKjoretoyProduksjonDetaljer([kjøretøy.produksjonsdataRestRec]);

    return (
        <InformasjonPopup
            tittel="Datapunkt for brøytebil"
            undertekst={popupUndertekst(kjøretøy.produksjonsdataRestRec, produksjonsdetaljer)}
            ikonPath={popupIkon(produksjonsdetaljer)}
            detaljWidth={380}
        >
            <PopupinnholdWrapper>
                <KjørtetøyPopupInnhold
                    produksjonsdetaljer={produksjonsdetaljer}
                    rodeNavn={rodeNavn}
                    sisteKoordinater={kjøretøy.lokasjon}
                />
            </PopupinnholdWrapper>
        </InformasjonPopup>
    );
};

const PopupinnholdWrapper = styled.div`
    padding: 16px;
    margin: 0;
    max-height: inherit;
    overflow-y: auto;
`;

const popupUndertekst = (
    målepunkt: number,
    produksjonsdetaljer?: ApiRespons<KjoretoyProduksjonsdetaljerDto[]>,
) =>
    produksjonsdetaljer?.suksess && produksjonsdetaljer.data.length
        ? `Kl ${timestampStringTilEnkeltKlokkeslett(produksjonsdetaljer.data[0].datoLogget)}`
        : `Målepunkt ${målepunkt.toString()}`;

const popupIkon = (produksjonsdetaljer?: ApiRespons<KjoretoyProduksjonsdetaljerDto[]>) =>
    produksjonsdetaljer?.suksess === false
        ? "/ikon/feil-kryss.svg"
        : "/ikon/kart/broytebil-sirkel.svg";

const hentRodeNavnFraId = (rodeId: string | undefined, roder: RodeDto[] | undefined): string => {
    if (rodeId === undefined || roder === undefined) {
        return "-";
    } else {
        const navn = roder.filter((rode) => rode.rodeId === rodeId)[0]?.rodeNavn;
        return navn ? navn : "-";
    }
};
