import { Point } from "geojson";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { KjøretøyRetning } from "./KjøretøyRetning";
import { Boldtext } from "../../../components/fellesKomponenter/typografi/Boldtext";
import { grader, graderTilRetning } from "./Grader";
import styled from "styled-components";
import React from "react";

interface DatafeltRetningProps {
    sisteKoordinater: Point[];
}

export const DatafeltRetning = ({ sisteKoordinater }: DatafeltRetningProps) => {
    const [førsteKoordinat, andreKoordinat] = hentKooridnater(sisteKoordinater);

    return (
        <RetningWrapper>
            <Tekst $størrelse={"S"}>Retning</Tekst>
            <RetningInnhold>
                <KjøretøyRetning sisteKoordinater={sisteKoordinater} />
                <Boldtext $størrelse="M">
                    {graderTilRetning(grader(andreKoordinat, førsteKoordinat))}
                </Boldtext>
            </RetningInnhold>
            <RetningInfo>
                Retningen er regnet ut ved hjelp av de to siste passeringspunktene vi har fra bilen,
                dette kan gi et feil bilde av retningen ved rundkjøringer og lignende
            </RetningInfo>
        </RetningWrapper>
    );
};

const hentKooridnater = (sisteKoordinater: Point[]): number[][] => {
    const førsteKoordinat = sisteKoordinater[0].coordinates;
    const andreKoordinat = sisteKoordinater[1].coordinates;
    return [førsteKoordinat, andreKoordinat];
};

const RetningWrapper = styled.div`
    display: flex;
    flex-direction: column;
`;

const RetningInnhold = styled.div`
    display: flex;
    flex-direction: row;
    gap: 8px;
    margin-top: 4px;
`;

const RetningInfo = styled.p`
    font-size: smaller;
    padding-top: 10px;
`;
