import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { Kjøretøydetaljer } from "./Kjøretøydetaljer";
import { Spinner } from "../../../components/fellesKomponenter/spinner/Spinner";
import React from "react";
import { ApiRespons } from "../../../api/api";
import { KjoretoyProduksjonsdetaljerDto } from "../../../api/useHentKjøretøyProduksjonsdetaljer";
import { Point } from "geojson";

interface KjøretøyPopupInnholdProps {
    produksjonsdetaljer?: ApiRespons<KjoretoyProduksjonsdetaljerDto[]>;
    rodeNavn?: string;
    className?: string;
    sisteKoordinater: Point[];
}
export const KjørtetøyPopupInnhold = ({
    produksjonsdetaljer,
    rodeNavn,
    sisteKoordinater,
}: KjøretøyPopupInnholdProps) => {
    if (produksjonsdetaljer?.suksess && produksjonsdetaljer.data.length === 0) {
        return (
            <Tekst>
                Klarte ikke finne produksjonsdetaljer for brøytebilens sist kjente loggpunkt.
            </Tekst>
        );
    }
    if (produksjonsdetaljer?.suksess) {
        const data = produksjonsdetaljer.data[0];
        return (
            <Kjøretøydetaljer
                hastighetKmh={data.hastighetkmh}
                erPlogNede={data.erplognede}
                erHøvelskjærNede={data.erhoevelskjaernede}
                erSideplogIBruk={data.ersideplogibruk}
                sprederbreddeVåtstoffCm={data.sprederbreddevaatstoffcm}
                sprederbreddeTørrstoffCm={data.sprederbreddetoerrstoffcm}
                kjøretøyId={data.kjoeretoyid}
                rodeNavn={rodeNavn}
                doseringVåtstoffMlm={data.doseringvaatstoffmlm2}
                doseringTørrstoffGm={data.doseringtoerrstoffgm2}
                erUnderliggendeSkjærNede={data.erunderliggendeskjaernede}
                materiale={data.materiale}
                eksternReferanse={data.eksternReferanse}
                erVåtstoffsprederPå={data.ervaatstoffsprederpaa}
                erTørrstoffsprederPå={data.ertoerrstoffsprederpaa}
                sisteKoordinater={sisteKoordinater}
            />
        );
    } else if (!produksjonsdetaljer) {
        return (
            <Spinner storrelse="liten" sentrert={true} inline={false}>
                Henter detaljer for kjøretøy...
            </Spinner>
        );
    } else {
        return <Tekst>{produksjonsdetaljer.feilmelding}</Tekst>;
    }
};
