import { Strek } from "../../../components/fellesKomponenter/Strek";
import styled from "styled-components";
import React from "react";
import { Point } from "geojson";
import { Datafelt } from "./KjøretøyPopupInnholdDatafelt";
import { DatafeltRetning } from "./KjøretøyPopupInngoldDatafeltRetning";
import { genererØktUrl } from "../../../øktdetaljerSide/øktUtils";

interface KjøretøydetaljerProps {
    hastighetKmh: number;
    erPlogNede?: boolean;
    erHøvelskjærNede?: boolean;
    erSideplogIBruk?: boolean;
    sprederbreddeVåtstoffCm: number;
    sprederbreddeTørrstoffCm: number;
    kjøretøyId?: string;
    rodeId?: string;
    rodeNavn?: string;
    materiale?: string;
    erUnderliggendeSkjærNede?: boolean;
    doseringVåtstoffMlm?: number;
    doseringTørrstoffGm?: number;
    eksternReferanse?: string;
    erVåtstoffsprederPå?: boolean;
    erTørrstoffsprederPå?: boolean;
    sisteKoordinater: Point[];
}

export const Kjøretøydetaljer = ({
    hastighetKmh,
    erPlogNede,
    erHøvelskjærNede,
    erSideplogIBruk,
    sprederbreddeVåtstoffCm,
    sprederbreddeTørrstoffCm,
    kjøretøyId,
    rodeNavn,
    materiale,
    erUnderliggendeSkjærNede,
    doseringVåtstoffMlm,
    doseringTørrstoffGm,
    eksternReferanse,
    erTørrstoffsprederPå,
    erVåtstoffsprederPå,
    sisteKoordinater,
}: KjøretøydetaljerProps) => (
    <>
        <Datalinje>
            <Datafelt tittel="Fart" data={`${hastighetKmh} km/t`} />
            <Datafelt
                tittel="Materiale"
                data={erVåtstoffsprederPå || erTørrstoffsprederPå ? materiale : undefined}
            />
        </Datalinje>
        <Strek />
        <Datalinje>
            <Datafelt tittel="Plog" data={entenEller("Nede", "Oppe", erPlogNede)} />
            <Datafelt
                tittel="Sideplog"
                data={entenEller("I bruk", "Ikke i bruk", erSideplogIBruk)}
            />
        </Datalinje>
        <Strek />
        <Datalinje>
            <Datafelt tittel="Tung høvel" data={entenEller("Nede", "Oppe", erHøvelskjærNede)} />
            <Datafelt
                tittel="Underliggende skjær"
                data={entenEller("Nede", "Oppe", erUnderliggendeSkjærNede)}
            />
        </Datalinje>
        <Strek />
        <Datalinje>
            <Datafelt
                tittel="Sprederbredde våtstoff"
                data={
                    erVåtstoffsprederPå && sprederbreddeVåtstoffCm
                        ? `${sprederbreddeVåtstoffCm} cm`
                        : undefined
                }
            />
            <Datafelt
                tittel="Dosering våtstoff"
                data={
                    erVåtstoffsprederPå && doseringVåtstoffMlm
                        ? `${doseringVåtstoffMlm} ml/m²`
                        : undefined
                }
            />
        </Datalinje>
        <Strek />
        <Datalinje>
            <Datafelt
                tittel="Sprederbredde tørrstoff"
                data={
                    erTørrstoffsprederPå && sprederbreddeTørrstoffCm
                        ? `${sprederbreddeTørrstoffCm} cm`
                        : undefined
                }
            />
            <Datafelt
                tittel="Dosering tørrstoff"
                data={
                    erTørrstoffsprederPå && doseringTørrstoffGm
                        ? `${doseringTørrstoffGm} g/m²`
                        : undefined
                }
            />
        </Datalinje>
        <Strek />

        <Datalinje>
            <Datafelt tittel="Kjøretøy ID" data={kjøretøyId} />
            <Datafelt
                tittel="Økt ID"
                data={eksternReferanse}
                url={genererØktUrl(eksternReferanse)}
            />
        </Datalinje>
        <Strek />
        <Datafelt tittel="Rode" data={rodeNavn} />
        <Strek />
        <DatafeltRetning sisteKoordinater={sisteKoordinater}></DatafeltRetning>
    </>
);

const entenEller = (enten: string, eller: string, gitt?: boolean) =>
    gitt === undefined ? undefined : gitt ? enten : eller;

const Datalinje = styled.div`
    display: flex;
`;
