import { Feature } from "geojson";
import { LeafletEvent } from "leaflet";
import { minutterTilTimerOgMinutter } from "../../utils/tid";
import { VeglenkePopupInfo } from "./veglenke/VeglenkePopup";
import { SisteKjøretøyDto } from "../../api/useHentSisteKjøretøy";
import { RodeDto } from "../../api/useHentRoder";
import { TrafikkmeldingerDto } from "../../api/useHentTrafikkmeldinger";
import { InformasjonsPopupType, PopupType } from "../Kartvisning/KartvisningGenerell";
import { Kamera } from "../../api/useHentVærstasjoner";

export const mapTilVeglenkePopupInfo = (event: LeafletEvent, feature: Feature) => {
    return {
        kartlinje: event.target,
        veglenkesekvensId: feature.properties?.veglenkesekvensId,
        veglenkeNummer: feature.properties?.veglenkeNummer,
        timerOgMinutterSiden: minutterTilTimerOgMinutter(feature.properties?.minutterSiden),
    };
};

export const mapTilRodePopupInfo = (event: LeafletEvent, feature: Feature) => {
    return {
        kartlinje: event.target,
        rodeId: feature?.properties?.rodeId,
        rodeNavn: feature?.properties?.rodeNavn,
        vinterdriftsKlasser: feature?.properties?.vinterdriftsKlasser,
        detaljer: feature?.properties?.detaljer,
    };
};

export const getPopupType = (popupInfo?: PopupType): InformasjonsPopupType => {
    if (popupInfo && (popupInfo as VeglenkePopupInfo).veglenkeNummer)
        return InformasjonsPopupType.VEGLENKE;
    else if (popupInfo && (popupInfo as SisteKjøretøyDto).lokasjon)
        return InformasjonsPopupType.KJØRETØY;
    else if (popupInfo && (popupInfo as Kamera).vegNummer) return InformasjonsPopupType.KAMERA;
    else if (popupInfo && (popupInfo as RodeDto).rodeId) return InformasjonsPopupType.RODE;
    else if (popupInfo && (popupInfo as TrafikkmeldingerDto).locations)
        return InformasjonsPopupType.TRAFIKKMELDING;
    else return InformasjonsPopupType.UKJENT;
};

export const rodeIdTilRodenavn = (rodeid: string, roder?: RodeDto[] | undefined) => {
    if (roder) {
        const rode = roder.find((rode) => rode.rodeId === rodeid);
        return rode ? rode.rodeNavn : "";
    }
    return "";
};

export const erSprederPå = (erTørrstoffsprederPå?: boolean, erVåtstoffsprederPå?: boolean) =>
    erTørrstoffsprederPå || erVåtstoffsprederPå;
