import React from "react";
import { InformasjonPopup } from "../InformasjonPopup";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { RodeVegnett } from "../../../api/useHentRoder";
import styled from "styled-components";
import { Boldtext } from "../../../components/fellesKomponenter/typografi/Boldtext";
import { hentKlasserMedSyklus } from "./vinterdriftsklasserUtils";
import { Vinterdriftsklasser } from "./Vinterdriftsklasser";

export interface RodePopupMedProduksjonInfo {
    kartlinje: any;
    rodeId: string;
    rodeNavn: string;
    vinterdriftsKlasser?: string[];
    detaljer: RodeVegnett;
}

interface RodePopupProps {
    rodePopupInfo: RodePopupMedProduksjonInfo;
}

export const RodePopup = ({ rodePopupInfo }: RodePopupProps) => {
    const klasserMedSyklus = hentKlasserMedSyklus(rodePopupInfo.vinterdriftsKlasser);
    return (
        <InformasjonPopup
            tittel={"Rode"}
            undertekst={rodePopupInfo.rodeId}
            ikonPath={"/ikon/kart/broytebil-sirkel.svg"}
            detaljWidth={360}
        >
            <PopupInnhold>
                <Boldtext $størrelse={"S"}>Navn </Boldtext>
                <Innhold $størrelse={"S"}>{rodePopupInfo.rodeNavn}</Innhold>
                <Vinterdriftsklasser klasserMedSyklus={klasserMedSyklus} />
                <Boldtext $størrelse={"S"}>Veger </Boldtext>
                <Innhold $størrelse={"S"}>
                    {rodePopupInfo.detaljer.vegsystemreferanse?.map((sekvensid) => (
                        <span key={sekvensid}>
                            {sekvensid}
                            <br />
                        </span>
                    ))}
                </Innhold>
            </PopupInnhold>
        </InformasjonPopup>
    );
};

const PopupInnhold = styled.div`
    padding: 0 16px;
    max-height: inherit;
    overflow-y: auto;
`;

const Innhold = styled(Tekst)`
    padding-bottom: 10px;
`;
