import {
    finnDriftsklasseMedHøyesteSyklustid,
    hentKlasserMedSyklus,
    Vinterdriftsklasse,
} from "./vinterdriftsklasserUtils";
import { RodeDto } from "../../../api/useHentRoder";

describe("vinterdriftsklasserUtils", () => {
    it("skal hente klasser med syklustid", () => {
        const klasseDka = hentKlasserMedSyklus([Vinterdriftsklasse.DkA]);
        const klasseDkbh = hentKlasserMedSyklus([Vinterdriftsklasse.DkBh]);
        const klasseDkC = hentKlasserMedSyklus([Vinterdriftsklasse.DkC]);
        const klasseDkD = hentKlasserMedSyklus([Vinterdriftsklasse.DkD]);
        const klasseGangOgSykkelvei = hentKlasserMedSyklus(["GsV"]);

        expect(klasseDka[0].syklus).toEqual("1,5 timer.");
        expect(klasseDkbh[0].syklus).toEqual("2 timer.");
        expect(klasseDkC[0].syklus).toEqual("2,5 timer for brøyting, 3 timer for strøing.");
        expect(klasseDkD[0].syklus).toEqual("3 timer for brøyting, 4 timer for strøing.");
        expect(klasseGangOgSykkelvei).toHaveLength(0);
    });

    it("skal filtrere bort vinterdriftsklasser som ikke skal vises", () => {
        const klasseVST = hentKlasserMedSyklus(["VST"]);

        expect(klasseVST).toHaveLength(0);
    });

    it("skal finne driftsklasse med høyeste syklustid", () => {
        const rodeDka: RodeDto = {
            rodeId: "1",
            rodeNavn: "Rode 1",
            vinterdriftsKlasser: [Vinterdriftsklasse.DkA],
            detaljer: {
                veglenke: [],
                geometri: {
                    type: "LineString",
                    coordinates: [],
                },
                vegsystemreferanse: [],
                gatenavn: [],
            },
        };
        const rodeDkbh: RodeDto = {
            rodeId: "2",
            rodeNavn: "Rode 2",
            vinterdriftsKlasser: [Vinterdriftsklasse.DkBh, Vinterdriftsklasse.DkA],
            detaljer: {
                veglenke: [],
                geometri: {
                    type: "LineString",
                    coordinates: [],
                },
                vegsystemreferanse: [],
                gatenavn: [],
            },
        };
        const rodeDkC: RodeDto = {
            rodeId: "3",
            rodeNavn: "Rode 3",
            vinterdriftsKlasser: [Vinterdriftsklasse.DkC],
            detaljer: {
                veglenke: [],
                geometri: {
                    type: "LineString",
                    coordinates: [],
                },
                vegsystemreferanse: [],
                gatenavn: [],
            },
        };

        const ingenRoder = finnDriftsklasseMedHøyesteSyklustid([]);
        const dka = finnDriftsklasseMedHøyesteSyklustid([rodeDka]);
        const dkBh = finnDriftsklasseMedHøyesteSyklustid([rodeDka, rodeDkbh]);
        const dkC = finnDriftsklasseMedHøyesteSyklustid([rodeDka, rodeDkbh, rodeDkC]);

        expect(ingenRoder).toBeUndefined();
        expect(dka).toEqual(Vinterdriftsklasse.DkA);
        expect(dkBh).toEqual(Vinterdriftsklasse.DkBh);
        expect(dkC).toEqual(Vinterdriftsklasse.DkC);
    });
});
