import React from "react";
import { InformasjonPopup } from "../InformasjonPopup";
import styled from "styled-components";
import { TrafikkmeldingerDto } from "../../../api/useHentTrafikkmeldinger";
import { StengtVegInnhold } from "./StengtVegPopupInnhold";

export interface StengtVegPopupProps {
    trafikkmelding: TrafikkmeldingerDto;
}

export const StengtVegPupup = ({ trafikkmelding }: StengtVegPopupProps) => {
    const beskrivelse = trafikkmelding.description ?? trafikkmelding.dataProcessingNote ?? "";
    const beskrivelseListe = beskrivelse.split("|");
    return (
        <InformasjonPopup
            tittel={trafikkmelding.locations[0].locationDescriptor ?? ""}
            undertekst={trafikkmelding.locations[0].roadNumber ?? ""}
            detaljWidth={696}
            ikonPath={trafikkmelding.roadClosed ? "/ikon/kart/stengt.svg" : "/ikon/kart/alert.svg"}
            ikonBorder={trafikkmelding.roadClosed ? 2 : 0}
        >
            <PopupInnhold>
                <StengtVegInnhold
                    type={trafikkmelding.recordType}
                    subType={trafikkmelding.recordSubtypes}
                    beskrivelse={beskrivelseListe}
                    starttid={trafikkmelding.overallStartTime?.toString()}
                    sluttid={trafikkmelding.overallEndTime?.toString()}
                    gjentagende={trafikkmelding.recurringTimePeriods}
                />
            </PopupInnhold>
        </InformasjonPopup>
    );
};

const PopupInnhold = styled.div`
    padding: 16px;
    margin: 0;
    max-height: inherit;
    overflow-y: auto;
`;
