import {
    reccuringTimePeriodToString,
    RecurringTimePeriods,
} from "../../../api/useHentTrafikkmeldinger";
import { camelCaseToSpace } from "../../../utils/tekst";
import { timestampStringTilNorsk } from "../../../utils/tid";
import styled from "styled-components";
import React from "react";

interface StengtVegInnholdProps {
    type?: string;
    subType: string[];
    beskrivelse: string[];
    starttid?: string;
    sluttid?: string;
    gjentagende: RecurringTimePeriods[];
}

export const StengtVegInnhold = ({
    type,
    subType,
    beskrivelse,
    sluttid,
    starttid,
    gjentagende,
}: StengtVegInnholdProps) => {
    return (
        <StyledStengtVegWrapper>
            <Underoverskrift>Type:</Underoverskrift>
            <StyledP>{type ? camelCaseToSpace(type) : "-"}</StyledP>
            <Underoverskrift>Underkategori:</Underoverskrift>
            {subType.length > 0 ? (
                subType.map((subType, idx) => (
                    <StyledP key={idx}>{camelCaseToSpace(subType)}</StyledP>
                ))
            ) : (
                <StyledP>-</StyledP>
            )}

            <Beskrivelse>
                <Underoverskrift>Beskrivelse:</Underoverskrift>
                {beskrivelse.map((setning, idx) => (
                    <StyledP key={idx}>{setning}</StyledP>
                ))}
            </Beskrivelse>

            <Underoverskrift>Overordnet starttid:</Underoverskrift>
            <StyledP>{starttid ? timestampStringTilNorsk(starttid) : "-"}</StyledP>

            <Underoverskrift>Overordnet beregnet sluttid:</Underoverskrift>
            <StyledP>{sluttid ? timestampStringTilNorsk(sluttid) : "-"}</StyledP>

            <Underoverskrift>Gjentagende:</Underoverskrift>
            {gjentagende.length > 0 ? (
                gjentagende.map((periode, idx) => (
                    <StyledP key={idx}>{reccuringTimePeriodToString(periode)}</StyledP>
                ))
            ) : (
                <StyledP>-</StyledP>
            )}
        </StyledStengtVegWrapper>
    );
};

const Underoverskrift = styled.p`
    font-size: 14px;
    font-weight: bold;
`;

const StyledP = styled.p`
    font-size: 14px;
    padding-bottom: 8px;
`;

const StyledStengtVegWrapper = styled.div`
    display: flex;
    flex-direction: column;
`;

const Beskrivelse = styled.div`
    font-size: 14px;
    border-radius: 0.25rem;
    display: flex;
    flex-direction: column;
`;
