import React from "react";
import styled from "styled-components";
import { timestampStringTilDatoOgTid } from "../../../../utils/tid";
import { Produksjonsdetaljer } from "../../../types/produksjonsdetaljer";
import {
    ProduksjonsdetaljerKolonne,
    ProduksjonsdetaljerKolonneNavn,
} from "../kolonneVelger/ProduksjonsdetaljerKolonneVelger";
import { hentKolonneBredde } from "./ProduksjonsdetaljerTabell";
import { tilFargekode } from "../../../utils/tidsintervallUtils";
import { ProduksjonKollonne, TabellKollonne } from "./ProduksjonsdetaljKollonne";
import { KjøretøyRetning } from "../../kjøretøy/KjøretøyRetning";
import Popup from "reactjs-popup";
import { Tekst } from "../../../../components/fellesKomponenter/typografi/Tekst";
import { genererØktUrl } from "../../../../øktdetaljerSide/øktUtils";
import { erSprederPå } from "../../popupUtils";
import {
    loggEventMedTabellnavn,
    TabellNavn,
    VeglenkePopupLoggEvent,
} from "../../../../utils/loggFrontend";

interface ProduksjonsdetaljRadProps {
    produksjonsdetalj: Produksjonsdetaljer;
    kolonner: ProduksjonsdetaljerKolonne[];
}

export const ProduksjonsdetaljRad = ({
    produksjonsdetalj,
    kolonner,
}: ProduksjonsdetaljRadProps) => {
    return (
        <TabellRad>
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Økt) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Økt)}
                    klikkbar={true}
                    url={genererØktUrl(produksjonsdetalj.eksternReferanse)}
                    onClick={() =>
                        loggEventMedTabellnavn(
                            TabellNavn.veglenkepopupTrykk,
                            VeglenkePopupLoggEvent.øktidKlikk,
                        )
                    }
                >
                    <StyledPopup
                        trigger={<span>{produksjonsdetalj.eksternReferanse}</span>}
                        position="right center"
                        on="hover"
                        arrow={false}
                    >
                        <Tekst $nomargin={true} $størrelse={"S"}>
                            Åpne øktdetaljer i ny fane
                        </Tekst>
                    </StyledPopup>
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(
                kolonner,
                ProduksjonsdetaljerKolonneNavn.Vegsystemreferansekortform,
            ) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(
                        ProduksjonsdetaljerKolonneNavn.Vegsystemreferansekortform,
                    )}
                >
                    {produksjonsdetalj.vegsystemreferansekortform}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Tid) && (
                <ProduksjonKollonne bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Tid)}>
                    <TidWrapper>
                        {timestampStringTilDatoOgTid(produksjonsdetalj.datoLogget)}
                        <IntervallSirkel
                            color={
                                produksjonsdetalj.minutterSiden
                                    ? tilFargekode(produksjonsdetalj.minutterSiden)
                                    : "#ffffff"
                            }
                        />
                    </TidWrapper>
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Retning) && (
                <TabellKollonne
                    $bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Retning)}
                    $ikon={true}
                >
                    <KjøretøyRetning
                        sisteKoordinater={[
                            produksjonsdetalj.sluttLokasjon.punkt,
                            produksjonsdetalj.startLokasjon.punkt,
                        ]}
                    />
                </TabellKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Kjøretøy) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Kjøretøy)}
                >
                    {produksjonsdetalj.kjøretøyId ?? "Ukjent"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Fart) && (
                <ProduksjonKollonne bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Fart)}>
                    {Math.round(produksjonsdetalj.hastighetKmHAvg)} km/t
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Materiale) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Materiale)}
                >
                    {!erSprederPå(
                        produksjonsdetalj.erTørrstoffsprederPå,
                        produksjonsdetalj.erVåtstoffsprederPå,
                    )
                        ? "-"
                        : (produksjonsdetalj.materiale?.navn.toString() ?? "-")}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Plog) && (
                <ProduksjonKollonne bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Plog)}>
                    {produksjonsdetalj.erPlogNede ? "Nede" : "Oppe"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.Sideplog) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.Sideplog)}
                >
                    {produksjonsdetalj.erSideplogIBruk ? "Nede" : "Oppe"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.TungHøvel) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.TungHøvel)}
                >
                    {produksjonsdetalj.erHøvelskjærNede ? "Nede" : "Oppe"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.UnderliggendeSkjær) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.UnderliggendeSkjær)}
                >
                    {produksjonsdetalj.erUnderliggendeSkjærNede ? "Nede" : "Oppe"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(
                        ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff,
                    )}
                >
                    {produksjonsdetalj.erTørrstoffsprederPå
                        ? produksjonsdetalj.sprederbreddetoerrstoffcm
                            ? `${produksjonsdetalj.sprederbreddetoerrstoffcm} cm`
                            : "-"
                        : "-"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(
                        ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff,
                    )}
                >
                    {produksjonsdetalj.erVåtstoffsprederPå
                        ? produksjonsdetalj.sprederbreddevaatstoffcm
                            ? `${produksjonsdetalj.sprederbreddevaatstoffcm} cm`
                            : "-"
                        : "-"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.DoseringTørrstoff) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.DoseringTørrstoff)}
                >
                    {produksjonsdetalj.erTørrstoffsprederPå
                        ? produksjonsdetalj.doseringtoerrstoffgm2
                            ? `${produksjonsdetalj.doseringtoerrstoffgm2} gm2`
                            : "-"
                        : "-"}
                </ProduksjonKollonne>
            )}
            {erKolonneIBruk(kolonner, ProduksjonsdetaljerKolonneNavn.DoseringVåttstoff) && (
                <ProduksjonKollonne
                    bredde={hentKolonneBredde(ProduksjonsdetaljerKolonneNavn.DoseringVåttstoff)}
                >
                    {produksjonsdetalj.erVåtstoffsprederPå
                        ? produksjonsdetalj.doseringvaatstoffmlm2
                            ? `${produksjonsdetalj.doseringvaatstoffmlm2} ml2`
                            : "-"
                        : "-"}
                </ProduksjonKollonne>
            )}
        </TabellRad>
    );
};

const erKolonneIBruk = (
    kolonner: ProduksjonsdetaljerKolonne[],
    kolonneÅSjekke: ProduksjonsdetaljerKolonneNavn,
) => kolonner.some((kolonne) => kolonne.navn === kolonneÅSjekke && kolonne.iBruk);

const TabellRad = styled.tr`
    display: flex;
    justify-items: stretch;
    border-bottom: 1px solid var(--gray-dark-65);
    width: fit-content;
`;

const TidWrapper = styled.span`
    display: flex;
    flex-direction: row;
    justify-content: space-between;
    margin: 0;
`;

const IntervallSirkel = styled.span<{ color: string }>`
    display: inline-block;
    background-color: ${(props) => props.color};
    border-radius: 50%;
    margin: 0 0 0 2px;
    padding: 2px;
    height: 6px;
    width: 6px;
    align-self: center;
`;

const StyledPopup = styled(Popup)`
    &-content {
        background-color: var(--gray-light);
        padding: 4px;
        font-size: 14px;
        max-width: 300px;
        color: var(--gray-dark);
    }
`;
