import { SorteringsKnapp } from "./SorteringsKnapp";
import React from "react";
import { hentKolonneBredde, SorterEtter } from "../ProduksjonsdetaljerTabell";
import styled from "styled-components";
import { ProduksjonsdetaljerKolonne } from "../../kolonneVelger/ProduksjonsdetaljerKolonneVelger";

interface ProduksjonsdetaljerHeaderProps {
    finnSorteringsretning: (sorteringsnøkkel: SorterEtter) => boolean | undefined;
    håndterSortering: (sorteringsnøkkel: SorterEtter) => void;
    kolonner: ProduksjonsdetaljerKolonne[];
}

export const ProduksjonsdetaljerHeader = ({
    finnSorteringsretning,
    håndterSortering,
    kolonner,
}: ProduksjonsdetaljerHeaderProps) => (
    <StyledTabellHeader>
        <HeaderRad>
            {kolonner
                .filter((kolonne) => kolonne.iBruk)
                .map((kolonne, index) => (
                    <HeaderKollonne key={index} $bredde={hentKolonneBredde(kolonne.navn)}>
                        <SorteringsKnapp
                            label={kolonne.navn}
                            sorteringsnøkkel={kolonne.sorteringsnøkkel}
                            håndterSortering={håndterSortering}
                            finnSorteringsretning={finnSorteringsretning}
                        />
                    </HeaderKollonne>
                ))}
        </HeaderRad>
    </StyledTabellHeader>
);

const StyledTabellHeader = styled.thead`
    position: sticky;
    top: 0;
    background-color: var(--white);
    width: fit-content;
`;

const HeaderRad = styled.tr`
    display: flex;
    border-bottom: 2px solid var(--orange);
`;

const HeaderKollonne = styled.th<{
    $bredde: number;
}>`
    top: 0;
    position: sticky;
    padding: 0.5rem;
    text-align: start;
    width: ${(props) => props.$bredde}px;
`;
