import styled from "styled-components";
import React, { useState } from "react";
import { ProduksjonsdetaljRad } from "./ProduksjonsdetaljRad";
import { Tekst } from "../../../../components/fellesKomponenter/typografi/Tekst";
import { Produksjonsdetaljer } from "../../../types/produksjonsdetaljer";
import { sorterProduksjonsdetaljer } from "./produksjonsdetaljerSorteringUtils";
import { ProduksjonsdetaljerHeader } from "./ProduksjonsdetaljerHeader/ProduksjonsdetaljerHeader";
import {
    ProduksjonsdetaljerKolonne,
    ProduksjonsdetaljerKolonneNavn,
} from "../kolonneVelger/ProduksjonsdetaljerKolonneVelger";

export type Sortering<T> = {
    sorterEtter: T;
    stigende: boolean;
};

export enum SorterEtter {
    datoLogget = "datoLogget",
    eksternReferanse = "eksternReferanse",
    kjøretøyId = "kjøretøyId",
    hastighetKmH = "hastighetKmHAvg",
    materiale = "materiale",
    erPlogNed = "erPlogNede",
    sideplog = "erSideplogIBruk",
    tungHøvel = "erHøvelskjærNede",
    underliggendeSkjær = "erUnderliggendeSkjærNede",
    sprederbreddetoerrstoffcm = "sprederbreddetoerrstoffcm",
    sprederbreddevaatstoffcm = "sprederbreddevaatstoffcm",
    doseringtoerrstoffgm2 = "doseringtoerrstoffgm2",
    doseringvaatstoffmlm2 = "doseringvaatstoffmlm2",
    vegsystemreferansekortform = "vegsystemreferansekortform",
}

interface ProduksjonsdetaljerTabellProps {
    filtrerteProduksjonsdetaljer: Produksjonsdetaljer[];
    kolonner: ProduksjonsdetaljerKolonne[];
    visSyklusFeil: boolean;
    alleProduksjonsdetaljer: Produksjonsdetaljer[];
}

export const ProduksjonsdetaljerTabell = ({
    filtrerteProduksjonsdetaljer,
    kolonner,
    visSyklusFeil,
    alleProduksjonsdetaljer,
}: ProduksjonsdetaljerTabellProps) => {
    const [sortering, setSortering] = useState<Sortering<SorterEtter>>({
        sorterEtter: SorterEtter.datoLogget,
        stigende: true,
    });

    const håndterSortering = (sorteringsNøkkel: SorterEtter) => {
        setSortering({
            sorterEtter: sorteringsNøkkel,
            stigende: sorteringsNøkkel === sortering.sorterEtter ? !sortering.stigende : true,
        });
    };

    const finnSorteringsretning = (sorteringsnøkkel: SorterEtter): boolean | undefined =>
        sortering.sorterEtter === sorteringsnøkkel ? sortering.stigende : undefined;

    if (visSyklusFeil) {
        return <Tekst style={{ padding: "16px" }}>Klarte ikke å filtrere for syklustid</Tekst>;
    }
    if (filtrerteProduksjonsdetaljer.length === 0) {
        return (
            <Tekst style={{ padding: "16px" }}>Det er ingen passeringer for valgte filtre</Tekst>
        );
    }

    const sorterteProduksjonsdetaljer = sorterProduksjonsdetaljer(
        filtrerteProduksjonsdetaljer,
        sortering,
    );

    return (
        <>
            {filtrerteProduksjonsdetaljer.length < alleProduksjonsdetaljer.length && (
                <StyledTekst $størrelse={"M"}>
                    Noen passeringer er skjult på grunn av valgte filtre
                </StyledTekst>
            )}
            <StyledTabell>
                <ProduksjonsdetaljerHeader
                    finnSorteringsretning={finnSorteringsretning}
                    håndterSortering={håndterSortering}
                    kolonner={kolonner}
                />
                <tbody>
                    {sorterteProduksjonsdetaljer.map((rad, index) => (
                        <ProduksjonsdetaljRad
                            produksjonsdetalj={rad}
                            kolonner={kolonner}
                            key={index}
                        />
                    ))}
                </tbody>
            </StyledTabell>
        </>
    );
};

const StyledTabell = styled.table`
    display: flex;
    padding: 0 16px;
    flex-direction: column;
    border-collapse: collapse;
    height: fit-content;
`;

const StyledTekst = styled(Tekst)`
    padding: 10px 0px 10px 16px;
`;

export const hentKolonneBredde = (kolonneNavn: ProduksjonsdetaljerKolonneNavn): number => {
    switch (kolonneNavn) {
        case ProduksjonsdetaljerKolonneNavn.Økt:
            return 70;
        case ProduksjonsdetaljerKolonneNavn.Tid:
            return 86;
        case ProduksjonsdetaljerKolonneNavn.Retning:
            return 86;
        case ProduksjonsdetaljerKolonneNavn.Kjøretøy:
            return 90;
        case ProduksjonsdetaljerKolonneNavn.Fart:
            return 110;
        case ProduksjonsdetaljerKolonneNavn.Materiale:
            return 100;
        case ProduksjonsdetaljerKolonneNavn.Plog:
            return 60;
        case ProduksjonsdetaljerKolonneNavn.Sideplog:
            return 100;
        case ProduksjonsdetaljerKolonneNavn.TungHøvel:
            return 120;
        case ProduksjonsdetaljerKolonneNavn.UnderliggendeSkjær:
            return 190;
        case ProduksjonsdetaljerKolonneNavn.DoseringTørrstoff:
            return 120;
        case ProduksjonsdetaljerKolonneNavn.DoseringVåttstoff:
            return 120;
        case ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff:
            return 150;
        case ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff:
            return 150;
        case ProduksjonsdetaljerKolonneNavn.Vegsystemreferansekortform:
            return 190;
        default:
            return 24;
    }
};
