import { Produksjonsdetaljer } from "../../../types/produksjonsdetaljer";
import { SorterEtter, Sortering } from "./ProduksjonsdetaljerTabell";
import { sort } from "d3-array";

export const sorterProduksjonsdetaljer = (
    produksjonsdetaljer: Produksjonsdetaljer[],
    sortering: Sortering<SorterEtter>,
) =>
    produksjonsdetaljer.sort((a, b) => {
        if (sortering.sorterEtter === "materiale") {
            return sortering.stigende ? materialeSammenlikner(b, a) : materialeSammenlikner(a, b);
        }
        if (
            [SorterEtter.doseringvaatstoffmlm2, SorterEtter.sprederbreddevaatstoffcm].includes(
                sortering.sorterEtter,
            )
        ) {
            return sortering.stigende
                ? våttstoffSammenlikner(b, a, sortering.sorterEtter)
                : våttstoffSammenlikner(a, b, sortering.sorterEtter);
        }
        if (
            [SorterEtter.sprederbreddetoerrstoffcm, SorterEtter.doseringtoerrstoffgm2].includes(
                sortering.sorterEtter,
            )
        ) {
            return sortering.stigende
                ? tørrstoffSammenlikner(b, a, sortering.sorterEtter)
                : tørrstoffSammenlikner(a, b, sortering.sorterEtter);
        }
        return sortering.stigende
            ? sammenlikner(b, a, sortering.sorterEtter)
            : sammenlikner(a, b, sortering.sorterEtter);
    });

const materialeSammenlikner = (a: Produksjonsdetaljer, b: Produksjonsdetaljer) => {
    const sorteringsVerdiA =
        a.erTørrstoffsprederPå || a.erVåtstoffsprederPå ? (a.materiale ?? "ukjent") : "sprederAv";
    const sorteringsVerdiB =
        b.erTørrstoffsprederPå || b.erVåtstoffsprederPå ? (b.materiale ?? "ukjent") : "sprederAv";
    return sorteringsVerdiB < sorteringsVerdiA ? 1 : sorteringsVerdiB > sorteringsVerdiA ? -1 : 0;
};

const tørrstoffSammenlikner = (
    a: Produksjonsdetaljer,
    b: Produksjonsdetaljer,
    sorterEtter: SorterEtter,
) => {
    const sorteringsVerdiA = a.erTørrstoffsprederPå
        ? (a[sorterEtter as keyof Produksjonsdetaljer] ?? 0)
        : 0;
    const sorteringsVerdiB = b.erTørrstoffsprederPå
        ? (b[sorterEtter as keyof Produksjonsdetaljer] ?? 0)
        : 0;
    return sorteringsVerdiB < sorteringsVerdiA ? 1 : sorteringsVerdiB > sorteringsVerdiA ? -1 : 0;
};

const våttstoffSammenlikner = (
    a: Produksjonsdetaljer,
    b: Produksjonsdetaljer,
    sorterEtter: SorterEtter,
) => {
    const sorteringsVerdiA = a.erVåtstoffsprederPå
        ? (a[sorterEtter as keyof Produksjonsdetaljer] ?? 0)
        : 0;
    const sorteringsVerdiB = b.erVåtstoffsprederPå
        ? (b[sorterEtter as keyof Produksjonsdetaljer] ?? 0)
        : 0;
    return sorteringsVerdiB < sorteringsVerdiA ? 1 : sorteringsVerdiB > sorteringsVerdiA ? -1 : 0;
};

const sammenlikner = (a: Produksjonsdetaljer, b: Produksjonsdetaljer, sorterEtter: SorterEtter) =>
    (b[sorterEtter as keyof Produksjonsdetaljer] ?? "ukjent") <
    (a[sorterEtter as keyof Produksjonsdetaljer] ?? "ukjent")
        ? 1
        : (b[sorterEtter as keyof Produksjonsdetaljer] ?? "ukjent") >
            (a[sorterEtter as keyof Produksjonsdetaljer] ?? "ukjent")
          ? -1
          : 0;
