import styled from "styled-components";
import { Tekst } from "../../../components/fellesKomponenter/typografi/Tekst";
import { Boldtext } from "../../../components/fellesKomponenter/typografi/Boldtext";
import { ProduksjonsdetaljerTabell } from "./ProduksjonsdetaljerTabell/ProduksjonsdetaljerTabell";
import { Produksjonsdetaljer } from "../../types/produksjonsdetaljer";
import { ProduksjonsdetaljerKolonneDropdown } from "./kolonneVelger/ProduksjonsdetaljerKolonneDropdown";
import React, { useEffect, useState } from "react";
import { ProduksjonsdetaljerKolonneNavn } from "./kolonneVelger/ProduksjonsdetaljerKolonneVelger";
import { genererMaksSyklustidStreng, manglerGyldigRodeData } from "./VeglenkeDetaljerUtils";
import { downloadExcel, EksporterTilExcel } from "../../../utils/EksporterTilExcel";
import { Checkbox } from "../../../components/fellesKomponenter/checkboxer/Checkbox";
import {
    erProduksjonInnenSyklustid,
    filtrerProduksjonsdetaljer,
} from "../../filtre/filtrerProduksjon/filtrerProduksjon";
import { RodeDto } from "../../../api/useHentRoder";
import { hentKlasserMedSyklus } from "../roder/vinterdriftsklasserUtils";
import { VinterdriftklasserInfo } from "../roder/VinterdriftklasserInfo";
import { ColumnWrapper } from "../../../components/fellesKomponenter/wrappers/wrappers";
import { hastighetsfilterAtom } from "../../jotai/HastighetsfilterAtom";
import { tidsfilterAtom } from "../../jotai/TidsfilterAtom";
import { useAtom, useAtomValue } from "jotai";
import { valgteKolonnerAtom } from "../../jotai/veglenkeKolonnerAtom";
import { defaultAktiveKolonner } from "./kolonneVelger/defaults";
import { produksjonsfilterAtom } from "../../../api/context/ProduksjonsfilterAtoms";
import { roderAtom } from "../../../api/context/apiAtoms";
import {
    loggEventMedTabellnavn,
    loggEventMedTabellnavnOgVerdi,
    TabellNavn,
    VeglenkePopupLoggEvent,
} from "../../../utils/loggFrontend";

interface VeglenkedetaljerProps {
    timerOgMinutterSiden?: string;
    produksjonsdetaljer: Produksjonsdetaljer[];
    roderPåVeglenken: RodeDto[];
}

export const Veglenkedetaljer = ({
    timerOgMinutterSiden,
    produksjonsdetaljer,
    roderPåVeglenken,
}: VeglenkedetaljerProps) => {
    const roder = useAtomValue(roderAtom);
    const hastighetsfilter = useAtomValue(hastighetsfilterAtom);
    const produksjonsfilter = useAtomValue(produksjonsfilterAtom);
    const tidsfilter = useAtomValue(tidsfilterAtom);
    const [aktiveKolonner, setAktiveKolonner] = useAtom(valgteKolonnerAtom);
    const [visSyklustid, setVisSyklustid] = useState<boolean>(false);
    const [filtrerteProduksjonsdetaljerMedSyklustid, setFiltrerteProduksjonsdetaljerMedSyklustid] =
        useState(produksjonsdetaljer);
    const [visSyklusFeil, setVisSyklusFeil] = useState<boolean>(false);

    const filtrerProduksjonsdetaljerMedSyklustid = () => {
        if (manglerGyldigRodeData(roderPåVeglenken, roder)) {
            setVisSyklusFeil(true);
            return;
        }
        const filtrertData = filtrerteProduksjonsdetaljer(produksjonsdetaljer).filter(
            (produksjonsdetalj: Produksjonsdetaljer) =>
                erProduksjonInnenSyklustid(produksjonsdetalj, roderPåVeglenken),
        );
        setFiltrerteProduksjonsdetaljerMedSyklustid(filtrertData);
    };

    useEffect(() => {
        if (visSyklustid) {
            filtrerProduksjonsdetaljerMedSyklustid();
        } else {
            setVisSyklusFeil(false);
        }
    }, [visSyklustid, produksjonsdetaljer]);

    const filtrerteProduksjonsdetaljer = (produksjonsdetaljer: Produksjonsdetaljer[]) =>
        filtrerProduksjonsdetaljer(
            produksjonsfilter,
            hastighetsfilter,
            tidsfilter,
            produksjonsdetaljer,
        );

    const filtrerteProduksjonsdetaljerSyklus = visSyklustid
        ? filtrerteProduksjonsdetaljerMedSyklustid
        : filtrerteProduksjonsdetaljer(produksjonsdetaljer);
    const toggleAktiveKolonner = (kolonneNavn: ProduksjonsdetaljerKolonneNavn): void => {
        const nyeAktiveKolonner = aktiveKolonner.map((kolonne) =>
            kolonne.navn === kolonneNavn ? { ...kolonne, iBruk: !kolonne.iBruk } : kolonne,
        );
        const kolonne = nyeAktiveKolonner.find((kolonne) => kolonne.navn === kolonneNavn);
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.kolonneVelgerTrykk,
            kolonneNavn,
            kolonne && kolonne.iBruk ? "På" : "Av",
        );
        setAktiveKolonner(nyeAktiveKolonner);
    };

    const nullstillAktiveKolonner = () => {
        loggEventMedTabellnavnOgVerdi(TabellNavn.kolonneVelgerTrykk, "Nullstill", "På");
        setAktiveKolonner(defaultAktiveKolonner);
    };

    const valgteFiltere = produksjonsfilter.filter((f) => f.valgt).map((f) => f.navn);

    const erForrigePasseringNegativ = (timerOgMinutterSiden: string) =>
        /(?<=-)\d+/.test(timerOgMinutterSiden);

    const håndterSyklustidEndring = () => {
        loggEventMedTabellnavn(TabellNavn.syklustidTrykk, !visSyklustid ? "På" : "Av");
        setVisSyklustid(!visSyklustid);
    };

    return (
        <>
            <EksportWrapper>
                <ColumnWrapper>
                    <CheckboxWrapper>
                        <Checkbox
                            størrelse={"S"}
                            key="syklustidcheck"
                            onChange={håndterSyklustidEndring}
                            checked={visSyklustid}
                            value={"Syklustidvisning"}
                            tekstStørrelse={"M"}
                        >
                            Vis kun produksjon innenfor syklustiden
                        </Checkbox>
                        <VinterdriftklasserInfo
                            klasserMedSyklus={hentKlasserMedSyklus(
                                roderPåVeglenken
                                    .filter((rode) => rode.vinterdriftsKlasser !== undefined)
                                    .flatMap((rode: RodeDto) => rode.vinterdriftsKlasser!),
                            )}
                        />
                    </CheckboxWrapper>
                    {visSyklustid && (
                        <Tekst $størrelse={"S"}>
                            {genererMaksSyklustidStreng(roderPåVeglenken)}
                        </Tekst>
                    )}
                </ColumnWrapper>

                <EksporterTilExcel
                    tekst={"Last ned som regneark"}
                    onClick={() => {
                        downloadExcel(
                            produksjonsdetaljer,
                            filtrerteProduksjonsdetaljerSyklus,
                            aktiveKolonner,
                            valgteFiltere,
                            roder?.data,
                        );
                        loggEventMedTabellnavn(
                            TabellNavn.veglenkepopupTrykk,
                            VeglenkePopupLoggEvent.lastNed,
                        );
                    }}
                />
            </EksportWrapper>
            <ProduksjonsdetaljerHeader>
                <TidSidenWrapper>
                    {timerOgMinutterSiden && !erForrigePasseringNegativ(timerOgMinutterSiden) && (
                        <>
                            <Tekst $størrelse="S">Tid siden forrige passering: </Tekst>
                            <Boldtext $størrelse="M">{timerOgMinutterSiden}</Boldtext>
                        </>
                    )}
                </TidSidenWrapper>
                <ProduksjonsdetaljerKolonneDropdown
                    kolonner={aktiveKolonner}
                    oppdaterProduksjonsdetaljerKolonne={toggleAktiveKolonner}
                    nullstillAktiveKolonner={nullstillAktiveKolonner}
                />
            </ProduksjonsdetaljerHeader>
            <ProduksjonsdetaljerTabell
                visSyklusFeil={visSyklusFeil}
                filtrerteProduksjonsdetaljer={filtrerteProduksjonsdetaljerSyklus}
                alleProduksjonsdetaljer={produksjonsdetaljer}
                kolonner={aktiveKolonner}
            />
        </>
    );
};

const TidSidenWrapper = styled.div`
    padding: 0 16px;
    margin: 0;
    display: flex;
    gap: 8px;
    align-items: flex-end;
`;

const ProduksjonsdetaljerHeader = styled.div`
    display: flex;
    justify-content: space-between;
    margin-bottom: 4px;
    margin-top: 16px;
`;

const EksportWrapper = styled.div`
    margin: 1rem 16px 0 16px;
    display: flex;
    gap: 20px;
    justify-content: space-between;
    align-items: flex-start;
`;

const CheckboxWrapper = styled.div`
    display: flex;
    gap: 0.5rem;
`;
