import {
    ProduksjonsdetaljerKolonne,
    ProduksjonsdetaljerKolonneNavn,
} from "./kolonneVelger/ProduksjonsdetaljerKolonneVelger";
import { SorterEtter } from "./ProduksjonsdetaljerTabell/ProduksjonsdetaljerTabell";
import { erAktiveKolonnerGyldige, manglerGyldigRodeData } from "./VeglenkeDetaljerUtils";
import { RodeDto } from "../../../api/useHentRoder";
import { ApiRespons, FetchStatus } from "../../../api/api";
import { defaultAktiveKolonner } from "./kolonneVelger/defaults";

describe("VeglenkeDetaljerUtils", () => {
    it("finner ugyldige kolloner", () => {
        const utdaterteKolonner: ProduksjonsdetaljerKolonne[] = [
            {
                navn: ProduksjonsdetaljerKolonneNavn.Økt,
                iBruk: true,
                sorteringsnøkkel: SorterEtter.eksternReferanse,
            },
            {
                navn: ProduksjonsdetaljerKolonneNavn.Tid,
                iBruk: true,
                sorteringsnøkkel: SorterEtter.datoLogget,
            },
            {
                navn: ProduksjonsdetaljerKolonneNavn.Retning,
                iBruk: false,
                sorteringsnøkkel: SorterEtter.datoLogget,
            },
            {
                navn: ProduksjonsdetaljerKolonneNavn.Kjøretøy,
                iBruk: true,
                sorteringsnøkkel: SorterEtter.kjøretøyId,
            },
            {
                // @ts-ignore
                navn: "Minimum fart",
                iBruk: true,
                sorteringsnøkkel: SorterEtter.hastighetKmH,
            },
        ];
        const erKolonnerGyldige = erAktiveKolonnerGyldige(utdaterteKolonner);
        expect(erKolonnerGyldige).toBe(false);
    });

    it("finner gyldige kolloner", () => {
        const erKolonnerGyldige = erAktiveKolonnerGyldige(defaultAktiveKolonner);
        expect(erKolonnerGyldige).toBe(true);
    });

    it("finner ut om det mangler gyldig rodedata", () => {
        const gyldigRode1: RodeDto = {
            rodeId: "1",
            rodeNavn: "Rode 1",
            vinterdriftsKlasser: ["DkA"],
            detaljer: {
                veglenke: [],
                geometri: {
                    type: "LineString",
                    coordinates: [],
                },
                vegsystemreferanse: [],
                gatenavn: [],
            },
        };

        const ugyldigRode1: RodeDto = {
            rodeId: "1",
            rodeNavn: "Rode 1",
            vinterdriftsKlasser: [],
            detaljer: {
                veglenke: [],
                geometri: {
                    type: "LineString",
                    coordinates: [],
                },
                vegsystemreferanse: [],
                gatenavn: [],
            },
        };

        const ugyldigRode2: RodeDto = {
            rodeId: "1",
            rodeNavn: "Rode 1",
            vinterdriftsKlasser: undefined,
            detaljer: {
                veglenke: [],
                geometri: {
                    type: "LineString",
                    coordinates: [],
                },
                vegsystemreferanse: [],
                gatenavn: [],
            },
        };

        const rodeApiResponse: ApiRespons<RodeDto[]> = {
            data: [gyldigRode1, ugyldigRode1, ugyldigRode2],
            suksess: true,
            status: FetchStatus.Suksess,
        };

        const gyldigRodedata = manglerGyldigRodeData([gyldigRode1], rodeApiResponse);
        const rodedataUtenVinterdriftsKlasser = manglerGyldigRodeData(
            [ugyldigRode1],
            rodeApiResponse,
        );
        const rodedataMedUndefinedVinterdriftsKlasser = manglerGyldigRodeData(
            [ugyldigRode2],
            rodeApiResponse,
        );
        expect(gyldigRodedata).toBe(false);
        expect(rodedataUtenVinterdriftsKlasser).toBe(true);
        expect(rodedataMedUndefinedVinterdriftsKlasser).toBe(true);
    });
});
