import {
    Filter,
    Filterkategori,
    Filtertype,
    MaterialOgAktivitetsNavn,
} from "../../../api/context/ProduksjonsfilterAtoms";
import { filterProduksjonslenker } from "./VeglenkePopup";
import { produksjonslenkerNordfjord2801231000 } from "../../../../__test_data__/produksjonslenkerNordfjord2801231000";
import { Produksjonslenke } from "../../types/produksjonslenke";
import { AktivitetKategori, AktivitetType } from "../../types/aktivitet";
import { MaterialKategori, MaterialType } from "../../types/materiale";
import { Hastighetsfilter } from "../../jotai/HastighetsfilterAtom";
import { RodeDto } from "../../../api/useHentRoder";
import { defaultTidsfilter } from "../../jotai/TidsfilterAtom";
import { hentRodeFraVeglenkeEllerProduksjonsdetaljer } from "../../utils/kartUtils";
import { Produksjonsdetaljer } from "../../types/produksjonsdetaljer";

describe("VeglenkePopup", () => {
    const veglenkesekvensId = 1;
    const veglenkeNummer = 1;
    const lenker: Produksjonslenke[] = [
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 1,
            hastighetKmH: 39,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.PlogNede,
                        type: AktivitetType.PlogNede,
                        kategori: AktivitetKategori.Brøyting,
                    },
                    ibruk: false,
                },
            ],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 2,
            hastighetKmH: 39,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.Sideplog,
                        type: AktivitetType.Sideplog,
                        kategori: AktivitetKategori.Brøyting,
                    },
                    ibruk: true,
                },
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.TungHøvel,
                        type: AktivitetType.TungHøvel,
                        kategori: AktivitetKategori.Høvling,
                    },
                    ibruk: false,
                },
            ],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 3,
            hastighetKmH: 46,
            produksjonstyper: [],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
                type: MaterialType.BefuktetFinkornetSalt,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 4,
            hastighetKmH: 39,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.Sideplog,
                        type: AktivitetType.Sideplog,
                        kategori: AktivitetKategori.Brøyting,
                    },
                    ibruk: false,
                },
            ],
            produksjonsmateriale: {
                navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
                type: MaterialType.BefuktetFinkornetSalt,
                kategori: MaterialKategori.Salt,
            },
        },
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 5,
            hastighetKmH: 46,
            produksjonstyper: [],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 5,
            hastighetKmH: 43,
            produksjonstyper: [],
            produksjonsmateriale: undefined,
        },
        {
            veglenkesekvensId: 1,
            veglenkeNummer: 1,
            økt: "1234",
            målepunkter: [1, 2, 3, 4],
            geometri: { type: "Point", coordinates: [1, 2] },
            minutterSiden: 5,
            hastighetKmH: 39,
            produksjonstyper: [
                {
                    aktivitet: {
                        navn: MaterialOgAktivitetsNavn.PlogNede,
                        type: AktivitetType.PlogNede,
                        kategori: AktivitetKategori.Brøyting,
                    },
                    ibruk: true,
                },
            ],
            produksjonsmateriale: undefined,
        },
    ];

    const hastighetsfilter: Hastighetsfilter = {
        verdi: "",
        valgt: false,
    };

    const filter: Filter[] = [
        {
            navn: "Plog nede",
            type: Filtertype.PlogNede,
            kategori: Filterkategori.Brøyting,
            valgt: false,
        },
        {
            navn: "Sideplog",
            type: Filtertype.Sideplog,
            kategori: Filterkategori.Brøyting,
            valgt: false,
        },
        {
            navn: "Underliggende skjær",
            type: Filtertype.UnderliggendeSkjær,
            kategori: Filterkategori.Høvling,
            valgt: false,
        },
        {
            navn: "Tung høvel",
            type: Filtertype.TungHøvel,
            kategori: Filterkategori.Høvling,
            valgt: false,
        },
        {
            navn: "Tørrsand",
            type: Filtertype.Tørrsand,
            kategori: Filterkategori.Sand,
            valgt: false,
        },
        {
            navn: "Fastsand",
            type: Filtertype.Fastsand,
            kategori: Filterkategori.Sand,
            valgt: false,
        },
        {
            navn: "Sand med saltinnblanding",
            type: Filtertype.SandMedSaltInnblanding,
            kategori: Filterkategori.Sand,
            valgt: false,
        },
        {
            navn: "Tørrsalt",
            type: Filtertype.Tørrsalt,
            kategori: Filterkategori.Salt,
            valgt: false,
        },
        {
            navn: "Befuktet salt",
            type: Filtertype.BefuktetSalt,
            kategori: Filterkategori.Salt,
            valgt: false,
        },
        {
            navn: "Saltslurry",
            type: Filtertype.BefuktetFinkornetSalt,
            kategori: Filterkategori.Salt,
            valgt: false,
        },
        {
            navn: "Saltløsning",
            type: Filtertype.Saltløsning,
            kategori: Filterkategori.Salt,
            valgt: false,
        },
        {
            navn: "Magnesiumklorid",
            type: Filtertype.Magnesiumklorid,
            kategori: Filterkategori.Salt,
            valgt: false,
        },
        {
            navn: "Ingen produksjon",
            type: Filtertype.IngenProduksjon,
            kategori: Filterkategori.IngenProduksjon,
            valgt: false,
        },
    ];

    const roder: RodeDto[] = [
        {
            rodeId: "1",
            rodeNavn: "Rode 1",
            detaljer: {
                veglenke: ["11111-1", "11111-2", "11111-3", "11111-4"],
                geometri: {
                    type: "MultiLineString",
                    coordinates: [[[17.11031, 68.67328]]],
                },
                vegsystemreferanse: ["ref"],
                gatenavn: ["gatenavn"],
            },
        },
        {
            rodeId: "2",
            rodeNavn: "Rode 2",
            detaljer: {
                veglenke: ["11111-5", "11111-6", "11111-7", "11111-8"],
                geometri: {
                    type: "MultiLineString",
                    coordinates: [[[17.11031, 68.67328]]],
                },
                vegsystemreferanse: ["ref"],
                gatenavn: ["gatenavn"],
            },
        },
        {
            rodeId: "3",
            rodeNavn: "Rode 3",
            detaljer: {
                veglenke: ["11111-1", "11111-9", "11111-10", "11111-11"],
                geometri: {
                    type: "MultiLineString",
                    coordinates: [[[17.11031, 68.67328]]],
                },
                vegsystemreferanse: ["ref"],
                gatenavn: ["gatenavn"],
            },
        },
    ];

    const produksjonsdetaljer: Produksjonsdetaljer[] = [
        {
            produksjonsdataRestRec: [1],
            kjøretøyId: "6883",
            datoLogget: "2023-01-28T04:17:05",
            hastighetKmHAvg: 48.0,
            erTørrstoffsprederPå: false,
            erVåtstoffsprederPå: false,
            erPlogNede: true,
            eksternReferanse: "644453",
            minutterSiden: 50,
            startLokasjon: {
                recordId: 2954550446,
                punkt: {
                    type: "Point",
                    coordinates: [17.372131, 68.743065],
                },
            },
            sluttLokasjon: {
                recordId: 2954550446,
                punkt: {
                    type: "Point",
                    coordinates: [17.372131, 68.743065],
                },
            },
            vegsystemreferansekortform: "FV7806 S3D1 m1784",
            rodeId: ["3"],
        },
    ];

    it("skal hente ut rodenavn der det finnes", () => {
        const lenkeHarIngenRode = hentRodeFraVeglenkeEllerProduksjonsdetaljer(
            roder,
            "1125861 - 18",
        );
        const lenkeHarRode = hentRodeFraVeglenkeEllerProduksjonsdetaljer(roder, "11111 - 2");
        const ingenRoder = hentRodeFraVeglenkeEllerProduksjonsdetaljer(undefined, "11111 - 5");
        const toRoder = hentRodeFraVeglenkeEllerProduksjonsdetaljer(roder, "11111-1");
        const ingenVeglenke = hentRodeFraVeglenkeEllerProduksjonsdetaljer(
            roder,
            "",
            produksjonsdetaljer,
        );

        expect(lenkeHarIngenRode).toStrictEqual([]);
        expect(lenkeHarRode).toStrictEqual([
            {
                rodeId: "1",
                rodeNavn: "Rode 1",
                detaljer: {
                    veglenke: ["11111-1", "11111-2", "11111-3", "11111-4"],
                    geometri: {
                        type: "MultiLineString",
                        coordinates: [[[17.11031, 68.67328]]],
                    },
                    vegsystemreferanse: ["ref"],
                    gatenavn: ["gatenavn"],
                },
            },
        ]);
        expect(ingenRoder).toStrictEqual([]);
        expect(toRoder).toStrictEqual([
            {
                rodeId: "1",
                rodeNavn: "Rode 1",
                detaljer: {
                    veglenke: ["11111-1", "11111-2", "11111-3", "11111-4"],
                    geometri: {
                        type: "MultiLineString",
                        coordinates: [[[17.11031, 68.67328]]],
                    },
                    vegsystemreferanse: ["ref"],
                    gatenavn: ["gatenavn"],
                },
            },
            {
                rodeId: "3",
                rodeNavn: "Rode 3",
                detaljer: {
                    veglenke: ["11111-1", "11111-9", "11111-10", "11111-11"],
                    geometri: {
                        type: "MultiLineString",
                        coordinates: [[[17.11031, 68.67328]]],
                    },
                    vegsystemreferanse: ["ref"],
                    gatenavn: ["gatenavn"],
                },
            },
        ]);
        expect(ingenVeglenke).toStrictEqual([
            {
                rodeId: "3",
                rodeNavn: "Rode 3",
                detaljer: {
                    veglenke: ["11111-1", "11111-9", "11111-10", "11111-11"],
                    geometri: {
                        type: "MultiLineString",
                        coordinates: [[[17.11031, 68.67328]]],
                    },
                    vegsystemreferanse: ["ref"],
                    gatenavn: ["gatenavn"],
                },
            },
        ]);
    });

    it("skal gi tom liste når ingen filter er valgt", () => {
        const resultat = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            filter,
            hastighetsfilter,
            defaultTidsfilter,
            lenker,
        );
        expect(resultat).toHaveLength(0);
    });

    it("skal vise kun plog ned når kun plog nede filter valgt", () => {
        const filterMedPlogNedeValgt = filter.map((f) => {
            if (f.type === Filtertype.PlogNede) {
                return { ...f, valgt: true };
            }
            return f;
        });
        const resultat = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            filterMedPlogNedeValgt,
            hastighetsfilter,
            defaultTidsfilter,
            lenker,
        );
        const forventetResultat: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 5,
                hastighetKmH: 39,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.PlogNede,
                            type: AktivitetType.PlogNede,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: true,
                    },
                ],
                produksjonsmateriale: undefined,
            },
        ];

        expect(resultat).toHaveLength(1);
        expect(resultat).toEqual(forventetResultat);
    });

    it("skal ikke vise ingen produksjon når ingen produksjon ikke er valgt", () => {
        const filterMedIngenProduksjon = filter.map((f) => {
            if (f.type === Filtertype.IngenProduksjon) {
                return { ...f, valgt: true };
            }
            return f;
        });
        const resultat = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            filterMedIngenProduksjon,
            hastighetsfilter,
            defaultTidsfilter,
            lenker,
        );
        const forventetResultat: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 1,
                hastighetKmH: 39,
                produksjonstyper: [
                    {
                        aktivitet: {
                            navn: MaterialOgAktivitetsNavn.PlogNede,
                            type: AktivitetType.PlogNede,
                            kategori: AktivitetKategori.Brøyting,
                        },
                        ibruk: false,
                    },
                ],
                produksjonsmateriale: undefined,
            },
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 5,
                hastighetKmH: 46,
                produksjonstyper: [],
                produksjonsmateriale: undefined,
            },
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 5,
                hastighetKmH: 43,
                produksjonstyper: [],
                produksjonsmateriale: undefined,
            },
        ];
        expect(resultat).toHaveLength(3);
        expect(resultat).toEqual(forventetResultat);
    });

    it("Skal kun vise ingenproduksjon med minst 45 kmt når ingen produksjon og hastighet på min 45 er valgt", () => {
        const filterMedIngenProduksjon = filter.map((f) => {
            if (f.type === Filtertype.IngenProduksjon) {
                return { ...f, valgt: true };
            }
            return f;
        });

        const hastighetsfilter = { verdi: "45", valgt: true };
        const resultat = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            filterMedIngenProduksjon,
            hastighetsfilter,
            defaultTidsfilter,
            lenker,
        );
        const forventetResultat: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 5,
                hastighetKmH: 46,
                produksjonstyper: [],
                produksjonsmateriale: undefined,
            },
        ];

        expect(resultat).toEqual(forventetResultat);
    });

    it("Skal kun vise plog nede og tung høvel med mist 45 kmt når respektive filtere er valgt", () => {
        const filterMedIngenProduksjon = filter.map((f) => {
            if (f.type === Filtertype.PlogNede || f.type === Filtertype.TungHøvel) {
                return { ...f, valgt: true };
            }
            return f;
        });
        const resultat = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            filterMedIngenProduksjon,
            { verdi: "45", valgt: true },
            defaultTidsfilter,
            lenker,
        );
        const forventetResultat: Produksjonslenke[] = [];

        expect(resultat).toEqual(forventetResultat);
    });

    it("Skal kun vise plog nede og tung høvel med minst 45 kmt når respektive filtere er valgt", () => {
        const filterMedIngenProduksjon = filter.map((f) => {
            if (
                f.type === Filtertype.BefuktetFinkornetSalt ||
                f.type === Filtertype.IngenProduksjon
            ) {
                return { ...f, valgt: true };
            }
            return f;
        });
        const resultat = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            filterMedIngenProduksjon,
            { verdi: "45", valgt: true },
            defaultTidsfilter,
            lenker,
        );
        const forventetResultat: Produksjonslenke[] = [
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 3,
                hastighetKmH: 46,
                produksjonstyper: [],
                produksjonsmateriale: {
                    navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
                    type: MaterialType.BefuktetFinkornetSalt,
                    kategori: MaterialKategori.Salt,
                },
            },
            {
                veglenkesekvensId: 1,
                veglenkeNummer: 1,
                økt: "1234",
                målepunkter: [1, 2, 3, 4],
                geometri: { type: "Point", coordinates: [1, 2] },
                minutterSiden: 5,
                hastighetKmH: 46,
                produksjonstyper: [],
                produksjonsmateriale: undefined,
            },
        ];

        expect(resultat).toEqual(forventetResultat);
    });

    it("viser kun plog nede og minst 46kmt når respektive filtere valt", () => {
        const filterPlogNede = filter.map((f) => {
            if (f.type === Filtertype.PlogNede) {
                return { ...f, valgt: true };
            }
            return f;
        });
        const hastighetsfilter: Hastighetsfilter = { verdi: "46", valgt: true };

        const resultat = filterProduksjonslenker(
            63,
            384504,
            filterPlogNede,
            hastighetsfilter,
            defaultTidsfilter,
            produksjonslenkerNordfjord2801231000,
        );

        expect(resultat).toHaveLength(1);
    });
});
