import { InformasjonPopup } from "../InformasjonPopup";
import { ApiRespons } from "../../../api/api";
import { defaultProduksjonsfilter, Filter } from "../../../api/context/ProduksjonsfilterAtoms";
import {
    erFilterGjeldene,
    produksjonslenkeTilFilterKriterie,
} from "../../filtre/filtrerProduksjon/filtrerProduksjon";
import { loggFrontend, LoggNivå } from "../../../utils/loggFrontend";
import {
    produksjonsdetaljerAtom,
    useHentProduksjondetaljer,
} from "../../../api/useHentProduksjonsdetaljer";
import { PopupInnhold } from "./PopupInnhold";
import { Produksjonslenke } from "../../types/produksjonslenke";
import { Produksjonsdetaljer } from "../../types/produksjonsdetaljer";
import { Hastighetsfilter, hastighetsfilterAtom } from "../../jotai/HastighetsfilterAtom";
import { øktProduksjonslenkerAtom } from "../../../api/context/ØktLenkerAtoms";
import { Tidsfilter, tidsfilterAtom } from "../../jotai/TidsfilterAtom";
import { hentRodeFraVeglenkeEllerProduksjonsdetaljer } from "../../utils/kartUtils";
import { veglenkePopupUndertekst } from "./VeglenkePopupUndertekst";
import { useAtomValue } from "jotai";
import { aktivKontraktAtom, tidspunktAtom } from "../../../api/context/kontraktAtoms";
import { roderAtom } from "../../../api/context/apiAtoms";

export interface VeglenkePopupInfo {
    kartlinje: any;
    veglenkesekvensId: number;
    veglenkeNummer: number;
    timerOgMinutterSiden?: string;
}

interface VeglenkePopupProps {
    veglenkePopupInfo: VeglenkePopupInfo;
    produksjonslenker: Produksjonslenke[];
}

export const VeglenkePopup = ({ veglenkePopupInfo, produksjonslenker }: VeglenkePopupProps) => {
    const produksjonsdetaljer = useAtomValue(produksjonsdetaljerAtom);
    const hastighetsfilter = useAtomValue(hastighetsfilterAtom);
    const aktivKontrakt = useAtomValue(aktivKontraktAtom);
    const tidspunkt = useAtomValue(tidspunktAtom);
    const roder = useAtomValue(roderAtom);
    const tidsfilter = useAtomValue(tidsfilterAtom);
    const øktProduksjonslenker = useAtomValue(øktProduksjonslenkerAtom);

    const veglenkeSekvensOgLenkeNummer = `${veglenkePopupInfo.veglenkesekvensId} - ${veglenkePopupInfo.veglenkeNummer}`;
    const roderPåVeglenken = hentRodeFraVeglenkeEllerProduksjonsdetaljer(
        roder?.data,
        veglenkeSekvensOgLenkeNummer,
        produksjonsdetaljer?.data,
    );
    const hentMålepunkter = (veglenkeNummer: number, veglenkesekvensId: number) => {
        const produksjonsfilter = defaultProduksjonsfilter;
        const punkter = filterProduksjonslenker(
            veglenkeNummer,
            veglenkesekvensId,
            produksjonsfilter,
            hastighetsfilter,
            tidsfilter,
            [...produksjonslenker, ...øktProduksjonslenker],
        ).flatMap((produksjonslenke) => produksjonslenke.målepunkter);

        if (punkter.length === 0) {
            const valgteFiltere = produksjonsfilter
                .filter((f) => f.valgt)
                .map((f) => f.navn)
                .toString();
            const loggInfo = `Ingen produksjonsdetaljer for veglenke ${veglenkeSekvensOgLenkeNummer}\n kontrakt: ${aktivKontrakt?.navn},\n tidspunkt: ${tidspunkt.toISOString()},\n valgteFiltere:${valgteFiltere}`;
            loggFrontend({
                loggNivå: LoggNivå.Warn,
                loggMelding: loggInfo,
            });
        }
        return punkter;
    };
    const målepunkter = hentMålepunkter(
        veglenkePopupInfo.veglenkeNummer,
        veglenkePopupInfo.veglenkesekvensId,
    );

    useHentProduksjondetaljer(målepunkter, tidspunkt);

    return (
        <InformasjonPopup
            tittel="Målepunkt for veglenke"
            undertekstHtml={veglenkePopupUndertekst(roderPåVeglenken, veglenkeSekvensOgLenkeNummer)}
            ikonPath={popupIkon(produksjonsdetaljer)}
            detaljWidth={680}
            skalHaDetaljMinHeight={true}
        >
            <PopupInnhold
                produksjonsdetaljer={produksjonsdetaljer}
                roderPåVeglenken={roderPåVeglenken}
                veglenkeSekvensOgLenkeNummer={veglenkeSekvensOgLenkeNummer}
                timerOgMinutterSiden={veglenkePopupInfo.timerOgMinutterSiden}
            />
        </InformasjonPopup>
    );
};

export const filterProduksjonslenker = (
    veglenkeNummer: number,
    veglenkesekvensId: number,
    produksjonsfilter: Filter[],
    hastighetsfilter: Hastighetsfilter,
    tidsfilter: Tidsfilter[],
    produksjonslenker: Produksjonslenke[],
): Produksjonslenke[] =>
    produksjonslenker.filter(
        (produksjonslenke) =>
            produksjonslenke.veglenkeNummer === veglenkeNummer &&
            produksjonslenke.veglenkesekvensId === veglenkesekvensId &&
            erFilterGjeldene(
                produksjonsfilter,
                hastighetsfilter,
                produksjonslenkeTilFilterKriterie(produksjonslenke),
                produksjonslenke.minutterSiden,
                produksjonslenke.hastighetKmH,
                produksjonslenke.økt,
                tidsfilter,
            ),
    );

const popupIkon = (produksjonsdetaljer?: ApiRespons<Produksjonsdetaljer[]>) =>
    produksjonsdetaljer?.suksess === false
        ? "/ikon/feil-kryss.svg"
        : "/ikon/kart/broytebil-sirkel.svg";
