import React from "react";
import { SorterEtter } from "../ProduksjonsdetaljerTabell/ProduksjonsdetaljerTabell";
import styled from "styled-components";
import { Checkbox } from "../../../../components/fellesKomponenter/checkboxer/Checkbox";
import { Tekst } from "../../../../components/fellesKomponenter/typografi/Tekst";

export enum ProduksjonsdetaljerKolonneNavn {
    Økt = "Øktid",
    Tid = "Tid",
    Kjøretøy = "Kjøretøy",
    Fart = "Fart (snitt)",
    Materiale = "Materiale",
    Plog = "Plog",
    Sideplog = "Sideplog",
    UnderliggendeSkjær = "Underliggende skjær",
    TungHøvel = "Tung høvel",
    SprederbreddeTørrstoff = "Sprederbredde tørrstoff",
    SprederbreddeVåttstoff = "Sprederbredde våttstoff",
    DoseringTørrstoff = "Dosering tørrstoff",
    DoseringVåttstoff = "Dosering våttstoff",
    Retning = "Retning",
    Vegsystemreferansekortform = "Vegsystemreferanse",
}

export type ProduksjonsdetaljerKolonne = {
    navn: ProduksjonsdetaljerKolonneNavn;
    iBruk: boolean;
    sorteringsnøkkel: SorterEtter;
};

interface ProduksjonsdetaljerKolonneVelgerProps {
    kolonner: ProduksjonsdetaljerKolonne[];
    oppdaterProduksjonsdetaljerKolonne: (kolonneNavn: ProduksjonsdetaljerKolonneNavn) => void;
    nullstillAktiveKolonner: () => void;
}

export const ProduksjonsdetaljerKolonneVelger = ({
    kolonner,
    oppdaterProduksjonsdetaljerKolonne,
    nullstillAktiveKolonner,
}: ProduksjonsdetaljerKolonneVelgerProps) => {
    return (
        <Container>
            <NullstillButton onClick={nullstillAktiveKolonner}>
                <Tekst $størrelse={"M"}>Nullstill valg</Tekst>
            </NullstillButton>
            {kolonner.map((kolonne, index) => (
                <Checkbox
                    key={`${kolonne.navn}-${index}`}
                    onChange={() => oppdaterProduksjonsdetaljerKolonne(kolonne.navn)}
                    checked={kolonne.iBruk}
                    value={"prodtabell" + index}
                    størrelse={"S"}
                    tekstStørrelse={"M"}
                >
                    {kolonne.navn}
                </Checkbox>
            ))}
        </Container>
    );
};

const Container = styled.div`
    background: var(--white);
    padding: 8px;
    display: flex;
    flex-direction: column;
    gap: 8px;

    @media (pointer: coarse) {
        gap: 12px;
    }
`;

const NullstillButton = styled.button`
    background-color: var(--white);
    border: none;
    cursor: pointer;
    display: flex;
    margin: auto auto auto auto;
    text-decoration: underline;

    &:hover p {
        font-weight: 600;
    }
`;
