import { render, screen } from "@testing-library/react";
import React from "react";
import { ApiRespons, FeilType, FetchStatus } from "../../api/api";
import "@testing-library/jest-dom";
import { Produksjonslenke } from "../types/produksjonslenke";
import { RodeDto } from "../../api/useHentRoder";
import { SisteKjøretøyDto } from "../../api/useHentSisteKjøretøy";
import { ProduksjonskartInnhold } from "../kartInnhold/ProduksjonskartInnhold";
import { produksjonslenkerAtom, roderAtom } from "../../api/context/apiAtoms";
import { TestProvider } from "../../utils/jotaiTestProvider";

const mockRodedata: ApiRespons<RodeDto[]> = {
    suksess: true,
    data: [],
    status: FetchStatus.Suksess,
};

const mockKjøretøyData: ApiRespons<SisteKjøretøyDto[]> = {
    suksess: true,
    data: [],
    status: FetchStatus.Suksess,
};

jest.mock("../../api/useHentWebkamera", () => ({
    useHentWebkamera: () => mockRodedata,
}));

jest.mock("../../api/useHentSisteKjøretøy", () => ({
    useHentSisteKjøretøy: () => mockKjøretøyData,
}));

describe("Kart", () => {
    it("skal vise spinner hvis data er undefined", async () => {
        render(<ProduksjonskartInnhold />);

        await screen.findByTestId("brøytebilspinner");

        expect(screen.getByTestId("brøytebilspinner"));
    });

    it("skal vise feilmelding hvis data har feil", async () => {
        const produksjonslenker: ApiRespons<Produksjonslenke[]> = {
            suksess: false,
            feilmelding: "Kunne ikke hente produksjonslenker",
            type: FeilType.UKJENT_FEIL,
            status: FetchStatus.Feil,
        };

        render(
            <TestProvider
                initialValues={[
                    [roderAtom, mockRodedata],
                    [produksjonslenkerAtom, produksjonslenker],
                ]}
            >
                <ProduksjonskartInnhold />
            </TestProvider>,
        );
        await screen.findByRole("list");

        expect(screen.getByRole("list")).toHaveTextContent("Kunne ikke hente produksjonslenker");
    });
});
