import { Dayjs, fraEnkelTimestampStr, tilEnkelTimestampStr } from "../../utils/tid";
import dayjs from "dayjs";
import { loggFrontend, LoggNivå } from "../../utils/loggFrontend";
import { sideInfo } from "../../sider";
import { Kontrakt } from "../../api/context/kontraktAtoms";

export interface KartUrlData {
    elrappKontraktId: number;
    timestamp: Dayjs;
}

export enum KartUrlSearchParameter {
    elrappkontrakt = "elrappkontrakt",
    tidspunkt = "tidspunkt",
}

export const settKartUrlParam = (nåværendePath: string, kartUrlData: KartUrlData): void => {
    if (nåværendePath.includes(sideInfo.produksjonskart.href)) {
        const urlParametre = new URLSearchParams();
        urlParametre.set(
            KartUrlSearchParameter.elrappkontrakt,
            kartUrlData.elrappKontraktId.toString(),
        );
        urlParametre.set(
            KartUrlSearchParameter.tidspunkt,
            tilEnkelTimestampStr(kartUrlData.timestamp),
        );
        window.history.replaceState(window.history.state, "", "?" + urlParametre.toString());
    }
};

export const hentKartUrlParam = (): KartUrlData | undefined => {
    if (typeof window !== "undefined") {
        const queryParam = new URLSearchParams(window.location.search);
        const elrappkontraktParam = queryParam.get(KartUrlSearchParameter.elrappkontrakt);
        const tidspunktParam = queryParam.get(KartUrlSearchParameter.tidspunkt);
        try {
            const parsetElrappkontrakt = Number(elrappkontraktParam);
            const parsetIsoTimestamp = tidspunktParam
                ? fraEnkelTimestampStr(tidspunktParam)
                : undefined;

            return parsetIsoTimestamp?.isValid() && parsetElrappkontrakt
                ? {
                      elrappKontraktId: parsetElrappkontrakt,
                      timestamp: parsetIsoTimestamp,
                  }
                : undefined;
        } catch (e) {
            loggFrontend({
                loggNivå: LoggNivå.Warn,
                loggMelding: `Klarte ikke parse queryparametre ${elrappkontraktParam} og ${tidspunktParam}: ${e}`,
            });
            return undefined;
        }
    }
};

export const finnInitTidspunkt = (): Dayjs => {
    const urlParam = hentKartUrlParam();
    const timestampFraUrl = urlParam?.timestamp;
    const nå = dayjs();
    return timestampFraUrl && !timestampFraUrl.isAfter(nå) ? timestampFraUrl : nå;
};

export const finnInitAktivKontrakt = (
    kontrakter: Kontrakt[],
    kontraktFraLocalstorage: Kontrakt | undefined,
): Kontrakt | undefined => {
    if (kontrakter.length > 0) {
        const urlParam = hentKartUrlParam();
        const kontraktFraUrl =
            urlParam &&
            kontrakter.find((kontrakt) => kontrakt.elrappId === urlParam.elrappKontraktId);
        if (kontraktFraUrl) {
            return kontraktFraUrl;
        } else if (
            kontraktFraLocalstorage &&
            kontrakter.find(
                (kontrakt) => kontrakt.elrappId === kontraktFraLocalstorage.elrappId,
            ) !== undefined
        ) {
            return localStorageKontraktTilKontrakt(
                kontraktFraLocalstorage as unknown as LocalStorageKontrakt,
            );
        } else {
            return kontrakter[0];
        }
    }
};

export interface LocalStorageKontrakt {
    navn: string;
    elrappId: number;
    navnNvdb: string;
    startDato: string | null;
    sluttDato: string | null;
}

export const localStorageKontraktTilKontrakt = (kontrakt: LocalStorageKontrakt): Kontrakt => {
    return {
        navn: kontrakt.navn,
        elrappId: kontrakt.elrappId,
        navnNvdb: kontrakt.navnNvdb,
        startDato: kontrakt.startDato ? dayjs(kontrakt.startDato) : undefined,
        sluttDato: kontrakt.sluttDato ? dayjs(kontrakt.sluttDato) : undefined,
    };
};
