import { Produksjonslenke } from "../types/produksjonslenke";
import { AktivitetType, AktivitetKategori } from "../types/aktivitet";
import { MaterialType, MaterialKategori } from "../types/materiale";
import { MaterialOgAktivitetsNavn } from "../../api/context/ProduksjonsfilterAtoms";
import { tilProduksjonslenkeGeojsonFeaturesEnkeltLag } from "../Kartvisning/geoJson/geoJSONutilsVeglenker";

describe("RodeKart utils", () => {
    it("skal ikke finnes duplikater i veglenker etter filtering", () => {
        const filtrerteLenker = tilProduksjonslenkeGeojsonFeaturesEnkeltLag(lenker).map(
            (feature) =>
                `${(feature.properties as Produksjonslenke).veglenkesekvensId}-${
                    (feature.properties as Produksjonslenke).veglenkeNummer
                }`,
        );
        const erElementerIListaUnik = (liste: string[]) =>
            Array.isArray(liste) && new Set(liste).size === liste.length;
        expect(erElementerIListaUnik(filtrerteLenker)).toBeTruthy();
    });
});

const lenker: Produksjonslenke[] = [
    {
        veglenkesekvensId: 1,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [
            {
                aktivitet: {
                    navn: MaterialOgAktivitetsNavn.PlogNede,
                    type: AktivitetType.PlogNede,
                    kategori: AktivitetKategori.Brøyting,
                },
                ibruk: true,
            },
        ],
        produksjonsmateriale: undefined,
    },
    {
        veglenkesekvensId: 2,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [
            {
                aktivitet: {
                    navn: MaterialOgAktivitetsNavn.Sideplog,
                    type: AktivitetType.Sideplog,
                    kategori: AktivitetKategori.Brøyting,
                },

                ibruk: true,
            },
            {
                aktivitet: {
                    navn: MaterialOgAktivitetsNavn.TungHøvel,
                    type: AktivitetType.TungHøvel,
                    kategori: AktivitetKategori.Høvling,
                },

                ibruk: true,
            },
        ],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.Tørrsand,
            type: MaterialType.Tørrsand,
            kategori: MaterialKategori.Sand,
        },
    },
    {
        veglenkesekvensId: 3,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.Fastsand,
            type: MaterialType.Fastsand,
            kategori: MaterialKategori.Sand,
        },
    },
    {
        veglenkesekvensId: 4,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [
            {
                aktivitet: {
                    navn: MaterialOgAktivitetsNavn.TungHøvel,
                    type: AktivitetType.TungHøvel,
                    kategori: AktivitetKategori.Høvling,
                },
                ibruk: true,
            },
        ],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.SandMedSaltInnblanding,
            type: MaterialType.SandMedSaltInnblanding,
            kategori: MaterialKategori.Sand,
        },
    },
    {
        veglenkesekvensId: 5,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.Tørrsalt,
            type: MaterialType.Tørrsalt,
            kategori: MaterialKategori.Salt,
        },
    },
    {
        veglenkesekvensId: 6,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.BefuktetSalt,
            type: MaterialType.BefuktetSalt,
            kategori: MaterialKategori.Salt,
        },
    },
    {
        veglenkesekvensId: 7,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.BefuktetFinkornetSalt,
            type: MaterialType.BefuktetFinkornetSalt,
            kategori: MaterialKategori.Salt,
        },
    },
    {
        veglenkesekvensId: 8,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.Saltløsning,
            type: MaterialType.Saltløsning,
            kategori: MaterialKategori.Salt,
        },
    },
    {
        veglenkesekvensId: 9,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
            type: MaterialType.Magnesiumklorid,
            kategori: MaterialKategori.Salt,
        },
    },
    {
        veglenkesekvensId: 10,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 43,
        produksjonstyper: [],
        produksjonsmateriale: undefined,
    },
    {
        veglenkesekvensId: 11,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 48,
        produksjonstyper: [],
        produksjonsmateriale: undefined,
    },
    {
        veglenkesekvensId: 12,
        veglenkeNummer: 1,
        økt: "1234",
        målepunkter: [1, 2, 3, 4],
        geometri: { type: "Point", coordinates: [1, 2] },
        minutterSiden: 1,
        hastighetKmH: 48,
        produksjonstyper: [],
        produksjonsmateriale: {
            navn: MaterialOgAktivitetsNavn.Magnesiumklorid,
            type: MaterialType.Magnesiumklorid,
            kategori: MaterialKategori.Salt,
        },
    },
];
