import { Produksjonsdetaljer } from "../kartSide/types/produksjonsdetaljer";
import { filtrerExcelDataPåKolonner, produksjonsdetaljerTilExcel } from "./EksporterTilExcel";
import { ProduksjonsdetaljerKolonneNavn } from "../kartSide/popup/veglenke/kolonneVelger/ProduksjonsdetaljerKolonneVelger";

describe("Excel filter", () => {
    const produksjonsdetaljer: Produksjonsdetaljer[] = [
        {
            produksjonsdataRestRec: [1],
            kjøretøyId: "6883",
            datoLogget: "2023-01-28T04:17:05",
            hastighetKmHAvg: 48.0,
            erTørrstoffsprederPå: false,
            erVåtstoffsprederPå: false,
            erPlogNede: true,
            eksternReferanse: "644453",
            minutterSiden: 50,
            startLokasjon: {
                recordId: 2954550446,
                punkt: {
                    type: "Point",
                    coordinates: [17.372131, 68.743065],
                },
            },
            sluttLokasjon: {
                recordId: 2954550446,
                punkt: {
                    type: "Point",
                    coordinates: [17.372131, 68.743065],
                },
            },
            vegsystemreferansekortform: "FV7806 S3D1 m1784",
            rodeId: ["zi_4283"],
        },
        {
            produksjonsdataRestRec: [2],
            kjøretøyId: "6883",
            datoLogget: "2023-01-28T04:16:59",
            hastighetKmHAvg: 61.0,
            erTørrstoffsprederPå: false,
            erVåtstoffsprederPå: false,
            erPlogNede: true,
            eksternReferanse: "644453",
            minutterSiden: 50,
            startLokasjon: {
                recordId: 2954550446,
                punkt: {
                    type: "Point",
                    coordinates: [17.372131, 68.743065],
                },
            },
            sluttLokasjon: {
                recordId: 2954550446,
                punkt: {
                    type: "Point",
                    coordinates: [17.372131, 68.743065],
                },
            },
            vegsystemreferansekortform: "FV7806 S3D1 m1784",
            rodeId: ["zi_4283"],
        },
    ];
    it("skal ikke filtrere bort noen kolonner når alle kolonner er valgt", () => {
        const excelData = produksjonsdetaljerTilExcel(produksjonsdetaljer);
        const kolonneNavn: ProduksjonsdetaljerKolonneNavn[] = [
            ProduksjonsdetaljerKolonneNavn.Økt,
            ProduksjonsdetaljerKolonneNavn.Tid,
            ProduksjonsdetaljerKolonneNavn.Kjøretøy,
            ProduksjonsdetaljerKolonneNavn.Fart,
            ProduksjonsdetaljerKolonneNavn.Materiale,
            ProduksjonsdetaljerKolonneNavn.Plog,
            ProduksjonsdetaljerKolonneNavn.Sideplog,
            ProduksjonsdetaljerKolonneNavn.UnderliggendeSkjær,
            ProduksjonsdetaljerKolonneNavn.TungHøvel,
            ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff,
            ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff,
            ProduksjonsdetaljerKolonneNavn.DoseringTørrstoff,
            ProduksjonsdetaljerKolonneNavn.DoseringVåttstoff,
            ProduksjonsdetaljerKolonneNavn.Retning,
            ProduksjonsdetaljerKolonneNavn.Vegsystemreferansekortform,
        ];
        const filtrertExcelData = excelData.map((row) => {
            return filtrerExcelDataPåKolonner(row, kolonneNavn);
        });
        expect(filtrertExcelData[0].length).toBe(kolonneNavn.length + 2);
        expect(filtrertExcelData[1].length).toBe(kolonneNavn.length + 2);
    });
    it("skal filtrere bort alle kolonner utenom sprederbredde", () => {
        const excelData = produksjonsdetaljerTilExcel(produksjonsdetaljer);
        const kolonneNavn: ProduksjonsdetaljerKolonneNavn[] = [
            ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff,
            ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff,
        ];
        const filtrertExcelData = excelData.map((row) => {
            return filtrerExcelDataPåKolonner(row, kolonneNavn);
        });
        expect(filtrertExcelData[0].length).toBe(kolonneNavn.length + 2);
        expect(filtrertExcelData[1].length).toBe(kolonneNavn.length + 2);
    });
    it("skal filtrere bort alle kolonner utenom fart", () => {
        const excelData = produksjonsdetaljerTilExcel(produksjonsdetaljer);
        const kolonneNavn: ProduksjonsdetaljerKolonneNavn[] = [ProduksjonsdetaljerKolonneNavn.Fart];
        const filtrertExcelData = excelData.map((row) => {
            return filtrerExcelDataPåKolonner(row, kolonneNavn);
        });
        expect(filtrertExcelData[0].length).toBe(kolonneNavn.length);
        expect(filtrertExcelData[1].length).toBe(kolonneNavn.length);
    });
    it("skal filtrere bort alle kolonner", () => {
        const excelData = produksjonsdetaljerTilExcel(produksjonsdetaljer);
        const kolonneNavn: ProduksjonsdetaljerKolonneNavn[] = [];
        const filtrertExcelData = excelData.map((row) => {
            return filtrerExcelDataPåKolonner(row, kolonneNavn);
        });
        expect(filtrertExcelData[0].length).toBe(kolonneNavn.length);
        expect(filtrertExcelData[1].length).toBe(kolonneNavn.length);
    });
});
