import { Produksjonsdetaljer } from "../kartSide/types/produksjonsdetaljer";
import Exceljs from "exceljs";
import styled from "styled-components";
import {
    ProduksjonsdetaljerKolonne,
    ProduksjonsdetaljerKolonneNavn,
} from "../kartSide/popup/veglenke/kolonneVelger/ProduksjonsdetaljerKolonneVelger";
import { grader, graderTilRetning } from "../kartSide/popup/kjøretøy/Grader";
import { RodeDto } from "../api/useHentRoder";
import { rodeIdTilRodenavn } from "../kartSide/popup/popupUtils";
import { KnappUtenStyling } from "../components/fellesKomponenter/knapper/KnappUtenStyling";
import { Tekst } from "../components/fellesKomponenter/typografi/Tekst";
interface ExcelNedlastingProps {
    onClick: () => void;
    tekst: string;
}

interface ExcelProduksjonsdetaljer {
    kjøretøyId?: string;
    datoLogget?: string;
    hastighetKmHAvg?: number;
    materiale?: string;
    erPlogNede?: string;
    erSideplogIBruk?: string;
    erHøvelskjærNede?: string;
    erUnderliggendeSkjærNede?: string;
    erTørrstoffsprederPå?: string;
    erVåtstoffsprederPå?: string;
    sprederbreddetoerrstoffcm?: number;
    sprederbreddevaatstoffcm?: number;
    doseringtoerrstoffgm2?: number;
    doseringvaatstoffmlm2?: number;
    eksternReferanse?: string;
    retning?: string;
    vegsystemreferansekortform?: string;
}

export const downloadExcel = async (
    alleProduksjonsdetaljer: Produksjonsdetaljer[],
    filtrerteProduksjonsdetaljer: Produksjonsdetaljer[],
    kolonner: ProduksjonsdetaljerKolonne[],
    valgteFiltere: string[],
    roder?: RodeDto[] | undefined,
) => {
    if (alleProduksjonsdetaljer.length === 0) return;
    const workbook = new Exceljs.Workbook();
    const worksheetAlt = workbook.addWorksheet("All data");
    skrivTilExcel(
        workbook,
        workbook.addWorksheet("Filtrert data"),
        filtrerteProduksjonsdetaljer,
        kolonner,
        roder,
        valgteFiltere,
    );
    skrivTilExcel(workbook, worksheetAlt, alleProduksjonsdetaljer, [], roder);

    const buffer = await workbook.xlsx.writeBuffer();
    const blob = new Blob([buffer], {
        type: "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
    });
    const url = window.URL.createObjectURL(blob);

    const a = document.createElement("a");
    a.href = url;
    a.download = "Produksjonsdetaljer.xlsx";
    a.click();

    window.URL.revokeObjectURL(url);
};

const leggTilMetadata = (worksheet: Exceljs.Worksheet, valgteFiltere?: string[]) => {
    const headerFiltrertData =
        "Her ser du dataen fra veglenken du har valgt. " +
        "Kolonnene er de samme som du har valgt å vise i kartet, " +
        'ønsker du å se all data kan du velge arkfane 1 "All data".';
    const headerAllData =
        "Her ser du all data fra den valgte veglenken, " +
        'ønsker du å se den filtrerte dataen kan du velge arkfane 2 "Filtrert data".';
    const url = window.location.href;

    worksheet.getCell("A2").value = valgteFiltere ? headerFiltrertData : headerAllData;
    worksheet.getCell("A3").value =
        "Gjennomsnittsfarten er beregnet basert på alle fartsmålinger som er gjennomført innenfor hvert minutt";
    worksheet.getCell("A4").value = "Lenke til den valgte kontrakten og tidspunkt: ";
    worksheet.getCell("A5").value = {
        text: url,
        hyperlink: url,
    };

    if (valgteFiltere) {
        worksheet.getCell("A7").value =
            "Valgte produksjonstyper: " + valgteFiltere.toString().replaceAll(",", ", ");
    }

    const fontSize = 16;
    worksheet.mergeCells("A5:K5");
    worksheet.getCell("A2").font = { size: fontSize };
    worksheet.getCell("A3").font = { size: fontSize };
    worksheet.getCell("A4").font = { size: fontSize };
    worksheet.getCell("A5").font = { size: fontSize, color: { argb: "00A2FF" } };
    worksheet.getCell("A7").font = { size: fontSize };
};

const skrivTilExcel = (
    workbook: Exceljs.Workbook,
    worksheet: Exceljs.Worksheet,
    data: Produksjonsdetaljer[],
    kolonner: ProduksjonsdetaljerKolonne[],
    roder?: RodeDto[] | undefined,
    valgteFiltere?: string[],
) => {
    const formatertData = produksjonsdetaljerTilExcel(data, roder);
    const START_RAD_NR = 10;

    for (let i = 0; i < START_RAD_NR - 1; i++) {
        worksheet.addRow([]);
    }
    const kolonneNavnListe = kolonner.reduce((acc, k) => {
        if (k.iBruk) {
            acc.push(k.navn);
        }
        return acc;
    }, [] as ProduksjonsdetaljerKolonneNavn[]);

    const headers = Object.keys(formatertData[0]).reduce((acc, key) => {
        if (
            (kolonneNavnListe.includes(keyMapping[key as keyof ExcelProduksjonsdetaljer]) ||
                kolonneNavnListe.length === 0) &&
            headerMapping[key] !== undefined
        ) {
            acc.push(headerMapping[key]);
        }
        return acc;
    }, [] as string[]);
    worksheet.addRow(headers);

    const filterEnd = tallTilBokstav(headers.length) + START_RAD_NR;
    worksheet.autoFilter = {
        from: "A" + START_RAD_NR,
        to: filterEnd,
    };

    formatertData.forEach((row) => {
        if (kolonneNavnListe.length > 0) {
            const filtretData = filtrerExcelDataPåKolonner(row, kolonneNavnListe);
            worksheet.addRow(filtretData);
        } else {
            const rowData = Object.values(row);
            worksheet.addRow(rowData);
        }
    });

    for (let rad = START_RAD_NR; rad <= data.length + START_RAD_NR; rad++) {
        for (let kolonne = 1; kolonne <= headers.length; kolonne++) {
            let cell = worksheet.getCell(rad, kolonne);
            (cell.border = {
                top: { style: "thin" },
                left: { style: "thin" },
                bottom: { style: "thin" },
                right: { style: "thin" },
            }),
                (cell.alignment = { horizontal: "center" }),
                (cell.font = { size: 12 });
        }
    }

    const headerRow = worksheet.getRow(START_RAD_NR);
    (headerRow as Exceljs.Row).font = { bold: true, size: 12 };

    settKolonnebredder(worksheet, headers);

    leggTilMetadata(worksheet, valgteFiltere);
    settDelsummer(worksheet, START_RAD_NR, formatertData, kolonneNavnListe);
};

const tallTilBokstav = (tall: number) => (tall + 9).toString(36);

const settDelsummer = (
    worksheet: Exceljs.Worksheet,
    startRad: number,
    data: ExcelProduksjonsdetaljer[],
    kolonneNavnListe: ProduksjonsdetaljerKolonneNavn[],
) => {
    let tittelCelle = worksheet.getCell(startRad - 1, 1);
    tittelCelle.value = "Delsummer:";
    tittelCelle.font = { bold: true, size: 12 };
    Object.keys(data[0]).forEach((key, index) => {
        if (
            (kolonneNavnListe.includes(keyMapping[key as keyof ExcelProduksjonsdetaljer]) ||
                kolonneNavnListe.length === 0) &&
            typeof data[0][key as keyof ExcelProduksjonsdetaljer] === "number"
        ) {
            const kolonneBokstav = tallTilBokstav(index + 1);
            const start = `${kolonneBokstav}${startRad + 1}`;
            const slutt = `${kolonneBokstav}${data.length + startRad}`;
            let cell = worksheet.getCell(startRad - 1, index + 1);

            cell.value = {
                formula: `SUBTOTAL(1,${start}:${slutt})`,
                date1904: false,
            };
        }
    });
};

const headerMapping: Record<string, string> = {
    kjøretøyId: "KjøretøyID",
    datoLogget: "Dato logget",
    hastighetKmHAvg: "Gjennomsnittlig hastighet (km/t)",
    materiale: "Materiale",
    erPlogNede: "Er plog nede",
    erSideplogIBruk: "Er sideplog i bruk",
    erHøvelskjærNede: "Er høvleskjær nede",
    erUnderliggendeSkjærNede: "Er underliggende skjær nede",
    erTørrstoffsprederPå: "Er tørrstoffspreder på",
    erVåtstoffsprederPå: "Er våtstoffspreder på",
    sprederbreddetoerrstoffcm: "Sprederbredde tørrstoff (cm)",
    sprederbreddevaatstoffcm: "Sprederbredde våtstoff (cm)",
    doseringtoerrstoffgm2: "Dosering tørrstoff (g/m2 | ml/m2)",
    doseringvaatstoffmlm2: "Dosering våtstoff (g/m2 | ml/m2)",
    eksternReferanse: "ØktID",
    retning: "Retning",
    rodenavn: "Rodenavn",
    vegsystemreferansekortform: "Vegsystemreferanse",
};

export const filtrerExcelDataPåKolonner = (
    data: ExcelProduksjonsdetaljer,
    kolonneNavnListe: ProduksjonsdetaljerKolonneNavn[],
): string[] => {
    return Object.entries(data).reduce((acc: string[], [key, value]) => {
        const mappedKey = keyMapping[key as keyof ExcelProduksjonsdetaljer];
        if (kolonneNavnListe.includes(mappedKey)) {
            if (value === null || value === undefined) acc.push("-");
            else acc.push(value);
        }
        return acc;
    }, []);
};

const settKolonnebredder = (worksheet: Exceljs.Worksheet, headers: string[]) => {
    for (let column = 1; column <= headers.length; column++) {
        const header = headers[column - 1];
        switch (header) {
            case headerMapping.materiale:
                worksheet.getColumn(column).width = 25;
                break;
            case headerMapping.datoLogget:
                worksheet.getColumn(column).width = 25;
                break;
            case headerMapping.eksternReferanse:
                worksheet.getColumn(column).width = 25;
                break;
            case headerMapping.retning:
                worksheet.getColumn(column).width = 25;
                break;
            case headerMapping.rodenavn:
                worksheet.getColumn(column).width = 60;
                break;
            case headerMapping.vegsystemreferansekortform:
                worksheet.getColumn(column).width = 25;
                break;
            default:
                worksheet.getColumn(column).width = header.length;
        }
    }
};

const keyMapping = {
    kjøretøyId: ProduksjonsdetaljerKolonneNavn.Kjøretøy,
    datoLogget: ProduksjonsdetaljerKolonneNavn.Tid,
    hastighetKmHAvg: ProduksjonsdetaljerKolonneNavn.Fart,
    materiale: ProduksjonsdetaljerKolonneNavn.Materiale,
    erPlogNede: ProduksjonsdetaljerKolonneNavn.Plog,
    erSideplogIBruk: ProduksjonsdetaljerKolonneNavn.Sideplog,
    erHøvelskjærNede: ProduksjonsdetaljerKolonneNavn.TungHøvel,
    erUnderliggendeSkjærNede: ProduksjonsdetaljerKolonneNavn.UnderliggendeSkjær,
    erTørrstoffsprederPå: ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff,
    erVåtstoffsprederPå: ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff,
    sprederbreddetoerrstoffcm: ProduksjonsdetaljerKolonneNavn.SprederbreddeTørrstoff,
    sprederbreddevaatstoffcm: ProduksjonsdetaljerKolonneNavn.SprederbreddeVåttstoff,
    doseringtoerrstoffgm2: ProduksjonsdetaljerKolonneNavn.DoseringTørrstoff,
    doseringvaatstoffmlm2: ProduksjonsdetaljerKolonneNavn.DoseringVåttstoff,
    eksternReferanse: ProduksjonsdetaljerKolonneNavn.Økt,
    retning: ProduksjonsdetaljerKolonneNavn.Retning,
    vegsystemreferansekortform: ProduksjonsdetaljerKolonneNavn.Vegsystemreferansekortform,
};

export const produksjonsdetaljerTilExcel = (
    produksjonsdetaljer: Produksjonsdetaljer[],
    roder?: RodeDto[] | undefined,
): ExcelProduksjonsdetaljer[] => {
    return produksjonsdetaljer.map((detalje) => ({
        kjøretøyId: detalje.kjøretøyId,
        datoLogget: detalje.datoLogget,
        hastighetKmHAvg: detalje.hastighetKmHAvg,
        materiale: detalje.materiale?.navn ?? "-",
        erPlogNede: detalje.erPlogNede ? "ja" : "nei",
        erSideplogIBruk: detalje.erSideplogIBruk ? "ja" : "nei",
        erHøvelskjærNede: detalje.erHøvelskjærNede ? "ja" : "nei",
        erUnderliggendeSkjærNede: detalje.erUnderliggendeSkjærNede ? "ja" : "nei",
        erTørrstoffsprederPå: detalje.erTørrstoffsprederPå ? "ja" : "nei",
        erVåtstoffsprederPå: detalje.erVåtstoffsprederPå ? "ja" : "nei",
        sprederbreddetoerrstoffcm: detalje.sprederbreddetoerrstoffcm,
        sprederbreddevaatstoffcm: detalje.sprederbreddevaatstoffcm,
        doseringtoerrstoffgm2: detalje.doseringtoerrstoffgm2,
        doseringvaatstoffmlm2: detalje.doseringvaatstoffmlm2,
        eksternReferanse: detalje.eksternReferanse,
        retning: graderTilRetning(
            grader(
                detalje.startLokasjon.punkt.coordinates,
                detalje.sluttLokasjon.punkt.coordinates,
            ),
        ),
        rodenavn: detalje.rodeId.map((id) => rodeIdTilRodenavn(id, roder)).join(" og "),
        vegsystemreferansekortform: detalje.vegsystemreferansekortform,
    }));
};

export const EksporterTilExcel = ({ onClick, tekst }: ExcelNedlastingProps) => {
    return (
        <LastNedExcelWrapper onClick={onClick}>
            <LastNedIkon />
            <LastNedTekst $nomargin={true} $størrelse={"S"}>
                {tekst}
            </LastNedTekst>
        </LastNedExcelWrapper>
    );
};

const LastNedExcelWrapper = styled(KnappUtenStyling)`
    width: max-content;
    display: flex;
    flex-direction: row;
    cursor: pointer;
    align-items: flex-end;
    gap: 4px;
`;

const LastNedIkon = styled.div`
    background: url("/ikon/last-ned.svg") no-repeat;
    background-size: 20px 20px;
    height: 20px;
    width: 20px;
    margin-right: 4px;
`;

const LastNedTekst = styled(Tekst)`
    border-bottom: 1px solid var(--gray-dark-65);
    line-height: 19px;
    &:hover {
        border-bottom: 2px solid var(--gray-dark-65);
        margin-bottom: -1px !important;
    }
    &:active {
        border-bottom: 3px solid var(--gray-dark-65);
        margin-bottom: -2px !important;
    }
`;
