import { DRIFTSPORTAL_API_URL } from "./baseUrl";
import { finnMiljø, Miljø } from "./miljø";

export enum LoggNivå {
    Debug = "debug",
    Info = "info",
    Warn = "warn",
    Error = "error",
}

type LoggInfo =
    | {
          loggNivå: LoggNivå.Error;
          loggMelding?: string;
          error: Error;
      }
    | {
          loggNivå: LoggNivå.Debug | LoggNivå.Info | LoggNivå.Warn;
          loggMelding: string;
          error?: Error;
      };

export const loggFrontend = async function loggFrontend(logginfo: LoggInfo) {
    if (finnMiljø() === Miljø.lokal || finnMiljø() === Miljø.mobil) {
        return;
    }
    const body = JSON.stringify({
        loggMelding: logginfo.loggMelding,
        feilmeldingNavn: `${logginfo.error?.name}`,
        feilmelding: `${logginfo.error?.message}`,
    });
    try {
        const res = await fetch(`${DRIFTSPORTAL_API_URL}/logging/${logginfo.loggNivå}`, {
            method: "POST",
            body,
            headers: {
                "content-type": "application/json",
            },
            credentials: "include",
        });
        if (!res.ok) {
            console.error(`${res.status}-feil ved logging av:\n ${body}`);
        }
    } catch (error) {
        console.error(`Ukjent feil ved logging av:\n ${body}`);
    }
};

export enum FrontendLoggEvent {
    driftsportalInnlasting = "Driftsportal innlasting",
    webkameraInnlasting = "Webkamera innlasting",
}

export const loggFrontendEvent = (event: FrontendLoggEvent) => {
    loggFrontend({
        loggNivå: LoggNivå.Info,
        loggMelding: `Event: ${event.toString()}`,
    });
};

export const loggEventMedTabellnavn = (tabellnavn: TabellNavn, event: string) => {
    loggFrontend({
        loggNivå: LoggNivå.Info,
        loggMelding: `Event - ${tabellnavn}: ${event}`,
    });
};

export const loggEventMedTabellnavnOgVerdi = (
    tabellnavn: TabellNavn,
    event: string,
    verdi: string,
) => {
    loggFrontend({
        loggNivå: LoggNivå.Info,
        loggMelding: `Event - ${tabellnavn}: ${event}, Verdi: ${verdi}`,
    });
};

export const loggSkjermstørrelse = (window: Window, side: Sider) => {
    loggEventMedTabellnavnOgVerdi(
        TabellNavn.skjermstørrelse,
        side,
        `Bredde: ${window.innerWidth}, Høyde: ${window.innerHeight}`,
    );
};

export const loggNettbrett = (side: Sider) => {
    const isPointerCoarse = matchMedia("(pointer:coarse)").matches;
    loggEventMedTabellnavnOgVerdi(
        TabellNavn.nettbrett,
        side,
        isPointerCoarse ? "Nettbrett" : "Datamaskin",
    );
};

export enum TabellNavn {
    filterKlikk = "Filter klikk",
    infoknappTrykk = "Infoknapp trykk",
    popupTrykk = "Popup trykk",
    burgermenyTrykk = "Burgermeny trykk",
    driftsportalkortlenkeKlikk = "Driftsportalkortlenke klikk",
    driftsportalfavoritt = "Driftsportalfavoritt",
    grafvalgØkt = "Grafvalg",
    øktdetaljer = "Øktdetaljer klikk",
    webkamera = "Webkamera trykk",
    webkameraFavoritt = "Webkamera favoritt",
    fylkesvelger = "Fylkesvelger",
    hastighetsfilterIMeny = "Hastighetsfilter i meny",
    kartparametere = "Kartparametere klikk",
    kartlagTrykk = "Kartlag trykk",
    veglenkepopupTrykk = "Veglenkepopup trykk",
    syklustidTrykk = "Syklustid trykk",
    kolonneVelgerTrykk = "Kolonnevelger trykk",
    sisteAktivtetTrykk = "Siste aktivitet trykk",
    skjermstørrelse = "Skjermstørrelse",
    nettbrett = "Nettbrett",
    friksjonsdashboard = "Friksjonsdashboard trykk",
    grafvalgFriksjon = "Grafvalg Friksjonsdashboard",
}

export enum InfoknappLoggEvent {
    datoInfoknapp = "Dato infoknapp",
    produksjonstyperInfoknapp = "Produksjonstyper infoknapp",
    fartfilterInfoknapp = "Fartfilter infoknapp",
    rodelisteInfoknapp = "Rodeliste infoknapp",
    veglenkepopupSyklustidInfoknapp = "Veglenkepopup syklustid infoknapp",
}

export enum PopupLoggEvent {
    rodelenke = "Rodelenke",
    veglenke = "Veglenke",
    kjøretøy = "Kjøretøymarker",
    kamera = "Kameramarker",
    trafikkmelding = "Trafikkmeldingmarker",
}

export enum VisIKartEvent {
    kameraOgVærstasjoner = "Kamera og værstasjoner",
    kjøretøy = "Kjøretøy",
    trafikkmeldinger = "Trafikkmeldinger",
    fargeforklaring = "Fargeforklaring",
    darkmode = "Darkmode",
    produksjon = "Produksjon",
    roder = "Roder",
}

export enum ØktdetaljerLoggEvent {
    velgNyØkt = "Velg ny økt",
    seGjennomsnitt = "Se gjennomsnitt (metadata)",
    zoom = "Zoom i graf",
}

export enum GrafvalgLoggEvent {
    produksjonsfilter = "Produksjonsfilter i graf",
    graftype = "Graftype",
    doseringstype = "Doseringstype",
    grenseverdi = "Manuell grenseverdi",
    standardgrenseverdi = "Standardgrenseverdi",
    filterForFriksjon = "Filter i friksjonsgraf",
}

export enum WebkameraLoggEvent {
    kameraModal = "Kamera modal",
    størrelse = "Størrelse",
}

export enum KartparametereLoggEvent {
    øktdetaljerLenke = "Øktdetaljer lenke klikk",
    lastned = "Last ned data",
    rodeIRodeliste = "Rode i rodeliste klikk",
}

export enum VeglenkePopupLoggEvent {
    lastNed = "Last ned",
    øktidKlikk = "Øktid klikk",
}

export enum TidSidenSisteAktivitetEvent {
    mindreEnnHalvannenTime = "Mindre enn 1,5 time",
    halvannenTilToTimer = "1,5 - 2 timer",
    toTilTreTimer = "2 - 3 timer",
    treTilFireTimer = "3 - 4 timer",
    fireTilTolvTimer = "4 - 12 timer",
    endre = "Endre",
    lagre = "Lagre",
    tilbakestill = "Tilbakestill",
}

export enum Sider {
    driftsportal = "Driftsportal",
    webkamera = "Webkamera",
    øktdetaljer = "Øktdetaljer",
    produksjonskart = "Produksjonskart",
}

export enum FriksjonLoggEvent {
    lastOppMålingSuksess = "Sukessfull opplasting av friksjonsmåling",
    lastOppMålingError = "Klarte ikke å laste opp fil",
    klikkIGraf = "Klikk i graf",
    zoom = "Zoom i graf",
}
