import {
    erMerEnnEtDøgnSiden,
    fraEnkelKlokkeslettString,
    fraEnkelTimestampStr,
    fraIsoDatoString,
    minutterTilTimerOgMinutter,
    tilEnkelKlokkeslettString,
    tilEnkelTimestampStr,
    tilIsoDatoString,
    timestampStringTilEnkeltKlokkeslett,
} from "./tid";
import dayjs from "dayjs";

describe("Tid", () => {
    describe("Dayjs-config", () => {
        const dayjsTimestamp = dayjs().set("month", 11);
        it("setter norsk språk", () => expect(dayjsTimestamp.format("MMMM")).toBe("desember"));
        it("parser til forventet custom format", () => {
            const customParset = dayjs("17.mai 1814", "DD.MMMM YYYY");
            expect(customParset.date()).toBe(17);
            expect(customParset.month()).toBe(4);
            expect(customParset.year()).toBe(1814);
        });
    });
    describe("Dayjs-parsing", () => {
        it("parser enkelt klokkeslett korrekt til dayjs", () => {
            const parsetKlokkeslett = fraEnkelKlokkeslettString("16:20");
            expect(parsetKlokkeslett.hour()).toBe(16);
            expect(parsetKlokkeslett.minute()).toBe(20);
        });
        it("parser ISO-dato korrekt til dayjs", () => {
            const parsetISODato = fraIsoDatoString("2022-12-24");
            expect(parsetISODato.date()).toBe(24);
            expect(parsetISODato.month()).toBe(11);
            expect(parsetISODato.year()).toBe(2022);
        });
        it("parser enkel timestamp korrekt til dayjs", () => {
            const parsetISODato = fraEnkelTimestampStr("2022-12-24 16:20");
            expect(parsetISODato.hour()).toBe(16);
            expect(parsetISODato.minute()).toBe(20);
            expect(parsetISODato.date()).toBe(24);
            expect(parsetISODato.month()).toBe(11);
            expect(parsetISODato.year()).toBe(2022);
        });
        describe("String-formatering", () => {
            const dayjsTimestamp = dayjs()
                .set("date", 24)
                .set("month", 11)
                .set("year", 2022)
                .set("hour", 16)
                .set("minute", 20)
                .set("second", 59)
                .set("millisecond", 999);
            it("formaterer dayjs som enkelt klokkeslett", () =>
                expect(tilEnkelKlokkeslettString(dayjsTimestamp)).toBe("16:20"));
            it("formaterer dayjs som ISO-dato", () =>
                expect(tilIsoDatoString(dayjsTimestamp)).toBe("2022-12-24"));
            it("timestampstring mappes til enkelt klokkeslett", () =>
                expect(timestampStringTilEnkeltKlokkeslett("2022-04-10T16:20:59")).toBe("16:20"));
            it("formaterer dayjs som enkel timestamp", () =>
                expect(tilEnkelTimestampStr(dayjsTimestamp)).toBe("2022-12-24 16:20"));
        });
        describe("Mer enn et døgn siden-logikk", () => {
            const nå = dayjs();
            it("gir false ved nøyaktig et døgn", () =>
                expect(erMerEnnEtDøgnSiden(nå.subtract(24, "hour"))).toBeFalsy());
            it("gir false ved mindre enn et døgn siden", () =>
                expect(erMerEnnEtDøgnSiden(nå.subtract(24, "hour").add(1, "minute"))).toBeFalsy());
            it("gir true ved mer enn et døgn siden", () =>
                expect(
                    erMerEnnEtDøgnSiden(nå.subtract(24, "hour").subtract(1, "minute")),
                ).toBeTruthy());
        });

        describe("Timer og minutter siden-tekstformatering", () => {
            it("gir undefines ved undefined", () => {
                expect(minutterTilTimerOgMinutter(undefined)).toBe(undefined);
            });
            it("gir minutttekst ved minutter under en time", () => {
                expect(minutterTilTimerOgMinutter(59)).toBe("59 minutter");
            });
            it("gjør 60 minutter om til en time", () => {
                expect(minutterTilTimerOgMinutter(60)).toBe("1 time");
            });
            it("gjør over 60 minutter til timer og minutter", () => {
                expect(minutterTilTimerOgMinutter(70)).toBe("1 time 10 minutter");
            });
            it("gir minutttekst i entall hvis bare ett minutt", () => {
                expect(minutterTilTimerOgMinutter(1)).toBe("1 minutt");
            });
            it("gir rett tekst ved flere timer og minutter", () => {
                expect(minutterTilTimerOgMinutter(60039)).toBe("1000 timer 39 minutter");
            });
        });
    });
});
const testTidspunkt = ({ år = 2020, måned = 1, dato = 1, time = 0, minutt = 0 }) =>
    new Date(år, måned - 1, dato, time, minutt);
