import { WebkameraDto } from "../api/useHentWebkamera";
import { KameraPanel } from "./KameraPanel";
import styled from "styled-components";
import React from "react";
import { KameraStørrelse } from "./types";

interface KameraGridProps {
    webkameradata: WebkameraDto[];
    valgteFylker: string[];
    skjulFylker: boolean;
    erFavoritter?: boolean;
    håndterFavorittKlikk: (id: string, navn: string, erFavoritt: boolean) => void;
    favoritter?: string[];
    størrelse: KameraStørrelse;
}

export const KameraGrid = ({
    webkameradata,
    valgteFylker,
    skjulFylker,
    erFavoritter,
    håndterFavorittKlikk,
    favoritter = [],
    størrelse,
}: KameraGridProps) => (
    <StyledKameraGrid>
        {webkameradata
            .filter(
                (dto) =>
                    (erFavoritter || valgteFylker.includes(dto.fylkesnummer)) &&
                    (erFavoritter || !skjulFylker || !dto.veg.includes("F")) &&
                    (!erFavoritter || favoritter.includes(dto.id.toString())),
            )
            .sort((a, b) => a.veg.localeCompare(b.veg))
            .map((kamera, index) => (
                <KameraPanel
                    id={kamera.id}
                    stedsnavn={kamera.stedsnavn}
                    veg={kamera.veg}
                    info={kamera.info}
                    vaervarsel={kamera.vaervarsel}
                    key={index}
                    håndterFavorittKlikk={håndterFavorittKlikk}
                    favoritter={favoritter}
                    størrelse={størrelse}
                />
            ))}
    </StyledKameraGrid>
);

const StyledKameraGrid = styled.div`
    display: flex;
    gap: 16px;
    flex-direction: row;
    flex-wrap: wrap;
    justify-content: center;
    margin-bottom: 64px;
`;
