import React from "react";
import { Spinner } from "../components/fellesKomponenter/spinner/Spinner";
import { Tekst } from "../components/fellesKomponenter/typografi/Tekst";
import { KameraGrid } from "./KameraGrid";
import styled from "styled-components";
import { useHentWebkamera } from "../api/useHentWebkamera";
import { breakpointNettbrett } from "../utils/constants";
import { KameraStørrelse } from "./types";

interface KamerasideInnholdProps {
    favoritter: string[];
    valgteFylker: string[];
    skjulFylkesveier: boolean;
    håndterFavorittKlikk: (id: string, navn: string, erFavoritt: boolean) => void;
    størrelse: KameraStørrelse;
}

export const WebcameraInnhold = ({
    favoritter,
    valgteFylker,
    skjulFylkesveier,
    håndterFavorittKlikk,
    størrelse,
}: KamerasideInnholdProps) => {
    const webkamera = useHentWebkamera();

    return (
        <Innhold>
            {!webkamera ? (
                <Spinner storrelse="liten" sentrert={true} inline={false}>
                    <Tekst>Henter webkameraer...</Tekst>
                </Spinner>
            ) : webkamera.suksess ? (
                <>
                    {favoritter.length > 0 && (
                        <>
                            <KameraGrid
                                webkameradata={webkamera.data}
                                valgteFylker={valgteFylker}
                                skjulFylker={skjulFylkesveier}
                                erFavoritter={true}
                                håndterFavorittKlikk={håndterFavorittKlikk}
                                favoritter={favoritter}
                                størrelse={størrelse}
                            />
                            <StyledHr />
                        </>
                    )}
                    <KameraGrid
                        webkameradata={webkamera.data}
                        valgteFylker={valgteFylker}
                        skjulFylker={skjulFylkesveier}
                        håndterFavorittKlikk={håndterFavorittKlikk}
                        favoritter={favoritter}
                        størrelse={størrelse}
                    />
                </>
            ) : (
                <Tekst>{webkamera.feilmelding}</Tekst>
            )}
        </Innhold>
    );
};

const Innhold = styled.div`
    padding: 0 2rem;
    max-width: 100rem;

    @media (max-width: ${breakpointNettbrett}) {
        padding: 0 1rem;
    }
`;

const StyledHr = styled.hr`
    margin-bottom: 64px;
`;
