import styled from "styled-components";
import React from "react";
import { EksternLenke } from "../components/fellesKomponenter/lenker/EksternLenke";
import { Modal } from "../components/fellesKomponenter/modal/Modal";
import { Heading } from "../components/fellesKomponenter/typografi/Heading";

export interface WebkamerModalProps {
    onClose: () => void;
    bildeUrl: string;
    stedsnavn: string;
    veg: string;
    info: string;
    vaervarsel: string;
    bildebredde: number;
}

export const WebkameraModal = ({
    onClose,
    bildeUrl,
    stedsnavn,
    veg,
    info,
    vaervarsel,
    bildebredde,
}: WebkamerModalProps) => {
    const bildeBreddeMaks = Math.min(bildebredde, 800).toString() + "px";

    return (
        <Modal id={"webkameramodal"} onClose={onClose}>
            <ModalHeader>
                <div>
                    <Heading as="h1" $stylelevel="4">
                        {veg} {stedsnavn}
                    </Heading>
                    <div>{info}</div>
                </div>
            </ModalHeader>
            <div>
                <img src={bildeUrl} alt={`Vegkamera ${veg} ${stedsnavn}`} width={bildeBreddeMaks} />
            </div>
            <EksternLenke href={vaervarsel}>Åpne værstasjon i Yr</EksternLenke>
        </Modal>
    );
};

const ModalHeader = styled.div`
    display: flex;
    justify-content: space-between;
    margin-bottom: 20px;
`;
