"use client";
import React, { useEffect, useState } from "react";
import styled from "styled-components";
import { WebcameraParametervalg } from "./WebcameraParametervalg";
import { WebcameraInnhold } from "./WebcameraInnhold";
import { SideHeader } from "../components/sideheader/SideHeader";
import ErrorBoundary from "../components/feil/ErrorBoundary";
import { useAtom } from "jotai";
import { kameraFavoritterAtom, kameraStørrelseAtom, valgteFylkerAtom } from "./jotai/atoms";
import { AuthenticationWrapper } from "../components/AuthenticationWrapper";
import {
    FrontendLoggEvent,
    loggEventMedTabellnavnOgVerdi,
    loggFrontendEvent,
    loggNettbrett,
    loggSkjermstørrelse,
    Sider,
    TabellNavn,
} from "../utils/loggFrontend";

export const WebkameraSide = () => {
    const [valgteFylker, settValgteFylker] = useAtom(valgteFylkerAtom);
    const [skjulFylker, settSkjulFylker] = useState<boolean>(false);
    const [favoritter, settFavoritter] = useAtom(kameraFavoritterAtom);
    const [størrelse, settStørrelse] = useAtom(kameraStørrelseAtom);

    useEffect(() => {
        loggFrontendEvent(FrontendLoggEvent.webkameraInnlasting);
        loggSkjermstørrelse(window, Sider.webkamera);
        loggNettbrett(Sider.webkamera);
    }, []);

    const håndterFavorittKlikk = (kameraId: string, navn: string, erFavoritt: boolean) => {
        const nyFavorittliste = erFavoritt
            ? favoritter.filter((favoritt) => favoritt !== kameraId)
            : [...favoritter, kameraId];
        settFavoritter(nyFavorittliste);
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.webkameraFavoritt,
            navn,
            !erFavoritt ? "På" : "Av",
        );
    };

    return (
        <ErrorBoundary info={`side: Webkamerasiden`}>
            <AuthenticationWrapper>
                <SideHeader side="webkamera" />
                <Sideinnhold>
                    <WebcameraParametervalg
                        valgteFylker={valgteFylker}
                        skjulFylkesveier={skjulFylker}
                        settSkjulFylkesveier={settSkjulFylker}
                        settStørrelse={settStørrelse}
                        settValgteFylker={settValgteFylker}
                    />
                    <WebcameraInnhold
                        favoritter={favoritter}
                        valgteFylker={valgteFylker}
                        skjulFylkesveier={skjulFylker}
                        håndterFavorittKlikk={håndterFavorittKlikk}
                        størrelse={størrelse}
                    />
                </Sideinnhold>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Sideinnhold = styled.main`
    display: flex;
    flex-direction: column;
    align-items: center;
    gap: 2rem;
`;
