import React, { useCallback, useState } from "react";
import { Checkbox } from "../../components/fellesKomponenter/checkboxer/Checkbox";
import styled from "styled-components";
import fylkeliste from "../../driftsportalSide/tekst/fylker.json";
import { Trekkspill } from "../../components/fellesKomponenter/trekkspill/Trekkspill";
import { useCloseOnOutsideClick } from "../../hooks/useCloseOnOutsideClick";
import { loggEventMedTabellnavnOgVerdi, TabellNavn } from "../../utils/loggFrontend";

interface FylkesfilterProps {
    valgteFylker: string[];
    håndterFylkesValg: (fylker: string[]) => void;
}

export const Fylkesfilter = ({ valgteFylker, håndterFylkesValg }: FylkesfilterProps) => {
    const [filterÅpen, settFilterÅpen] = useState(false);

    const lukkDropDown = useCallback(() => {
        settFilterÅpen(false);
    }, [settFilterÅpen, valgteFylker]);

    const handleToggleFylke = (fylkesnummer: string, tittel: string) => {
        const nyListe = valgteFylker.includes(fylkesnummer)
            ? valgteFylker.filter((fylke) => fylke !== fylkesnummer)
            : valgteFylker.concat(fylkesnummer);
        håndterFylkesValg(nyListe);
        loggEventMedTabellnavnOgVerdi(
            TabellNavn.fylkesvelger,
            tittel,
            !valgteFylker.includes(fylkesnummer) ? "På" : "Av",
        );
    };
    const id = "filterknapp";
    useCloseOnOutsideClick(id, lukkDropDown);

    return (
        <div id={id}>
            <Trekkspill
                åpen={filterÅpen}
                tittel={"Velg fylker"}
                type={"Ramme"}
                onClick={() => {
                    settFilterÅpen(!filterÅpen);
                }}
                width="250px"
            >
                <FylkeInnhold>
                    {filterÅpen &&
                        fylkeliste
                            .sort((fylke1, fylke2) => fylke1.tittel.localeCompare(fylke2.tittel))
                            .map((fylke, i) => (
                                <Checkbox
                                    key={`${fylke.tittel}-${i}`}
                                    onChange={(e) => {
                                        handleToggleFylke(fylke.fylkesnummer, fylke.tittel);
                                    }}
                                    checked={valgteFylker.includes(fylke.fylkesnummer)}
                                    value={fylke.fylkesnummer}
                                >
                                    {fylke.tittel}
                                </Checkbox>
                            ))}
                </FylkeInnhold>
            </Trekkspill>
        </div>
    );
};

const FylkeInnhold = styled.div`
    padding: 20px 16px;
    background: var(--white);
    display: flex;
    flex-direction: column;
    gap: 8px;
`;
