"use client";
import React, { MutableRefObject, useMemo } from "react";
import { Produksjonslenke } from "../kartSide/types/produksjonslenke";
import { MapContainer, TileLayer } from "react-leaflet";
import { getGeoJsonØktVeglenke } from "../kartSide/Kartvisning/geoJson/geoJSONutilsVeglenker";
import { ChangeView } from "../kartSide/Kartvisning/ChangeView";
import { crsUtm33N } from "../kartSide/utils/crs";
import styles from "../kartSide/Kartvisning/Kartvisning.module.css";
import { finnKartBoundsForØktdetaljer } from "../kartSide/Kartvisning/kartBoundsUtils";
import { ZoomKnapp } from "../kartSide/Kartvisning/ZoomKnapp";
import "leaflet/dist/leaflet.css";
import { useUntabableClusters } from "../hooks/useUntabableClusters";
import { defaultBounds } from "../kartSide/utils/kartUtils";
import { useAtomValue } from "jotai";
import { aktivHoverRecordAtom } from "./jotai/atoms";

export interface ØktKarvisningProps {
    produksjonslenker: Produksjonslenke[];
    containerRef: MutableRefObject<any>;
}

export const OktKartvisning = ({ produksjonslenker, containerRef }: ØktKarvisningProps) => {
    const aktivHoverRecord = useAtomValue(aktivHoverRecordAtom);
    useUntabableClusters();

    const kartBounds = useMemo(() => {
        if (produksjonslenker.length > 0) {
            return finnKartBoundsForØktdetaljer(produksjonslenker);
        }
        return defaultBounds;
    }, [produksjonslenker]);

    const øktGeoJson = useMemo(
        () => getGeoJsonØktVeglenke(produksjonslenker, aktivHoverRecord),
        [produksjonslenker, aktivHoverRecord],
    );

    return (
        <MapContainer
            className={styles.kartvisningokt}
            center={[64.6, 9.5022]}
            scrollWheelZoom
            crs={crsUtm33N}
            zoom={16}
            minZoom={4}
            maxZoom={16}
            zoomControl={false}
            zoomDelta={0.8}
            zoomSnap={0}
            keyboard={false}
            attributionControl={false}
        >
            <TileLayer
                attribution="© NVDB, Geovekst, kommunene og Open Street Map contributors (utenfor Norge)"
                url="https://services.geodataonline.no/arcgis/rest/services/Trafikkportalen/GeocacheTrafikkJPG/MapServer/tile/{z}/{y}/{x}"
                subdomains="123456789"
            />
            <ChangeView kartBounds={kartBounds} medPadding={true} />
            {øktGeoJson}
            <ZoomKnapp size="small" />
        </MapContainer>
    );
};
