"use client";
import { OktdetaljerVisning } from "./OktdetaljerVisning";
import { SideHeader } from "../components/sideheader/SideHeader";
import styled from "styled-components";
import { øktProduksjonslenkerResponsAtom } from "../api/context/ØktLenkerAtoms";
import { KartvisningFeil } from "../kartSide/feil/KartvisningFeil";
import { hentFeil } from "../kartSide/utils/kartSideUtils";
import ErrorBoundary from "../components/feil/ErrorBoundary";
import BrøytebilSpinner from "../kartSide/brøytebilSpinner/BrøytebilSpinner";
import { useAtomValue } from "jotai";
import { øktProduksjonsdetaljerAtom } from "../api/context/InitØktdetaljer";
import { AuthenticationWrapper } from "../components/AuthenticationWrapper";
import { Feil, FetchStatus, Suksess } from "../api/api";
import { hentFetchStatusFraResponser } from "./øktUtils";
import { useEffect } from "react";
import { loggNettbrett, loggSkjermstørrelse, Sider } from "../utils/loggFrontend";

export const OktdetaljerSide = () => {
    const produksjonsdetaljerRespons = useAtomValue(øktProduksjonsdetaljerAtom);
    const produksjonslenkerRespons = useAtomValue(øktProduksjonslenkerResponsAtom);
    useEffect(() => {
        loggSkjermstørrelse(window, Sider.øktdetaljer);
        loggNettbrett(Sider.øktdetaljer);
    }, []);

    const fetchStatus = hentFetchStatusFraResponser([
        produksjonslenkerRespons,
        produksjonsdetaljerRespons,
    ]);

    return (
        <ErrorBoundary info="Feil i øktdetaljersiden, side: Øktdetaljer">
            <AuthenticationWrapper>
                <Container>
                    <SideHeader side={"øktdetaljer"} />
                    {fetchStatus === FetchStatus.Laster && <BrøytebilSpinner />}

                    {fetchStatus === FetchStatus.Feil && (
                        <KartvisningFeil
                            feilmeldinger={hentFeil(
                                [produksjonslenkerRespons, produksjonsdetaljerRespons].filter(
                                    (respons) => respons?.status === "Feil",
                                ) as Feil[],
                            )}
                        />
                    )}

                    {fetchStatus === FetchStatus.Suksess && (
                        <OktdetaljerVisning
                            produksjonslenker={(produksjonslenkerRespons as Suksess<any>).data}
                            produksjonsdetaljer={(produksjonsdetaljerRespons as Suksess<any>).data}
                        />
                    )}

                    {fetchStatus === FetchStatus.IkkeHentet && (
                        <OktdetaljerVisning produksjonslenker={[]} produksjonsdetaljer={[]} />
                    )}
                </Container>
            </AuthenticationWrapper>
        </ErrorBoundary>
    );
};

const Container = styled.div`
    margin: 20px 20px 100px 20px;
    background-color: var(--white);
`;
