import React, { useRef } from "react";
import styled from "styled-components";
import { Grafer } from "./grafer/Grafer";
import { Metadata } from "./metadata/Metadata";
import { ØktKarvisningProps } from "./OktKartvisning";
import { Produksjonslenke } from "../kartSide/types/produksjonslenke";
import dynamic from "next/dynamic";
import { RowWrapper } from "../components/fellesKomponenter/wrappers/wrappers";
import { Produksjonsdetaljer } from "../kartSide/types/produksjonsdetaljer";
import { breakpointNettbrett } from "../utils/constants";
import { Spinner } from "../components/fellesKomponenter/spinner/Spinner";

interface ØktdetaljerVisningProps {
    produksjonslenker: Produksjonslenke[];
    produksjonsdetaljer: Produksjonsdetaljer[];
}

export const OktdetaljerVisning = ({
    produksjonslenker,
    produksjonsdetaljer,
}: ØktdetaljerVisningProps) => {
    const kartvisningContainerRef = useRef<any>(null);

    return (
        <>
            <RowWrapper>
                <KartvisningContainer ref={kartvisningContainerRef}>
                    <DynamicKartvisning
                        produksjonslenker={produksjonslenker}
                        containerRef={kartvisningContainerRef}
                    />
                </KartvisningContainer>
                <Metadata produksjonsdetaljer={produksjonsdetaljer} />
            </RowWrapper>
            {produksjonsdetaljer.length > 0 && <Grafer produksjonsdetaljer={produksjonsdetaljer} />}
        </>
    );
};

const DynamicKartvisning = dynamic<ØktKarvisningProps>(
    () => import("./OktKartvisning").then((mod) => mod.OktKartvisning),
    {
        loading: () => <Spinner />,
        ssr: false,
    },
);

const KartvisningContainer = styled.div`
    height: 400px;
    width: 70%;
    @media (max-width: ${breakpointNettbrett}) {
        width: 100%;
    }
`;
