import { ØktdetaljerLegend } from "./ØktdetaljerLegend";
import { Grafdata } from "./Grafer";
import React, { useState } from "react";
import { GeneriskGraf } from "../../components/grafer/GeneriskGraf";
import { Line } from "recharts";
import { useAtomValue, useSetAtom } from "jotai";
import {
    aktivGrafKategoriAtom,
    aktivGrafTypeAtom,
    aktivHoverRecordAtom,
    grafdataAtom,
    GrafType,
} from "../jotai/atoms";
import { OktdetaljerTooltip } from "./OktdetaljerTooltip";
import { hentStartOgSluttTid } from "./grafUtils";
import dayjs from "dayjs";
import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";

interface GeneriskØktGrafProps {
    tickArrayYaxis: number[];
    grafdata: Grafdata[];
    doseringsBenenvning?: string;
}

export const GeneriskØktGraf = ({
    tickArrayYaxis,
    grafdata,
    doseringsBenenvning,
}: GeneriskØktGrafProps) => {
    const [synligGrafdata, setSynligGrafdata] = useState<Grafdata[]>(grafdata);
    const aktivGrafKategori = useAtomValue(aktivGrafKategoriAtom);
    const aktivGrafType = useAtomValue(aktivGrafTypeAtom);
    const setAktivHoverRecord = useSetAtom(aktivHoverRecordAtom);
    const grafdataHeleØkta = useAtomValue(grafdataAtom);
    const { startTid, sluttTid } = hentStartOgSluttTid(grafdataHeleØkta);

    const dataKey = () => {
        switch (aktivGrafType) {
            case GrafType.hastighet:
                return "hastighetKmHAvg";
            case GrafType.dosering:
                return "doseringtoerrstoffgm2";
            case GrafType.sprederbredde:
                return "sprederbreddetoerrstoffcm";
        }
    };
    const dataKeyLinje2 = () => {
        switch (aktivGrafType) {
            case GrafType.dosering:
                return "doseringvaatstoffmlm2";
            case GrafType.sprederbredde:
                return "sprederbreddevaatstoffcm";
        }
    };

    const customLegend = (
        <ØktdetaljerLegend
            grafdata={synligGrafdata}
            setGrafdata={(data: Grafdata[]) => setSynligGrafdata(data)}
        />
    );

    const customTooltip = (
        <OktdetaljerTooltip setAktivHoverRecord={setAktivHoverRecord} type={aktivGrafKategori} />
    );

    const dataKeyXaxis = (produksjonsdetalje: Produksjonsdetaljer) => {
        return dayjs(produksjonsdetalje.datoLogget).valueOf();
    };

    return (
        <GeneriskGraf
            tickArrayYaxis={tickArrayYaxis}
            customLegend={customLegend}
            doseringsBenevning={doseringsBenenvning}
            customTooltip={customTooltip}
            startTid={startTid}
            sluttTid={sluttTid}
            dataKeyXaxis={dataKeyXaxis}
        >
            <>
                {synligGrafdata
                    ?.filter((data) => data.visible)
                    .map((data, index) => (
                        <Line
                            key={"linje" + index}
                            data={data.data}
                            type="monotone"
                            dataKey={dataKey()}
                            stroke={data.color}
                            strokeWidth={2}
                            dot={false}
                            activeDot={{ r: 6 }}
                            name={data.tittel}
                            isAnimationActive={false}
                        />
                    ))}
                {aktivGrafType === GrafType.dosering &&
                    synligGrafdata
                        ?.filter((data) => data.visible)
                        .map((data, index) => (
                            <Line
                                key={"linje2" + index}
                                data={data.data}
                                type="monotone"
                                dataKey={dataKeyLinje2()}
                                stroke={data.color}
                                strokeWidth={2}
                                dot={false}
                                activeDot={{ r: 6 }}
                                name={data.tittel}
                                isAnimationActive={false}
                            />
                        ))}
            </>
        </GeneriskGraf>
    );
};
