import styled from "styled-components";
import React, { useEffect } from "react";
import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { produksjonsdetaljerTilGrafdata } from "./grafUtils";
import { HastighetsGraf } from "./HastighetsGraf";
import { DoseringsGraf } from "./DoseringsGraf";
import {
    aktivGrafKategoriAtom,
    grafdataAtom,
    grafdataDoseringAtom,
    GrafKategori,
} from "../jotai/atoms";
import { useAtom, useAtomValue } from "jotai";

export interface Grafdata {
    color: string;
    tittel: string;
    data: Produksjonsdetaljer[];
    visible: boolean;
}

export const Grafer = ({ produksjonsdetaljer }: { produksjonsdetaljer: Produksjonsdetaljer[] }) => {
    const aktivGraf = useAtomValue(aktivGrafKategoriAtom);
    const [grafdata, setGrafdata] = useAtom(grafdataAtom);
    const grafdataDosering = useAtomValue(grafdataDoseringAtom);

    useEffect(() => {
        setGrafdata(produksjonsdetaljerTilGrafdata(produksjonsdetaljer));
    }, [produksjonsdetaljer]);

    return (
        <Container>
            <GrafContainer>
                {aktivGraf === GrafKategori.hastighet && grafdata.length > 0 && (
                    <HastighetsGraf grafdata={grafdata} visDosering={grafdataDosering.length > 0} />
                )}
                {aktivGraf === GrafKategori.dosering && grafdataDosering.length > 0 && (
                    <DoseringsGraf grafdata={grafdataDosering} />
                )}
            </GrafContainer>
        </Container>
    );
};

const Container = styled.div`
    display: flex;
    flex-direction: column;
    margin-bottom: 120px;
`;

const GrafContainer = styled.div`
    display: flex;
    flex-direction: column;
    width: 100%;
    margin: 20px 0;
`;
