import { ReferanselinjeValg } from "../../components/grafer/ReferanselinjeValg";
import { GeneriskGrafvalg, ValgContainer } from "../../components/grafer/GeneriskGrafvalg";
import { AktivGrafValg } from "../../components/grafer/AktivGrafValg";
import { Grafdata } from "./Grafer";
import { hentTicksYaxisHastighet, hentUnikeGrafdata } from "./grafUtils";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import styled from "styled-components";
import { GeneriskØktGraf } from "./GeneriskØktGraf";
import { hentTittelOgTillattVerdier } from "./referanselinjeUtils";
import { GrafKategori } from "../jotai/atoms";
import { Skillelinje } from "../../components/grafer/styles";

interface HastighetsGrafProps {
    grafdata: Grafdata[];
    visDosering: boolean;
}
export const HastighetsGraf = ({ grafdata, visDosering }: HastighetsGrafProps) => {
    const tickArrayYaxis = hentTicksYaxisHastighet(grafdata);
    const unikeGrafdata = hentUnikeGrafdata(grafdata);
    const trekkspillInnhold = hentTittelOgTillattVerdier(GrafKategori.hastighet, unikeGrafdata);

    return (
        <>
            <GeneriskØktGraf tickArrayYaxis={tickArrayYaxis} grafdata={grafdata}></GeneriskØktGraf>
            <GeneriskGrafvalg>
                <ValgContainer>
                    {visDosering && (
                        <>
                            <AktivGrafValg grafside={"øktdetaljer"} />
                            <Skillelinje />
                        </>
                    )}
                    <ReferanselinjeValg trekkspillInnhold={trekkspillInnhold} />
                </ValgContainer>
                <InfotekstWrapper>
                    <Tekst $nomargin={true} $størrelse={"M"} $bold={true}>
                        Hvordan regnes farten ut?
                    </Tekst>
                    <Tekst $størrelse={"M"} $nomargin={true}>
                        Når entreprenørene sender inn data fra bilene så er produksjonen knyttet til
                        GPS-punkter. ELRAPP knytter disse punktene til veglenker sånn at man skal
                        kunne se hvor de har kjørt på veien (avkjørsler, filer etc). Disse
                        veglenkene viser vi igjen i kartet. Veglenker har ulik lengde, noen er korte
                        og noen er lange (det ser du i kartet når du holder musen over produksjon
                        uten å trykke på det, noen er lange og noen er korte). GPS-punktene fra
                        entreprenørene kommer med jevne mellomrom (hver 100 m). Farten som sendes
                        inn fra bilene er hastigheten bilen har på det GPS-punktet som dataen er
                        registrert på. Siden GPS-punktene blir gjort om til veglenker så lager vi en
                        snitthastighet på denne måten:
                    </Tekst>
                    <Tekst $størrelse={"M"} $nomargin={false}>
                        <i>
                            For ett kjøretøy på én økt som gjør samme aktivitet og/eller legger
                            samme materiale innenfor samme veglenke og innenfor maks ett minutt -
                            slår vi sammen punkthastighetene som har kommet inn og regner ut
                            snittet.
                        </i>
                    </Tekst>
                </InfotekstWrapper>
            </GeneriskGrafvalg>
        </>
    );
};

const InfotekstWrapper = styled.div`
    display: flex;
    flex-direction: column;
    margin-top: 20px;
`;
