import { TooltipProps } from "recharts";
import { NameType, ValueType } from "recharts/types/component/DefaultTooltipContent";
import dayjs from "dayjs";
import styled from "styled-components";
import React, { useEffect } from "react";
import { hentDoseringsBenevning, hentProduksjonsKategoriNavn } from "./grafUtils";
import { GrafKategori } from "../jotai/atoms";

interface ØktdetaljerTooltip extends TooltipProps<ValueType, NameType> {
    setAktivHoverRecord: (record: number[] | undefined) => void;
    type: GrafKategori;
}

export const OktdetaljerTooltip = ({
    active,
    label,
    payload,
    setAktivHoverRecord,
    type,
}: ØktdetaljerTooltip) => {
    const produksjonsdataRestRec = payload && payload[0]?.payload.produksjonsdataRestRec;

    useEffect(
        () =>
            active && payload && payload.length
                ? setAktivHoverRecord(payload[0].payload.produksjonsdataRestRec)
                : setAktivHoverRecord(undefined),
        [produksjonsdataRestRec],
    );

    if (active && payload && payload.length) {
        return (
            <TooltipContainer>
                {type === GrafKategori.hastighet ? (
                    <p>{`Hastighet: ${payload[0].value} km/t`}</p>
                ) : (
                    <>
                        <p>{`Dosering tørrstoff: ${payload[0].payload.doseringtoerrstoffgm2} gm2`}</p>
                        <p>{`Dosering våttstoff: ${payload[0].payload.doseringvaatstoffmlm2} ml2`}</p>
                        <p>{`Sprederbredde tørrstoff: ${payload[0].payload.sprederbreddetoerrstoffcm} cm`}</p>
                        <p>{`Sprederbredde våttstoff: ${payload[0].payload.sprederbreddevaatstoffcm} cm`}</p>
                    </>
                )}
                <p>{`Dato: ${dayjs(label).format("DD.MM")}`}</p>
                <p>{`Klokkeslett: ${dayjs(label).format("HH:mm")}`}</p>
                <p>{`Produksjon: ${hentProduksjonsKategoriNavn([payload[0].payload])}`}</p>
            </TooltipContainer>
        );
    }
    return null;
};

const TooltipContainer = styled.div`
    background-color: white;
    border: 1px solid black;
    padding: 10px;

    p {
        color: var(--gray-dark);
        margin: 0;
    }
`;
