import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { MaterialOgAktivitetsNavn } from "../../api/context/ProduksjonsfilterAtoms";
import { MaterialKategori, MaterialType } from "../../kartSide/types/materiale";
import {
    concatVegsystemreferanse,
    erLikProduksjon,
    hentProduksjonsKategoriNavn,
    hentStartOgSluttTid,
    hentTicksYaxisDosering,
    hentTicksYaxisHastighet,
    hentUnikeGrafdata,
    produksjonsdetaljerTilGrafdata,
} from "./grafUtils";
import { Grafdata } from "./Grafer";
import dayjs from "dayjs";
import { GrafKategori, GrafType } from "../jotai/atoms";
import {
    hentTillattDosering,
    hentTillattMakshastighet,
    hentTittelOgTillattVerdier,
    TrekkspillInnhold,
} from "./referanselinjeUtils";

describe("Avvik utils", () => {
    it("skal returnere true ved lik produksjon", () => {
        const erLikProduksjon1 = erLikProduksjon(produksjonsdetaljer[0], produksjonsdetaljer[1]);
        const erLikProduksjon2 = erLikProduksjon(produksjonsdetaljer[0], produksjonsdetaljer[6]);
        const erLikProduksjon3 = erLikProduksjon(produksjonsdetaljer[3], produksjonsdetaljer[4]);
        const erLikProduksjon4 = erLikProduksjon(produksjonsdetaljer[4], produksjonsdetaljer[5]);
        expect(erLikProduksjon1).toBe(true);
        expect(erLikProduksjon2).toBe(false);
        expect(erLikProduksjon3).toBe(true);
        expect(erLikProduksjon4).toBe(false);
    });

    it("skal dele opp liste ved ulike produksjonstyper og tid", () => {
        const forventetGrafdata: Grafdata[] = [
            {
                color: "#1D7721",
                tittel: "Brøyting",
                data: [produksjonsdetaljer[0], produksjonsdetaljer[1], produksjonsdetaljer[2]],
                visible: true,
            },
            {
                color: "#1D4289",
                tittel: "Strøing med fastsand",
                data: [produksjonsdetaljer[3], produksjonsdetaljer[4]],
                visible: true,
            },
            {
                color: "#B63434",
                tittel: "Brøyting og strøing med tørrsalt",
                data: [produksjonsdetaljer[5]],
                visible: true,
            },
            {
                color: "#B63434",
                tittel: "Brøyting og strøing med tørrsalt",
                data: [produksjonsdetaljer[6]],
                visible: true,
            },
            {
                color: "#444F55",
                tittel: "Ingen produksjon",
                data: [produksjonsdetaljer[7]],
                visible: true,
            },
        ];

        const grafdata = produksjonsdetaljerTilGrafdata(produksjonsdetaljer);
        expect(grafdata).toEqual(forventetGrafdata);
    });

    it("skal endre dato logget til riktig format for graf", () => {
        const dato = produksjonsdetaljer[0].datoLogget;
        const datoEndret = dato.slice(0, 10) + " " + dato.slice(11, 16);
        expect(datoEndret).toBe("2023-01-28 04:17");
    });

    it("skal hente riktig tittel", () => {
        const brøyting = [produksjonsdetaljer[0], produksjonsdetaljer[1], produksjonsdetaljer[2]];
        const fastsand = [produksjonsdetaljer[3]];
        const tørrsaltOgPlog = [produksjonsdetaljer[5]];
        const ingenProd = [produksjonsdetaljer[7]];

        expect(hentProduksjonsKategoriNavn(brøyting)).toBe("Brøyting");
        expect(hentProduksjonsKategoriNavn(fastsand)).toBe("Strøing med fastsand");
        expect(hentProduksjonsKategoriNavn(tørrsaltOgPlog)).toBe(
            "Brøyting og strøing med tørrsalt",
        );
        expect(hentProduksjonsKategoriNavn(ingenProd)).toBe("Ingen produksjon");
    });

    it("skal hente riktig tillatt makshastighet", () => {
        const brøyting = [produksjonsdetaljer[0], produksjonsdetaljer[1], produksjonsdetaljer[2]];
        const fastsand = [produksjonsdetaljer[3]];
        const tørrsaltOgPlog = [produksjonsdetaljer[5]];
        const ingenProd = [produksjonsdetaljer[7]];

        expect(hentTillattMakshastighet(brøyting)).toBe(40);
        expect(hentTillattMakshastighet(fastsand)).toBe(25);
        expect(hentTillattMakshastighet(tørrsaltOgPlog)).toBe(40);
        expect(hentTillattMakshastighet(ingenProd)).toBe(undefined);
    });

    it("skal hente tillatt dosering", () => {
        const brøyting = [produksjonsdetaljer[0], produksjonsdetaljer[1], produksjonsdetaljer[2]];
        const fastsand = [produksjonsdetaljer[3]];
        const tørrsaltOgPlog = [produksjonsdetaljer[5]];
        const ingenProd = [produksjonsdetaljer[7]];

        expect(hentTillattDosering(brøyting)).toBe(undefined);
        expect(hentTillattDosering(fastsand)).toBe(150);
        expect(hentTillattDosering(tørrsaltOgPlog)).toBe(40);
        expect(hentTillattDosering(ingenProd)).toBe(undefined);
    });

    it("skal slå sammen vegsystemreferanser", () => {
        const vegsystemReferanser = concatVegsystemreferanse(produksjonsdetaljer);
        const forventetVegsystemReferanser = [
            "FV7806 S3D1",
            "FV7806 S3D2",
            "FV7806 S3D3",
            "FV7806 S3D4",
            "FV7806 S3D5",
            "FV7806 S3D6",
            "FV7806 S3D7",
        ];

        expect(vegsystemReferanser).toEqual(forventetVegsystemReferanser);
        expect(concatVegsystemreferanse([])).toEqual([]);
    });

    it("skal hente unik grafdata", () => {
        const unikGrafdata: Grafdata[] = [
            {
                color: "#1D7721",
                tittel: "Brøyting",
                data: [produksjonsdetaljer[0], produksjonsdetaljer[1], produksjonsdetaljer[2]],
                visible: true,
            },
            {
                color: "#1D4289",
                tittel: "Strøing med fastsand",
                data: [produksjonsdetaljer[3], produksjonsdetaljer[4]],
                visible: true,
            },
            {
                color: "#B63434",
                tittel: "Brøyting og strøing med tørrsalt",
                data: [produksjonsdetaljer[5]],
                visible: true,
            },
            {
                color: "#444F55",
                tittel: "Ingen produksjon",
                data: [produksjonsdetaljer[7]],
                visible: true,
            },
        ];

        expect(hentUnikeGrafdata(produksjonsdetaljerTilGrafdata(produksjonsdetaljer))).toEqual(
            unikGrafdata,
        );
    });

    it("skal hente tittel og tillatt makshastighet for graf", () => {
        const tittelOgHastighet: TrekkspillInnhold[] = [
            { tittel: "Brøyting (40 km/t)", verdi: 40, grafKategori: GrafKategori.hastighet },
            {
                tittel: "Strøing med fastsand (25 km/t)",
                verdi: 25,
                grafKategori: GrafKategori.hastighet,
            },
            {
                tittel: "Brøyting og strøing med tørrsalt (40 km/t)",
                verdi: 40,
                grafKategori: GrafKategori.hastighet,
            },
            {
                tittel: "Brøyting og strøing med tørrsalt (40 km/t)",
                verdi: 40,
                grafKategori: GrafKategori.hastighet,
            },
        ];
        expect(
            hentTittelOgTillattVerdier(
                GrafKategori.hastighet,
                produksjonsdetaljerTilGrafdata(produksjonsdetaljer),
            ),
        ).toEqual(tittelOgHastighet);
    });

    it("skal hente tittel og tillatt dosering for graf", () => {
        const tittelOgDosering: TrekkspillInnhold[] = [
            {
                tittel: "Strøing med fastsand (min 150 g/m²)",
                verdi: 150,
                grafKategori: GrafKategori.dosering,
            },
            {
                tittel: "Brøyting og strøing med tørrsalt (maks 40 g/m²)",
                verdi: 40,
                grafKategori: GrafKategori.dosering,
            },
            {
                tittel: "Brøyting og strøing med tørrsalt (maks 40 g/m²)",
                verdi: 40,
                grafKategori: GrafKategori.dosering,
            },
        ];
        expect(
            hentTittelOgTillattVerdier(
                GrafKategori.dosering,
                produksjonsdetaljerTilGrafdata(produksjonsdetaljer),
            ),
        ).toEqual(tittelOgDosering);
    });

    it("skal hente ticks y aksen hastighet", () => {
        const ticks = [0, 10, 20, 30, 40, 50, 60, 70, 80];
        expect(
            hentTicksYaxisHastighet(produksjonsdetaljerTilGrafdata(produksjonsdetaljer)),
        ).toEqual(ticks);
    });

    it("skal hente ticks y aksen dosering", () => {
        const ticksDosering = [0, 20, 40, 60];
        const ticksSprederbredde = [0, 20, 40, 60];
        expect(
            hentTicksYaxisDosering(
                produksjonsdetaljerTilGrafdata(produksjonsdetaljer),
                GrafType.dosering,
            ),
        ).toEqual(ticksDosering);
        expect(
            hentTicksYaxisDosering(
                produksjonsdetaljerTilGrafdata(produksjonsdetaljer),
                GrafType.sprederbredde,
            ),
        ).toEqual(ticksSprederbredde);
    });

    it("skal hente start og slutt", () => {
        const startOgSlutt = {
            startTid: dayjs("2023-01-28T04:17:05.000Z"),
            sluttTid: dayjs("2023-01-28T04:27:16.000Z"),
        };
        expect(
            JSON.stringify(
                hentStartOgSluttTid(produksjonsdetaljerTilGrafdata(produksjonsdetaljer)),
            ),
        ).toEqual(JSON.stringify(startOgSlutt));
    });
});

const produksjonsdetaljer: Produksjonsdetaljer[] = [
    {
        produksjonsdataRestRec: [0],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:17:05Z",
        hastighetKmHAvg: 48.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D1 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [1],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:18:06Z",
        hastighetKmHAvg: 61.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D2 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [2],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:19:07Z",
        hastighetKmHAvg: 49.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D3 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [3],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:20:08Z",
        hastighetKmHAvg: 40.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: false,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Fastsand,
            kategori: MaterialKategori.Sand,
            navn: MaterialOgAktivitetsNavn.Fastsand,
        },
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D3 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [4],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:21:09Z",
        hastighetKmHAvg: 40.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: false,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Fastsand,
            kategori: MaterialKategori.Sand,
            navn: MaterialOgAktivitetsNavn.Fastsand,
        },
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D4 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [5],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:22:10Z",
        hastighetKmHAvg: 50.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Tørrsalt,
            kategori: MaterialKategori.Salt,
            navn: MaterialOgAktivitetsNavn.Tørrsalt,
        },
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D5 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [6],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:26:15Z",
        hastighetKmHAvg: 50.0,
        erTørrstoffsprederPå: true,
        erVåtstoffsprederPå: false,
        erPlogNede: true,
        eksternReferanse: "644453",
        minutterSiden: 50,
        materiale: {
            type: MaterialType.Tørrsalt,
            kategori: MaterialKategori.Salt,
            navn: MaterialOgAktivitetsNavn.Tørrsalt,
        },
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D6 m1784",
        rodeId: ["zi_4283"],
    },
    {
        produksjonsdataRestRec: [7],
        kjøretøyId: "6883",
        datoLogget: "2023-01-28T04:27:16Z",
        hastighetKmHAvg: 52.0,
        erTørrstoffsprederPå: false,
        erVåtstoffsprederPå: false,
        erPlogNede: false,
        eksternReferanse: "644453",
        minutterSiden: 50,
        startLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        sluttLokasjon: {
            recordId: 2954550446,
            punkt: {
                type: "Point",
                coordinates: [17.372131, 68.743065],
            },
        },
        vegsystemreferansekortform: "FV7806 S3D7 m1784",
        rodeId: ["zi_4283"],
    },
];
