import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { capitalizeFirst } from "../../utils/tekst";
import dayjs from "dayjs";
import { MaterialKategori, MaterialType } from "../../kartSide/types/materiale";
import { Grafdata } from "./Grafer";
import { GrafType } from "../jotai/atoms";
import { lagArrayMedInkrementer } from "../../components/grafer/fellesGrafUtils";

export const produksjonsdetaljerTilGrafdata = (
    produksjonsdetaljer: Produksjonsdetaljer[],
): Grafdata[] => {
    let gjeldeneListe: Produksjonsdetaljer[] = [];
    return produksjonsdetaljer.reduce((accumulator: Grafdata[], produksjonsdetalje, index) => {
        const previousProduksjonsdetalje = produksjonsdetaljer[index - 1];
        if (index === 0) {
            gjeldeneListe.push(produksjonsdetalje);
        } else if (
            dayjs(produksjonsdetalje.datoLogget).diff(
                dayjs(previousProduksjonsdetalje.datoLogget),
                "minute",
            ) > 2 ||
            !erLikProduksjon(previousProduksjonsdetalje, produksjonsdetalje)
        ) {
            accumulator.push(mapProduksjonsdetaljerTilGrafdata(gjeldeneListe));
            gjeldeneListe = [];
            gjeldeneListe.push(produksjonsdetalje);
        } else {
            gjeldeneListe.push(produksjonsdetalje);
        }
        if (index === produksjonsdetaljer.length - 1 && gjeldeneListe.length > 0) {
            accumulator.push(mapProduksjonsdetaljerTilGrafdata(gjeldeneListe));
        }
        return accumulator;
    }, []);
};

const mapProduksjonsdetaljerTilGrafdata = (
    produksjonsdetaljer: Produksjonsdetaljer[],
): Grafdata => {
    return {
        color: hentLinjeFarge(produksjonsdetaljer),
        tittel: hentProduksjonsKategoriNavn(produksjonsdetaljer),
        data: produksjonsdetaljer,
        visible: true,
    };
};
export const erLikProduksjon = (
    produksjon1: Produksjonsdetaljer,
    produksjon2: Produksjonsdetaljer,
): boolean => {
    return (
        produksjon1.erTørrstoffsprederPå === produksjon2.erTørrstoffsprederPå &&
        produksjon1.erVåtstoffsprederPå === produksjon2.erVåtstoffsprederPå &&
        produksjon1.erPlogNede === produksjon2.erPlogNede &&
        produksjon1.erSideplogIBruk === produksjon2.erSideplogIBruk &&
        produksjon1.erHøvelskjærNede === produksjon2.erHøvelskjærNede &&
        produksjon1.erUnderliggendeSkjærNede === produksjon2.erUnderliggendeSkjærNede &&
        produksjon1.materiale?.navn === produksjon2.materiale?.navn
    );
};

export const hentProduksjonsKategoriNavn = (dataliste: Produksjonsdetaljer[]): string => {
    const data = dataliste[0];
    const erBrøyting = data.erPlogNede;
    const erSideplog = data.erSideplogIBruk;
    const erHøvling = data.erHøvelskjærNede || data.erUnderliggendeSkjærNede;
    const erStrøing = data.erTørrstoffsprederPå || data.erVåtstoffsprederPå;
    const erIngenProuksjon = !erBrøyting && !erSideplog && !erHøvling && !erStrøing;

    const brøyting = erBrøyting ? "Brøyting" : "";
    const sideplog = erSideplog ? "Sideplog" : "";
    const høvling = erHøvling ? "Høvling" : "";
    const strøing = erStrøing ? "Strøing med " + data.materiale?.navn : "";
    const ingenProduksjon = erIngenProuksjon ? "Ingen produksjon" : "";

    const produksjonsArray = [brøyting, sideplog, høvling, strøing].filter((label) => label !== "");
    const lengde = produksjonsArray.length;

    if (lengde === 0) {
        return ingenProduksjon;
    }
    const førsteDel = produksjonsArray.slice(0, -1).join(", ");
    const sisteDel = produksjonsArray[lengde - 1];
    const kombinertProduksjon = lengde === 1 ? sisteDel : [førsteDel, sisteDel].join(" og ");
    return capitalizeFirst(kombinertProduksjon);
};

export const hentLinjeFarge = (dataliste: Produksjonsdetaljer[]): string => {
    const data = dataliste[0];
    const erBrøytingEllerSideplog = data.erPlogNede || data.erSideplogIBruk;
    const erHøvling = data.erHøvelskjærNede || data.erUnderliggendeSkjærNede;
    const erStrøing = data.erTørrstoffsprederPå || data.erVåtstoffsprederPå;
    const erIngenProuksjon = !erBrøytingEllerSideplog && !erHøvling && !erStrøing;

    const erBrøyting = data.erPlogNede;
    const erSideplog = data.erSideplogIBruk;

    const erSalt = data.materiale?.kategori === MaterialKategori.Salt;
    const erSand = data.materiale?.kategori === MaterialKategori.Sand;

    if (erIngenProuksjon) {
        return "#444F55";
    } else if (erBrøytingEllerSideplog && !erHøvling && !erStrøing) {
        if (erBrøyting && !erSideplog) {
            return "#1D7721";
        } else if (!erBrøyting && erSideplog) {
            return "#077197";
        } else if (erBrøyting && erSideplog) {
            return "#2D6C79";
        }
    } else if (erBrøytingEllerSideplog && erHøvling && !erStrøing) {
        return "#0E0099";
    } else if (!erBrøytingEllerSideplog && erHøvling && !erStrøing) {
        return "#8420CB";
    } else if (!erBrøytingEllerSideplog && !erHøvling && erStrøing) {
        if (erSalt) {
            if (data.materiale?.type === MaterialType.BefuktetSalt) {
                return "#1D4289";
            } else if (data.materiale?.type === MaterialType.Saltløsning) {
                return "#5D3754";
            } else if (data.materiale?.type === MaterialType.BefuktetFinkornetSalt) {
                return "#9C386C";
            } else if (data.materiale?.type === MaterialType.Magnesiumklorid) {
                return "#B63434";
            } else if (data.materiale?.type === MaterialType.Tørrsalt) {
                return "#B63434";
            }
        } else if (erSand) {
            if (data.materiale?.type === MaterialType.Fastsand) {
                return "#1D4289";
            } else if (data.materiale?.type === MaterialType.Tørrsand) {
                return "#5D3754";
            } else if (data.materiale?.type === MaterialType.SandMedSaltInnblanding) {
                return "#B63434";
            }
        }
    } else if ((erBrøytingEllerSideplog || erHøvling) && erStrøing) {
        if (erSalt) {
            if (data.materiale?.type === MaterialType.BefuktetSalt) {
                return "#D3273E";
            } else if (data.materiale?.type === MaterialType.Saltløsning) {
                return "#8420CB";
            } else if (data.materiale?.type === MaterialType.BefuktetFinkornetSalt) {
                return "#077197";
            } else if (data.materiale?.type === MaterialType.Magnesiumklorid) {
                return "#B63434";
            } else if (data.materiale?.type === MaterialType.Tørrsalt) {
                return "#B63434";
            }
        } else if (erSand) {
            if (data.materiale?.type === MaterialType.Fastsand) {
                return "#D3273E";
            } else if (data.materiale?.type === MaterialType.Tørrsand) {
                return "#8420CB";
            } else if (data.materiale?.type === MaterialType.SandMedSaltInnblanding) {
                return "#077197";
            }
        }
    } else {
        return "#000000";
    }
    return "#000000";
};

export function formatAxisTid(tickItem: string) {
    return dayjs(tickItem).format("HH:mm");
}

export const concatVegsystemreferanse = (produksjonsdetaljer: Produksjonsdetaljer[]): string[] =>
    produksjonsdetaljer
        .reduce((accumulator: string[], produksjonsdetalje) => {
            const lastIndex = produksjonsdetalje.vegsystemreferansekortform?.lastIndexOf(" ");
            const vegsystemreferanseUtenMeter =
                produksjonsdetalje.vegsystemreferansekortform?.substring(0, lastIndex);
            if (!accumulator.find((item: any) => item === vegsystemreferanseUtenMeter)) {
                vegsystemreferanseUtenMeter && accumulator.push(vegsystemreferanseUtenMeter);
            }
            return accumulator;
        }, [])
        .sort();

export const hentUnikeGrafdata = (grafdataliste: Grafdata[]) =>
    grafdataliste.filter(
        (value, index, self) =>
            index === self.findIndex((grafdata) => grafdata.tittel === value.tittel),
    );

export const hentTicksYaxisHastighet = (grafdataliste: Grafdata[]) => {
    const maksMåltHastighet =
        Math.max(
            ...grafdataliste
                .flatMap((grafdata) => grafdata.data)
                .map((produksjonsdetalj) => produksjonsdetalj.hastighetKmHAvg),
        ) + 20;
    const possibleTicksYaxis = lagArrayMedInkrementer(20, 10);
    return possibleTicksYaxis.filter((tick) => tick <= maksMåltHastighet);
};

export const hentTicksYaxisDosering = (grafdataliste: Grafdata[], grafType: GrafType) => {
    const maksMåltDosering =
        Math.max(
            ...grafdataliste
                .flatMap((grafdata) => grafdata.data)
                .map((produksjonsdetalj) => {
                    if (grafType === GrafType.dosering) {
                        if (produksjonsdetalj.doseringtoerrstoffgm2) {
                            return produksjonsdetalj.doseringtoerrstoffgm2;
                        } else if (produksjonsdetalj.doseringvaatstoffmlm2) {
                            return produksjonsdetalj.doseringvaatstoffmlm2;
                        } else {
                            return 0;
                        }
                    } else if (grafType === GrafType.sprederbredde) {
                        if (produksjonsdetalj.sprederbreddetoerrstoffcm) {
                            return produksjonsdetalj.sprederbreddetoerrstoffcm;
                        } else if (produksjonsdetalj.sprederbreddevaatstoffcm) {
                            return produksjonsdetalj.sprederbreddevaatstoffcm;
                        } else {
                            return 0;
                        }
                    }
                    return 0;
                }),
        ) + 40;
    const erSand = grafdataliste[0].data.some(
        (produksjonsdetalj) => produksjonsdetalj.materiale?.kategori === MaterialKategori.Sand,
    );
    const maksVerdi = erSand ? Math.max(maksMåltDosering, 220) : Math.max(maksMåltDosering, 60);
    const possibleTicksYaxis = lagArrayMedInkrementer(40, 20);
    return possibleTicksYaxis.filter((tick) => tick <= maksVerdi);
};

export const hentStartOgSluttTid = (grafdataliste: Grafdata[]) => {
    const tidRange = grafdataliste
        .flatMap((grafdata) => grafdata.data)
        .map((produksjonsdetalj) => produksjonsdetalj.datoLogget)
        .sort();
    const sluttTid = dayjs(tidRange[grafdataliste.flatMap((grafdata) => grafdata.data).length - 1]);
    const startTid = dayjs(tidRange[0]);
    return { startTid: startTid, sluttTid: sluttTid };
};

export const hentDoseringsBenevningAxis = (grafdataliste: Grafdata[]) => {
    const proddetaljer = grafdataliste.map((grafdata) => grafdata.data).flat();
    const tørrstoff = proddetaljer.some(
        (produksjonsdetalj) => produksjonsdetalj.erTørrstoffsprederPå,
    )
        ? "g/m² "
        : "";
    const våtstoff = proddetaljer.some((produksjonsdetalj) => produksjonsdetalj.erVåtstoffsprederPå)
        ? "ml/m²"
        : "";
    return tørrstoff + våtstoff;
};

export const hentDoseringsBenevning = (proddetaljer: Produksjonsdetaljer) => {
    if (proddetaljer.erTørrstoffsprederPå) {
        return "g/m²";
    } else {
        return "ml/m²";
    }
};
