import { GrafKategori } from "../jotai/atoms";
import { Grafdata } from "./Grafer";
import { MaterialKategori } from "../../kartSide/types/materiale";
import { hentDoseringsBenevning } from "./grafUtils";
import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { MaterialOgAktivitetsNavn } from "../../api/context/ProduksjonsfilterAtoms";

export interface TrekkspillInnhold {
    tittel: string;
    verdi: number | undefined;
    grafKategori: GrafKategori;
}

export const hentTittelOgTillattVerdier = (aktivGraf: GrafKategori, unikeGrafdata: Grafdata[]) => {
    return aktivGraf === GrafKategori.hastighet
        ? hentTittelOgTillattHastighet(unikeGrafdata)
        : hentTittelOgTillattDosering(unikeGrafdata);
};

const hentTittelOgTillattHastighet = (grafdataliste: Grafdata[]): TrekkspillInnhold[] =>
    grafdataliste.reduce((trekkspillinnhold: TrekkspillInnhold[], grafdata) => {
        const tillattMakshastighet = hentTillattMakshastighet(grafdata.data);
        if (tillattMakshastighet !== undefined) {
            trekkspillinnhold.push({
                tittel: grafdata.tittel + " (" + tillattMakshastighet + " km/t)",
                verdi: tillattMakshastighet,
                grafKategori: GrafKategori.hastighet,
            });
        }
        return trekkspillinnhold;
    }, []);

const hentTittelOgTillattDosering = (grafdataliste: Grafdata[]): TrekkspillInnhold[] =>
    grafdataliste.reduce((trekkspillinnhold: TrekkspillInnhold[], grafdata) => {
        const tillattDosering = hentTillattDosering(grafdata.data);
        const benevning = hentDoseringsBenevning(grafdata.data[0]);
        const minEllerMaks =
            grafdata.data[0].materiale?.kategori === MaterialKategori.Salt ? "maks " : "min ";
        if (tillattDosering !== undefined) {
            trekkspillinnhold.push({
                tittel:
                    grafdata.tittel + " (" + minEllerMaks + tillattDosering + " " + benevning + ")",
                verdi: tillattDosering,
                grafKategori: GrafKategori.dosering,
            });
        }
        return trekkspillinnhold;
    }, []);

export const hentTillattMakshastighet = (dataliste: Produksjonsdetaljer[]): number | undefined => {
    const data = dataliste[0];
    const erBrøyting = data.erPlogNede || data.erSideplogIBruk;
    const erHøvling = data.erHøvelskjærNede || data.erUnderliggendeSkjærNede;
    const erfastsand = data.materiale?.navn === MaterialOgAktivitetsNavn.Fastsand;
    const ersandØvrig =
        data.materiale?.navn === MaterialOgAktivitetsNavn.Tørrsand ||
        data.materiale?.navn === MaterialOgAktivitetsNavn.SandMedSaltInnblanding;
    const erSaltløsning = data.materiale?.navn === MaterialOgAktivitetsNavn.Saltløsning;
    const erSaltslurry = data.materiale?.navn === MaterialOgAktivitetsNavn.BefuktetFinkornetSalt;
    const erSaltØvrig =
        data.materiale?.navn === MaterialOgAktivitetsNavn.Tørrsalt ||
        data.materiale?.navn === MaterialOgAktivitetsNavn.BefuktetSalt ||
        data.materiale?.navn === MaterialOgAktivitetsNavn.Saltløsning ||
        data.materiale?.navn === MaterialOgAktivitetsNavn.Magnesiumklorid;

    const brøytingMaks = erBrøyting ? 40 : undefined;
    const høvlingMaks = erHøvling ? 40 : undefined;
    const fastsandMaks = erfastsand ? 25 : undefined;
    const sandØvrigMaks = ersandØvrig ? 30 : undefined;
    const saltløsningMaks = erSaltløsning ? 50 : undefined;
    const saltslurryMaks = erSaltslurry ? 35 : undefined;
    const saltØvrigMaks = erSaltØvrig ? 30 : undefined;

    const tillattHastighetsListe: number[] = [
        brøytingMaks,
        høvlingMaks,
        fastsandMaks,
        sandØvrigMaks,
        saltløsningMaks,
        saltslurryMaks,
        saltØvrigMaks,
    ].filter((label) => label !== undefined) as number[];

    return tillattHastighetsListe.length > 0 ? Math.max(...tillattHastighetsListe) : undefined;
};

export const hentTillattDosering = (dataliste: Produksjonsdetaljer[]): number | undefined => {
    const data = dataliste[0];
    const erfastsand = data.materiale?.navn === MaterialOgAktivitetsNavn.Fastsand;
    const ersandØvrig =
        data.materiale?.navn === MaterialOgAktivitetsNavn.Tørrsand ||
        data.materiale?.navn === MaterialOgAktivitetsNavn.SandMedSaltInnblanding;
    const erSalt = data.materiale?.kategori === MaterialKategori.Salt;

    const fastsandMin = erfastsand ? 150 : undefined;
    const sandØvrigMin = ersandØvrig ? 180 : undefined;
    const saltMaks = erSalt ? 40 : undefined;

    const tillattDoseringsListe: number[] = [fastsandMin, sandØvrigMin, saltMaks].filter(
        (label) => label !== undefined,
    ) as number[];
    return tillattDoseringsListe.length > 0 ? Math.max(...tillattDoseringsListe) : undefined;
};
