import { atom } from "jotai/index";
import { Grafdata } from "../grafer/Grafer";

export enum GrafKategori {
    hastighet = "hastighet",
    dosering = "dosering",
    friksjon = "friksjon",
    temperatur = "temperatur",
}

export enum GrafType {
    hastighet = "hastighet",
    dosering = "dosering",
    sprederbredde = "sprederbredde",
    friksjon = "friksjon",
    temperatur = "temperatur",
}

export const aktivHoverRecordAtom = atom<number[] | undefined>(undefined);

export const aktivGrafKategoriAtom = atom(
    (get) => {
        const grafType = get(aktivGrafTypeAtom);
        switch (grafType) {
            case GrafType.hastighet:
                return GrafKategori.hastighet;
            case GrafType.dosering:
            case GrafType.sprederbredde:
                return GrafKategori.dosering;
            case GrafType.friksjon:
                return GrafKategori.friksjon;
            case GrafType.temperatur:
                return GrafKategori.temperatur;
        }
    },
    (get, set, update: GrafKategori) => {
        const aktivGrafType = () => {
            switch (update) {
                case GrafKategori.hastighet:
                    return GrafType.hastighet;
                case GrafKategori.dosering:
                    return GrafType.dosering;
                case GrafKategori.friksjon:
                    return GrafType.friksjon;
                case GrafKategori.temperatur:
                    return GrafType.temperatur;
            }
        };
        set(aktivGrafTypeAtom, aktivGrafType());
    },
);

const aktivGrafType = atom<GrafType>(GrafType.hastighet);

export const aktivGrafTypeAtom = atom(
    (get) => get(aktivGrafType),
    (get, set, update: GrafType) => {
        set(aktivGrafType, update);
        set(reflinjeIKartAtom, undefined);
    },
);

export const grafdataAtom = atom<Grafdata[]>([]);
export const grafdataDoseringAtom = atom<Grafdata[]>((get) => {
    const grafdata = get(grafdataAtom);
    const doseringGrafdata = grafdata.filter((g) =>
        g.data.some(
            (prod) =>
                (prod.doseringvaatstoffmlm2 !== undefined && prod.doseringvaatstoffmlm2 !== 0) ||
                (prod.doseringtoerrstoffgm2 !== undefined && prod.doseringtoerrstoffgm2 !== 0),
        ),
    );
    return doseringGrafdata ?? [];
});

export const reflinjeIKartAtom = atom<number | undefined>(undefined);
