"use client";
import styled from "styled-components";
import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { concatVegsystemreferanse } from "../grafer/grafUtils";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { useState } from "react";
import { hentGjennomsnittsverdierForProduksjonsdetaljer } from "./metadataUtils";
import { KnappSekundær } from "../../components/fellesKomponenter/knapper/KnappSekundær";
import { AnimatePresence } from "framer-motion";
import { VelgNyØkt } from "./VelgNyØkt";
import { Snittverdier } from "./Snittverdier";
import { Vegsystemreferanser } from "./Vegsystemreferanser";
import { Øktopplysninger } from "./Øktopplysninger";
import { breakpointNettbrett } from "../../utils/constants";

interface MetadataProps {
    produksjonsdetaljer: Produksjonsdetaljer[];
}

export const Metadata = ({ produksjonsdetaljer }: MetadataProps) => {
    const [seVelgØkt, setSeVelgØkt] = useState<boolean>(produksjonsdetaljer.length === 0);
    const [seAlleVegreferanser, setSeAlleVegreferanser] = useState<boolean>(false);
    const [seSnittverdier, setSeSnittverdier] = useState<boolean>(false);
    const vegsystemrefs = concatVegsystemreferanse(produksjonsdetaljer);
    const metadataSnittverdier =
        hentGjennomsnittsverdierForProduksjonsdetaljer(produksjonsdetaljer);

    return (
        <MetadataContainer>
            <AnimatePresence mode={"wait"}>
                {seVelgØkt ? (
                    <VelgNyØkt
                        setSeVelgØkt={setSeVelgØkt}
                        seVelgØkt={seVelgØkt}
                        produksjonsdetaljer={produksjonsdetaljer}
                    />
                ) : (
                    <>
                        <KnappWrapper>
                            <KnappSekundær size={"Small"} onClick={() => setSeVelgØkt(true)}>
                                <NyKnappInnhold>Velg ny økt</NyKnappInnhold>
                            </KnappSekundær>
                        </KnappWrapper>
                        <Øktopplysninger produksjonsdetaljer={produksjonsdetaljer} />
                        <Snittverdier
                            metadataSnittverdier={metadataSnittverdier}
                            seSnittverdier={seSnittverdier}
                            setSeSnittverdier={setSeSnittverdier}
                        />
                        <Vegsystemreferanser
                            seAlleVegreferanser={seAlleVegreferanser}
                            setSeAlleVegreferanser={setSeAlleVegreferanser}
                            vegsystemrefs={vegsystemrefs}
                        />
                    </>
                )}
            </AnimatePresence>
        </MetadataContainer>
    );
};

export const KnappWrapper = styled.div`
    display: flex;
    flex-direction: row;
    justify-content: flex-end;
`;

const NyKnappInnhold = styled.span`
    display: flex;
    align-items: center;

    &:before {
        content: "";
        flex-shrink: 0;
        background: url("/ikon/magnifying-glass.svg") no-repeat 50%;
        background-color: var(--white);
        height: 24px;
        width: 24px;
        background-size: 90%;
        margin-right: 8px;
    }
`;

export const Kategori = styled(Tekst).attrs(() => ({
    nomargin: true,
    størrelse: "M",
    $bold: true,
    as: "span",
}))``;

export const KategoriTabell = styled(Kategori)`
    width: 100px;
`;

export const Opplysning = styled(Tekst).attrs(() => ({
    nomargin: true,
    størrelse: "M",
    as: "span",
}))``;

const MetadataContainer = styled.div`
    display: flex;
    flex-direction: column;
    width: 30%;
    background-color: var(--gray-light);
    padding: 20px;
    gap: 10px;
    height: 360px;
    overflow: auto;

    @media (max-width: ${breakpointNettbrett}) {
        width: 70%;
    }
`;

export const Container = styled.div`
    display: flex;
    flex-direction: column;
    gap: 4px;
`;

export const VisSkjulKnapp = styled.button`
    display: flex;
    align-items: center;
    border: 0;
    width: fit-content;
    justify-content: space-between;
    background-color: transparent;
    padding: 0 2px;
    text-decoration: underline;

    &:hover {
        cursor: pointer;
    }
`;
