import { Container, Kategori, Opplysning, VisSkjulKnapp } from "./Metadata";
import styled from "styled-components";
import { Tekst } from "../../components/fellesKomponenter/typografi/Tekst";
import { MetadataGjennomsnittsType } from "./metadataUtils";
import { ØktdetaljerLoggEvent, loggEventMedTabellnavn, TabellNavn } from "../../utils/loggFrontend";
interface SnittverdierProps {
    metadataSnittverdier: MetadataGjennomsnittsType[];
    seSnittverdier: boolean;
    setSeSnittverdier: (seSnittverdier: boolean) => void;
}

export const Snittverdier = ({
    metadataSnittverdier,
    seSnittverdier,
    setSeSnittverdier,
}: SnittverdierProps) => {
    const håndterVisSnittverdier = (seSnittverdier: boolean) => {
        setSeSnittverdier(seSnittverdier);
        loggEventMedTabellnavn(TabellNavn.øktdetaljer, ØktdetaljerLoggEvent.seGjennomsnitt);
    };
    return (
        <Container>
            <Kategori>Gjennomsnittverdier for økt:</Kategori>
            {seSnittverdier ? (
                <>
                    {metadataSnittverdier.map((snittverdi, index) => (
                        <div key={index}>
                            <Snittverdi $bold={true}>{snittverdi.tittel}</Snittverdi>
                            <Snittverdi>
                                Gjennomsnittshastighet: {snittverdi.snitthastighetAvg} km/t
                            </Snittverdi>
                            {snittverdi.snittDoseringTørrstoff && (
                                <Snittverdi>
                                    Dosering tørrstoff: {snittverdi.snittDoseringTørrstoff} g/m2
                                </Snittverdi>
                            )}
                            {snittverdi.snittDoseringVåtstoff && (
                                <Snittverdi>
                                    Dosering våttstoff: {snittverdi.snittDoseringVåtstoff} l/m2
                                </Snittverdi>
                            )}
                            {snittverdi.snittSprederbreddeTørrstoff && (
                                <Snittverdi>
                                    Sprederbredde tørrstoff:{" "}
                                    {snittverdi.snittSprederbreddeTørrstoff} cm
                                </Snittverdi>
                            )}
                            {snittverdi.snittSprederbreddeVåttstoff && (
                                <Snittverdi>
                                    Sprederbredde våttstoff:{" "}
                                    {snittverdi.snittSprederbreddeVåttstoff} cm
                                </Snittverdi>
                            )}
                        </div>
                    ))}

                    <VisSkjulKnapp onClick={() => setSeSnittverdier(false)}>
                        <Opplysning>Skjul</Opplysning>
                    </VisSkjulKnapp>
                </>
            ) : (
                <VisSkjulKnapp onClick={() => håndterVisSnittverdier(true)}>
                    <Opplysning>Vis alle</Opplysning>
                </VisSkjulKnapp>
            )}
        </Container>
    );
};

const Snittverdi = styled(Tekst).attrs(() => ({
    $nomargin: true,
    $størrelse: "M",
}))``;
