import { Produksjonsdetaljer } from "../../kartSide/types/produksjonsdetaljer";
import { hentProduksjonsKategoriNavn } from "../grafer/grafUtils";

export interface MetadataGjennomsnittsType {
    tittel: string;
    snitthastighetAvg: number;
    snittDoseringVåtstoff?: number;
    snittDoseringTørrstoff?: number;
    snittSprederbreddeVåttstoff?: number;
    snittSprederbreddeTørrstoff?: number;
    antallMålinger: number;
}

export const hentGjennomsnittsverdierForProduksjonsdetaljer = (
    produksjonsdetaljer: Produksjonsdetaljer[],
) => {
    if (produksjonsdetaljer.length === 0) {
        return [];
    }
    const produksjonsdetaljerMedTittel = hentProduksjonsdetaljerMedTittel(produksjonsdetaljer);
    const grupperteProduksjonsdetaljer = grupperProduksjonsdetaljer(produksjonsdetaljerMedTittel);
    return hentMetadataGjennomsnitt(grupperteProduksjonsdetaljer);
};

interface ProduksjonsdetaljMedTittel extends Produksjonsdetaljer {
    tittel: string;
}

const hentProduksjonsdetaljerMedTittel = (produksjonsdetaljer: Produksjonsdetaljer[]) =>
    produksjonsdetaljer.map((produksjonsdetalj) => ({
        ...produksjonsdetalj,
        tittel: hentProduksjonsKategoriNavn([produksjonsdetalj]),
    }));

const grupperProduksjonsdetaljer = (produksjonsdetaljerMedTittel: ProduksjonsdetaljMedTittel[]) =>
    produksjonsdetaljerMedTittel.reduce((gruppering: ProduksjonsdetaljMedTittel[][], current) => {
        const finnesIGruppering = gruppering.find((item) => item[0].tittel === current.tittel);
        if (!finnesIGruppering) {
            gruppering.push([current]);
        } else if (finnesIGruppering) {
            gruppering.find((item) => item[0].tittel === current.tittel)?.push(current);
        }
        return gruppering;
    }, []);

const hentMetadataGjennomsnitt = (
    grupperteProduksjonsdetaljer: ProduksjonsdetaljMedTittel[][],
): MetadataGjennomsnittsType[] =>
    grupperteProduksjonsdetaljer.map((proddetaljMedTittel) => {
        const harDosering = proddetaljMedTittel.some(
            (detalj) => detalj.erTørrstoffsprederPå || detalj.erVåtstoffsprederPå,
        );

        const snitthastighetAvg = hentGjennomsnittsverdi(
            proddetaljMedTittel.map((detalj) => detalj.hastighetKmHAvg),
        );

        const doseringTørrstoff: number[] = proddetaljMedTittel.reduce((acc: number[], detalj) => {
            if (detalj.doseringtoerrstoffgm2 !== undefined) {
                acc.push(detalj.doseringtoerrstoffgm2);
            }
            return acc;
        }, []);

        const doseringVåttstoff: number[] = proddetaljMedTittel.reduce((acc: number[], detalj) => {
            if (detalj.doseringvaatstoffmlm2 !== undefined) {
                acc.push(detalj.doseringvaatstoffmlm2);
            }
            return acc;
        }, []);

        const sprederbreddeTørrstoff: number[] = proddetaljMedTittel.reduce(
            (acc: number[], detalj) => {
                if (detalj.sprederbreddetoerrstoffcm !== undefined) {
                    acc.push(detalj.sprederbreddetoerrstoffcm);
                }
                return acc;
            },
            [],
        );

        const sprederbreddeVåttstoff: number[] = proddetaljMedTittel.reduce(
            (acc: number[], detalj) => {
                if (detalj.sprederbreddevaatstoffcm !== undefined) {
                    acc.push(detalj.sprederbreddevaatstoffcm);
                }
                return acc;
            },
            [],
        );

        const snittDoseringTørrstoff = harDosering
            ? hentGjennomsnittsverdi(doseringTørrstoff)
            : undefined;
        const snittDoseringVåttstoff = harDosering
            ? hentGjennomsnittsverdi(doseringVåttstoff)
            : undefined;

        const snittSprederbreddeTørrstoff = harDosering
            ? hentGjennomsnittsverdi(sprederbreddeTørrstoff)
            : undefined;
        const snittSprederbreddeVåttstoff = harDosering
            ? hentGjennomsnittsverdi(sprederbreddeVåttstoff)
            : undefined;

        return {
            tittel: proddetaljMedTittel[0].tittel,
            snitthastighetAvg: snitthastighetAvg,
            snittDoseringVåtstoff: snittDoseringVåttstoff,
            snittDoseringTørrstoff: snittDoseringTørrstoff,
            snittSprederbreddeVåttstoff: snittSprederbreddeVåttstoff,
            snittSprederbreddeTørrstoff: snittSprederbreddeTørrstoff,
            antallMålinger: proddetaljMedTittel.length,
        };
    });

export const hentGjennomsnittsverdi = (nummerliste: number[]) => {
    const snitt = nummerliste.reduce((a, b) => a + b, 0) / nummerliste.length;
    return Math.round(snitt);
};
